@charset "UTF-8";
footer {clear:both;margin:10px 0 0 0;padding:10px 0;border-top:1px solid $mid-gray }
footer .footerpage {clear:both;margin:0px 0px;padding:26px 0px;}


// home
.subfooter, .subfooterright {padding:10px 20px 20px 20px;border-left:1px solid $light-gray;margin:30px 0;font-size:0.8em}
.subfooter h3, .subfooterright h3 {font-size:0.7em;text-transform:uppercase;letter-spacing:4px;color:#999;margin:0;padding:0 0 20px 0}
.subfooterright {border-right:1px solid $light-gray;}


/*sub footer page*/
.subfooter-page {margin:20px 0 0 0;padding:25px 0 0 0;}
.subfooter-page h5 {font-size:0.7em;text-transform:uppercase;letter-spacing: 3px;color:$steel;margin-bottom:0;border-top:1px solid $mid-gray;padding:20px 0 ;min-height:20px;}
.subfooter-page ul {font-size:0.8em;}