<div>
  <div class="row relation-row" data-dojo-attach-point="broaderContainerNode">
    <div class="large-11 columns">
      <p>Broader</p>
    </div>
    <div class="large-1 columns">
      <a href="#" class="button tiny" data-dojo-attach-event="onClick: _addBroader" title="Add broader concept"><i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row large-12 columns"
       data-dojo-attach-point="broaderGridNode">
  </div>

  <div class="row relation-row" data-dojo-attach-point="narrowerContainerNode">
    <div class="large-11 columns">
      <p>Narrower</p>
    </div>
    <div class="large-1 columns">
      <a href="#" class="button tiny" data-dojo-attach-event="onClick: _addNarrower" title="Add narrower concept"><i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row large-12 columns"
       data-dojo-attach-point="narrowerGridNode">
  </div>

  <div class="row relation-row" data-dojo-attach-point="relatedContainerNode">
    <div class="large-11 columns">
      <p>Related</p>
    </div>
    <div class="large-1 columns">
      <a href="#" class="button tiny" data-dojo-attach-event="onClick: _addRelated" title="Add related concept"><i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row large-12 columns"
       data-dojo-attach-point="relatedGridNode">
  </div>

  <div class="row relation-row" data-dojo-attach-point="membersContainerNode">
    <div class="large-11 columns">
      <p>Members</p>
    </div>
    <div class="large-1 columns">
      <a href="#" class="button tiny" data-dojo-attach-event="onClick: _addMembers" title="Add members"><i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row large-12 columns"
       data-dojo-attach-point="membersGridNode">
  </div>

  <div class="row relation-row" data-dojo-attach-point="memberOfContainerNode">
    <div class="large-11 columns">
      <p>Member of</p>
    </div>
    <div class="large-1 columns">
      <a href="#" class="button tiny" data-dojo-attach-event="onClick: _addMemberOf" title="Add member of concept"><i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row large-12 columns"
       data-dojo-attach-point="memberOfGridNode">
  </div>

  <div class="row relation-row" data-dojo-attach-point="subordinateArraysContainerNode">
    <div class="large-11 columns">
      <p>Subordinate arrays</p>
    </div>
    <div class="large-1 columns">
      <a href="#" class="button tiny" data-dojo-attach-event="onClick: _addSubordinateArray" title="Add subordinate array"><i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row large-12 columns"
       data-dojo-attach-point="subordinateGridNode">
  </div>

  <div class="row relation-row" data-dojo-attach-point="superordinatesCollContainerNode">
    <div class="large-11 columns">
      <p>Superordinates</p>
    </div>
    <div class="large-1 columns">
      <a href="#" class="button tiny" data-dojo-attach-event="onClick: _addSuperordinates" title="Add superordinates"><i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row large-12 columns"
       data-dojo-attach-point="superordinatesCollGridNode">
  </div>

  <div class="row" data-dojo-attach-point="inferConceptRelationsContainerNode" style="margin-top: 10px">
    <div class="placeholder-container radio-container">
      <label style="width: 80%">Should member concepts of this collection be seen as narrower concept of a superordinate of the collection</label>
      <input type="radio" name="inferConceptRelations" data-dojo-attach-point="inferConceptRelationsYesNode" /> Yes
      <input type="radio" name="inferConceptRelations" data-dojo-attach-point="inferConceptRelationsNoNode" /> No
    </div>
  </div>

</div>