<div>
  <div class="row relation-row" style="margin-bottom: 5px;">
    <div class="large-offset-10 large-2 columns">
      <a style="float: right;" href="#" class="button tiny" data-dojo-attach-event="onClick: _addNote" title="Add note">Add Note&nbsp;&nbsp;<i class="fa fa-plus"></i></a>
    </div>
  </div>
  <div class="row">
    <div class="large-12 columns" style="padding: 0;">
      <div data-dojo-attach-point="noteGridNode" style="max-height: 350px;"></div>
    </div>
  </div>
</div>