HERITAGETYPESDATA = [
    {
        "broader": [945],
        "id": 1467,
        "labels": [{"label": "aachten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een aacht is een ondergrondse schuilplaats uitgegraven in de leembodem (soms ook mergel) die gebruikt werd als toevluchtsoord tijdens de Tachtigjarige oorlog (1568-1648).  Ze stonden bijna altijd in verbinding met nabijgelegen hoeven, vierkantshoeven en soms ook kerken. Sommige aachten werden ook nog na de 17de eeuw gebruikt. Het fenomeen is vooral bekend in Belgisch en Nederlands Limburg.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1467",
    },
    {
        "broader": [889],
        "id": 934,
        "labels": [
            {"label": "aalmoezenierswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/934",
    },
    {
        "broader": [151],
        "id": 1,
        "labels": [{"label": "aalpompen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een aalpomp is een pomp waarmee men de vloeibare mest uit de aalput van de stal haalt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische gebouwen'.",
                "type": "historyNote",
            },
        ],
        "related": [499, 642],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1",
    },
    {
        "broader": [923],
        "id": 2,
        "labels": [
            {"label": "aanlegplaatsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "steigers", "language": "nl-BE", "type": "altLabel"},
            {"label": "kades", "language": "nl-BE", "type": "altLabel"},
            {"label": "aarden", "language": "nl-BE", "type": "altLabel"},
            {"label": "amers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1489, 1931],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een aanlegplaats is een constructie voor het aanleggen van vaartuigen, vaak in de vorm van een steiger of kade.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2",
    },
    {
        "broader": [],
        "id": 2149,
        "labels": [
            {"label": "aanplanten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "plantages", "language": "nl-BE", "type": "altLabel"},
            {"label": "planterijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1840],
        "narrower": [2151, 2152],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een aanplant is een productief bodemgebruik waarbij een monocultuur van gelijkjarige opgaande bomen vlaksgewijs wordt aangeplant in een regelmatig plantverband met als doel het hout voor productiedoeleinden te oogsten (bijvoorbeeld sparren, populieren, wilgen \u2026). Aanplanten kunnen ook in bossen worden ingeplant.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "10/09/2015: PT aangepast van plantages naar aanplanten",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2149",
    },
    {
        "broader": [328],
        "id": 3,
        "labels": [
            {"label": "aardappelkelders", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een aardappelkelder is een kelder om aardappelen en andere wortel- en knolgewassen op te slaan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische gebouwen'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/3",
    },
    {
        "broader": [2113],
        "id": 2115,
        "labels": [
            {"label": "abdijdomeinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een abdijdomein is een domein waarvan de eigendommen in bezit zijn van een abdij. Dit bestaat (meestal) uit een abdij met kerk en (nuts)tuinen, tiendenschuur, molen, hoeve(s), omliggende landerijen,\u2026",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2115",
    },
    {
        "broader": [359],
        "id": 4,
        "labels": [{"label": "abdijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een abdij is een klooster voor mannelijke of vrouwelijke gemeenschappen van religieuze orden, met respectievelijk een abt of een abdis aan het hoofd.",
                "type": "scopeNote",
            }
        ],
        "related": [5, 6, 243, 354, 358, 1786, 1788, 1789, 1790],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/4",
    },
    {
        "broader": [190],
        "id": 5,
        "labels": [{"label": "abdijhoeven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1419],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een abdijhoeve is een hoeve die door een abdij of priorij zelf wordt uitgebaat. Deze zijn dus niet in pacht door derden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'gekoppeld aan gidsterm "hoeven naar functie" op 07/10/2011 (LM)',
                "type": "historyNote",
            },
        ],
        "related": [4, 354],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/5",
    },
    {
        "broader": [230],
        "id": 6,
        "labels": [{"label": "abdijkerken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kerken van abdijen.",
                "type": "scopeNote",
            }
        ],
        "related": [242, 4],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/6",
    },
    {
        "broader": [63],
        "id": 1483,
        "labels": [
            {"label": "acetyleenfabriekjes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een acetyleenfabriekje is een klein bouwsel waarin acetyleengas werd geproduceerd en via buisleidingen naar het interieur van woningen of kastelen kon worden geleid waar speciaal toegeruste gaslampen werden opgesteld. Vermits het in die periode (begin 20ste eeuw) innovatief en vrij duur was, is het bekend bij de woningen van meer gegoede burgerij en adel. Dergelijke bouwsels werden doorgaans ook afzonderlijk gebouwd omwille van veiligheidsaspecten (o.m. ontbranding).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1483",
    },
    {
        "broader": [63],
        "id": 7,
        "labels": [{"label": "achterhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een achterhuis is een aanbouw achter een woonhuis die enkel via dit woonhuis toegankelijk is.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/7",
    },
    {
        "broader": [1966],
        "id": 2126,
        "labels": [
            {"label": "actieve kreken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een actieve kreek is een kreek die nog steeds onder getijdeninvloed staat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2126",
    },
    {
        "broader": [1967],
        "id": 2128,
        "labels": [
            {"label": "actieve meanders", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een actieve meander is een meander in een bestaande natuurlijke waterloop waarin de processen van erosie en afzetting nog plaatsvinden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2128",
    },
    {
        "broader": [323],
        "id": 8,
        "labels": [
            {"label": "administratiegebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een administratiegebouw is een gebouw waarin administraties van openbare diensten gevestigd zijn.",
                "type": "scopeNote",
            }
        ],
        "related": [158, 215],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/8",
    },
    {
        "broader": [1967],
        "id": 2129,
        "labels": [
            {"label": "afgesneden meanders", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een afgesneden meander is een meander die niet meer watervoerend is en die afgesneden is van de huidige natuurlijke waterloop. De afsnijding kan natuurlijk tot stand gekomen zijn of door menselijk ingrijpen aangestuurd. De landschappelijke en hydrologische omstandigheden ten tijde van de afsnijding waren vergelijkbaar met de huidige.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2129",
    },
    {
        "broader": [237],
        "id": 893,
        "labels": [{"label": "afsluitingen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [136, 185, 186, 317, 1514, 1515, 1516, 1519],
        "notes": [],
        "related": [334, 350],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/893",
    },
    {
        "broader": [179],
        "id": 1682,
        "labels": [
            {"label": "afsluitingshagen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1681],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een afsluitingshaag is een geschoren haag als afsluiting van een erf, tuin, park, moestuin, al dan niet met vlechtwerk of in kruismotief.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1682",
    },
    {
        "broader": [187],
        "id": 9,
        "labels": [{"label": "afspanningen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een afspanning is een herberg met huurhouderij langsheen de weg, waar men zijn reis onderbreekt en paarden en rijtuigen kan stallen en/of huren.",
                "type": "scopeNote",
            }
        ],
        "related": [198, 187],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/9",
    },
    {
        "broader": [237],
        "id": 290,
        "labels": [
            {"label": "afstandsmarkeringen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [705, 962],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Palen of stenen die op welbepaalde afstanden van elkaar langs de weg zijn geplaatst en op die manier een afstand aangeven.",
                "type": "scopeNote",
            }
        ],
        "related": [509],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/290",
    },
    {
        "broader": [1096],
        "id": 1097,
        "labels": [
            {"label": "afvalkuilen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "afvalputten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een afvalkuil is een kuil in de grond gebruikt om afval in te deponeren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1097",
    },
    {
        "broader": [1072],
        "id": 1073,
        "labels": [
            {"label": "afvallagen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "dumplagen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een afvallaag is een antropogene laag die is ontstaan door depositie of dumpen van afval.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1073",
    },
    {
        "broader": [1082],
        "id": 1083,
        "labels": [
            {"label": "afwateringsgreppels", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een afwateringsgreppel is een greppel bedoeld om waterafvoer of drainage te voorzien.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1083",
    },
    {
        "broader": [932],
        "id": 1626,
        "labels": [{"label": "afweerbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1605],
        "narrower": [1629],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een afweerboom is een boom die dient om iets dreigends of onaangenaams af te weren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1626",
    },
    {
        "id": 2133,
        "labels": [{"label": "afzettingen", "language": "nl-BE", "type": "prefLabel"}],
        "member_of": [1851],
        "members": [2134, 2135, 2136, 2137],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2133",
    },
    {
        "broader": [1307],
        "id": 1308,
        "labels": [
            {"label": "agrarische complexen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [438, 641, 1310, 1311, 261, 190],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1308",
    },
    {
        "broader": [1307],
        "id": 151,
        "labels": [
            {"label": "agrarische gebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1, 35, 81, 286, 422, 529, 642, 1313, 1314, 1482],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Term gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische gebouwen' en BT gewijzigd van 'economische gebouwen en structuren' naar 'agrarische gebouwen en complexen'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/151",
    },
    {
        "broader": [1271],
        "id": 1307,
        "labels": [
            {
                "label": "agrarische gebouwen en complexen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004895"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1308, 151],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1307",
    },
    {
        "broader": [],
        "id": 2103,
        "labels": [
            {
                "label": "agrarische landschappen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": ["http://vocab.getty.edu/aat/300008631"],
        },
        "member_of": [1847],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een agrarisch landschap is een landschap waarin akkers, weilanden en/of boomgaarden domineren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2103",
    },
    {
        "broader": [1053],
        "id": 2112,
        "labels": [
            {
                "label": "agrarische nederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een agrarische nederzetting is een economische nederzetting, aangelegd in functie van de ontginning van landbouwgronden. Een agrarische nederzetting is afhankelijk van de omliggende gronden en bestaat voornamelijk uit hoeves die nog steeds een agrarisch gebruik kennen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: term toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2112",
    },
    {
        "broader": [],
        "id": 1905,
        "labels": [{"label": "akkerlanden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": ["http://vocab.getty.edu/aat/300132443"],
        },
        "member_of": [1840],
        "narrower": [1906, 1907, 1908, 1909],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een akkerland is een productief bodemgebruik waarbij \xe9\xe9n- of meerjarige gewassen worden geteeld door middel van zaaien of planten (vaak in wisselteelt).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Objectencatalogus NGI: <a href="http://www.ngi.be/gdes/">http://www.ngi.be/gdes/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1905",
    },
    {
        "broader": [],
        "id": 2049,
        "labels": [{"label": "albeluvisols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1856],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een albeluvisol is een bodem met een aanrijkingshorizont van klei, gevormd in zandleem of leem, gekenmerkt door een zeer onregelmatige en vaak golvende grens tussen de bleke uitlogingshorizont en donkere aanrijkingshorizont.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2049",
    },
    {
        "broader": [307],
        "id": 884,
        "labels": [
            {
                "label": "algemene elementen van nijverheidsgebouwen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [137, 233, 258, 275, 511],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Term gewijzigd van 'ambachtelijke en industri\xeble infrastructuur' naar 'algemene elementen van nijverheidsgebouwen'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/884",
    },
    {
        "broader": [],
        "id": 2050,
        "labels": [{"label": "alisols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1856],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een alisol is een bodem met een aanrijkingshorizont van klei, gevormd in zandleem of leem, gekenmerkt door een zure samenstelling.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2050",
    },
    {
        "broader": [1992],
        "id": 1993,
        "labels": [
            {"label": "alluviale kommen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een alluviale kom is een depressie in de alluviale vlakte achter een oeverwal  of kreekrug. In de kom heerst(e) een rustig sedimentatiemilieu, waarin  fijn bodemmateriaal (klei) wordt/werd afgezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1977],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1993",
    },
    {
        "broader": [1982],
        "id": 1989,
        "labels": [
            {"label": "alluviale vlakten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "riviervlakten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1990],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een alluviale vlakte is een vlakte die is ontstaan door erosie- en/of sedimentatieprocessen van een niet-getijdengebonden rivier, waarbij oorspronkelijk losse bodemmaterialen als alluvium zijn afgezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "2/10/2014: toegevoegd bij integratie landschappelijke elementen",
                "type": "historyNote",
            },
        ],
        "related": [1977],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1989",
    },
    {
        "broader": [1584],
        "id": 1585,
        "labels": [{"label": "alpentuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een alpentuin is een rotstuin met natuurlijke of kunstmatige rotsen voor de teelt van alpiene planten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1585",
    },
    {
        "broader": [1779],
        "id": 1784,
        "labels": [{"label": "altaren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300003725"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een altaar is een tafel of verhoogde plaats bestemd om godsdienstige plechtigheden te verrichten en voor het opdragen van het misoffer.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1784",
    },
    {
        "broader": [1393],
        "id": 1394,
        "labels": [
            {
                "label": "ambachtelijke objecten",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Hieronder kunnen gerekend worden: metaalslakken, gietvormen, weefgetouwen, spinklosjes, weefgewichten, enz\u2026",
                "type": "scopeNote",
            }
        ],
        "related": [1378],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1394",
    },
    {
        "broader": [323],
        "id": 11,
        "labels": [{"label": "ambassades", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ambassade is het hoofdkantoor van een ambassadeur. Ambassadeurs zijn de diplomatieke vertegenwoordigers van een ander land.",
                "type": "scopeNote",
            }
        ],
        "related": [109],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/11",
    },
    {
        "broader": [237],
        "id": 1532,
        "labels": [
            {"label": "amsterdammertjes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een amsterdammertje is een paaltje om het parkeren op de stoep te voorkomen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1532",
    },
    {
        "broader": [],
        "id": 2043,
        "labels": [{"label": "anthrosols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1852],
        "narrower": [2044],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een anthrosol is een bodem waarvan de bovenste laag door eeuwenlange landbouwbewerking sterk is aangerijkt met organisch rijk materiaal (mest, plaggen, teelaarde). Wordt aangeduid op de bodemkaart met letter m: (\u2026m)",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2043",
    },
    {
        "broader": [1227],
        "id": 1255,
        "labels": [
            {"label": "antropomorfe graven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1248],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een antropomorf graf is een graf dat de menselijke omtrek sterk benadert. Het graf is het breedst aan de schouders en smaller naar het voeteinde toe. Voor het hoofd werd vaak een nis uitgespaard, waarvan de bodem soms enkele centimeters hoger ligt. De constructiematerialen en afwerking kunnen sterk verschillen. Sommige graven werden opgebouwd uit gestapelde stenen bijeengehouden door kalkmortel (mogelijk ook nog glad afgewerkt met een kalkmortellaagje), andere graven kenden geen stenen opbouw, maar wel een kalkmortellaagje. Op dit graf kwam een deksel van hout of stenen platen, waarna de kuil tot het loopniveau weer met grond gevuld werd. Het hoogtepunt van het voorkomen van dergelijke graven kan geplaatst worden in de 10de-11de eeuw.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Bru M.-A., Stoops G. &amp; Vermeiren G. 2007, Gent: Antropomorfe graven in Gent, in: Erfgoedmemo, vol. 30.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1255",
    },
    {
        "broader": [885],
        "id": 26,
        "labels": [
            {"label": "apotheken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "drogisterijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een apotheek is een winkel waar medicijnen bereid en verkocht worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/26",
    },
    {
        "broader": [284],
        "id": 27,
        "labels": [
            {"label": "appartementsgebouwen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "flatgebouwen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [521, 2178, 2179, 2180, 2181],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een appartementsgebouw is een meergezinswoning waarin meerdere appartementen of wooneenheden voorzien zijn, meestal boven elkaar gelegen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/27",
    },
    {
        "broader": [1197],
        "id": 1198,
        "labels": [{"label": "aquaducten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een aquaduct is een kunstmatige waterweg om water over lange afstanden te vervoeren, meestal met behulp van de zwaartekracht; wordt ook gebruikt voor brugachtige bouwwerken die een waterweg of kanaal over een dal, een rivier of een ander obstakel heenvoeren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1198",
    },
    {
        "broader": [116],
        "id": 776,
        "labels": [{"label": "aquaria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/776",
    },
    {
        "broader": [196],
        "id": 28,
        "labels": [
            {"label": "arbeiderscit\xe9s", "language": "nl-BE", "type": "prefLabel"},
            {"label": "arbeidershuisvesting", "language": "nl-BE", "type": "altLabel"},
            {"label": "fabriekscit\xe9s", "language": "nl-BE", "type": "altLabel"},
            {"label": "cit\xe9s ouvri\xe8res", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2169, 57],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een arbeiderscit\xe9 omvat meerdere woningen voor arbeiders,  vaak in dienst van dezelfde werkgever. Ontworpen als een geheel en vaak gefinancierd door de werkgever, maar ook door sociale huisvestingsmaatschappijen of de vrije markt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term aangepast van arbeidershuisvesting naar arbeiderscit\xe9s + aanpassing SN bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [391, 29],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/28",
    },
    {
        "broader": [522],
        "id": 29,
        "labels": [
            {"label": "arbeiderswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een arbeiderswoning is het bescheiden woonhuis van een arbeider, veelal een rijwoning.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT aangepast naar 'woonhuizen naar vormelijk type'",
                "type": "historyNote",
            },
        ],
        "related": [285, 343, 28],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/29",
    },
    {
        "broader": [346],
        "id": 30,
        "labels": [{"label": "arboreta", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een arboretum is een bomentuin. In een dergelijke tuin kweekt men in dienst van de wetenschap verschillende boomsoorten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "22/04/2011: SN licht herschreven door Leen om deze consistenter te maken.",
                "type": "historyNote",
            },
        ],
        "related": [337, 346, 440],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/30",
    },
    {
        "broader": [443],
        "id": 1535,
        "labels": [{"label": "arcades", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300002580"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een arcade is een bogenstelling met zijn rechtstanden van zuilen of pijlers. Op enige afstand voor een muur geplaatst en overdekt vormt de arcade hiermee een galerij.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1535",
    },
    {
        "broader": [],
        "id": 1389,
        "labels": [
            {"label": "archeologische depots", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1390, 1391, 1392],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een depot is een om opzettelijke redenen (vanuit religieusrituele, functionele en sociale achtergronden) gedeponeerd object (of meerdere objecten) in hetzij droge context (hoge delen van duinen en donken, dekzandkoppen enz.) hetzij natte context (water, moeras, rivier,...). Het kan gaan om een stuk grondstof, halffabricaten en/of eindproducten, maar ook om de depositie van menselijke resten die geen zichtbare grafstructuur hebben bv. veenlijken of menselijke deposities in een waterput.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "De Wit G. &amp; Sloos A. 2008, De interpretatie van archeologische waarnemingen in Archis. Een concept voor een nieuwe set complextypen, in: Rapportage Archeologische Monumentenzorg 165, Amersfoort.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1389",
    },
    {
        "id": 1373,
        "labels": [
            {
                "label": "archeologische indicaties",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1090, 1374, 1381, 1385, 1744, 1796],
        "notes": [],
        "sources": [{"citation": "Code Goede Praktijk", "markup": None}],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1373",
    },
    {
        "broader": [],
        "id": 1393,
        "labels": [
            {
                "label": "archeologische objecten",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            1394,
            1395,
            1396,
            1397,
            1398,
            1399,
            1400,
            1402,
            1403,
            1404,
            1405,
            1406,
            1407,
            1408,
            1412,
            1414,
        ],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1393",
    },
    {
        "id": 1071,
        "labels": [
            {
                "label": "archeologische sporen en uitgravingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1072, 1082, 1088, 1096, 1100, 1101, 1102, 1104, 1105, 1108, 1109],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1071",
    },
    {
        "broader": [323],
        "id": 31,
        "labels": [
            {"label": "archiefgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een archiefgebouw is een bewaarplaats van een archief.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/31",
    },
    {
        "broader": [522],
        "id": 32,
        "labels": [
            {"label": "architectenwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een architectenwoning is een woonhuis bewoond door de bouwmeester of architect die het ontwierp, meestal met atelier.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.\n06/10/2011: definitie verruimd door toevoeging van bouwmeester.(LM)",
                "type": "historyNote",
            },
        ],
        "related": [254],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/32",
    },
    {
        "broader": [],
        "id": 2053,
        "labels": [{"label": "arenosols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1855],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een arenosol is een erg zandige bodem met beperkte profielontwikkeling (bijvoorbeeld bij actieve duinen).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2053",
    },
    {
        "broader": [1148],
        "id": 34,
        "labels": [{"label": "arsenalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een arsenaal is een opslagplaats voor wapens en andere militaire uitrustingen, vaak met bijbehorende werkplaatsen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'militaire gebouwen en constructies' naar 'militaire gebouwen' bij integratie.",
                "type": "historyNote",
            },
        ],
        "related": [328],
        "sources": [
            {
                "citation": 'Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Begrippenlijst van de Stichting Menno van Coehoorn (<a href="http://www.coehoorn.nl/">http://www.coehoorn.nl/</a>)',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/34",
    },
    {
        "broader": [151],
        "id": 35,
        "labels": [
            {"label": "asten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "eesten", "language": "nl-BE", "type": "altLabel"},
            {"label": "droogvloeren", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1014],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ast is een gebouw met van onderuit verwarmde vloer om grondstoffen, zoals hop, tabak, suiker en cichorei, te drogen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische gebouwen'.",
                "type": "historyNote",
            },
        ],
        "related": [419, 422, 21],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005; Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/35",
    },
    {
        "broader": [896],
        "id": 1512,
        "labels": [
            {"label": "atletiekbanen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300000611"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een atletiekbaan is een piste in de open lucht, meestal in de vorm van een langgerekt ovaal, van markeringen voorzien, voornamelijk voor hardloopwedstrijden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1512",
    },
    {
        "broader": [21],
        "id": 36,
        "labels": [
            {"label": "azijnfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een azijnfabriek is een industrieel of ambachtelijk bedrijf waar men azijn produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/36",
    },
    {
        "broader": [484],
        "id": 958,
        "labels": [
            {
                "label": "baan- en seinwachterswoningen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een baan- en seinwachterswoning is het woonhuis voor een baan- en/of seinwachter. Baanwachters houden toezicht op een deel van een spoorweg. Seinwachters bedienen seinen in een seinhuis langs de spoorbaan.",
                "type": "scopeNote",
            }
        ],
        "related": [944],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/958",
    },
    {
        "broader": [1200],
        "id": 1201,
        "labels": [
            {"label": "badhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "balnea", "language": "nl-BE", "type": "altLabel"},
            {"label": "balneum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1202],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Romeins badhuis is een openbare of particuliere bouwconstructie van gewone proporties waar ruimtes waren voorzien om zich te baden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'thermen' voor monumentale Romeinse baden.\nGebruik 'stoven' voor middeleeuwse badhuizen met ruimere functie van ontmoetingsplaats.",
                "type": "note",
            },
        ],
        "related": [1127],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1201",
    },
    {
        "broader": [78],
        "id": 1456,
        "labels": [
            {"label": "baggervaartuigen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "baggeraars", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een baggervaartuig is een vaartuig met baggermachine voor het ophalen van slib, zand enz., het graven of uitdiepen van kanalen en havens en het verwijderen van zandbanken en/of een vaartuig waarin het opgebaggerde slib gestort wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005 (lemma baggermachine en baggerschip)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1456",
    },
    {
        "broader": [1621],
        "id": 1625,
        "labels": [{"label": "bakenbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bakenboom is een boom aangeplant als baken en bijgevolg als vast merkteken het vaarwater markeert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "1) Van Daele 2) Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1625",
    },
    {
        "broader": [63],
        "id": 773,
        "labels": [{"label": "bakhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300266040"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bakhuis is een bijgebouw met een oven voor het bakken van brood.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/10/2014: BT gewijzigd van 'bakovens' naar 'bijgebouwen' --&gt; een bakhuis is immers geen bakoven --&gt; bakoven is eerder deel van bakhuis.",
                "type": "historyNote",
            },
        ],
        "related": [39],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/773",
    },
    {
        "broader": [885],
        "id": 38,
        "labels": [{"label": "bakkerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bakkerij is een winkel waar men in de eerste plaats brood bakt en verkoopt.",
                "type": "scopeNote",
            }
        ],
        "related": [201, 39],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/38",
    },
    {
        "broader": [21],
        "id": 39,
        "labels": [{"label": "bakovens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bakoven is een vrijstaande, met hout gestookte broodoven, al dan niet in een bakhuis.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "14/04/2011: BT aangepast van 'bijgebouwen' naar 'gebouwen voor voedings- en genotsmiddelenproductie'",
                "type": "historyNote",
            },
        ],
        "related": [38, 773],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005; Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/39",
    },
    {
        "broader": [174],
        "id": 40,
        "labels": [
            {"label": "baldakijngraven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een baldakijngraf is een grafmonument met een overhuiving.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/40",
    },
    {
        "broader": [522],
        "id": 41,
        "labels": [
            {"label": "baljuwhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "drossaardhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een baljuwhuis is een ambtswoning van baljuws. Baljuws zijn gerechtelijke ambtenaren die aan het hoofd van de schepenbank stonden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [222],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/41",
    },
    {
        "broader": [925],
        "id": 42,
        "labels": [
            {"label": "ballonloodsen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ballonloods is een gebouw voor opslag van en herstellingen aan luchtballons en zeppelins.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/42",
    },
    {
        "broader": [893],
        "id": 1514,
        "labels": [{"label": "balustrades", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300001989"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een balustrade is een laag hekwerk van balusters en een erop rustend dekstuk  als borstwering van een bordes,  terras  of trap.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1514",
    },
    {
        "broader": [887],
        "id": 43,
        "labels": [{"label": "bankgebouwen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bankgebouw is een gebouw waar geld en waardepapieren bewaard en verhandeld worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/43",
    },
    {
        "broader": [323],
        "id": 1122,
        "labels": [{"label": "basilicae", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een basilica is een (in oorsprong Romeins) religieus of seculier gebouw dat wordt gekenmerkt door een rechthoekige plattegrond, onderverdeeld in een hoger schip met twee lagere zijbeuken, en verlicht door lichtbeukramen; meestal afgesloten met een apsis.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a href="http://www.onderzoeksbalans.be/.">http://www.onderzoeksbalans.be/.</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1122",
    },
    {
        "broader": [230],
        "id": 772,
        "labels": [{"label": "basilieken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/772",
    },
    {
        "broader": [1040],
        "id": 1041,
        "labels": [
            {"label": "basiskampen", "language": "nl-BE", "type": "prefLabel"},
            {
                "label": "residenti\xeble kampen",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een basiskamp is een tijdelijke woonplaats voor gehele families die dient als uitvalsbasis voor de exploitatie van het omliggende landschap.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {"citation": "cursusmateriaal UGent (Prof. Ph. Cromb\xe9)", "markup": None}
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1041",
    },
    {
        "broader": [1151],
        "id": 771,
        "labels": [
            {"label": "bastions", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vestingfronten", "language": "nl-BE", "type": "altLabel"},
            {"label": "bolwerken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bastion is een vijfhoekige aarden of stenen uitbouw van een verdedigingswerk naar oorspronkelijk Italiaans ontwerp, ook wel bolwerk of dwinger geheten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: term was NPT van vestingfronten. Bastion meer gebruikte term, dus omgewisseld. BT gewijzigd van 'verdedigingswerken' naar 'verdedigingswerkonderdelen'.",
                "type": "historyNote",
            },
        ],
        "related": [1185],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/771",
    },
    {
        "broader": [1150],
        "id": 967,
        "labels": [{"label": "batterijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'versterkte sites'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/967",
    },
    {
        "id": 1832,
        "labels": [
            {"label": "bebouwingspatronen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1033, 2113],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1832",
    },
    {
        "broader": [323],
        "id": 45,
        "labels": [
            {
                "label": "bedelaarsinstellingen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "onvrije kolonies", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bedelaarsinstelling is een instelling waar bedelaars en landlopers verplicht (land)arbeid verrichtten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/45",
    },
    {
        "broader": [513],
        "id": 46,
        "labels": [
            {"label": "bedevaartkapellen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bedevaartkapel is een kapel op een bedevaartroute of waarnaar pelgrims bedevaarten ondernemen.",
                "type": "scopeNote",
            }
        ],
        "related": [47],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/46",
    },
    {
        "broader": [230],
        "id": 47,
        "labels": [
            {"label": "bedevaartkerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bedevaartkerk is een kerk waarnaar pelgrims bedevaarten ondernemen om relikwie\xebn of miraculeuze beelden te vereren of een verschijning van Maria te herdenken.",
                "type": "scopeNote",
            }
        ],
        "related": [46],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/47",
    },
    {
        "broader": [140],
        "id": 1524,
        "labels": [
            {"label": "bedriegertjes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300260407"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bedriegertje is een kniehoog fonteintje als onderdeel van speelse waterwerken in tuinen en parken die bezoekers onverhoeds natte onderbenen bezorgen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "1) Van Dale online 2) AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1524",
    },
    {
        "broader": [48],
        "id": 888,
        "labels": [{"label": "beelden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [412, 1526, 1527, 1529, 1530],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Driedimensionale voorstellingen van onder meer mensen, mythologische figuren of dieren.",
                "type": "scopeNote",
            }
        ],
        "related": [443],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/888",
    },
    {
        "broader": [440],
        "id": 1573,
        "labels": [
            {"label": "beeldentuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een beeldentuin is een siertuin waarin beelden worden tentoongesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1573",
    },
    {
        "broader": [1233],
        "id": 1237,
        "labels": [
            {"label": "beenderpakgraven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Knochenlager", "language": "nl-BE", "type": "altLabel"},
            {"label": "beendernesten", "language": "nl-BE", "type": "altLabel"},
            {"label": "blocs d'ossements", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een beenderpakgraf is een graf waarin de geselecteerde crematieresten van de overledene, die op de brandstapel was verast, gewikkeld in een organische zak of doek werden gedeponeerd (zonder houtskool en brandstapelresten).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Onderzoeksbalans <a href="http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving">http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving</a> 2) Hiddink H. 2003, Het grafritueel in de Late IJzertijd en Romeinse tijd in het Maas-Demer-Scheldegebied in het bijzonder van twee grafvelden bij Weert, Zuidnederlandse Archeologische Rapporten vol. 11. 3) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1237",
    },
    {
        "broader": [1200],
        "id": 1203,
        "labels": [{"label": "beerkuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een beerkuil is een kuil waarin uitwerpselen werden geloosd v\xf3\xf3r de opkomst van (bakstenen) beerputten. Deze kunnen eventueel ook met vlechtwerk afgelijnd zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1203",
    },
    {
        "broader": [1200],
        "id": 1206,
        "labels": [{"label": "beerputten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een beerput is een ondergrondse constructie in de vorm van een kelder of put bedoeld voor de opvang van uitwerpselen met vaak een secundaire functie als afval- en vergaarbak. Deze putten zijn vaak gelegen onder een toilethokje achter een woonhuis. Tonputten (meerdere op elkaar geplaatste tonnen) en vierkante beerputten komen het meeste voor. Beerputten kunnen uitgevoerd zijn in hout of in (bak)steenbouw. Soms is er aanwijzing voor een (houten) vloer op de bodem van de beerput waarin een opening zou gelaten zijn om het afvloeien van vocht toe te laten, terwijl de vastere massa achterbleef. Het beer zelf werd vaak gebruikt als meststof.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Heirbaut E. 2008, Onderzoek naar de eerste eeuwse beerputten uit oppidum Batavorum (Nijmegen NL), in: Romeinendag. Jaarlijks Belgisch congres voor Romeinse archeologie 19/04/2008, pp. 55-59. 2) Bitter P., Ostkamp S. &amp; Roedema R. 2002, De beerput als bron. Archeologische vondsten van het dagelijks leven in het oude Alkmaar, Alkmaar.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1206",
    },
    {
        "broader": [889],
        "id": 50,
        "labels": [
            {"label": "begijnenhuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [806],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een begijnenhuis is een woonhuis in een begijnhof.",
                "type": "scopeNote",
            }
        ],
        "related": [53, 359],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/50",
    },
    {
        "broader": [230],
        "id": 52,
        "labels": [
            {"label": "begijnhofkerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kerken van begijnhoven.",
                "type": "scopeNote",
            }
        ],
        "related": [53],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/52",
    },
    {
        "broader": [359],
        "id": 53,
        "labels": [{"label": "begijnhoven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een begijnhof is een nederzetting, vaak ommuurd, waar begijnen leven. Begijnen zijn vrouwen die als geestelijke zusters samenleven, maar geen kloostergelofte afleggen.",
                "type": "scopeNote",
            }
        ],
        "related": [52, 50],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/53",
    },
    {
        "broader": [932],
        "id": 1762,
        "labels": [
            {
                "label": "begraafplaatsbeplantingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1756],
        "narrower": [1642],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Begraafplaatsbeplanting is beplanting die werd aangeplant op een begraafplaats.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1762",
    },
    {
        "broader": [142],
        "id": 54,
        "labels": [
            {"label": "begraafplaatsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "grafvelden", "language": "nl-BE", "type": "altLabel"},
            {"label": "necropolen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [232, 292, 1258, 1260, 1415, 1416],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een begraafplaats is een terrein waar de stoffelijke resten van overledenen begraven worden, uitgestrooid of bijgezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '24/01/2011: SN gewijzigd van "Terreinen, doorgaans buiten het dorps- of stadscentrum gelegen, waar overledenen begraven worden."\n19/05/2011: SN gewijzigd van "Een begraafplaats kan algemeen beschouwd worden als een terrein waar overledenen begraven worden."',
                "type": "historyNote",
            },
        ],
        "related": [231],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/54",
    },
    {
        "broader": [522],
        "id": 55,
        "labels": [
            {"label": "bejaardenwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bejaardenwoning is een individuele wooneenheid die specifiek opgevat is om bejaarden zo zelfstandig mogelijk te laten wonen, eventueel verbonden met een verzorgingseenheid. In het laatste geval spreekt men van aanleunwoning of serviceflat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term verplaatst van woonwijken - sociale huisvesting naar hier + SN uitgebreid ikv integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [368],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/55",
    },
    {
        "broader": [1962],
        "id": 1965,
        "labels": [{"label": "beken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008703"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een beek is een relatief smalle natuurlijke waterloop met een doorgaans ondiepe bedding, zonder getijdeninvloed.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1965",
    },
    {
        "broader": [323],
        "id": 56,
        "labels": [{"label": "belforten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een belfort is een versterkte toren, die soms afzonderlijk staat of vaak verbonden is met een stadhuis of stedelijke markthal (lakenhal). Het belfort bood een veilige plaats voor het bewaren van charters, de stadsgelden en andere waardevolle bezittingen van de stad (hiervoor waren in de fundering kelders voorzien) en werd gebruikt voor het hangen van de stadsklok. De versterking deed ook dienst als uitkijktoren met alarmklok. Het belfort was lange tijd het enige offici\xeble gebouw van de stad en werd dan ook gebruikt als vergaderzaal van de schepenen. Als monumentale uitdrukkingen van de gemeentelijke vrijheden bezitten de belforten een diepgewortelde symbolische betekenis. Er werden nog belforten opgetrokken tot aan WO II.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '26/01/2011: SN beetje aangepast. Oorspronkelijk: "Versterkte torens, oorspronkelijk bedoeld als bewaarplaats van de geschreven stedelijke voorrechten en vergaderplaats van de stadsraad, vaak met een wapenarsenaal. De versterking deed ook dienst als uitkijktoren met alarmklok. Als monumentale uitdrukkingen van de gemeentelijke vrijheden bezitten de belforten een diepgewortelde symbolische betekenis. Er werden nog belforten opgetrokken tot aan WO II."',
                "type": "historyNote",
            },
        ],
        "related": [260],
        "sources": [
            {
                "citation": "HEIRMAN, M. 2003: Vlaamse belforten, Werelderfgoed, Leuven",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/56",
    },
    {
        "broader": [28],
        "id": 57,
        "labels": [{"label": "beluiken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een beluik is een groep arbeiderswoningen op inpandig terrein, vaak met een overbouwde toegang. Synoniemen zijn koeren, gangen, forten of ingangen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/57",
    },
    {
        "broader": [444],
        "id": 58,
        "labels": [
            {"label": "belved\xe8res", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1540],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Tuinpaviljoenen, bedoeld om van een uitzicht te genieten. Deze zijn meestal geplaatst op een verhevenheid in een tuin, park of het landschap.",
                "type": "scopeNote",
            }
        ],
        "related": [313, 314],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/58",
    },
    {
        "broader": [926],
        "id": 59,
        "labels": [
            {"label": "benzinestations", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bezinestation is een plaats die is uitgerust om brandstof te tanken en waar eventueel ook andere benodigdheden voor motorvoertuigen en reizigers te verkrijgen zijn.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/59",
    },
    {
        "broader": [1685],
        "id": 746,
        "labels": [
            {"label": "berceaus", "language": "nl-BE", "type": "prefLabel"},
            {"label": "loofgangen", "language": "nl-BE", "type": "altLabel"},
            {"label": "lovergangen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/900031486"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een berceau is een met een loofgewelf overdekte plantengang, doorgaans ondersteund door een houten of metalen constructie.",
                "type": "scopeNote",
            }
        ],
        "related": [165, 342],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/746",
    },
    {
        "broader": [323],
        "id": 60,
        "labels": [
            {
                "label": "bergen van barmhartigheid",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "pandjeshuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een berg van barmhartigheid is een pand(jes)huis waar men geld leende op krediet van roerende goederen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/60",
    },
    {
        "broader": [212],
        "id": 754,
        "labels": [
            {"label": "betonfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/754",
    },
    {
        "broader": [507],
        "id": 1018,
        "labels": [
            {"label": "betreedbare kapellen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kapellen als betreedbare gebouwtjes. De plattegrond is vaak rechthoekig met een vlakke, halfronde of veelhoekige achterzijde, maar ook kapellen met een centrale plattegrond (rond of achtzijdig) komen voor. In de grotere versies staan stoelen of banken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31 maart 2010: term toegevoegd + scope-note toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1018",
    },
    {
        "broader": [887],
        "id": 61,
        "labels": [
            {"label": "beursgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een beursgebouw is een gebouw waar kooplieden samenkomen om geldelijke transacties af te sluiten of om goederen te verhandelen (goederenbeurs).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/61",
    },
    {
        "broader": [1393],
        "id": 1396,
        "labels": [
            {"label": "bevestigingselementen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Elementen waarmee losse delen aan elkaar worden vastgemaakt of samengehouden. Hieronder vallen nagels en spijkers, maar ook sloten (hangsloten, schuifsloten, deursloten,\u2026), haken, enz\u2026",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Sleutels voor sloten vallen onder werktuigen.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'National Monuments Record thesaurus (English Heritage), <a href="http://thesaurus.english-heritage.org.uk/frequentuser.htm">http://thesaurus.english-heritage.org.uk/frequentuser.htm</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1396",
    },
    {
        "broader": [1080],
        "id": 1947,
        "labels": [
            {"label": "bevloeiingsgrachten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bevloeiingsgracht is een gracht met een daaraan gekoppeld sluizensysteem aangelegd om hooilanden of \u2013weiden (zgn. vloeiweiden) periodiek te bevloeien.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1947",
    },
    {
        "broader": [389],
        "id": 1939,
        "labels": [
            {"label": "bevloeiingssluizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "irrigatiesluizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1861],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bevloeiingssluis is een sluis voor de bevloeiing van landbouwgronden met water en sedimenten uit een waterloop (zie vloeiweide).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1939",
    },
    {
        "broader": [323],
        "id": 62,
        "labels": [{"label": "bibliotheken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bibliotheek is een gebouw waar boeken bewaard en geraadpleegd kunnen worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Enkel vrijstaande bibliotheken zijn opgenomen in de databank.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/62",
    },
    {
        "broader": [328],
        "id": 946,
        "labels": [
            {"label": "bietenkelders", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bietenkelder is een kelder om bieten op te slaan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische gebouwen'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/946",
    },
    {
        "broader": [147],
        "id": 63,
        "labels": [{"label": "bijgebouwen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": [
                "http://vocab.getty.edu/aat/300008001",
                "http://vocab.getty.edu/aat/300004062",
            ],
            "related": [],
        },
        "member_of": [],
        "narrower": [
            7,
            74,
            145,
            200,
            206,
            245,
            254,
            329,
            350,
            384,
            486,
            492,
            518,
            1483,
            773,
            461,
            892,
        ],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/63",
    },
    {
        "broader": [147],
        "id": 2089,
        "labels": [
            {"label": "binnenplaatsen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004095"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1765],
        "narrower": [2088],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een binnenplaats is een niet-overdekte ruimte die geheel of gedeeltelijk wordt omsloten door de muren van een gebouw.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: term toegevoegd i.f.v. beschermingsdatabank",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandstalige Art &amp; Architecture Thesaurus",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2089",
    },
    {
        "broader": [78],
        "id": 1435,
        "labels": [
            {"label": "binnenschepen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1428],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een binnenschip is een vaartuig voor de binnenvaart.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1435",
    },
    {
        "broader": [321],
        "id": 64,
        "labels": [
            {"label": "bioscopen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "cinema's", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bioscoop is een gebouw ingericht voor het vertonen van films.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/64",
    },
    {
        "broader": [889],
        "id": 65,
        "labels": [
            {
                "label": "bisschoppelijke paleizen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bisschoppelijk paleis is een stadspaleis van een bisschop.",
                "type": "scopeNote",
            }
        ],
        "related": [405, 359],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/65",
    },
    {
        "broader": [20],
        "id": 66,
        "labels": [{"label": "blekerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een blekerij is een industrieel of ambachtelijk bedrijf waar men stoffen bleekt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/66",
    },
    {
        "broader": [237],
        "id": 1533,
        "labels": [{"label": "bloembakken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300237566"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bloembak is een houder waarin planten voor decoratieve doeleinden worden geplaatst.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1533",
    },
    {
        "broader": [1586],
        "id": 1587,
        "labels": [
            {"label": "bloemenparterres", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bloemenparterre is een parterre dat hoofdzakelijk uit bloeiende bol-en knolgewassen, eenjarige en doorlevende kruidachtige planten en lage heesters bestaat.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1587",
    },
    {
        "broader": [440],
        "id": 1574,
        "labels": [
            {"label": "bloementuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008135"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1575],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bloementuin is een siertuin waarin hoofdzakelijk bloemen worden geteeld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1574",
    },
    {
        "broader": [1531],
        "id": 67,
        "labels": [
            {"label": "bloemenuurwerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Uurwerken in een bloemenperk als onderdeel van een tuin- of parkaanleg.",
                "type": "scopeNote",
            }
        ],
        "related": [481, 531],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/67",
    },
    {
        "broader": [438],
        "id": 767,
        "labels": [
            {"label": "bloemisterijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/767",
    },
    {
        "broader": [2078],
        "id": 2079,
        "labels": [
            {
                "label": "blokvormige ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2080],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een blokvormig ontginningspatroon heeft een duidelijke structuur, de percelen zijn meestal vierhoekig van vorm en vergelijkbaar van grootte met vaak rechte en evenwijdig lopende perceelsgrenzen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2079",
    },
    {
        "broader": [2064],
        "id": 2065,
        "labels": [
            {"label": "bocagelandschappen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bocagelandschap is een gesloten landschap gevormd door kleine blokvormige percelen met gesloten perceelrandbegroeiingen van voornamelijk houtkanten, houtwallen, hagen, knotbomenrijen, ... waardoor het zicht sterk belemmerd wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2065",
    },
    {
        "id": 1840,
        "labels": [{"label": "bodemgebruik", "language": "nl-BE", "type": "prefLabel"}],
        "member_of": [],
        "members": [73, 1841, 1905, 1914, 1915, 1918, 1930, 1910, 1917, 2149],
        "notes": [],
        "sources": [{"citation": "Nationaal Geografisch Instituut", "markup": None}],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1840",
    },
    {
        "id": 2132,
        "labels": [{"label": "bodems", "language": "nl-BE", "type": "prefLabel"}],
        "member_of": [1851],
        "members": [1854, 1853, 1852, 1855, 2040, 2057],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2132",
    },
    {
        "id": 1851,
        "labels": [
            {"label": "bodems en afzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [2133, 2132],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1851",
    },
    {
        "id": 1854,
        "labels": [
            {
                "label": "bodems met aanrijkingshorizont",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [2132],
        "members": [1856, 2052],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1854",
    },
    {
        "id": 1856,
        "labels": [
            {
                "label": "bodems met aanrijkingshorizont van klei",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1854],
        "members": [2049, 2050, 2051],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1856",
    },
    {
        "id": 1853,
        "labels": [
            {
                "label": "bodems met oxidatie-/reductieverschijnselen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [2132],
        "members": [2047, 2048],
        "notes": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1853",
    },
    {
        "id": 1852,
        "labels": [
            {
                "label": "bodems met sterke menselijke invloed",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [2132],
        "members": [2043, 2045],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1852",
    },
    {
        "id": 1855,
        "labels": [
            {
                "label": "bodems zonder of met beperkte profielontwikkeling",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [2132],
        "members": [2046, 2053, 2054, 2055, 2056],
        "notes": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1855",
    },
    {
        "broader": [522],
        "id": 69,
        "labels": [
            {
                "label": "boerenarbeiderswoningen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "daglonerswoningen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boerenarbeiderswoning is een woonhuis voor landarbeiders die voor een dagloon werken en niet inwonen op een hoeve.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31/01/2011: BT gewijzigd van 'agrarische gebouwen' naar 'woonhuizen naar bewoners'",
                "type": "historyNote",
            },
        ],
        "related": [71],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/69",
    },
    {
        "broader": [71],
        "id": 70,
        "labels": [
            {"label": "boerenburgerhuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boerenburgerhuis is een aanzienlijke boerenwoning, doorgaans van twee bouwlagen.",
                "type": "scopeNote",
            }
        ],
        "related": [71],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/70",
    },
    {
        "broader": [1603],
        "id": 1973,
        "labels": [{"label": "boerentuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boerentuin is een doorgaans kleine en meestal omhaagde tuin die steeds een duidelijk afgescheiden onderdeel vormt van een boerenerf. Vaak is de tuin ingericht voor nut (groenten, kleinfruit) en sier (bloemen), soms ook aangevuld met elementen in vormsnoei, die vaak ge\xefnspireerd zijn op het agrarisch gebeuren of op boerderijdieren(topiary).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1973",
    },
    {
        "broader": [522],
        "id": 71,
        "labels": [
            {"label": "boerenwoningen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "pachterswoningen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [70],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boerenwoning is het woonhuis van een hoeve. Deze staan vaak in verbinding met andere gebouwen van het bedrijf, in de eerste plaats met stallen en schuren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Op 25/06/2009 BT gewijzigd, van \"hoeven\" naar \"gebouwen voor land- en tuinbouw\".\n31/01/2011: BT gewijzigd van 'agrarische gebouwen' naar 'woonhuizen naar bewoners'.",
                "type": "historyNote",
            },
        ],
        "related": [70, 69, 190],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/71",
    },
    {
        "broader": [479],
        "id": 764,
        "labels": [
            {"label": "bolderskoten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "bolderbanen", "language": "nl-BE", "type": "altLabel"},
            {"label": "bolbanen", "language": "nl-BE", "type": "altLabel"},
            {"label": "boltra's", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bolderskot of bolderbaan is een langgestrekte, soms komvormige speelbaan (verhouding ca. 11 X 3m), al dan niet overdekt en gebruikelijk op aarden ondergrond, waarin met houten afgeplatte en afgeronde schijven of bollen naar een vast doel of \u2018stek\u2019 (vaak houten staakje) wordt gerold. De baan wordt in twee speelrichtingen gebruikt (2 houten stekken op ca. 7m afstand van elkaar) en is doorgaans voorzien van een afscherming op de korte zijden om te beletten dat de bollen uit de baan gespeeld worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/764",
    },
    {
        "broader": [],
        "id": 2073,
        "labels": [{"label": "bolle akkers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1850],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bolle akker is een (vaak aaneengeschakelde) landinrichtingsvorm waarbij het centrum van een door grachten omzoomd akkerperceel onder invloed van langdurige ploegtechnieken hoger ligt dan de randen. De perceelsgrachten zelf staan in functie van een verbeterde ontwatering.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2073",
    },
    {
        "broader": [932],
        "id": 72,
        "labels": [{"label": "bomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1653, 1656, 1655],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boom is een houtachtig gewas met een zeer groot wortelgestel en een enkelvoudige, stevige, houtige en zich secundair verdikkende, overblijvende stam, die zich op zekere hoogte boven de grond vertakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Daele", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/72",
    },
    {
        "broader": [1656],
        "id": 1658,
        "labels": [{"label": "bomencirkels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bomencirkel is een cirkelvormige bomenrij.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1658",
    },
    {
        "broader": [1656],
        "id": 1657,
        "labels": [{"label": "bomenclumps", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bomenclump omvat in groep aangeplante bomen en dit steeds volgens een strak plantverband.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1657",
    },
    {
        "broader": [72],
        "id": 1656,
        "labels": [{"label": "bomengroepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1657, 1658, 1662, 1664, 2195],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bomengroep is een verzameling van bij elkaar zijnde of behorende bomen, al dan niet in plantverband.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Daele", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1656",
    },
    {
        "broader": [72],
        "id": 1655,
        "labels": [{"label": "bomenrijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bomenrij is een in lijn aangeplante bomengroep met een regelmatige plantafstand doorgaans uitgevoerd met gelijkjarige bomen van dezelfde soort.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1655",
    },
    {
        "broader": [86],
        "id": 1487,
        "labels": [{"label": "boogbruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007838"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1486],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boogbrug is een brug waarin bogen de belangrijkste ondersteunende elementen zijn.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1487",
    },
    {
        "broader": [],
        "id": 73,
        "labels": [{"label": "boomgaarden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1840],
        "narrower": [1700, 1701, 1702],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boomgaard is een omsloten stuk (weide)grond beplant met vruchtbomen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "30/07/2014: verplaatst van 'houtig erfgoed' --&gt; 'bomen naar groepering' naar bodemgebruik bij integratie met de thesaurustermen voor landschappen.",
                "type": "historyNote",
            },
        ],
        "related": [792, 1636, 1707],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005 2) Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/73",
    },
    {
        "broader": [1019],
        "id": 763,
        "labels": [{"label": "boomkapellen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Specifieke vormen van kastkapellen, bevestigd aan een boom.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31 maart 2010: BT gewijzigd van kapellen (klein erfgoed) naar kastkapellen. Scope-note toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/763",
    },
    {
        "broader": [1656],
        "id": 1662,
        "labels": [{"label": "boomweiden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boomweide is een bomengroep met louter opgaande bomen, aangeplant op een grasland in een vrij plantverband, vaak als onderdeel van een tuin- of parkarchitecturaal concept.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term aangepast van bosweide naar boomweide; BT aangepast van hooghoutpercelen naar bomengroepen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1662",
    },
    {
        "broader": [63],
        "id": 74,
        "labels": [{"label": "boothuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boothuis is een bijgebouw voor het stallen van boten, aan en soms gedeeltelijk in het water gelegen.",
                "type": "scopeNote",
            }
        ],
        "related": [78],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/74",
    },
    {
        "broader": [321],
        "id": 1126,
        "labels": [{"label": "bordelen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bordeel is een gebouw waarin prostitutie als bedrijf wordt uitgeoefend.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1126",
    },
    {
        "broader": [888],
        "id": 1527,
        "labels": [
            {"label": "borstbeelden", "language": "nl-BE", "type": "prefLabel"},
            {"label": "bustes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300047457"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een borstbeeld is de afbeelding van een persoon, die het hoofd met een gedeelte van de borst voorstelt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1527",
    },
    {
        "broader": [18],
        "id": 75,
        "labels": [
            {"label": "borstelfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een borstelfabriek is een industrieel of ambachtelijk bedrijf waar men borstels produceert.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'nijverheidsgebouwen en productieplaatsen' naar 'gebouwen voor hout- en papiernijverheid'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/75",
    },
    {
        "broader": [1151],
        "id": 1187,
        "labels": [
            {"label": "borstweringen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een borstwering is een beschutting van aarde (grond), steen of ander materiaal, ter bescherming van erachter opgestelde schutters of geschut; in de middeleeuwen veelal bestaande uit gekanteelde muren, later meestal van aarde.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1187",
    },
    {
        "broader": [],
        "id": 1841,
        "labels": [{"label": "bossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": ["http://vocab.getty.edu/aat/300132451"],
        },
        "member_of": [1840],
        "narrower": [2161],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bos is een doorgaans productief bodemgebruik met een vegetatie gedomineerd door bomen en/of struiken die zijn aangeplant en/of spontaan ontwikkeld. Vaak wordt een bos periodiek gekapt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "30/07/2014: toegevoegd bij integratie met landschapsthesaurus",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [1842, 1846, 1659],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1841",
    },
    {
        "id": 1659,
        "labels": [
            {
                "label": "bossen naar beheersvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1660, 1666, 1667],
        "notes": [],
        "sources": [],
        "superordinates": [1841],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1659",
    },
    {
        "id": 1846,
        "labels": [
            {"label": "bossen naar gebruik", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1663, 1927, 1928, 2143],
        "notes": [],
        "sources": [],
        "superordinates": [1841],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1846",
    },
    {
        "id": 1842,
        "labels": [
            {
                "label": "bossen naar soortsamenstelling",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1843, 1844, 1845],
        "notes": [],
        "sources": [],
        "superordinates": [1841],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1842",
    },
    {
        "broader": [343],
        "id": 77,
        "labels": [
            {"label": "boswachterswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een boswachterswoning is het woonhuis van een boswachter. Boswachters zijn beheerders van bossen.",
                "type": "scopeNote",
            }
        ],
        "related": [337, 206, 484, 930],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/77",
    },
    {
        "broader": [1561],
        "id": 346,
        "labels": [
            {"label": "botanische tuinen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "plantentuinen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [30, 1562],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een botanische tuin is een voor het publiek toegankelijke tuin waar men in dienst van de wetenschap verschillende plantensoorten kweekt.",
                "type": "scopeNote",
            }
        ],
        "related": [30, 337, 440],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/346",
    },
    {
        "broader": [21],
        "id": 79,
        "labels": [{"label": "bottelarijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bottelarij is een industrieel of ambachtelijk bedrijf waar men drank op flessen tapt.",
                "type": "scopeNote",
            }
        ],
        "related": [84, 107, 494],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/79",
    },
    {
        "broader": [1393],
        "id": 1397,
        "labels": [
            {"label": "bouwelementen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "bv. draagbalken, zuilentrommels, ...",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1397",
    },
    {
        "broader": [1393],
        "id": 1398,
        "labels": [
            {"label": "bouwmaterialen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "bv. bakstenen, dakpannen, natuursteenblokken,...",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1398",
    },
    {
        "broader": [479],
        "id": 966,
        "labels": [{"label": "bowlingbanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/966",
    },
    {
        "broader": [1590],
        "id": 1591,
        "labels": [
            {"label": "bowling greens", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bowling green is een rechthoekig, verdiept aangelegd grasveld in een geometrische tuin, oorspronkelijk ten behoeve van het croquetspel.",
                "type": "scopeNote",
            }
        ],
        "related": [1596],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1591",
    },
    {
        "broader": [1072],
        "id": 1074,
        "labels": [{"label": "brandlagen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brandlaag is een laag van verband materiaal.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1074",
    },
    {
        "broader": [1233],
        "id": 1242,
        "labels": [
            {"label": "brandrestengraven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Brandgrubengr\xe4ber", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brandrestengraf is een graf waarin gecremeerde beenderen, vermengd met de restanten van de brandstapel (zonder beenderresten uit te selecteren), in een kuil gedeponeerd zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Onderzoeksbalans <a href="http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving">http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving</a> 2) Hiddink H. 2003, Het grafritueel in de Late IJzertijd en Romeinse tijd in het Maas-Demer-Scheldegebied in het bijzonder van twee grafvelden bij Weert, Zuidnederlandse Archeologische Rapporten vol. 11.',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1242",
    },
    {
        "broader": [1233],
        "id": 1236,
        "labels": [
            {
                "label": "Brandschuttungsgr\xe4ber",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "brandafvalgraven", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Brandschuttungsgrab is een graf waarbij de kuil met crematieresten (afzonderlijk ingezameld verbrand menselijk bot) niet werd opgevuld met schone grond, maar met verbrandingsresten. Hoewel een deel van het verbrande bot uit deze resten is geselecteerd, is een aanzienlijk deel achtergebleven tussen de verbrandingsresten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Hiddink H. 2003, Het grafritueel in de Late IJzertijd en Romeinse tijd in het Maas-Demer-Scheldegebied in het bijzonder van twee grafvelden bij Weert, Zuidnederlandse Archeologische Rapporten vol. 11.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1236",
    },
    {
        "broader": [142],
        "id": 1228,
        "labels": [{"label": "brandstapels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1226],
        "narrower": [1229],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brandstapel is een stapel brandbaar materiaal voor het verbranden van de doden als een begrafenisrite.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1228",
    },
    {
        "broader": [323],
        "id": 80,
        "labels": [
            {"label": "brandweerkazernes", "language": "nl-BE", "type": "prefLabel"},
            {"label": "brandweerarsenalen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brandweerkazerne is een uitvalsbasis van de brandweer. In de brandweerkazernes worden de brandweerwagens gestald en worden de dienstdoende brandweerlieden gehuisvest.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/80",
    },
    {
        "broader": [151],
        "id": 81,
        "labels": [
            {"label": "braskoten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "voederkeukens", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een braskot is een gebouw op een hoeve waar men bras bereidt. Bras is voedsel voor dieren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/81",
    },
    {
        "broader": [237],
        "id": 2087,
        "labels": [
            {"label": "brievenbussen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300003853"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brievenbus is een bus aan de openbare weg of in een postkantoor waarin men te verzenden brieven deponeert.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toevoegen term n.a.v. verwijderen term straatmeubilair.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal, 1994, Van Dale Lexicografie, Utrecht, Antwerpen.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2087",
    },
    {
        "broader": [1324],
        "id": 1325,
        "labels": [{"label": "briquetage", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Zoutwinning door middel van het verhitten van zeewater boven een vuur. Hiervoor gebruikt men schalen of kommen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Hendriks J. 1994, Prisma Archeologie in de Lage Landen, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1325",
    },
    {
        "broader": [1586],
        "id": 1588,
        "labels": [
            {"label": "broderieparterres", "language": "nl-BE", "type": "prefLabel"},
            {"label": "parterres de broderie", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een broderieparterre is een parterre dat hoofdzakelijk uit sierlijk aangeplante palmhaagjes bestaat.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1588",
    },
    {
        "broader": [1843],
        "id": 1921,
        "labels": [{"label": "broekbossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een broekbos is een loofbos aangeplant en/of spontaan ontwikkeld op een periodiek waterverzadigde bodem.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1921",
    },
    {
        "broader": [2033],
        "id": 83,
        "labels": [{"label": "bronnen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bron is een plaats waar een geconcentreerde, natuurlijke uitvloeiing van grondwater optreedt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: verplaatst van 'kunstmatige wateroppervlakken' naar 'grondwateruittredingen' bij integratie thesaurustermen landschappen. Sn aangepast; was voorheen: 'Een bron is een plaats waar water uit de grond opwelt.'",
                "type": "historyNote",
            },
        ],
        "related": [500],
        "sources": [
            {
                "citation": 'Objectencatalogus NGI: <a href="http://www.ngi.be/gdes/">http://www.ngi.be/gdes/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/83",
    },
    {
        "broader": [21],
        "id": 84,
        "labels": [
            {"label": "brouwerijen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "brouwhuizen", "language": "nl-BE", "type": "altLabel"},
            {"label": "kammen", "language": "nl-BE", "type": "altLabel"},
            {"label": "paanhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brouwerij is een industrieel of ambachtelijk gebouw waar bieren worden gebrouwen.",
                "type": "scopeNote",
            }
        ],
        "related": [79, 300, 85],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/84",
    },
    {
        "broader": [522],
        "id": 85,
        "labels": [
            {"label": "brouwerswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brouwerswoning is een woonhuis van een brouwer, meestal in de nabijheid van de brouwerij gelegen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [84, 119],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/85",
    },
    {
        "broader": [13],
        "id": 86,
        "labels": [{"label": "bruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een brug is een bouwwerk dat wegen of landschapselementen die het verkeer bemoeilijken, overspant.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Ook de lokalen waar de brugwachter toezicht houdt, maken deel uit van de bruginfrastructuur en worden opgenomen bij bruggen.",
                "type": "note",
            },
        ],
        "related": [959, 1016, 439],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [1485, 1486],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/86",
    },
    {
        "id": 1485,
        "labels": [
            {"label": "bruggen naar functie", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [841],
        "notes": [],
        "sources": [],
        "superordinates": [86],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1485",
    },
    {
        "id": 1486,
        "labels": [
            {"label": "bruggen naar vorm", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1487, 1488],
        "notes": [],
        "sources": [],
        "superordinates": [86],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1486",
    },
    {
        "broader": [1656],
        "id": 2195,
        "labels": [{"label": "bundelbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bundelboom is een bomengroep ontstaan door het ineen groeien van verschillende bomen die in eenzelfde plantgat zijn neergepoot, soms als onderdeel van een bosbouwkundig experiment of als verwijzing naar een bijzondere symboliek.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term toegevoegd bij revisie termen houtig erfgoed",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2195",
    },
    {
        "broader": [522],
        "id": 2175,
        "labels": [
            {"label": "bungalows", "language": "nl-BE", "type": "prefLabel"},
            {
                "label": "gelijkvloerse woningen",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005495"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bungalow is een (meestal) vrijstaande woning bestaande uit een enkele bouwlaag, met dag- en nachtgedeelte op de begane grond, eventueel met \xe9\xe9n kamer op een tweede woonlaag (semi-bungalow). Bungalows dateren vooral van na de Tweede Wereldoorlog.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: Toegevoegd bij integratie met termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2175",
    },
    {
        "broader": [1149],
        "id": 87,
        "labels": [{"label": "bunkers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Een bunker is een zwaar versterkte verdedigingsstelling, steeds met dikke betonnen wanden en gedeeltelijk in de grond ingegraven. De term "bunker" komt uit het Duits en werd voor het eerst toegepast in WO I.',
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'versterkte gebouwen'.",
                "type": "historyNote",
            },
        ],
        "related": [945, 710],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank; WIKI",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/87",
    },
    {
        "broader": [1371],
        "id": 88,
        "labels": [{"label": "burchten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een burcht is een middeleeuws versterkt gebouw of groep van gebouwen van een vorst of heer, meestal gelegen op een plaats die de omgeving en belangrijke land- of waterwegen beheersen of op een moeilijk bereikbare plaats. De nadruk bij een burcht ligt op de militaire functie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN aangepast. oorspronkelijk: \"Middeleeuwse versterkte woningen van vorsten of heren, meestal gelegen op plaatsen die de belangrijke land- of waterwegen van de omgeving beheersen of die moeilijk bereikbaar zijn.\"\n18/04/2011: BT gewijzigd van 'kastelen (woningen)' naar 'kastelen (verdedigingswerken)'",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'kastelen' voor de versterkte woonplaats van een heer waar de nadruk eerder op de residenti\xeble functie ligt.",
                "type": "note",
            },
        ],
        "related": [141, 99, 223, 293, 124],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/88",
    },
    {
        "broader": [522],
        "id": 89,
        "labels": [{"label": "burgerhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [825],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een burgerhuis is het woonhuis van bemiddelde burgers.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar vormelijk type\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [188, 409],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/89",
    },
    {
        "broader": [1171],
        "id": 1172,
        "labels": [{"label": "burgi", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een burgus is een wachtpost bestaande uit een toren met verdedigingswerken. Burgi verschenen vanaf de 2de eeuw als versterkings/controlepost langs wegen bij nederzettingen, waaronder villae, en waren vooral in de Laat-Romeinse periode wijd verspreid. Langs de Rijn verschenen al wachtposten in de 1ste eeuw.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "De Wit G. &amp; Sloos A. 2008, De interpretatie van archeologische waarnemingen in Archis. Een concept voor een nieuwe set complextypen, in: Rapportage Archeologische Monumentenzorg 165, Amersfoort.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1172",
    },
    {
        "broader": [485],
        "id": 755,
        "labels": [{"label": "bushokjes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/755",
    },
    {
        "broader": [1233],
        "id": 1235,
        "labels": [{"label": "bustumgraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een bustumgraf is een graf waarbij de brandstapel ter plaatse boven de open grafkuil opgericht wordt. Tijdens het branden stortte de stapel in de kuil; de grafkuil wordt dan ook steeds gekenmerkt door geblakerde wanden want het vuur bleef zeker nog een tijd branden en nasmeulen. Pas wanneer het geheel voldoende was afgekoeld kon het gecremeerd bot ingezameld worden of eventuele grafgiften in de kuil worden geplaatst. Busta zijn vrij zeldzaam in onze gewesten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1229],
        "sources": [
            {
                "citation": '1) Onderzoeksbalans <a href="http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving">http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1235",
    },
    {
        "broader": [881],
        "id": 91,
        "labels": [{"label": "caf\xe9s", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een caf\xe9 is een publieke gelegenheid waar drank geserveerd wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [187, 247, 423],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/91",
    },
    {
        "broader": [891],
        "id": 92,
        "labels": [
            {"label": "calvariebergen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Beeldengroepen bestaande uit Jezus aan het kruis en Maria en Johannes aan weerskanten. Veelal op een imitatie-rotsformatie geplaatst.",
                "type": "scopeNote",
            }
        ],
        "related": [513, 366],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/92",
    },
    {
        "broader": [],
        "id": 2054,
        "labels": [{"label": "cambisols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1855],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cambisol is een bodem met een beginnende profielontwikkeling, wat zich uit in het ontwikkelen van bodemstructuur en/of duidelijke verkleuring.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2054",
    },
    {
        "broader": [13],
        "id": 1502,
        "labels": [
            {"label": "captatiegalerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een captatiegalerij is een ondergrondse gemetselde constructie met gaten in de wanden voor de opvang en verzameling van grondwater uit watervoerende aardlagen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1502",
    },
    {
        "broader": [1555],
        "id": 1556,
        "labels": [{"label": "cascades", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006792"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cascade als tuinelement is een waterval waarbij het water trapsgewijs of van rots op rots valt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "1) Van Dale online 2) AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1556",
    },
    {
        "broader": [321],
        "id": 93,
        "labels": [{"label": "casino's", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een casino is een gebouw voor kansspelen. In de meest prestigieuze gokgelegenheden kan men eveneens dansen en algemeen verpozen, vaak met voorzieningen voor eten, drinken en muziek.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'In de "casino\'s" in de Mijnstreek, gebouwd door het mijnpatronaat, werden geen gokspelen beoefend; deze zijn opgenomen als ontspannings- en verenigingsgebouwen.',
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/93",
    },
    {
        "broader": [1161],
        "id": 1162,
        "labels": [
            {"label": "castella", "language": "nl-BE", "type": "prefLabel"},
            {"label": "castellum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een castellum is een Romeinse legerplaats voor de hulptroepen. Er verbleven zo'n 500 \xe0 1000 man. Castella werden onder andere langs de limes gebouwd. Een castellum was in feite een sterk verkleinde vorm van een castrum.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1162",
    },
    {
        "broader": [501],
        "id": 1199,
        "labels": [
            {"label": "castella aquae", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een castellum aquae is een Romeinse waterdistributiebouwwerk, meestal reservoir, dat is gebouwd op een plaats waar water dat is aangeleverd via een aquaduct naar verschillende punten in de stad wordt gestuurd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1199",
    },
    {
        "broader": [1161],
        "id": 1164,
        "labels": [
            {"label": "castra", "language": "nl-BE", "type": "prefLabel"},
            {"label": "castrum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een castrum is een permanent Romeins militair kampement opgezet volgens een rastervormig patroon; tijdens de middeleeuwen ook een aanduiding voor kastelen, forten of versterkte torens. De interne indeling van Romeinse castra is gestandaardiseerd. Vanaf de 4 poorten van het kamp liepen twee wegen, de via principalis en de via praetoria die loodrecht in het centrum van het fort sneden. Kleinere wegen verdeelden het fort verder in regelmatige blokken. Centraal binnen het fort lag de principia, het hoofdkwartier.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1164",
    },
    {
        "broader": [1150],
        "id": 1176,
        "labels": [
            {"label": "causewayed enclosures", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Causewayed enclosures komen meestal voor op heuveltoppen en worden omgeven door concentrische grachten en wallen. Dwars over deze grachten en wallen lopen over regelmatige afstanden causeways (verhoogde wegen). Ze komen voor in Frankrijk, Engeland, Belgi\xeb, Scandinavi\xeb, Duitsland, Itali\xeb, Ierland en Slowakije. Niet te verwarren met heuvelforten die tot een latere periode behoren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1177],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1176",
    },
    {
        "broader": [174],
        "id": 1261,
        "labels": [{"label": "cenotafen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cenotaaf is een leeg grafmonument ter ere van een dode wiens lijk men niet heeft of men elders begraven heeft.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1261",
    },
    {
        "broader": [151],
        "id": 1482,
        "labels": [
            {"label": "champignonkelders", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een champignonkelder is een kelder waarin champignons vanuit broed worden opgekweekt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1482",
    },
    {
        "broader": [1151],
        "id": 1188,
        "labels": [{"label": "chicanes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een chicane is een toegangsweg naar een vestingspoort of donjon, op zodanig geknikte of bochtige wijze aangelegd dat de aanvaller de poort niet rechtstreeks kon beschieten, doch zelf zo veel mogelijk aan beschieting werd blootgesteld.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1188",
    },
    {
        "broader": [440],
        "id": 1576,
        "labels": [
            {"label": "Chinese tuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Chinese tuin is een siertuin die hoofdzakelijk uit Chinese tuinelementen en planten is samengesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1576",
    },
    {
        "broader": [21],
        "id": 94,
        "labels": [
            {"label": "chocoladefabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een chocoladefabriek is een industrieel of ambachtelijk bedrijf waar men chocolade produceert en verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/94",
    },
    {
        "broader": [1526],
        "id": 95,
        "labels": [
            {"label": "Christusbeelden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [921],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Driedimensionale beelden van Jezus.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Enkel de Christusbeelden die voorkomen op plaatsen waar hun aanwezigheid niet logisch volgt uit de context, zijn opgenomen in de databank.",
                "type": "note",
            },
        ],
        "related": [184, 412, 507],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/95",
    },
    {
        "broader": [21],
        "id": 96,
        "labels": [
            {"label": "cichoreifabrieken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "suikerijfabrieken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cichoreifabriek is een industrieel bedrijf waar men cichorei roost en maalt tot een surrogaat voor koffie.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/96",
    },
    {
        "broader": [174],
        "id": 97,
        "labels": [{"label": "cippes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cippes is een blokvormig grafmonument, bekroond door gestyleerde acroteria op de hoeken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/97",
    },
    {
        "broader": [1033],
        "id": 1044,
        "labels": [
            {
                "label": "circulaire nederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1035],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een circulaire nederzetting is een nederzetting die zich straalsgewijs vanuit de kern heeft ontwikkeld.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.\n23/06/2015: BT gewijzigd (was 'agglomeraties')",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Tys D., Buyle E., Verdurmen I. &amp; Canters F. 2010, Vectorisering en karakterisering van nederzettingskernen op basis van het zgn. 'gereduceerd kadaster', SKAR-rapport 5, VUB.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1044",
    },
    {
        "broader": [321],
        "id": 98,
        "labels": [{"label": "circussen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een circus is een rond theater voor voorstellingen van acrobatie en dressuur.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/98",
    },
    {
        "broader": [1184],
        "id": 99,
        "labels": [
            {"label": "citadellen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "dwangburchten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een citadel is een zelfstandig verdedigbaar vestingwerk binnen of nabij een stad met het doel de inwoners van de stad in bedwang te houden of als laatste weerstandspunt na de val van de stad.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verblijfplaatsen voor militairen' naar 'vestingen'.",
                "type": "historyNote",
            },
        ],
        "related": [141, 88],
        "sources": [
            {
                "citation": 'Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005; Begrippenlijst van de Stichting Menno van Coehoorn (<a href="http://www.coehoorn.nl/">http://www.coehoorn.nl/</a>)',
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/99",
    },
    {
        "broader": [463],
        "id": 100,
        "labels": [{"label": "clubhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een clubhuis is een gebouw voor sport- of gezelligheidsverenigingen; het dient als uitvalsbasis voor hun activiteiten.",
                "type": "scopeNote",
            }
        ],
        "related": [207],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/100",
    },
    {
        "broader": [1603],
        "id": 1561,
        "labels": [
            {"label": "collectietuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [346, 1563],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een collectietuin is een tuin waarin plantenverzamelingen op systematische wijze zijn ondergebracht.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1561",
    },
    {
        "broader": [],
        "id": 1974,
        "labels": [
            {"label": "colluviale processen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een colluviaal proces is het proces waarbij geomorfologische elementen gevormd worden onder invloed van bodemerosie waarbij bodemmateriaal van een helling is afgespoeld en zich aan de voet van de helling accumuleert.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [2004],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1974",
    },
    {
        "broader": [359],
        "id": 102,
        "labels": [
            {"label": "commanderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een commanderij is een gebouw met bijhorende landerijen waar een commandeur van een geestelijke ridderorde zijn zetel had. Naast de commandeur woonden er soms ook broeders, waardoor de stichting de aard van een klooster kreeg.",
                "type": "scopeNote",
            }
        ],
        "related": [243],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/102",
    },
    {
        "broader": [2060],
        "id": 2061,
        "labels": [
            {
                "label": "compartimentenlandschappen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {
                "label": "moza\xefeklandschappen",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een compartimentenlandschap is een landschap bestaande uit een moza\xefek van open ruimten, zoals graslanden of akkers en dichte massa's, zoals bossen, vaak aangevuld met houtkanten en dreven waardoor een landschap ontstaat met afwisselende zichten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2061",
    },
    {
        "broader": [321],
        "id": 104,
        "labels": [{"label": "concertzalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een concertzaal is een gebouw voor publieke muziekuitvoeringen.",
                "type": "scopeNote",
            }
        ],
        "related": [181, 327, 429],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/104",
    },
    {
        "broader": [343],
        "id": 105,
        "labels": [
            {"label": "conci\xebrgewoningen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "portierswoningen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een conci\xebrgewoning is het woonhuis van een conci\xebrge. Conci\xebrges zijn personen die belast zijn met het toezicht op het gebouw, het toelaten van bezoekers, schoonmaak en kleine reparaties.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/105",
    },
    {
        "broader": [304],
        "id": 768,
        "labels": [
            {"label": "conservatoria", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/768",
    },
    {
        "broader": [21],
        "id": 107,
        "labels": [
            {"label": "conservenfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een conservenfabriek is een industrieel bedrijf waar men voedsel inblikt.",
                "type": "scopeNote",
            }
        ],
        "related": [79],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/107",
    },
    {
        "broader": [22],
        "id": 108,
        "labels": [
            {
                "label": "constructiewerkplaatsen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een constructiewerkplaats is een industrieel of ambachtelijk bedrijf waar metalen constructies en onderdelen gemonteerd en hersteld worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'nijverheidsgebouwen' naar 'gebouwen voor metaalverwerking'.",
                "type": "historyNote",
            },
        ],
        "related": [511],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/108",
    },
    {
        "broader": [323],
        "id": 109,
        "labels": [{"label": "consulaten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een consulaat is het hoofdkantoor van een consul. Consuls zijn vertegenwoordigers van de handelsbelangen van een ander land.",
                "type": "scopeNote",
            }
        ],
        "related": [11],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/109",
    },
    {
        "broader": [50],
        "id": 806,
        "labels": [{"label": "conventen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een convent is een gemeenschapshuis in het begijnhof, waar een groot aantal, minder gegoede begijnen een gemeenschappelijk onderkomen vond. Ook nieuwe begijnen brachten hun noviciaat door in een convent onder toezicht van een conventmeesteres.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "VAN AERSCHOT S. &amp; HEIRMAN M. 2001: Vlaamse begijnhoven, Werelderfgoed, Leuven",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/806",
    },
    {
        "broader": [440],
        "id": 1577,
        "labels": [
            {"label": "cottagetuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cottagetuin is een landelijke tuin voor nut en sier bij een cottage, meestal tot stand gekomen zonder tuinontwerp.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1577",
    },
    {
        "broader": [2060],
        "id": 2063,
        "labels": [
            {"label": "coulissenlandschappen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een coulissenlandschap is een landschap met veel ijle perceelsrandbegroeiingen zoals bomenrijen of houtkanten waardoor gefiltreerde zichten mogelijk zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2063",
    },
    {
        "broader": [],
        "id": 1744,
        "labels": [{"label": "crash sites", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1373],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een crash site is een plaats waar tijdens de Eerste of Tweede Wereldoorlog een vliegtuig is neergestort.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1744",
    },
    {
        "broader": [1227],
        "id": 1233,
        "labels": [
            {"label": "crematiegraven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "brandgraven", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1232],
        "narrower": [1235, 1236, 1237, 1242, 1243],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een crematiegraf is een graf waarin crematieresten zijn bijgezet. Crematie is in de Lage Landen een algemeen begrafenisritueel dat optreedt vanaf de middenbronstijd (ca. 1800 v.Chr.) en doorloopt tot in de vroege middeleeuwen. Bij de opkomst van het christendom wordt crematie volledig verdrongen, tot in de 20ste eeuw.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Ervynck A., Degryse P., Vandenabeele P. &amp; Verstraeten G. 2009, Natuurwetenschappen en archeologie. Methode en interpretatie, Leuven.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1233",
    },
    {
        "broader": [142],
        "id": 110,
        "labels": [{"label": "crematoria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1226],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een crematorium is een gebouw voor lijkverbranding.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'funerair erfgoed' naar 'funerair gerelateerde constructies'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/110",
    },
    {
        "broader": [],
        "id": 1091,
        "labels": [{"label": "crop marks", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1090],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een crop mark is een variatie in de kleur of groei van gewassen of andere vegetatie op het bodemoppervlak die een patroon vormt die de aanwezigheid van begraven muren, grachten of andere structuren kunnen aantonen. Crop marks worden gebruikt om op luchtfoto's archeologische sites op te sporen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1091",
    },
    {
        "broader": [147],
        "id": 2162,
        "labels": [
            {"label": "crypten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "krochten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004618"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1767],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een crypte is een ondergrondse ruimte onder het altaarhuis of volledige verdieping onder een kerk, die vaak als begraafplaats dient.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "12/11/2015: toegevoegd op vraag van DBES (Katrien C.)",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandstalige Art &amp; Architecture Thesaurus (<a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>)\n2) Haslinghuis E.J. &amp; Janse H. 1997: <em>Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie</em>, Leiden.',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2162",
    },
    {
        "broader": [1959],
        "id": 2024,
        "labels": [
            {"label": "cuestafronten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "cuestaflanken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cuestafront is een steilrand langs de steile zijde van een cuesta.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2024",
    },
    {
        "broader": [],
        "id": 2023,
        "labels": [{"label": "cuesta's", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cuesta is een langgerekte asymmetrische terreinverheffing die zijn ongelijkzijdigheid te danken heeft aan de aanwezigheid van zachthellende geologische lagen met afwisselende erosiegevoeligheid.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2023",
    },
    {
        "broader": [321],
        "id": 111,
        "labels": [
            {"label": "culturele centra", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cultureel centrum is een lokaal centrum voor culturele activiteiten, zoals tentoonstellingen, theatervoorstellingen en muziekuitvoeringen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/111",
    },
    {
        "broader": [888],
        "id": 1526,
        "labels": [
            {"label": "cultusbeelden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [95, 278, 184],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cultusbeeld is een beeld dat voorwerp is van godsdienstige verering.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1526",
    },
    {
        "broader": [359],
        "id": 1116,
        "labels": [
            {"label": "cultusplaatsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "heiligdommen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1117, 1118, 1119, 1121],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cultusplaats is een locatie waar de cultus van een bepaald niet-christelijk geloof beleefd wordt. Dit kan in open lucht zijn of in (een) gebouw(en). Het domein rond een tempel uit de Gallo-Romeinse periode wordt 'temenos' genoemd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1116",
    },
    {
        "broader": [],
        "id": 1072,
        "labels": [{"label": "cultuurlagen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [1073, 1074, 1076, 1077, 1078, 1079],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een cultuurlaag is een laag ontstaan door menselijke activiteit.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1072",
    },
    {
        "broader": [147],
        "id": 1792,
        "labels": [{"label": "daken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300002098"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1765],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dak is de overdekking van een gebouw of onderdeel ervan (inclusief het dakwerk en het geraamte), bestaande uit \xe9\xe9n of meer hellende vlakken of uit een horizontaal vlak.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.\n2) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1792",
    },
    {
        "broader": [150],
        "id": 965,
        "labels": [
            {"label": "dakpannenbakkerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dakpannenbakkerij is een fabriek/werkplaats waar dakpannen worden gemaakt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Term aangepast van 'dakpannenfabrieken' naar dakpannenbakkerijen' om archeologische toewijzingen mogelijk te maken.\n26/01/2011: SN toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/965",
    },
    {
        "broader": [440],
        "id": 1578,
        "labels": [{"label": "daktuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008131"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een daktuin is een terras op een vlak dak met beplanting in een aardlaag of in bakken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1578",
    },
    {
        "broader": [],
        "id": 1997,
        "labels": [{"label": "dalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [1998, 2000, 1999],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dal is een langgerekte, lager gelegen reli\xebfvorm.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1997",
    },
    {
        "broader": [2079],
        "id": 2080,
        "labels": [
            {
                "label": "dambordvormige ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dambordvormig ontginningspatroon bestaat uit vierkante blokken die van elkaar gescheiden worden door perceelsgrenzen die loodrecht op elkaar staan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2080",
    },
    {
        "broader": [923],
        "id": 1220,
        "labels": [{"label": "dammen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dam is een hindernis gelegen in een water bedoeld om de waterstroom te beperken, te controleren of tegen te houden (bv. om de waterspiegel te verhogen).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'dijken' voor hindernissen gelegen langsheen een water (rivier of zee) bedoeld om het achterliggende land te beschermen tegen overstroming.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1220",
    },
    {
        "broader": [321],
        "id": 113,
        "labels": [
            {"label": "dansgelegenheden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dansgelegenheid is een gebouw dat is ontworpen om er te dansen.",
                "type": "scopeNote",
            }
        ],
        "related": [139],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/113",
    },
    {
        "broader": [1149],
        "id": 1797,
        "labels": [
            {"label": "deep dug-outs", "language": "en-GB", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "en-GB",
                "markup": None,
                "note": "Een deep dug-out is een ondergrondse ruimte, uitgewerkt met zwaar constructiehout en bereikbaar via verschillende trappenconstructies die bedoeld is als slaap- en schuilplaats, hospitaal, militair hoofdkwartier,... Typisch in context van de Eerste Wereldoorlog.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1797",
    },
    {
        "broader": [889],
        "id": 803,
        "labels": [{"label": "dekenijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/803",
    },
    {
        "broader": [2030],
        "id": 2031,
        "labels": [
            {"label": "dekzandruggen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dekzandrug is een zandrug overwegend opgebouwd met tijdens de ijstijden (toendrastormen) afgezet dekzand, vaak op de overgang van toenmalige onbegroeide naar begroeide gebieden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2031",
    },
    {
        "broader": [153],
        "id": 1523,
        "labels": [
            {"label": "demarcatiepalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een demarcatiepaal is een gedenksteen die in Belgi\xeb en Frankrijk aangeeft tot waar het Duitse Westfront reikte tijdens de Eerste Wereldoorlog.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1523",
    },
    {
        "broader": [1389],
        "id": 1390,
        "labels": [
            {
                "label": "deposities van menselijke resten",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een depositie van menselijke resten omvat skeletresten die zonder zichtbare grafstructuur werden gedeponeerd. Deze kunnen voorkomen in een verscheidenheid aan contexten (bv. veenlijken, funderingsoffers,...).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1390",
    },
    {
        "broader": [],
        "id": 1992,
        "labels": [
            {"label": "depressies", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kommen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [1993, 1994, 1996, 2038],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een depressie is een ge\xefsoleerde, lager gelegen reli\xebfvorm (meestal kom- of schotelvormig) die volledig omringd is door hoger gelegen land.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1992",
    },
    {
        "broader": [147],
        "id": 2096,
        "labels": [{"label": "deuren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300002803"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1765],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een deur is een barri\xe8re om een deuropening af te sluiten die meestal leidt naar binnenruimtes of die scheiden.",
                "type": "scopeNote",
            }
        ],
        "related": [2095],
        "sources": [
            {
                "citation": "Nederlandse Art &amp; Architecture Thesaurus (AAT-NL)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2096",
    },
    {
        "broader": [932],
        "id": 1637,
        "labels": [{"label": "devotiebomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1605],
        "narrower": [1638, 1639],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een devotieboom is een devote aanplanting horende bij een religieus bouwkundig element of symbool.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1637",
    },
    {
        "broader": [24],
        "id": 114,
        "labels": [
            {"label": "diamantslijperijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een diamantslijperij is een ambachtelijk bedrijf waar men diamant slijpt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/114",
    },
    {
        "broader": [466],
        "id": 115,
        "labels": [
            {"label": "dierenasielen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dierenasiel is een gebouw voor de opvang van dieren, die (tijdelijk) geen eigenaar hebben.",
                "type": "scopeNote",
            }
        ],
        "related": [116, 892],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/115",
    },
    {
        "broader": [1227],
        "id": 1251,
        "labels": [{"label": "dierengraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1231],
        "narrower": [2166],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dierengraf is een graf waarin gecremeerde of ge\xefnhumeerde botresten van \xe9\xe9n of meer dieren werd geplaatst. De te onderscheiden hoofdgroepen zijn hier hondengraven en paardengraven.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1251",
    },
    {
        "broader": [321],
        "id": 1504,
        "labels": [{"label": "dierenparken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1507],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dierenpark is een afgesloten park waar al dan niet exotische dieren per aparte leefgroepen met beperkte vrijheid worden uitgezet.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1504",
    },
    {
        "broader": [321],
        "id": 116,
        "labels": [{"label": "dierentuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [776],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dierentuin is een tuin of park waar een verzameling al dan niet uitheemse dieren wordt gehouden.",
                "type": "scopeNote",
            }
        ],
        "related": [115, 892],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/116",
    },
    {
        "broader": [63],
        "id": 892,
        "labels": [
            {"label": "dierenverblijven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004963"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [131, 192, 411, 477],
        "notes": [],
        "related": [115, 116, 411],
        "sources": [],
        "subordinate_arrays": [1471],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/892",
    },
    {
        "broader": [923],
        "id": 1223,
        "labels": [{"label": "dijken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1490, 1491],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dijk is een opgeworpen wallichaam, dat het land tegen het buitenwater (zee of rivier) moet beschermen of dat een droge passage door een nat gebied mogelijk moet maken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.\n31/07/2014: SN gewijzigd bij integratie met landschapstermen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'dammen' voor hindernissen die gelegen zijn in een water met de bedoeling om het water tegen te houden (bv. om waterspiegel te verhogen).",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Baas, H., Mobach B. &amp; Renes H. 2005: Leestekens van het landschap, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1223",
    },
    {
        "broader": [522],
        "id": 119,
        "labels": [
            {"label": "directeurswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een directeurswoning is een woonhuis van directeurs of beheerders van onder meer inrichtingen, bedrijven of havens. Bij bedrijven kan het ook gaan om beheerders die in dienst zijn van de eigenaar.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.\n01/10/2014: '...onder meer scholen, inrichtingen, bedrijven of havens.' werd aangepast naar '...onder meer inrichtingen, bedrijven of havens.'",
                "type": "historyNote",
            },
        ],
        "related": [85],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/119",
    },
    {
        "broader": [526],
        "id": 899,
        "labels": [{"label": "dispensaria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/899",
    },
    {
        "broader": [21],
        "id": 121,
        "labels": [
            {"label": "distilleerderijen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "branderijen", "language": "nl-BE", "type": "altLabel"},
            {"label": "stokerijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een distilleerderij is een industrieel of ambachtelijk bedrijf waar men alcoholische dranken stookt.",
                "type": "scopeNote",
            }
        ],
        "related": [163],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/121",
    },
    {
        "broader": [323],
        "id": 801,
        "labels": [
            {"label": "districtshuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/801",
    },
    {
        "broader": [1966],
        "id": 2127,
        "labels": [{"label": "dode kreken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dode kreek is een kreek die niet langer onder getijdeninvloed staat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2127",
    },
    {
        "broader": [923],
        "id": 122,
        "labels": [{"label": "dokken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dok is een havenbassin met kade.",
                "type": "scopeNote",
            }
        ],
        "related": [947, 401, 534],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/122",
    },
    {
        "broader": [1779],
        "id": 1781,
        "labels": [
            {"label": "doksalen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "oksalen", "language": "nl-BE", "type": "altLabel"},
            {"label": "doxalen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300003788"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een doksaal is een hoge afsluiting tussen priesterkoor en lekenruimte waarop zich een kansel en tribune bevindt. Van deze plaats werden gezangen en gebeden gereciteerd.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1781",
    },
    {
        "broader": [466],
        "id": 2101,
        "labels": [
            {"label": "dokterspraktijken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900032157"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dokterspraktijk is een gebouw bestemd voor de uitoefening van medische en paramedische  beroepen.",
                "type": "scopeNote",
            }
        ],
        "related": [123],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2101",
    },
    {
        "broader": [522],
        "id": 123,
        "labels": [
            {"label": "dokterswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dokterswoning is het woonhuis van een dokter, meestal met praktijk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [2101],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/123",
    },
    {
        "broader": [1992],
        "id": 2038,
        "labels": [{"label": "dolines", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een doline is een ketel- of trechtervormige depressie ontstaan door instorting als gevolg van de oplossing van onderliggende kalksteen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2038",
    },
    {
        "broader": [],
        "id": 2113,
        "labels": [{"label": "domeinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1832],
        "narrower": [2114, 2115],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een domein is een economische nederzetting met een centrale eigendomsstructuur van een niet noodzakelijk aaneensluitend geheel van gebouwen en gronden  van een grootgrondbezitter die ook de ontginning bepaalde. De eigendomsstructuur kan in de loop van de tijd versnipperd zijn geraakt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2113",
    },
    {
        "broader": [522],
        "id": 1141,
        "labels": [{"label": "domus", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een domus is een Romeinse stadswoning.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1141",
    },
    {
        "broader": [1171],
        "id": 124,
        "labels": [{"label": "donjons", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een donjon is een zware toren als kern van een versterking. In oorsprong soms solitair op een motte of verhevenheid gelegen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "18/04/2011: BT gewijzigd van 'kastelen (woningen)' naar 'torens'",
                "type": "historyNote",
            },
        ],
        "related": [88, 141, 223, 1745, 293],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/124",
    },
    {
        "broader": [2003],
        "id": 2006,
        "labels": [{"label": "donken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een donk is een lage, ge\xefsoleerde heuvel in een vlakte, depressie of dal, daargaans bestaande uit zandig materiaal en uitstekend boven jongere kleiige, lemige of venige afzettingen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2006",
    },
    {
        "broader": [440],
        "id": 1580,
        "labels": [
            {"label": "doolhoven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "haagdoolhoven", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een doolhof is een kunstig aangelegde figuur met kronkelpaden tussen hoge heggen, die zo ingewikkeld zijn aangelegd dat de bezoeker er makkelijk in kan verdwalen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'labyrinten' voor dergelijke constructies waarin men niet kan verdwalen.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1580",
    },
    {
        "broader": [1997],
        "id": 1998,
        "labels": [
            {"label": "doorbraakdalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een doorbraakdal is een dal ontstaan na een (plaatselijke) doorbraak van een heuvel of een rug onder invloed van rivier- of smeltwatererosie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1980, 1977],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1998",
    },
    {
        "broader": [147],
        "id": 1788,
        "labels": [{"label": "dormitoria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900031987"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1785],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dormitorium is een slaapzaal van een klooster, meestal aan de oostkant van de pandgang gelegen. Het dormitorium ligt dicht naast het koor, liefst boven het calefactorium (stookzaal), maar ook wel boven de kapittelzaal. De zalen waren voorzien van schotten of gordijnen om afzonderlijke slaapplaatsen te cre\xebren die correspondeerden met een venster en een kleine muurkast.",
                "type": "scopeNote",
            }
        ],
        "related": [4, 243],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1788",
    },
    {
        "broader": [1033],
        "id": 1062,
        "labels": [{"label": "dorpen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1036],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Het onderscheid tussen dorp, gemeente en stad is betrekkelijk en varieert naar gelang de individuele, regionale context. Dorp is meestal een aanduiding voor een compacte nederzetting, die kan vari\xebren in grootte, maar meestal groter is dan een buurtschap en kleiner dan een gemeente, en die zich duidelijk onderscheidt van het landelijke gebied eromheen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Tys D., Buyle E., Verdurmen I. &amp; Canters F. 2010, Vectorisering en karakterisering van nederzettingskernen op basis van het zgn. 'gereduceerd kadaster', SKAR-rapport 5, VUB.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1062",
    },
    {
        "broader": [522],
        "id": 126,
        "labels": [
            {"label": "dorpswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dorpswoning is een bescheiden woonhuis in een dorp. In het Ancien R\xe9gime doorgaans van 1 bouwlaag, later ook van twee bouwlagen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar vormelijk type\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [409],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/126",
    },
    {
        "broader": [323],
        "id": 127,
        "labels": [
            {"label": "douanekantoren", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een douanekantoor is het kantoor van de douane, die de in- en uitvoer van goederen en het personenverkeer controleert.",
                "type": "scopeNote",
            }
        ],
        "related": [940, 1754],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/127",
    },
    {
        "broader": [522],
        "id": 1754,
        "labels": [
            {"label": "douanierswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een douanierswoning is de woning van een douane-beambte, meestal gelegen in de onmiddellijke omgeving van zijn werkterrein. Een douanier controleert het verkeer van mensen en goederen aan de grenzen.",
                "type": "scopeNote",
            }
        ],
        "related": [127],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1754",
    },
    {
        "broader": [931],
        "id": 1110,
        "labels": [
            {"label": "drenkplaatsen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1111],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een drenkplaats is een plaats waar men het vee laat drinken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1110",
    },
    {
        "broader": [1110],
        "id": 1111,
        "labels": [
            {"label": "drenkpoelen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "dobbe", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een drenkpoel is een ondiep stilstaand water waar men het vee laat drinken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1111",
    },
    {
        "broader": [1212],
        "id": 128,
        "labels": [{"label": "dreven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dreef is een al dan niet verharde weg met aan weerskanten een of meer aangeplante rijen bomen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'infrastructuur voor landverkeer' naar 'wegen'.",
                "type": "historyNote",
            },
        ],
        "related": [221],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/128",
    },
    {
        "broader": [933],
        "id": 129,
        "labels": [
            {"label": "driesen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "green", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dries is een gemene grond in gebruik als een gemeenschappelijke verzamel- en overnachtingsplaats voor het vee in een dorpskern en wordt gekenmerkt door de aanwezigheid van een poel. Ook bomen en hagen voor algemeen gebruik werden hier aangeplant. Later evolueerden driesen vaak tot dorpspleinen. De term is ontstaan uit de weidefunctie van het drieslagstelsel en leeft soms nog in die hoedanigheid als weide verder.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '26/01/2011: SN aangepast. Oorspronkelijk: "Gemeenschappelijke verzamel- en overnachtingsplaatsen voor het vee in dorpskernen, waar ook bomen en hagen voor algemeen gebruik werden aangeplant. Later evolueerden driesen vaak tot dorpspleinen."',
                "type": "historyNote",
            },
        ],
        "related": [347],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/129",
    },
    {
        "broader": [78],
        "id": 1442,
        "labels": [
            {"label": "drijvende werktuigen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een drijvend werktuig is een gespecialiseerd vaartuig zoals een bok, kraan, ponton, graanzuiger, ijsbreker of betonningsvaartuig.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1442",
    },
    {
        "broader": [1997],
        "id": 1999,
        "labels": [{"label": "droogdalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een droogdal is een dal, meestal beperkt in omvang, dat tijdens de ijstijden werd gevormd door het bovengronds afvoeren van (smelt)water op een bevroren ondergrond. Deze dalen zijn nu niet meer watervoerend.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1980],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1999",
    },
    {
        "broader": [923],
        "id": 947,
        "labels": [{"label": "droogdokken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een droogdok is een uitgegraven kom met sluizen bij een waterloop of de zee om schepen in te herstellen.",
                "type": "scopeNote",
            }
        ],
        "related": [122, 374],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/947",
    },
    {
        "broader": [2071],
        "id": 2072,
        "labels": [
            {"label": "droogmakerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een droogmakerij is een door een ringdijk begrensde ontwatering ontstaan na drooglegging van (een deel van) een natuurlijke watervlakte, waarbinnen het waterpeil kunstmatig en continu geregeld moet worden. Initieel gebeurde de bemaling door middel van poldermolens, later door pompgemalen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2072",
    },
    {
        "broader": [18],
        "id": 1284,
        "labels": [{"label": "droogovens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een droogoven is een oven die wordt gebruikt voor het drogen van timmerhout.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1100],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1284",
    },
    {
        "broader": [384],
        "id": 1475,
        "labels": [
            {"label": "druivenserres", "language": "nl-BE", "type": "prefLabel"},
            {"label": "druivenkassen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een druivenserre is een serre waarin tafeldruiven worden geteeld, ook als uitbouw aan een huis.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1475",
    },
    {
        "broader": [943],
        "id": 130,
        "labels": [{"label": "drukkerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een drukkerij is een industrieel of ambachtelijk bedrijf waar men drukwerk produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [449],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/130",
    },
    {
        "broader": [892],
        "id": 131,
        "labels": [{"label": "duifhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [918, 919],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een duifhuis is een constructie die is ingericht om duiven te houden. In of aan een gebouw of vrijstaand. Indien vrijstaand gaat het om constructies op een paal (duiventillen) of in de vorm van een toren (duiventorens).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/131",
    },
    {
        "broader": [2003],
        "id": 2007,
        "labels": [{"label": "duinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2019, 2020],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een duin is een heuvel(complex) ontstaan door opstuiving van door de wind aangevoerd zand (eolische reli\xebfvorm).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1975],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [2008, 2016],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2007",
    },
    {
        "id": 2008,
        "labels": [
            {"label": "duinen naar ligging", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [2009, 2014, 2015],
        "notes": [],
        "sources": [],
        "superordinates": [2007],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2008",
    },
    {
        "id": 2016,
        "labels": [
            {
                "label": "duinen naar verschijningsvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [2017, 2120],
        "notes": [],
        "sources": [],
        "superordinates": [2007],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2016",
    },
    {
        "broader": [1992],
        "id": 1996,
        "labels": [{"label": "duinpannen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een duinpan is een depressie in de duinen, ontstaan door verstuiving (uitwaaien) van het duinzand.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1996",
    },
    {
        "broader": [2030],
        "id": 2032,
        "labels": [
            {"label": "duinzandruggen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een duinzandrug is een zandrug overwegend opgebouwd met lokaal verstoven duinzand.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2032",
    },
    {
        "broader": [131],
        "id": 918,
        "labels": [{"label": "duiventillen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/918",
    },
    {
        "broader": [131],
        "id": 919,
        "labels": [{"label": "duiventorens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/919",
    },
    {
        "broader": [923],
        "id": 1932,
        "labels": [{"label": "dukdalven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007937"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een dukdalf is een in het water geplaatste constructie bestaande uit \xe9\xe9n of meerdere zware palen, meestal bestemd voor de bescherming tegen aanvaring van bruggen, sluizen, enz. of voor het aanleggen van vaartuigen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1932",
    },
    {
        "broader": [284],
        "id": 2182,
        "labels": [
            {"label": "duplexwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300112185"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een duplexwoning is een gebouw met \xe9\xe9n woning op de gelijkvloerse verdieping en \xe9\xe9n op de eerste verdieping, soms met de bedoeling om op termijn samengevoegd te worden tot \xe9\xe9n eengezinswoning. Meestal  opgericht in het kader van de woningnood na de Tweede Wereldoorlog.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2182",
    },
    {
        "broader": [147],
        "id": 1271,
        "labels": [
            {
                "label": "economische gebouwen en structuren",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [103, 328, 1307, 307],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1271",
    },
    {
        "broader": [1033],
        "id": 1053,
        "labels": [
            {
                "label": "economische nederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1034],
        "narrower": [1054, 1055, 1058, 2112],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1053",
    },
    {
        "broader": [892],
        "id": 1470,
        "labels": [
            {"label": "eendenhuisjes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1471],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een eendenhuisje is een verblijf voor eenden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1470",
    },
    {
        "broader": [237],
        "id": 132,
        "labels": [{"label": "eendenkooien", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Constructies, gedeeltelijk op het land en gedeeltelijk in het water, om wilde eenden te vangen. Vormen een geheel van bochtige, nauw uitlopende pijpen, omgeven door een haag of een omheining.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/132",
    },
    {
        "broader": [103],
        "id": 881,
        "labels": [
            {
                "label": "eet- en drinkgelegenheden",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300122175"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [91, 187, 214, 247, 287, 362, 423],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Term opgesplitst van 'horecazaken' naar 'eet- en drinkgelegenheden' en 'logeergelegenheden'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/881",
    },
    {
        "broader": [16],
        "id": 134,
        "labels": [
            {"label": "elektriciteitscabines", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een elektriciteitscabine is een gebouw waar elektrische middenspanning wordt omgezet in laagspanning alvorens die lokaal te distribueren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/134",
    },
    {
        "broader": [16],
        "id": 133,
        "labels": [
            {
                "label": "elektriciteitscentrales",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een elektriciteitscentrale is een gebouw waar men elektriciteit produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/133",
    },
    {
        "broader": [16],
        "id": 135,
        "labels": [
            {
                "label": "elektrische onderstations",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een elektrisch onderstation is een gebouw waar elektrische hoogspanning wordt omgezet in middenspanning alvorens die regionaal te distribueren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/135",
    },
    {
        "broader": [1059],
        "id": 2104,
        "labels": [
            {
                "label": "enkelvoudige pleinnederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een enkelvoudige pleinnederzetting is een pleinnederzetting waar de bebouwing is geconcentreerd rond \xe9\xe9n plein.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2104",
    },
    {
        "broader": [],
        "id": 1975,
        "labels": [
            {"label": "eolische processen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een eolisch proces is het proces waarbij geomorfologische elementen gevormd worden onder invloed van (krachtige) wind.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [2007, 2030, 2122, 2123],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1975",
    },
    {
        "broader": [932],
        "id": 1644,
        "labels": [
            {"label": "erfbeplantingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1756],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Erfbeplanting is beplanting die gesitueerd is binnen het erf.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1644",
    },
    {
        "broader": [893],
        "id": 136,
        "labels": [{"label": "erfpijlers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een erfpijler is een pijler die de toegang of de grens van een erf markeert.",
                "type": "scopeNote",
            }
        ],
        "related": [186],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/136",
    },
    {
        "broader": [1293],
        "id": 1294,
        "labels": [{"label": "ertswinning", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2102],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar een erts gewonnen is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1294",
    },
    {
        "broader": [1135],
        "id": 1136,
        "labels": [{"label": "erven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Een erf is het gebied direct om een huis of (met name) een boerderij. Ook de opstal zelf hoort bij het erf. De naam verwijst naar erfgoed, dat wat men kan erven. De term "zwervende erven" wordt gebruikt voor boerderijen die rondzwerven in een lokaal landschap waarbij de boerderij telkens weer opschoof naargelang de landbouwgrond uitgeput geraakte. Een zwervend erf omvat steeds een hoofdgebouw met enkele spijkertjes en bijgebouwen. Ze komen voor tijdens de bronstijd en de vroege - en middenijzertijd.',
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1136",
    },
    {
        "broader": [],
        "id": 1976,
        "labels": [
            {"label": "estuariene processen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een estuarien proces is het proces waarbijgeomorfologische elementen gevormd worden in een estuarium, dit is het mondingsgebied van een rivier onderhevig aan getijdewerking, waar het zoete rivierwater in contact treedt met het zoute zeewater en er dus een brak milieu heerst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1985, 2029],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1976",
    },
    {
        "broader": [1608],
        "id": 1611,
        "labels": [{"label": "etagebomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een etageboom is een boom waarvan alle gesteltakken in \xe9\xe9n horizontaal vlak of soms in meerdere horizontale vlakken worden geleid. Soms wordt de eerste etage ondersteund door een draagconstructie. In principe worden de loten, die zich ontwikkelen op de gesteltakken, jaarlijks teruggezet. Bij oudere bomen wordt het beheer soms uitgevoerd in kapcyclussen en is het beheer te vergelijken met dat van een gekandelaarde boom.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1611",
    },
    {
        "broader": [933],
        "id": 1115,
        "labels": [
            {"label": "executieplaatsen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een executieplaats is een locatie waar terechtstellingen werden uitgevoerd. Deze komen bijvoorbeeld voor tijdens de middeleeuwen in de vorm van galgen(velden/heuvels), maar ook in tijden van oorlog (Wereldoorlogexecutieplaatsen).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1115",
    },
    {
        "broader": [1040],
        "id": 1049,
        "labels": [
            {"label": "extractiekampen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "tijdelijke kampen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een extractiekamp is een niet-residentieel kamp. Deze werden niet gebruikt als woonplaats, maar wel als tijdelijke uitvalsbasis voor vuursteenbewerking, jacht, de ontginning van grondstoffen en soms het deels verwerken van de vangst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {"citation": "cursusmateriaal UGent (Prof. Ph. Cromb\xe9)", "markup": None}
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1049",
    },
    {
        "broader": [1293],
        "id": 1295,
        "labels": [
            {"label": "extractiekuilen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "ontginningskuilen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een extractiekuil is een kuil gevormd door het extraheren/ontginnen van grondstoffen uit de bodem.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Te gebruiken voor niet nader bepaalde ontginningskuilen.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1295",
    },
    {
        "broader": [884],
        "id": 137,
        "labels": [
            {"label": "fabrieksschoorstenen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fabriekschoorsteen is een hoog rookkanaal boven een stookplaats in een fabriek.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/137",
    },
    {
        "broader": [892],
        "id": 138,
        "labels": [
            {"label": "fazantenhokken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1471],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fazantenhok is een verblijf voor fazanten, eventueel met bijhorende ren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/138",
    },
    {
        "broader": [892],
        "id": 1601,
        "labels": [
            {"label": "fazantenrennen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1471],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fazantenren is een afgesloten loopplaats voor de opkweek van fazanten, al dan niet bij een fazantenhok.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Bij het toekennen van deze term ligt de nadruk op het belang van de ren en niet op het bijhorend hok. Als het hok van groter belang is dan de ren, ken dan de term 'fazantenhokken' toe.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "OE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1601",
    },
    {
        "broader": [321],
        "id": 139,
        "labels": [{"label": "feestzalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een feestzaal is een gebouw dat is ontworpen om er te feesten.",
                "type": "scopeNote",
            }
        ],
        "related": [113],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/139",
    },
    {
        "broader": [1308],
        "id": 1310,
        "labels": [
            {"label": "fermes indig\xe8nes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Ferme indig\xe8ne is een term ingevoerd vanuit de luchtfotografie om ge\xefsoleerde nederzettingen en boerderijen in het landschap aan te duiden. Archeologisch gaat het om omgrachte erven van bewoningen met een gecompartimenteerde structuur, waarin \xe9\xe9n hoofdgebouw en enkele bijgebouwen ingeplant zijn die tot \xe9\xe9n agrarische eenheid behoren. Ze komen vooral voor tijdens de late ijzertijd. Men moet dergelijke structuren ook bekijken in het kader van het latere romanisatieproces waarbij deze - letterlijk vertaald - inheemse boerderijen als tegenhangers en tegelijkertijd voorgangers kunnen gezien worden van de opkomende Romeinse villae.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'inheemse nederzettingen' voor dergelijke structuren die tot de Romeinse periode behoren. Let wel: het is vaak moeilijk een onderscheid te maken tussen wat ijzertijd is en wat Romeins bij inheemse structuren op het raakvlak van deze periodes.",
                "type": "note",
            },
        ],
        "related": [1068],
        "sources": [
            {
                "citation": "1) Roymans N. 1996, The sword or the plough. Regional dynamics in the romanisation of Belgic Gaul and the Rhineland area, in: N. Roymans (ed.), From the sword to the plough. Three studies on the earliest romanisation of Northern Gaul, Amsterdam Archaeological Studies 1, pp. 9-127. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1310",
    },
    {
        "broader": [932],
        "id": 1631,
        "labels": [
            {"label": "fetisjbomen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "koortsbomen", "language": "nl-BE", "type": "altLabel"},
            {"label": "lapjesbomen", "language": "nl-BE", "type": "altLabel"},
            {"label": "spijkerbomen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1605],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fetisjboom is een boom die vereerd wordt en waarvan men in de heilzame werking gelooft. Fetisjbomen worden ook al eens aangewend om iemand iets kwalijk toe te wensen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1631",
    },
    {
        "broader": [13],
        "id": 1503,
        "labels": [{"label": "filterhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een filterhuis is een gesloten constructie onder dak waar zand en leem kunnen bezinken zodat de waterleidingen niet kunnen verzanden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1503",
    },
    {
        "broader": [],
        "id": 1977,
        "labels": [
            {"label": "fluviatiele processen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fluviatiel proces is het proces waarbij geomorfologische elementen gevormd worden onder invloed van de eroderende werking van een natuurlijke waterloop (rivier of beek).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1989, 1991, 1993, 1994, 1998, 2000, 2028],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1977",
    },
    {
        "broader": [],
        "id": 2046,
        "labels": [{"label": "fluvisols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1855],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fluvisol is een bodem met weinig tot geen profielontwikkeling, gevormd in gebieden die regelmatig (en recent) overstromen of overstroomden, o.a. riviervalleien en getijdengebieden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2046",
    },
    {
        "broader": [1308],
        "id": 641,
        "labels": [{"label": "fokkerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [814],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fokkerij is een bedrijf waar dieren gefokt worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische complexen'.",
                "type": "historyNote",
            },
        ],
        "related": [438],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/641",
    },
    {
        "broader": [237],
        "id": 140,
        "labels": [{"label": "fonteinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300006179"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1524],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fontein is een bouwwerk of installatie met openingen die zijn bedoeld om water te laten spuiten of stromen. Soms ligt de nadruk op het sierlijke aspect (als ornament in een tuin, park of plein), soms is de primaire functie de voorziening van openbaar drinkwater.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'klein erfgoed' naar 'infrastructuur voor waterbevoorrading en -afvoer'.\n19/12/2014: SN aangepast; was \"Een fontein is een installatie om water met zekere kracht en sierlijkheid te laten opspuiten, doorgaans als ornament in een tuin of op een plein.\"",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'pompen' voor werktuigen met zwengel gebruikt om water op te pompen uit de grond.",
                "type": "note",
            },
        ],
        "related": [500],
        "sources": [
            {
                "citation": '1) Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005\n2) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>\n3) Onroerend Erfgoed',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/140",
    },
    {
        "broader": [1150],
        "id": 141,
        "labels": [
            {"label": "forten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "fortificaties", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1178, 1177],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fort is een permanente versterking voor troepen, gesloten en naar alle zijden verdedigbaar, vaak omringd door elementen als greppels, grachten en wallen en vaak gebruikt als uitvalsposten in of nabij vijandelijk gebied. Forten hebben een eigen garnizoen, maar geen burgerbevolking. Kleiner en minder zwaar versterkt dan 'vestingen'.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verblijfplaatsen voor militairen' naar 'versterkte sites'.\nSN uitgebreid. Oorspronkelijk: \"Zelfstandige, gesloten en naar alle zijden verdedigbare vestingwerken, met een eigen garnizoen maar zonder burgerbevolking.\"",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'vestingen' voor militaire constructies die groter en zwaarder versterkt zijn dan forten.",
                "type": "note",
            },
        ],
        "related": [88, 99, 1184, 1793, 124],
        "sources": [
            {
                "citation": '1) Begrippenlijst van de Stichting Menno van Coehoorn (<a href="http://www.coehoorn.nl/">http://www.coehoorn.nl/</a>)\n2) Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/141",
    },
    {
        "broader": [932],
        "id": 1636,
        "labels": [{"label": "fruitbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1605],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een fruitboom is een veredelde boom die eetbare vruchten voortbrengt.",
                "type": "scopeNote",
            }
        ],
        "related": [73],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1636",
    },
    {
        "broader": [317],
        "id": 792,
        "labels": [{"label": "fruitmuren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1517, 1518],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Bakstenen, al dan niet witgeschilderde muren, in de regel ter afscherming van moestuinen en die bestemd zijn om leifruit tegen te kweken.",
                "type": "scopeNote",
            }
        ],
        "related": [295, 73],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/792",
    },
    {
        "broader": [1082],
        "id": 1084,
        "labels": [
            {"label": "funderingsgreppels", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een funderingsgreppel is een greppel gegraven om ruimte te voorzien voor de fundering van een gebouw of andere constructie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [1076],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1084",
    },
    {
        "broader": [1072],
        "id": 1076,
        "labels": [
            {"label": "funderingslagen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een funderingslaag is een laag aangelegd voor de fundering van een constructie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [1084],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1076",
    },
    {
        "broader": [142],
        "id": 174,
        "labels": [
            {
                "label": "funeraire constructies",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            40,
            97,
            170,
            171,
            172,
            173,
            175,
            352,
            366,
            370,
            414,
            532,
            879,
            1261,
            1268,
            1269,
            1270,
            1794,
        ],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gedenktekens op graven.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: PT gewijzigd van 'grafmonumenten' naar 'funeraire constructies' vanwege geladen betekenis van 'monumenten'.",
                "type": "historyNote",
            },
        ],
        "related": [153],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/174",
    },
    {
        "broader": [147],
        "id": 142,
        "labels": [
            {
                "label": "funeraire gebouwen en structuren",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1227, 174, 54],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: BT van 'funerair erfgoed' gewijzigd van 'onroerend erfgoed' naar 'gebouwen en structuren'.\n'funerair erfgoed' gewijzigd naar 'funeraire gebouwen en structuren'",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [1226],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/142",
    },
    {
        "broader": [1393],
        "id": 1399,
        "labels": [
            {
                "label": "funeraire, rituele en religieuze objecten",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Wordt algemeen gebruikt voor voorwerpen die worden geassocieerd met of gebruikt bij rituelen, en in het geval van funeraire objecten, rituelen met betrekking tot begraven en cremeren. Hieronder vallen objecten zoals pelgrimsinsignes, wierookbranders, amuletten, grafstenen, altaren, maar ook deze objecten die aan de hand van hun specifieke context als ritueel/religieus/funerair kunnen bestempeld worden, hoewel ze in een andere context een ander gebruik hebben (bv. als wapen).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1399",
    },
    {
        "id": 1226,
        "labels": [
            {
                "label": "funerair gerelateerde constructies",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1228, 110, 143, 269, 331],
        "notes": [],
        "sources": [],
        "superordinates": [142],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1226",
    },
    {
        "broader": [142],
        "id": 143,
        "labels": [{"label": "funeraria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1226],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een funerarium is een gebouw waar overledenen worden opgebaard en gegroet, in afwachting van de begrafenis of crematie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'funerair erfgoed' naar 'funerair gerelateerde constructies'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/143",
    },
    {
        "broader": [27],
        "id": 2179,
        "labels": [
            {"label": "galerijflatgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004843"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een galerijflatgebouw is een appartementsgebouw met ontsluiting en circulatie via een galerij, al dan niet beglaasd, en al dan niet per twee of drie verdiepingen (respectievelijk duplex- en triplexgalerijen). Wanneer de functie van deze galerijen niet enkel ontsluiting en circulatie omvat, worden deze ook aangeduid als streets-in-the-air.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting",
                "type": "historyNote",
            },
        ],
        "related": [521],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2179",
    },
    {
        "broader": [894],
        "id": 144,
        "labels": [
            {"label": "garagebedrijven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een garagebedrijf is een bedrijf waar men herstellingen aan auto's en andere motorvoertuigen uitvoert.",
                "type": "scopeNote",
            }
        ],
        "related": [145],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/144",
    },
    {
        "broader": [63],
        "id": 145,
        "labels": [{"label": "garages", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een garage is een vrijstaande overdekte stalling voor motorvoertuigen van bewoners",
                "type": "scopeNote",
            }
        ],
        "related": [144, 336],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/145",
    },
    {
        "broader": [16],
        "id": 146,
        "labels": [
            {"label": "gasfabrieken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "gashouders", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gasfabriek is een industrieel bedrijf waar men gas produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/146",
    },
    {
        "broader": [886],
        "id": 1124,
        "labels": [{"label": "gasthuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [166, 1125],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gasthuis is oorspronkelijk een huis dat ter opvang en verpleging van gasten is ingericht. In deze betekenis is het reeds in de 17de eeuw verouderd, en ge\xebvolueerd naar twee types, nl.: het Godshuis ('h\xf4tel-Dieu', dat evolueert naar 'hospice') waar het accent ligt op het opvangen van ouden van dagen, wezen &amp; weduwen, en het hospitaal ('h\xf4pital') waar het accent ligt op de ziekenverzorging en dat evolueert naar het ziekenhuis.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.\n27/04/2011: scopenote opgemaakt door LM",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1124",
    },
    {
        "broader": [1617],
        "id": 1620,
        "labels": [
            {"label": "geboortebomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een geboorteboom is een boom die als symbolische handeling geplant wordt bij de geboorte van een kind.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1620",
    },
    {
        "broader": [1541],
        "id": 367,
        "labels": [
            {"label": "gebouwde ru\xefnes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gebouwde ru\xefne is een tuinelement dat als ru\xefne geconcipieerd en gebouwd is en als ru\xefne wordt onderhouden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/367",
    },
    {
        "broader": [],
        "id": 147,
        "labels": [
            {
                "label": "gebouwen en structuren",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300265418"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [142, 1271, 63, 323, 359, 319, 466, 321, 13, 293, 520],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: 'bouwkundig erfgoed' werd gewijzigd naar 'gebouwen en structuren' bij integratie met termen voor archeologisch erfgoed",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [1765],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/147",
    },
    {
        "broader": [24],
        "id": 212,
        "labels": [
            {
                "label": "gebouwen en structuren voor de productie van kalk en cement",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [754, 1289, 700],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Industri\xeble of ambachtelijke bedrijven die kalk en/of cement produceren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Term aangepast van 'kalk- en cementfabrieken' naar 'gebouwen en structuren voor de productie van kalk en cement' om het toewijzen van archeologische termen mogelijk te maken.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/212",
    },
    {
        "broader": [24],
        "id": 149,
        "labels": [
            {
                "label": "gebouwen en structuren voor fijnkeramische nijverheid",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [964, 812, 1285],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Industri\xeble of ambachtelijke bedrijven die aardewerk en porselein produceren.",
                "type": "scopeNote",
            }
        ],
        "related": [150],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/149",
    },
    {
        "broader": [24],
        "id": 1287,
        "labels": [
            {
                "label": "gebouwen en structuren voor glasproductie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1288, 164],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1287",
    },
    {
        "broader": [24],
        "id": 150,
        "labels": [
            {
                "label": "gebouwen en structuren voor grofkeramische nijverheid",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [965, 817, 1286, 1283],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Industri\xeble of ambachtelijke bedrijven die bakstenen, dakpannen en greswaren produceren. Gres is dichtgesinterd aardewerk van vette klei, dat onder meer gebruikt werd voor rioolbuizen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Term uitgebreid van 'gebouwen voor grofkeramische nijverheid' naar 'gebouwen en structuren voor grofkeramische nijverheid'.",
                "type": "historyNote",
            },
        ],
        "related": [149],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/150",
    },
    {
        "broader": [307],
        "id": 22,
        "labels": [
            {
                "label": "gebouwen en structuren voor metaalbe- en verwerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300122139"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [108, 288, 390, 1280, 1281, 1282],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Term aangepast van 'gebouwen voor metaalverwerking' naar 'gebouwen en structuren voor metaalbe- en verwerking'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/22",
    },
    {
        "broader": [307],
        "id": 1417,
        "labels": [
            {
                "label": "gebouwen en structuren voor petroleumnijverheid",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen en structuren voor petroleumnijverheid zijn gebouwen en structuren (zoals pijpleidingen, opslagtanks) die opgericht zijn in functie van het proces van petroleumtransport, -opslag en -raffinage.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Toegeveoegd door LM op 14/07/2011 naar aanleiding van inventarisatie van de site Petroleum-Zuid te Antwerpen. Scope-Note opgemaakt in overleg met Frank Becuwe.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1417",
    },
    {
        "broader": [307],
        "id": 21,
        "labels": [
            {
                "label": "gebouwen en structuren voor voedings- en genotsmiddelenproductie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            36,
            39,
            79,
            84,
            94,
            96,
            107,
            121,
            163,
            201,
            246,
            274,
            300,
            316,
            341,
            386,
            416,
            419,
            421,
            471,
            474,
            494,
            533,
            941,
            1764,
            1292,
        ],
        "notes": [],
        "related": [35, 199],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/21",
    },
    {
        "broader": [307],
        "id": 14,
        "labels": [
            {
                "label": "gebouwen, structuren en indicaties voor delfstofwinning",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1008, 1293],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Term aangepast van 'gebouwen en constructies voor delfstofwinning' naar 'gebouwen, structuren en indicaties voor delfstofwinning'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/14",
    },
    {
        "broader": [103],
        "id": 894,
        "labels": [
            {
                "label": "gebouwen van dienstverlenende bedrijven",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300129541"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [144, 198, 219, 493],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/894",
    },
    {
        "broader": [307],
        "id": 15,
        "labels": [
            {
                "label": "gebouwen voor chemische nijverheid",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300253852"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [210, 270, 464, 524, 907],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/15",
    },
    {
        "broader": [103],
        "id": 887,
        "labels": [
            {
                "label": "gebouwen voor financi\xeble instellingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005213"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [43, 61],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/887",
    },
    {
        "broader": [1271],
        "id": 103,
        "labels": [
            {
                "label": "gebouwen voor handel en dienstverlening",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005147"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1272, 215, 306, 162, 894, 887, 885, 881],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'gebouwen en structuren' naar 'economische gebouwen en structuren'.\nTerm gewijzigd van 'gebouwen voor handel en economie' naar 'gebouwen voor handel en dienstverlening'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/103",
    },
    {
        "broader": [307],
        "id": 18,
        "labels": [
            {
                "label": "gebouwen voor hout- en papiernijverheid",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": ["http://vocab.getty.edu/aat/300006304"],
            "related": [],
        },
        "member_of": [],
        "narrower": [75, 194, 220, 239, 252, 276, 289, 380, 487, 1284, 335],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/18",
    },
    {
        "broader": [307],
        "id": 24,
        "labels": [
            {
                "label": "gebouwen voor nijverheid i.v.m. minerale producten",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1287, 212, 150, 114, 149, 413, 1324],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/24",
    },
    {
        "broader": [319],
        "id": 152,
        "labels": [
            {
                "label": "gebouwen voor secundair onderwijs",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [733, 738],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen voor onderwijs verstrekt aan leerlingen tussen 12 en 18 jaar, zowel algemeen (ASO) als technisch (TSO), beroeps- (BSO) en kunstonderwijs (KSO).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/152",
    },
    {
        "broader": [307],
        "id": 20,
        "labels": [
            {
                "label": "gebouwen voor textiel- en lederwarenproductie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            716,
            1290,
            268,
            66,
            209,
            227,
            378,
            394,
            428,
            465,
            432,
            448,
            472,
            512,
            519,
            527,
            1366,
        ],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/20",
    },
    {
        "broader": [],
        "id": 1102,
        "labels": [
            {"label": "gebouwplattegronden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gebouwplattegrond is een geheel van een aantal grondsporen die samen toelaten een reconstructie van een structuurplattegrond te maken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1102",
    },
    {
        "broader": [237],
        "id": 153,
        "labels": [{"label": "gedenktekens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [322, 1523],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Vrijstaande monumenten of ingemetselde platen om gebeurtenissen of personen te gedenken.",
                "type": "scopeNote",
            }
        ],
        "related": [174],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/153",
    },
    {
        "broader": [1608],
        "id": 2197,
        "labels": [
            {
                "label": "ge\xebnte bomen en struiken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ge\xebnte boom of struik is een kunstmatig gevormde boom of struik waarbij de onderstam op een bepaalde hoogte is vastgemaakt en nadien vergroeid is met het bovenstaand gewas, vaak ter verbetering (veredeling) van de boom of struik. Er bestaan verschillende enttechnieken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2197",
    },
    {
        "broader": [2007],
        "id": 2020,
        "labels": [
            {"label": "gefixeerde duinen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "niet-actieve duinen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gefixeerde duin is een duin(complex) met een aaneengesloten begroeiing waardoor het zand momenteel niet meer verstuift.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '- Objectencatalogus NGI: <a href="http://www.ngi.be/gdes/">http://www.ngi.be/gdes/</a>\n- agentschap Onroerend Erfgoed',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2020",
    },
    {
        "broader": [466],
        "id": 154,
        "labels": [
            {
                "label": "gehandicapteninstellingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gehandicapteninstelling is een gebouw voor de opvang en verzorging van motorisch of mentaal gehandicapten.",
                "type": "scopeNote",
            }
        ],
        "related": [204, 357, 644],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/154",
    },
    {
        "broader": [1033],
        "id": 1063,
        "labels": [{"label": "gehuchten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1036],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gehucht is een klein landelijke centrum dat beschikt over elementaire algemene voorzieningen en voorzieningen op het gebied van onderwijs en godsdienst, maar meestal niet meer dan 250 inwoners telt; kan ook verwijzen naar de kleinste opgenomen eenheden in een gemeentelijk bestuur.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Tys D., Buyle E., Verdurmen I. &amp; Canters F. 2010, Vectorisering en karakterisering van nederzettingskernen op basis van het zgn. 'gereduceerd kadaster', SKAR-rapport 5, VUB.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1063",
    },
    {
        "broader": [1608],
        "id": 1609,
        "labels": [
            {"label": "gekandelaarde bomen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kandelaber", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gekandelaarde boom is een boom waarvan alle gesteltakken op een bepaalde lengte worden afgezet en die hierop opnieuw uitlopen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1609",
    },
    {
        "broader": [1671],
        "id": 1672,
        "labels": [
            {"label": "gekruiste hagen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gekruiste haag is een geschoren haag die ondoordringbaar wordt gemaakt door alle uitgeselecteerde twijgen, meestal van bij het tijdstip van aanplanten en vaak ook daarna, kruiselings in te vlechten, waarbij natuurlijke verenting werd beoogd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term aangepast van kruishagen naar gekruiste hagen. SN aangepast.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1672",
    },
    {
        "broader": [1671],
        "id": 1674,
        "labels": [
            {"label": "gelegde hagen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "geleide hagen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gelegde haag is een veekering waarbij de haag voor het vee ondoordringbaar wordt gemaakt door, meestal na verjonging van de haag, alle uitgeselecteerde twijgen in dezelfde richting schuin te leiden. Om de twijgen te kunnen ombuigen werden ze aan de basis verzwakt door ze gedeeltelijk door te kappen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1674",
    },
    {
        "broader": [1207],
        "id": 156,
        "labels": [{"label": "gemakhuisjes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gemakshuisje is een bijgebouw bij een woonhuis dat dient als toilet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'bijgebouwen' naar 'toiletten'.",
                "type": "historyNote",
            },
        ],
        "related": [1207, 324],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/156",
    },
    {
        "broader": [923],
        "id": 157,
        "labels": [{"label": "gemalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [956, 1492],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gemaal is een installatie voor het kunstmatig ontlasten van overtollig water van polders.",
                "type": "scopeNote",
            }
        ],
        "related": [189, 297],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/157",
    },
    {
        "broader": [321],
        "id": 2168,
        "labels": [
            {"label": "gemeenschapslokalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gemeenschapslokaal is een gebouw voor de behartiging van de sociaal-culturele belangen van een dorps- of wijkgemeenschap.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>\n2) Van Dale groot woordenboek (1994)',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2168",
    },
    {
        "broader": [323],
        "id": 158,
        "labels": [
            {"label": "gemeentehuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gemeentehuis is een gebouw waarin het bestuur en (doorgaans) de administratie van een gemeente is ondergebracht en waar zich de raadszalen en het kantoor van de burgemeester bevinden.",
                "type": "scopeNote",
            }
        ],
        "related": [376, 402, 8],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/158",
    },
    {
        "broader": [1841],
        "id": 1845,
        "labels": [
            {"label": "gemengde bossen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1842],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gemengd bos is een bos bestaand uit een mengvorm van naald- en loofbossen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1845",
    },
    {
        "broader": [237],
        "id": 159,
        "labels": [
            {"label": "geodetische punten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Elementen die vaste punten binnen een geodetisch net markeren. Aan de hand van geodetische punten meet men afstanden om een terrein in kaart te brengen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/159",
    },
    {
        "broader": [],
        "id": 2039,
        "labels": [
            {
                "label": "geologische ontsluitingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een geologische ontsluiting is een plaats waar minstens \xe9\xe9n ondergrondse bodem- of geologische laag of een geomorfologisch verschijnsel zichtbaar is, zoals in een groeve, bouwput of steile beek- of rivieroever. Geologische ontsluitingen maken het mogelijk om een onder normale omstandigheden onzichtbaar geologisch verschijnsel toch waar te nemen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2039",
    },
    {
        "id": 1859,
        "labels": [
            {
                "label": "geomorfologische elementen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1857],
        "members": [
            1982,
            1992,
            1997,
            2002,
            2003,
            2022,
            2023,
            2027,
            2037,
            2125,
            1962,
            1967,
            1968,
            2033,
            2035,
            2036,
            2039,
            1959,
        ],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1859",
    },
    {
        "id": 1857,
        "labels": [
            {
                "label": "geomorfologische elementen en processen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1858, 1859],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1857",
    },
    {
        "id": 1858,
        "labels": [
            {
                "label": "geomorfologische processen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1857],
        "members": [1974, 1975, 1976, 1978, 1979, 1980, 1981, 1977, 2147],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1858",
    },
    {
        "broader": [932],
        "id": 1630,
        "labels": [
            {"label": "gerechtsbomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1605],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gerechtsboom is een boom aangeplant op de plaats waar zich een vierschare of schepenbank bevond. Dit is de plaats waar recht werd gesproken tijdens het Ancien R\xe9gime, in Vlaanderen ca. v\xf3\xf3r 1795.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1630",
    },
    {
        "broader": [323],
        "id": 160,
        "labels": [
            {"label": "gerechtsgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [718, 1123],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gerechtsgebouw is een gebouw waar recht wordt gesproken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/160",
    },
    {
        "broader": [1841],
        "id": 1928,
        "labels": [
            {"label": "geriefhoutbossen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1846],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een geriefhoutbos is een bos van beperkte omvang, doorgaans op of bij een boerenerf, oorspronkelijk gebruikt voor kleinschalige houtwinning, voornamelijk ten behoeve van nieuwe of te herstellen handgereedschappen, werktuigen, afsluitingen, vlechtwerken,\u2026).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1928",
    },
    {
        "broader": [1608],
        "id": 1671,
        "labels": [
            {"label": "geschoren hagen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "scheerhagen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1674, 1676, 1672],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een geschoren haag is een beplantingsvorm waarbij heester- of boomsoorten op zeer korte afstand van elkaar worden geplant in \xe9\xe9n of meerdere rijen en die \xe9\xe9n of meerdere keren per jaar wordt geschoren. Er zijn verschillende technieken ontwikkeld om de haag ondoordringbaar te maken of om het gat in de haag te dichten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: BT aangepast van 'hagen naar beheersvorm'",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1671",
    },
    {
        "broader": [190],
        "id": 1420,
        "labels": [
            {"label": "gesloten hoeven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1418],
        "narrower": [1425],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gesloten hoeve is een hoeve waarvan de diverse bestanddelen haaks op elkaar aansluiten waardoor een vierkante of rechthoekige plattegrond ontstaat met centraal een afgesloten binnenplaats.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Toegevoegd op 07/10/2011 na overleg op inventariswerkgroep en met Sophie Mortier (LM)\nOp 05/01/2012 gewijzigd van "vierkantshoeven" naar "gesloten hoeven", met "vierkantshoeven" als NT.(LM)',
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1420",
    },
    {
        "broader": [],
        "id": 2064,
        "labels": [
            {"label": "gesloten landschappen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1848],
        "narrower": [2065],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gesloten landschap is een landschap met veel perceelsrandbegroeiingen en/of bossen waardoor het zicht steeds beperkt wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2064",
    },
    {
        "broader": [1963],
        "id": 1964,
        "labels": [
            {"label": "getijdenrivieren", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een getijdenrivier is het gedeelte van een rivier dat onder getijdeninvloed.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1964",
    },
    {
        "broader": [323],
        "id": 161,
        "labels": [
            {"label": "gevangenissen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "tuchthuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gevangenis is een gebouw waar veroordeelden een celstraf uitzitten. Tijdens de middeleeuwen werden hier niet enkel misdadigers opgesloten in afwachting van een proces, maar ook schuldenaars, mentaal gehandicapten en oorlogsgevangenen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '27/01/2011: SN aangepast. Oorspronkelijk: "Gebouwen waar veroordeelden een celstraf uitzitten."',
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) Troubleyn L. e.a. 2009, Consumption patterns and living conditions inside Het Steen, the late medieval prison of Malines (Mechelen, Belgium), in: Journal of archaeology in the Low Countries Vol. 1, nr. 2, pp. 5-47.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/161",
    },
    {
        "broader": [901],
        "id": 1021,
        "labels": [
            {"label": "gevelniskapellen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Specifieke vormen van niskapellen, ingewerkt in de gevel van een woonhuis, stal of schuur; respectievelijk ter bescherming van de bewoners, het vee of de oogst. Vaak wordt het beeld afgeschermd door glas of doorzichtige kunststof.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31 maart 2010: term en scope-note toegevoegd.\n25/02/2016: SN aangevuld met afscherming.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1021",
    },
    {
        "broader": [147],
        "id": 1791,
        "labels": [{"label": "gevels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300076168"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1765],
        "narrower": [2095],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gevel is een muur die zichtbaar is aan de buitenkant van een gebouw. Er wordt gesproken van voorgevel, zijgevel, achtergevel.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1791",
    },
    {
        "broader": [1671],
        "id": 1676,
        "labels": [
            {"label": "gevlochten hagen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vlechthagen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gevlochten haag is een bij veekeringen en erfafsluitingen toegepaste techniek waarbij zijtakken van het haagplantsoen zijwaarts in de haag worden gevlochten om het gat in de haag te dichten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1676",
    },
    {
        "broader": [22],
        "id": 1280,
        "labels": [{"label": "gieterijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gieterij is een complex/werkplaats waar metalen omgesmolten worden en tot voorwerpen worden gegoten. Een klokkengieterij is een werkplaats waar klokken worden geproduceerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1280",
    },
    {
        "broader": [103],
        "id": 162,
        "labels": [
            {"label": "gildehuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "ambachtsgebouwen", "language": "nl-BE", "type": "altLabel"},
            {"label": "hanzehuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gildehuis is een gebouw waar beroepsverenigingen uit het ancien r\xe9gime, zoals ambachten en gilden, hun bijeenkomsten hielden.",
                "type": "scopeNote",
            }
        ],
        "related": [306, 463],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/162",
    },
    {
        "broader": [21],
        "id": 163,
        "labels": [
            {
                "label": "gist- en spiritusfabrieken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gist- en spiritusfabriek is een industrieel bedrijf waar men gist produceert en/of waar men brandspiritus distilleert uit alcohol.",
                "type": "scopeNote",
            }
        ],
        "related": [121],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/163",
    },
    {
        "broader": [1151],
        "id": 1189,
        "labels": [{"label": "glacis", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een glacis is het terrein rondom vestingwerken dat met een dergelijke hellingsgraad loopt dat de aanvallers de verdedigers niet kunnen beschieten, maar zelf wel blootstaan aan het geschut van de verdediging. Achter de glacis lag een verborgen weg ('bedekte weg') waarlangs de verdediging zijn troepen kon bewegen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht. 2) RE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1189",
    },
    {
        "broader": [1287],
        "id": 1288,
        "labels": [
            {"label": "glasblazerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een glasblazerij is een ambachtelijke werkplaats waar glas wordt geblazen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1288",
    },
    {
        "broader": [1287],
        "id": 164,
        "labels": [
            {"label": "glasfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een glasfabriek is een industrieel of ambachtelijk bedrijf waar men glas maakt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT is gewijzigd van 'gebouwen voor nijverheid ivm minerale producten' naar 'gebouwen en structuren voor glasproductie'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/164",
    },
    {
        "broader": [],
        "id": 2047,
        "labels": [{"label": "gleysols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1853],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gleysol is een bodem met een sterk schommelende grondwatertafel op geringe diepte. Deze bodems vertonen typische \u2018gley\u2019verschijnselen: rood/bruin/gele \u2018spikkels\u2019 ingevolge oxiderende omstandigheden en grijsblauwe stippels ingevolge reduceerde omstandigheden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2047",
    },
    {
        "broader": [1124],
        "id": 166,
        "labels": [
            {"label": "godshuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "armenhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een godshuis is een liefdadigheidsinstelling, opgericht ter ere van God, waar armen (bejaarden, wezen, weduwen) opgevangen en verzorgd worden en (vaak) een vorm van uitkering genieten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT 'gasthuizen' toegevoegd bij integratie met archeologische termen\n27/04/2010: scope note licht aangepast door LM, op basis van korte studie van het fenomeen godshuizen, gasthuizen en passantenhuizen.",
                "type": "historyNote",
            },
        ],
        "related": [506, 368, 837],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/166",
    },
    {
        "broader": [896],
        "id": 1511,
        "labels": [{"label": "golfbanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een golfbaan is een terrein om golf te spelen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1511",
    },
    {
        "broader": [522],
        "id": 167,
        "labels": [
            {"label": "gouverneurswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gouverneurswoning is het woonhuis van een gouverneur. Gouverneurs zijn voorzitters van provincieraden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/167",
    },
    {
        "broader": [1905],
        "id": 1909,
        "labels": [{"label": "graanakkers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een graanakker is een akkerland bezaaid met graan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1909",
    },
    {
        "broader": [180],
        "id": 168,
        "labels": [{"label": "graanhallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een graanhal is een markthal waar graan gewogen, gekeurd, opgeslagen en verhandeld wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [281],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/168",
    },
    {
        "broader": [1837],
        "id": 1080,
        "labels": [{"label": "grachten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1947, 1948],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gracht (infrastructuur) is een relatief smalle en ondiepe kunstmatige waterloop bestemd voor aan- en afvoer van (oppervlakte)water.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.\n01/10/2014: qualifier aangepast van 'morfologisch element' naar 'infrastructuur' bij invoegen van thesaurustermen landschappen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'grachten (verdedigingselementen)' voor grachten die gebruikt werden met verdedigingsdoeleinden.",
                "type": "note",
            },
        ],
        "related": [1109, 1137, 1152],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1080",
    },
    {
        "broader": [1145],
        "id": 1152,
        "labels": [{"label": "grachten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1153],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een gracht (verdedigingselement) of verdedigingsgracht is een brede, langwerpige uitgraving in de grond bedoeld voor verdediging.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'grachten (infrastructuur)' voor grachten die werden aangelegd met oog op infrastructuur of die niet functioneel te duiden zijn.",
                "type": "note",
            },
        ],
        "related": [1080],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1152",
    },
    {
        "broader": [174],
        "id": 170,
        "labels": [{"label": "grafheuvels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafheuvel is een heuvel van opgeworpen aarde boven een of meerdere graven.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [1262, 1263, 1265],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/170",
    },
    {
        "id": 1262,
        "labels": [
            {
                "label": "grafheuvels naar periode",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [858],
        "notes": [],
        "sources": [],
        "superordinates": [170],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1262",
    },
    {
        "id": 1263,
        "labels": [
            {
                "label": "grafheuvels naar status",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1264],
        "notes": [],
        "sources": [],
        "superordinates": [170],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1263",
    },
    {
        "id": 1265,
        "labels": [
            {"label": "grafheuvels naar vorm", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1266],
        "notes": [],
        "sources": [],
        "superordinates": [170],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1265",
    },
    {
        "broader": [307],
        "id": 943,
        "labels": [
            {"label": "grafische nijverheid", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [130, 449],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/943",
    },
    {
        "broader": [174],
        "id": 171,
        "labels": [{"label": "grafkapellen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafkapel is een kapel voor priv\xe9- of familiegraven.",
                "type": "scopeNote",
            }
        ],
        "related": [231],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/171",
    },
    {
        "broader": [174],
        "id": 1268,
        "labels": [{"label": "grafkelders", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafkelder is een gemetseld en meestal overwelfd graf, vaak ruimer dan een gedolven graf, zodat de kelder meerdere overledenen kan bevatten, bv. voor een familiegraf.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1268",
    },
    {
        "broader": [174],
        "id": 172,
        "labels": [{"label": "grafkruisen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafkruis is een grafmonument in de vorm van een kruis.",
                "type": "scopeNote",
            }
        ],
        "related": [891],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/172",
    },
    {
        "broader": [1227],
        "id": 1256,
        "labels": [{"label": "grafkuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1248],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafkuil is een kuil gegraven voor een graf (hetzij inhumatie, hetzij crematie).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1256",
    },
    {
        "broader": [174],
        "id": 173,
        "labels": [{"label": "grafplaten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafplaat is een grafmonument in de vorm van een rechtstaande stenen plaat, ingemetseld in of geplaatst tegen een muur.",
                "type": "scopeNote",
            }
        ],
        "related": [414],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/173",
    },
    {
        "broader": [174],
        "id": 175,
        "labels": [{"label": "grafzerken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafzerk is een liggende stenen plaat die een graf afdekt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/175",
    },
    {
        "broader": [174],
        "id": 532,
        "labels": [{"label": "grafzuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grafzuil is een grafmonument in de vorm van een vrijstaande zuil, meestal halfweg afgebroken om de abruptheid van de dood te symboliseren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VCM", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/532",
    },
    {
        "broader": [],
        "id": 1910,
        "labels": [{"label": "graslanden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": ["http://vocab.getty.edu/aat/300008874"],
        },
        "member_of": [1840],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grasland is een doorgaans productief bodemgebruik met een vegetatie die gedomineerd wordt door grassen (ook wel broek, beemd, meers).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [2153, 2154],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1910",
    },
    {
        "id": 2153,
        "labels": [
            {
                "label": "graslanden naar beheersvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1913, 1911],
        "notes": [],
        "sources": [],
        "superordinates": [1910],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2153",
    },
    {
        "id": 2154,
        "labels": [
            {
                "label": "graslanden naar soortensamenstelling",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [2155, 2156, 2157, 2158],
        "notes": [],
        "sources": [],
        "superordinates": [1910],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2154",
    },
    {
        "broader": [1586],
        "id": 1590,
        "labels": [
            {"label": "grasparterres", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1591],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grasparterre is een parterre waarvan het belangrijkste bestanddeel gazon is.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1590",
    },
    {
        "broader": [142],
        "id": 1227,
        "labels": [{"label": "graven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een graf is een uitgraving in de grond die wordt gebruikt voor begraving.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'funeraire constructies' en bijhorende termen voor constructies die gebouwd werden rondom of op het graf.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [1230, 1231, 1232, 1248],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1227",
    },
    {
        "id": 1230,
        "labels": [
            {
                "label": "graven naar aantal bijzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1249, 1250],
        "notes": [],
        "sources": [],
        "superordinates": [1227],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1230",
    },
    {
        "id": 1232,
        "labels": [
            {
                "label": "graven naar begrafenisritueel",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1233, 1245],
        "notes": [],
        "sources": [],
        "superordinates": [1227],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1232",
    },
    {
        "id": 1231,
        "labels": [
            {"label": "graven naar inhoud", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1251, 1252],
        "notes": [],
        "sources": [],
        "superordinates": [1227],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1231",
    },
    {
        "id": 1248,
        "labels": [
            {"label": "graven naar vorm", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1255, 1256, 1257],
        "notes": [],
        "sources": [],
        "superordinates": [1227],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1248",
    },
    {
        "broader": [1918],
        "id": 1919,
        "labels": [
            {"label": "grazige ruigten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grazige ruigte is een ruigte waarvan de spontane vegetatiegroei bestaat uit ruigtekruiden die (nog) niet gedomineerd is door struiken en/of jonge bomen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1919",
    },
    {
        "broader": [1621],
        "id": 1623,
        "labels": [{"label": "grensbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grensboom is een boom aangeplant als markering of voor het vastleggen van administratieve grenzen (gemeente-, provincie- landsgrens).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1623",
    },
    {
        "broader": [237],
        "id": 176,
        "labels": [
            {"label": "grensmarkeringen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [787, 961],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Opvallende monumenten, vaste objecten of kentekens die behulpzaam zijn bij het vaststellen van de locatie van landsgrenzen.",
                "type": "scopeNote",
            }
        ],
        "related": [2165],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/176",
    },
    {
        "broader": [176],
        "id": 961,
        "labels": [{"label": "grenspalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/961",
    },
    {
        "broader": [176],
        "id": 787,
        "labels": [{"label": "grensstenen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/787",
    },
    {
        "broader": [],
        "id": 1082,
        "labels": [{"label": "greppels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [1083, 1084, 1085, 1086, 1087],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een greppel is een smalle, langwerpige, ondiepe uitgraving in de grond.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1082",
    },
    {
        "broader": [328],
        "id": 1484,
        "labels": [
            {"label": "groentekelders", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een groentekelder is een kelder waar wortelgroente en kolen voor verbruik tot de nieuwe oogst worden ingekuild.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1484",
    },
    {
        "broader": [],
        "id": 2036,
        "labels": [
            {"label": "grondverschuivingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grondverschuiving is een geologisch verschijnsel waarbij bodemmateriaal hellingafwaarts beweegt onder invloed van de zwaartekracht. Grondverschuivingen worden meestal be\xefnvloed door een combinatie van hoge neerslag en menselijk ingrijpen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2036",
    },
    {
        "broader": [],
        "id": 2033,
        "labels": [
            {
                "label": "grondwateruittredingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [83, 2034],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een grondwateruittreding is een geohydrologisch verschijnsel waarbij grondwater aan de oppervlakte komt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2033",
    },
    {
        "broader": [885],
        "id": 178,
        "labels": [{"label": "groothandels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een groothandel is een bedrijf dat in het groot handelswaar verkoopt.",
                "type": "scopeNote",
            }
        ],
        "related": [491, 517],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/178",
    },
    {
        "broader": [443],
        "id": 441,
        "labels": [{"label": "grotten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1536, 1537],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kunstmatige grotten in een tuin of een park.",
                "type": "scopeNote",
            }
        ],
        "related": [279],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/441",
    },
    {
        "broader": [1088],
        "id": 1089,
        "labels": [{"label": "haardkuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haardkuil is een kleine circulaire kuil (die zich meestal voordoet als eenvoudige verkleuring met een compacte houtskoolvulling)die als haard werd gebruikt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Peters F. &amp; Peeters J. 2001, De opgravingen van de mesolithische en neolithische vindplaats Urk-E4 (Domineesweg, gemeente Urk), in: Rapportage Archeologische Monumentenzorg 93, Amersfoort.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1089",
    },
    {
        "broader": [],
        "id": 1088,
        "labels": [
            {"label": "haardplaatsen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [1089],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haardplaats is een plaats waar een brandplaats gelokaliseerd was. Deze kunnen vari\xebren van zeer primitieve oppervlaktehaarden (geen structurele kenmerken, enkel houtskoolconcentraties), over haardkuilen (ingegraven structuren van mogelijk diepe kuilen waarin het brandbaar materiaal werd geplaatst) tot open haarden (openingen of nissen in schoorstenen of muren waarin een vuur werd gemaakt). Ze werden gebruikt als kookplaats of verwarming.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) Peters F. &amp; Peeters J. 2001, De opgravingen van de mesolithische en neolithische vindplaats Urk-E4 (Domineesweg, gemeente Urk), in: Rapportage Archeologische Monumentenzorg 93, Amersfoort.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1088",
    },
    {
        "broader": [20],
        "id": 1366,
        "labels": [
            {"label": "haarsnijderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haarsnijderij is een fabriek of atelier waar konijnen- en hazenvellen worden verwerkt tot viltklaar haar voor de productie van vilten hoeden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'toegevoegd door LM op 1/2/2011 naar aanleiding van integratie thesaurus archeologie, en opheffing term "andere gebouwen voor bewerking van dierenhuid en -haar"\nOp 27/04/2011 scope note toegevoegd door LM na overleg met de specialist ter zake, Leen Heyvaert, conservator van het Stedelijk Museum te Lokeren.',
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Leen Heyvaert, conservator Stedelijk Museum Lokeren",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1366",
    },
    {
        "broader": [932],
        "id": 179,
        "labels": [
            {"label": "hagen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "heggen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haag is een heining dienstig als bescherming of afpaling van een stuk land, bestaand uit naast elkaar geplaatste boomsoorten, struiken en/of heesters die in een bepaalde gedaante worden geschoren of gekapt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "14/12/2012: Term aangepast van 'hagen en houtkanten' naar hagen (bij integratie met thesaurus houtig erfgoed)",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "In de context van de databank bouwkundig erfgoed: enkel die hagen die een geheel (tuin, erf, weide) omringen.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [1670, 1681],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/179",
    },
    {
        "broader": [179],
        "id": 1689,
        "labels": [
            {
                "label": "hagen als erosiebestrijding",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1681],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haag als erosiebestrijding is hakhout met als doel bodems vast te leggen en hierdoor erosie te bestrijden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1689",
    },
    {
        "broader": [179],
        "id": 1690,
        "labels": [
            {
                "label": "hagen als oeverversteviging",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1681],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haag als oeverversteviging is hakhout met als doel waterlopen vast te leggen en hierdoor erosie te bestrijden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1690",
    },
    {
        "id": 1670,
        "labels": [
            {
                "label": "hagen naar beheersvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [],
        "notes": [],
        "sources": [],
        "superordinates": [179],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1670",
    },
    {
        "id": 1681,
        "labels": [
            {"label": "hagen naar functie", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [1682, 1683, 1685, 1686, 1689, 1690],
        "notes": [],
        "sources": [],
        "superordinates": [179],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1681",
    },
    {
        "broader": [893],
        "id": 1515,
        "labels": [{"label": "haha's", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005048"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haha is een (droge) sloot, gracht of greppel rond landschappelijke parken en tuinen om te bereiken dat het vee in de weide een onderdeel van het zicht vanuit de tuin is, maar niet in de eigenlijke tuin kan komen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1515",
    },
    {
        "broader": [1841],
        "id": 1667,
        "labels": [
            {"label": "hakhoutpercelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1659],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hakhoutperceel is een perceel met bomen en struiken die periodiek dicht bij het maaiveld gekapt wordt (voor brand- en geriefhout). De jonge generatie bestaat uit uitlopers van de gekapte stronken (stobben of stoven).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1667",
    },
    {
        "broader": [1608],
        "id": 1711,
        "labels": [
            {"label": "hakhoutstoven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "schaarhout", "language": "nl-BE", "type": "altLabel"},
            {"label": "slaghout", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hakhoutstoof is een kunstmatig gevormde boom of struik die periodiek bij de grond wordt  afgezet en waarvan de stobbe opnieuw uitloopt.  De hoogte van de hakhoutstoof wordt bepaald tijdens de eerste afzetbeurt. De maximale knothoogte wordt hier bepaald op 1 meter (indien de knothoogte hoger is, is sprake van knotbomen). Het beheer wordt uitgevoerd in kapcyclussen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term aangepast van hakhout naar hakhoutstoven en ondergebracht onder houtige beplantingen naar beheersvorm + SN aangepast.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1711",
    },
    {
        "broader": [],
        "id": 2060,
        "labels": [
            {"label": "halfopen landschappen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1848],
        "narrower": [2061, 2063],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een halfopen landschap is een landschap met perceelsrandbegroeiingen en bossen waardoor afwisselend (door)zichten mogelijk zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2060",
    },
    {
        "broader": [73],
        "id": 1701,
        "labels": [
            {"label": "halfstamboomgaarden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een halfstamboomgaard is een boomgaard met fruitbomen op halve stam (ca. 100-150 cm).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1701",
    },
    {
        "broader": [885],
        "id": 180,
        "labels": [{"label": "hallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300005238"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [168, 469, 475, 260],
        "notes": [],
        "related": [281],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/180",
    },
    {
        "broader": [103],
        "id": 885,
        "labels": [
            {"label": "handelsgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005230"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [26, 38, 178, 235, 281, 388, 483, 491, 516, 517, 459, 180, 2167],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een handelsgebouw is een gebouw waar producten en goederen worden verhandeld.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/885",
    },
    {
        "broader": [86],
        "id": 1488,
        "labels": [{"label": "hangbruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007868"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1486],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hangbrug is een horizontale vaste brug, waarvan het brugdek opgehangen is aan kabels.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "1) Van Dale online 2) AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1488",
    },
    {
        "broader": [321],
        "id": 181,
        "labels": [
            {"label": "harmoniezalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een harmoniezaal is een gebouw waar harmonieorkesten repeteren en voorstellingen houden.",
                "type": "scopeNote",
            }
        ],
        "related": [104],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/181",
    },
    {
        "broader": [923],
        "id": 250,
        "labels": [{"label": "havenkranen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een havenkraan is een werktuig (in havencontext) dat zware ladingen kan verplaatsen, voornamelijk door middel van een uitstekende, draaiende arm.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Term hernoemd van 'kranen' naar 'havenkranen'. BT gewijzigd van 'infrastructuur' naar 'infrastructuur aan en in het water'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/250",
    },
    {
        "broader": [923],
        "id": 182,
        "labels": [{"label": "havens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een haven is een natuurlijk of uitgegraven waterbekken aan de zee of aan de oever van een waterloop, waar vaartuigen voor anker kunnen gaan.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/182",
    },
    {
        "broader": [1564],
        "id": 935,
        "labels": [{"label": "heemtuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een heemtuin is een (deel van een) collectie- en siertuin waar planten en eventueel ook dieren uit de inheemse flora (en fauna) ter instructie te bezichtigen zijn.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/935",
    },
    {
        "broader": [],
        "id": 1914,
        "labels": [{"label": "heiden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/900020898"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1840],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een heide is een weinig productief bodemgebruik met een vegetatie die gedomineerd wordt door dwergstruiken (droge variant met struikheide, natte variant met dopheide) en/of ijl bos.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1914",
    },
    {
        "broader": [1564],
        "id": 1566,
        "labels": [{"label": "heidetuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een heidetuin is een collectie- en siertuin waarin allerlei soorten heide en zuur minnende siergewassen zijn geplant.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1566",
    },
    {
        "broader": [1526],
        "id": 184,
        "labels": [
            {"label": "heiligenbeelden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Driedimensionale beelden van heiligen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Enkel de heiligenbeelden die voorkomen op plaatsen waar hun aanwezigheid niet logisch volgt uit de context, zijn opgenomen in de databank.",
                "type": "note",
            },
        ],
        "related": [95, 412, 507],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/184",
    },
    {
        "broader": [95],
        "id": 921,
        "labels": [
            {"label": "Heilig Hartbeelden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Heilig Hartbeeld bestaat uit een staande Christusfiguur, ten voeten uit, in een lang gewaad. Op zijn borst is in reli\xebf een vlammend hart aangebracht. De handen zijn zegenend opgeheven of wijzen naar het hart.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "07/04/2014: SN toegevoegd op vraag van Elise.",
                "type": "historyNote",
            },
        ],
        "related": [507],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/921",
    },
    {
        "broader": [1910],
        "id": 2157,
        "labels": [
            {"label": "heischrale graslanden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2154],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Heischrale graslanden zijn graslanden met een specifieke soortensamenstelling van grassen, kruiden en dwergstruiken, be\xefnvloed door een overwegend zuur, voedselarm en zandig substraat. Er komen zowel droge als natte varianten voor.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/09/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2157",
    },
    {
        "broader": [893],
        "id": 185,
        "labels": [{"label": "hekken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hek is een afscheiding of omheining met stijlen, regels en spijlen.",
                "type": "scopeNote",
            }
        ],
        "related": [350, 186],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/185",
    },
    {
        "broader": [893],
        "id": 186,
        "labels": [{"label": "hekpijlers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hekpijler is een pijler, soms bovenaan verbonden, om een hek of poort aan op te hangen.",
                "type": "scopeNote",
            }
        ],
        "related": [136, 185],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/186",
    },
    {
        "broader": [174],
        "id": 1794,
        "labels": [
            {"label": "heldenhuldezerken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "heldenhuldezerkjes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een heldenhuldezerk is een betonnen zerk in de vorm van een Keltisch kruis, naar een ontwerp van Joe English. Ze werden vanaf augustus 1916 door het Vlaamsgezinde Comit\xe9 Heldenhulde geplaatst op graven van Vlaamse studenten en vrienden. De kostprijs werd betaald door de kameraden. Vooral de befaamde letters AVV-VVK en de blauwvoet verwijzen naar het Vlaamse gedachtegoed.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "18/03/2014: term toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1794",
    },
    {
        "broader": [881],
        "id": 187,
        "labels": [{"label": "herbergen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [9],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een herberg is een publieke gelegenheid waar reizigers onderdak en maaltijden kunnen krijgen.",
                "type": "scopeNote",
            }
        ],
        "related": [9, 91, 193],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/187",
    },
    {
        "broader": [932],
        "id": 1617,
        "labels": [
            {"label": "herdenkingsbomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1605],
        "narrower": [1618, 1620],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een herdenkingsboom is een boom die werd aangeplant om een bepaalde gebeurtenis te herdenken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1617",
    },
    {
        "broader": [522],
        "id": 188,
        "labels": [{"label": "herenhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een herenhuis is een aanzienlijk woonhuis in de stad, doorgaans van vier of meer travee\xebn en meestal met koetsdoorrit.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar vormelijk type\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [89, 405, 468, 262],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/188",
    },
    {
        "broader": [888],
        "id": 1529,
        "labels": [{"label": "hermen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300047170"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een herme is een versieringsmotief bestaande uit een naar onderen taps toelopende pijler of pilaster waarvan het bovendeel door een buste, oorspronkelijk van Hermes, wordt gevormd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "17/08/2015: BT aangepast naar beelden bij verwijderen van 'tuinbeelden'",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1529",
    },
    {
        "broader": [141],
        "id": 1177,
        "labels": [
            {"label": "heuvelforten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hillforts", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een heuvelfort is een verdedigingswerk dat bestaat uit wallen en greppels die rond een versterkte zone op een centrale verhoging liggen; veelvoorkomend in het Europa van de bronstijd en de ijzertijd. Niet te verwarren met causewayed enclosures die tot een vroegere periode behoren (neolithicum).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1176],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1177",
    },
    {
        "broader": [],
        "id": 2022,
        "labels": [{"label": "heuvelrijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een heuvelrij is een aaneenschakeling van heuvels die daardoor het uitzicht vertoont van een golvende rug.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2022",
    },
    {
        "broader": [],
        "id": 2003,
        "labels": [{"label": "heuvels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [2004, 2007, 2006],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een heuvel is een hoger gelegen reli\xebfvorm, begrensd door min of meer steile randen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2003",
    },
    {
        "broader": [923],
        "id": 189,
        "labels": [
            {"label": "hevelduikers", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hevels", "language": "nl-BE", "type": "altLabel"},
            {"label": "sifons", "language": "nl-BE", "type": "altLabel"},
            {"label": "grondduikers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hevelduiker is een hevelvormige koker onder een weg, of door een dijk of een dam, om water door te laten.",
                "type": "scopeNote",
            }
        ],
        "related": [157],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/189",
    },
    {
        "broader": [360],
        "id": 724,
        "labels": [{"label": "hippodromen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/724",
    },
    {
        "broader": [1621],
        "id": 1624,
        "labels": [{"label": "hoekbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hoekboom is een boom aangeplant voor het vastleggen van kadastrale percelen of gebruikspercelen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1624",
    },
    {
        "broader": [1308],
        "id": 190,
        "labels": [
            {"label": "hoeven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "boerderijen", "language": "nl-BE", "type": "altLabel"},
            {"label": "herenhoeven", "language": "nl-BE", "type": "altLabel"},
            {"label": "pachthoeven", "language": "nl-BE", "type": "altLabel"},
            {"label": "hofsteden", "language": "nl-BE", "type": "altLabel"},
            {"label": "hoeves", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hoeve is een landbouwbedrijf, bestaande uit een boerenwoning, bijgebouwen en bijhorend erf met beplantingen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "18/01/2001: bijhorend land gewijzigd in bijhorend erf. (LM)\n25/01/2011: BT gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische complexen'.\n26/02/2015: 'met beplantingen' werd toegevoegd nav WG Databanken 17/10/2014.",
                "type": "historyNote",
            },
        ],
        "related": [71],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [1418, 1419],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/190",
    },
    {
        "broader": [190],
        "id": 1423,
        "labels": [
            {
                "label": "hoeven met losse bestanddelen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1418],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hoeve met losse bestanddelen is een hoeve waarbij de verschillende bestanddelen los van elkaar staan geschikt rond het erf. Deze schikking kan in een min of meer vierkante vorm zijn, maar ook in een U-vorm of in een L-vorm.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Toegevoegd op 07/10/2011 na overleg op inventariswerkgroep en met Sophie Mortier (LM)",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1423",
    },
    {
        "id": 1419,
        "labels": [
            {"label": "hoeven naar functie", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [],
        "members": [5, 223, 240],
        "notes": [],
        "sources": [],
        "superordinates": [190],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1419",
    },
    {
        "id": 1418,
        "labels": [
            {
                "label": "hoeven naar vormelijk type",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1422, 1423, 1420],
        "notes": [],
        "sources": [],
        "superordinates": [190],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1418",
    },
    {
        "broader": [319],
        "id": 191,
        "labels": [{"label": "hogescholen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hogeschool is een gebouw voor hoger niet-universitair onderwijs.",
                "type": "scopeNote",
            }
        ],
        "related": [643, 417],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/191",
    },
    {
        "broader": [1212],
        "id": 1214,
        "labels": [
            {"label": "holle wegen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "grubbe", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een holle weg of grub(be) is een weg die uitgesleten of uitgegraven is en daardoor (gedeeltelijk) tussen twee hellingen ligt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1214",
    },
    {
        "broader": [360],
        "id": 723,
        "labels": [{"label": "hondenbanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/723",
    },
    {
        "broader": [892],
        "id": 192,
        "labels": [{"label": "hondenhokken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hondenhok is een verblijf voor honden, eventueel met bijhorende ren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/192",
    },
    {
        "broader": [297],
        "id": 929,
        "labels": [{"label": "hondenmolens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hondenmolen is een molen die door een hond wordt aangedreven.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/929",
    },
    {
        "broader": [1948],
        "id": 1957,
        "labels": [
            {"label": "hoofdgrachten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hoofdwatergangen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hoofdgracht is een centrale afvoergracht waarin het (oppervlakte)water van het nabijgelegen grachtenstelsel wordt samengebracht en afgevoerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1957",
    },
    {
        "broader": [1841],
        "id": 1660,
        "labels": [
            {"label": "hooghoutpercelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1659],
        "narrower": [1661],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hooghoutbos is een typisch 'bomenbos' van opgaande bomen met \xe9\xe9n stam op \xe9\xe9n wortelstelsel. Op deze manier kunnen dikke bomen met lange stammen gekweekt worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1660",
    },
    {
        "broader": [73],
        "id": 1702,
        "labels": [
            {"label": "hoogstamboomgaarden", "language": "nl-BE", "type": "prefLabel"},
            {"label": "weideboomgaarden", "language": "nl-BE", "type": "altLabel"},
            {"label": "fruitweiden", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hoogstamboomgaard is een aanplant van hoogstamfruitbomen op grasland. De takvrije stamhoogte bedraagt minstens twee meter. Een hoogstamboomgaard laat multifunctioneel landgebruik toe (fruitteelt en beweiding). De bomen worden op rechte lijnen geplant volgens een strak plantverband.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1702",
    },
    {
        "broader": [1910],
        "id": 1913,
        "labels": [{"label": "hooilanden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2153],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hooiland is een grasland waarbij enkel maaigras wordt geoogst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1913",
    },
    {
        "broader": [1911],
        "id": 1912,
        "labels": [{"label": "hooiweiden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hooiweide is een weiland waarbij maaigras wordt geoogst en vee in nabegrazing wordt ingezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1912",
    },
    {
        "broader": [1905],
        "id": 1906,
        "labels": [{"label": "hopakkers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hopakker is een akkerland beplant met hopranken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1906",
    },
    {
        "broader": [35],
        "id": 1014,
        "labels": [{"label": "hopasten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Toegevoegd 28/10/2009 naar aanleiding van Evaluatie door Frank Becuwe van de Inventaris Hoperfgoed van "De Keteniers".',
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1014",
    },
    {
        "broader": [328],
        "id": 1015,
        "labels": [
            {"label": "hopmagazijnen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Toegevoegd op 28/10/2009 naar aanleiding van de evaluatie door Frank Becuwe van de "Inventaris Hoperfgoed" door De Keteniers.',
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1015",
    },
    {
        "broader": [328],
        "id": 1275,
        "labels": [
            {"label": "horrea", "language": "nl-BE", "type": "prefLabel"},
            {"label": "horreum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een horreum is een Romeins pakhuis, meestal gebruikt voor de oplag van graan of wijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1275",
    },
    {
        "broader": [1272],
        "id": 193,
        "labels": [
            {"label": "hotels", "language": "nl-BE", "type": "prefLabel"},
            {"label": "pensions", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hotel is een gebouw dat is ingericht om onderdak te bieden aan reizigers.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'horecazaken' naar 'logeergelegenheden'.",
                "type": "historyNote",
            },
        ],
        "related": [187],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/193",
    },
    {
        "broader": [],
        "id": 932,
        "labels": [
            {"label": "houtige beplantingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [72, 179, 1640, 1645],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [1756, 1604, 1605],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/932",
    },
    {
        "id": 1604,
        "labels": [
            {
                "label": "houtige beplantingen naar beheersvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1648, 1608, 1651],
        "notes": [],
        "sources": [],
        "superordinates": [932],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1604",
    },
    {
        "id": 1605,
        "labels": [
            {
                "label": "houtige beplantingen naar functie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1617, 1621, 1626, 1630, 1631, 1637, 1636],
        "notes": [],
        "sources": [],
        "superordinates": [932],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1605",
    },
    {
        "id": 1756,
        "labels": [
            {
                "label": "houtige beplantingen naar locatie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1643, 1644, 1757, 1761, 1762, 1641],
        "notes": [],
        "sources": [],
        "superordinates": [932],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1756",
    },
    {
        "broader": [1608],
        "id": 1679,
        "labels": [{"label": "houtkanten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1680],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een houtkant is een lijnvormige beplanting die naargelang zijn toepassing (bv. het vastleggen van taluds en waterlopen) in breedte kan vari\xebren en beplant wordt met boom- en/of heestersoorten in een dicht plantverband en in de regel als hakhout wordt beheerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: BT aangepast van hagen naar beheersvorm.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1679",
    },
    {
        "broader": [1318],
        "id": 1319,
        "labels": [
            {"label": "houtskoolbranderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1320],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een houtskoolbranderij is een plaats waar houtskool geproduceerd wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "28/01/2011: Term toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {"citation": "Instituut voor Natuur- en Bosonderzoek", "markup": None}
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1319",
    },
    {
        "broader": [1679],
        "id": 1680,
        "labels": [{"label": "houtwallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een houtwal is een houtkant op een verhoogde afscheiding tussen twee percelen. Hij kan een grens aangeven van bijvoorbeeld een landgoed of een woonwijk.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1680",
    },
    {
        "broader": [18],
        "id": 194,
        "labels": [
            {"label": "houtzagerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een houtzagerij is een industrieel of ambachtelijk bedrijf waar men hout tot planken en balken verzaagt.",
                "type": "scopeNote",
            }
        ],
        "related": [380],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/194",
    },
    {
        "broader": [196],
        "id": 2170,
        "labels": [
            {"label": "hoven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hofjes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hof is een als geheel opgevatte groepering van woningen rond een binnenplein, een groenzone of een pijpenkop, gelegen buiten de verkeersstroom.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term toegevoegd bij integratie",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2170",
    },
    {
        "broader": [343],
        "id": 195,
        "labels": [
            {"label": "hovenierswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hovenierswoning is het woonhuis van een hovenier. Hoveniers staan in voor het tuinonderhoud van aanzienlijke domeinen.",
                "type": "scopeNote",
            }
        ],
        "related": [337, 930],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/195",
    },
    {
        "broader": [147],
        "id": 2097,
        "labels": [{"label": "huistorens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1765],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een huistoren is een toren als onderdeel van een stadspaleis of rijke patrici\xebrswoning. Ze komen vooral voor in de 16de eeuw en hebben vaak een zes- of achthoekige vorm.Ze zouden voor branddetectie en als uitkijkpost voor schepen kunnen hebben gediend. Veel logischer is evenwel de symbolische functie van macht en uitstraling.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2097",
    },
    {
        "broader": [338],
        "id": 720,
        "labels": [{"label": "hulpkerken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/720",
    },
    {
        "broader": [151],
        "id": 1313,
        "labels": [
            {"label": "hutkommen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Grubenhaus", "language": "nl-BE", "type": "altLabel"},
            {"label": "komhutten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hutkom is een gedeeltelijk ingegraven, rechthoekige houten constructie die gewoonlijk ongeveer 3 op 2 meter groot was. In de korte wanden stonden meestal palen die waarschijnlijk een zadeldak hebben gedragen. De wanden waren opgebouwd uit zoden, planken of vlechtwerk. Hutkommen hadden waarschijnlijk geen residenti\xeble functie, maar werden eerder gebruikt als opslagplaats voor goederen of als plaats voor het uitoefenen van ambachten zoals textielbewerking (spinnen en weven) en het bewerken van hout, metaal of bot. Hutkommen zijn een vroegmiddeleeuws fenomeen, hoewel ze ook nog kunnen voorkomen tijdens de volle middeleeuwen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Hoegen R.D. 2004, Bewoningssporen uit de periode Late Ijzertijd \u2013 Romeinse tijd (250 v.Chr. \u2013 450 n.Chr.), in: C.W. Koot &amp; R. Berkvens (eds.), Bredase akkers eeuwenoud. 400 jaar bewoningsgeschiedenis op de rand van zand en klei, Rapportage Archeologische Monumentenzorg 102, pp. 211-272. 2) Hermsen I. 2007, Een afdaling in het verleden. Archeologisch onderzoek van bewoningsresten uit de prehistorie en de Romeinse Tijd op het terrein Colmschate (gemeente Deventer), in: Rapportages Archeologie Deventer 19. 3) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1313",
    },
    {
        "broader": [522],
        "id": 1142,
        "labels": [{"label": "hutten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [1143],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hut is een eenvoudig gebouwd of kleine en bescheiden woning, meestal gemaakt uit natuurlijke materialen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1142",
    },
    {
        "broader": [894],
        "id": 198,
        "labels": [
            {"label": "huurhouderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een huurhouderij is een bedrijf dat paarden en rijtuigen stalt en/of verhuurt.",
                "type": "scopeNote",
            }
        ],
        "related": [9],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/198",
    },
    {
        "broader": [1200],
        "id": 1337,
        "labels": [
            {"label": "hypocausta", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hypocaustum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een hypocaustum is een Romeins verwarmingssysteem waarbij hete lucht uit ovens circuleert door ruimten onder de vloer en verwarmingskanalen in muren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "28/01/2011: Term toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1337",
    },
    {
        "broader": [307],
        "id": 199,
        "labels": [{"label": "ijsfabrieken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ijsfabriek is een industrieel bedrijf waar men uit water kunstijs produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [21],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/199",
    },
    {
        "broader": [63],
        "id": 200,
        "labels": [{"label": "ijskelders", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ijskelder is een geheel of gedeeltelijk ingegraven kelder voor de bewaring van ijs voor de koeling van levensmiddelen. Bedekt met aarde, waarbij al dan niet een heuvel ontstaat. Ze zijn dikwijls bekroond met een paviljoen of beplant met bomen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/200",
    },
    {
        "broader": [1294],
        "id": 2102,
        "labels": [
            {"label": "ijzerertswinning", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "IJzerertswinning is een locatie waar ijzererts gewonnen is.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2102",
    },
    {
        "id": 1381,
        "labels": [
            {
                "label": "indicaties naar hoeveelheid",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1373],
        "members": [1382, 1383, 1384],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1381",
    },
    {
        "id": 1090,
        "labels": [
            {
                "label": "indicaties uit luchtfotografie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1373],
        "members": [1091, 1092, 1093, 1094],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1090",
    },
    {
        "broader": [],
        "id": 1375,
        "labels": [
            {
                "label": "indicaties voor beenbewerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1374],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische resten of aanwijzingen (op een bepaalde plaats) die het omvormen/behandelen van been aantonen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1375",
    },
    {
        "id": 1385,
        "labels": [
            {
                "label": "indicaties voor bouwtechnieken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1373],
        "members": [1386, 1387, 1388],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1385",
    },
    {
        "broader": [14],
        "id": 1293,
        "labels": [
            {
                "label": "indicaties voor delfstofwinning",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1294, 1295, 1296, 1299, 1300, 1301, 1304, 1306, 1302],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik voor niet nader bepaalde ontginningskuil 'extractiekuil'.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1293",
    },
    {
        "broader": [],
        "id": 1376,
        "labels": [
            {
                "label": "indicaties voor glasbewerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1374],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische resten of aanwijzingen (op een bepaalde plaats) die het omvormen/behandelen van glas aantonen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1376",
    },
    {
        "id": 1374,
        "labels": [
            {
                "label": "indicaties voor grondstofbewerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1373],
        "members": [1375, 1376, 1377, 1378, 1379],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1374",
    },
    {
        "broader": [],
        "id": 1377,
        "labels": [
            {
                "label": "indicaties voor houtbewerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1374],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische resten of aanwijzingen (op een bepaalde plaats) die het omvormen/behandelen/modelleren van hout aantonen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1377",
    },
    {
        "broader": [],
        "id": 1386,
        "labels": [
            {
                "label": "indicaties voor houtbouw",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1385],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische indicaties voor de bouw van houten constructies.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1386",
    },
    {
        "broader": [],
        "id": 1378,
        "labels": [
            {
                "label": "indicaties voor metaalbewerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1374],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische resten of aanwijzingen (op een bepaalde plaats) die het omvormen/behandelen/modelleren van metaal aantonen.",
                "type": "scopeNote",
            }
        ],
        "related": [1394],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1378",
    },
    {
        "broader": [],
        "id": 1379,
        "labels": [
            {
                "label": "indicaties voor steenbewerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1374],
        "narrower": [1380],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische resten of aanwijzingen (op een bepaalde plaats) die het omvormen/behandelen van steen aantonen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1379",
    },
    {
        "broader": [],
        "id": 1387,
        "labels": [
            {
                "label": "indicaties voor steenbouw",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1385],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische indicaties voor de bouw van stenen constructies.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1387",
    },
    {
        "broader": [],
        "id": 1388,
        "labels": [
            {
                "label": "indicaties voor vakwerkbouw",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1385],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische indicaties die wijzen op de lokale stijl van bouwen waarbij de ruimten die tussen het zware ondersteunende constructiehout zitten worden gevuld met leem of ander materiaal.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>\n2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1388",
    },
    {
        "broader": [1379],
        "id": 1380,
        "labels": [
            {
                "label": "indicaties voor vuursteenbewerking",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Archeologische resten of aanwijzingen (op een bepaalde plaats) die het omvormen/behandelen van vuursteen aantonen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1380",
    },
    {
        "broader": [72],
        "id": 1653,
        "labels": [
            {"label": "individuele bomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1654],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een individuele boom is een boom die binnen een geheel op zichzelf merkwaardig is, doch niet noodzakelijk alleenstaand is (zoals vb. \xe9\xe9n bijzondere boom in een bos of bomengroep).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1653",
    },
    {
        "broader": [1227],
        "id": 1250,
        "labels": [
            {"label": "individuele graven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1230],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1250",
    },
    {
        "broader": [21],
        "id": 201,
        "labels": [
            {
                "label": "industri\xeble bakkerijen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een industri\xeble bakkerij is een bakkerij voor de groothandel.",
                "type": "scopeNote",
            }
        ],
        "related": [38],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/201",
    },
    {
        "broader": [466],
        "id": 202,
        "labels": [
            {"label": "infirmerie\xebn", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een infirmerie is een gebouw met zalen voor de verpleging van zieken en gewonden.",
                "type": "scopeNote",
            }
        ],
        "related": [267, 526, 369],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/202",
    },
    {
        "broader": [147],
        "id": 13,
        "labels": [
            {"label": "infrastructuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300008553"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [
            16,
            86,
            415,
            424,
            446,
            485,
            523,
            1200,
            1493,
            1837,
            1838,
            923,
            924,
            925,
            926,
        ],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [1194],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/13",
    },
    {
        "broader": [13],
        "id": 923,
        "labels": [
            {
                "label": "infrastructuur aan en in het water",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300007926"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [
            2,
            122,
            157,
            182,
            189,
            203,
            250,
            271,
            305,
            349,
            373,
            374,
            389,
            401,
            534,
            645,
            717,
            947,
            1220,
            1223,
            1494,
            1496,
            1932,
            1941,
            1944,
            482,
        ],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/923",
    },
    {
        "broader": [13],
        "id": 16,
        "labels": [
            {
                "label": "infrastructuur voor de productie en distributie van elektriciteit en gas",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [134, 133, 135, 146],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'nijverheidsgebouwen' naar 'infrastructuur'.",
                "type": "historyNote",
            }
        ],
        "related": [433],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/16",
    },
    {
        "broader": [13],
        "id": 926,
        "labels": [
            {
                "label": "infrastructuur voor landverkeer",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": ["http://vocab.getty.edu/aat/300007800"],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1212, 59, 336, 505],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/926",
    },
    {
        "broader": [13],
        "id": 925,
        "labels": [
            {
                "label": "infrastructuur voor luchtverkeer",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300000678"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [476, 42, 273, 2098],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/925",
    },
    {
        "broader": [13],
        "id": 924,
        "labels": [
            {
                "label": "infrastructuur voor spoorverkeer",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300169606"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [382, 396, 397, 398, 433, 434, 1747],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/924",
    },
    {
        "id": 1194,
        "labels": [
            {
                "label": "infrastructuur voor waterbevoorraading en -afvoer",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [500, 501, 502, 503, 504, 1195, 1196, 1197, 1503, 1502],
        "notes": [],
        "sources": [],
        "superordinates": [13],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1194",
    },
    {
        "broader": [1791],
        "id": 2095,
        "labels": [
            {"label": "ingangsomlijstingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ingangsomlijsting is de omlijsting waarin een deur of poort is ingebracht, vaak in natuursteen en decoratief uitgewerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [2096],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2095",
    },
    {
        "broader": [1033],
        "id": 1068,
        "labels": [
            {
                "label": "inheemse nederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1038],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een inheemse nederzetting of een inheems-Romeinse nederzetting is een Romeinse nederzetting die nog in de ijzertijdtraditie verder leeft, maar wel al geromaniseerd is of toch al in contact is gekomen met de Romeinse invloedssfeer. Zo wonen ze nog in de pre-Romeinse woonstalhuizen en er komt lokaal aardewerk voor naast Romeinse import.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [1310],
        "sources": [
            {
                "citation": '1) 5.6.2.3.4.3. Landelijke bewoning uit de Romeinse tijd in Vlaanderen, in: Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a href="http://www.onderzoeksbalans.be/.">http://www.onderzoeksbalans.be/.</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1068",
    },
    {
        "broader": [1119],
        "id": 1120,
        "labels": [
            {
                "label": "inheems-Romeinse tempels",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {
                "label": "Gallo-Romeinse tempels",
                "language": "nl-BE",
                "type": "altLabel",
            },
            {
                "label": "Gallo-Romeinse omgangstempels",
                "language": "nl-BE",
                "type": "altLabel",
            },
            {"label": "fanum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een inheems-Romeinse tempel is een tempel in onze streken uit de Romeinse periode. Met de komst van de Romeinen in de Lage Landen werden ook de landelijke heiligdommen geleidelijk geromaniseerd. Daarbij bleef de min of meer vierkante vorm gehandhaafd, maar werd het cultusterrein zelf vervangen door de Gallo-Romeinse tempel, met in het midden een hoge cella die geheel werd omgeven door een zuilengalerij.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Hendriks J. 1994, Prisma Archeologie in de Lage Landen, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1120",
    },
    {
        "broader": [1227],
        "id": 1245,
        "labels": [
            {"label": "inhumatiegraven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "lijkbegravingen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1232],
        "narrower": [1246, 1247],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een inhumatiegraf is een graf waarin onverbrande menselijke resten zijn bijgezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.\n23/03/2016: SN aangepast bij afstemmen thesaurus met CGP.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Code Goede Praktijk", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1245",
    },
    {
        "broader": [389],
        "id": 1938,
        "labels": [
            {"label": "inlaatsluizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900025956"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1861],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een inlaatsluis is een sluis die op gewenste tijden water in laat (bijvoorbeeld om het grondwaterpeil in een polder op peil te houden, polderwater of grachten van steden of water van visvijvers te verversen, vaardiepte van kanalen op peil te houden,\u2026).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1938",
    },
    {
        "broader": [923],
        "id": 203,
        "labels": [
            {"label": "inschepingsgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een inschepingsgebouw is een gebouw in de haven waar tickets en paspoorten gecontroleerd worden en waar men wacht vooraleer in te schepen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/203",
    },
    {
        "broader": [319],
        "id": 204,
        "labels": [
            {
                "label": "instituten voor blinden of doofstommen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen voor onderwijs voor blinden of doofstommen.",
                "type": "scopeNote",
            }
        ],
        "related": [154],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/204",
    },
    {
        "broader": [147],
        "id": 2091,
        "labels": [{"label": "interieur", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300124520"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1765],
        "narrower": [2093, 2150],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een interieur is het binnenhuis, het inwendige van een gebouw en kamer.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: term toegevoegd i.f.v. beschermingsdatabank",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.\n2) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2091",
    },
    {
        "broader": [147],
        "id": 1779,
        "labels": [
            {
                "label": "interieurelementen van kerken en kapellen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1767],
        "narrower": [1780, 1781, 1784],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1779",
    },
    {
        "broader": [319],
        "id": 205,
        "labels": [{"label": "internaten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een internaat is een verblijf voor inwonende leerlingen van het lager of secundair onderwijs.",
                "type": "scopeNote",
            }
        ],
        "related": [712],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/205",
    },
    {
        "broader": [389],
        "id": 1933,
        "labels": [
            {"label": "inundatiesluizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900032050"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1863],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een inundatiesluis is een sluis die dient om in oorlogstijd of bij oorlogsdreiging snel te kunnen worden geopend om ten behoeve van de verdediging grote stukken land onder water te zetten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Arends G.J. 1994: Sluizen en stuwen. De ontwikkeling van de sluis- en stuwbouw in Nederland tot 1940, Delft, 69.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1933",
    },
    {
        "broader": [522],
        "id": 2174,
        "labels": [
            {"label": "invalidenwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een invalidenwoning is een individuele wooneenheid die specifiek opgevat is om invaliden zo zelfstandig mogelijk te laten wonen (zoals brede deuropeningen en het ontbreken van niveauverschillen).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2174",
    },
    {
        "broader": [1841],
        "id": 1927,
        "labels": [
            {"label": "jachtbossen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "warandes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1846],
        "narrower": [2142],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een jachtbos is een bos oorspronkelijk aangelegd en gebruikt voor jachtdoeleinden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1927",
    },
    {
        "broader": [63],
        "id": 206,
        "labels": [{"label": "jachthuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een jachthuis is een gebouw op een kasteeldomein voor logement tijdens de jacht.",
                "type": "scopeNote",
            }
        ],
        "related": [77, 262, 444],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/206",
    },
    {
        "broader": [1412],
        "id": 1413,
        "labels": [
            {"label": "jachtobjecten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Hieronder vallen deze objecten die gebruikt worden tijdens de jacht. Dit zijn onder meer bepaalde lithische objecten (zoals pijlbewapening), jachtbewapening, maar ook vishaken en slingers.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1413",
    },
    {
        "broader": [343],
        "id": 719,
        "labels": [
            {
                "label": "jachtopzienerswoningen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/719",
    },
    {
        "broader": [440],
        "id": 1583,
        "labels": [
            {"label": "Japanse tuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Japanse tuin is een siertuin die hoofdzakelijk uit Japanse tuinelementen en planten is samengesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1583",
    },
    {
        "broader": [463],
        "id": 207,
        "labels": [
            {"label": "jeugdbewegingslokalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een jeugdbewegingslokaal is een gebouw voor bijeenkomsten van jeugdbewegingen.",
                "type": "scopeNote",
            }
        ],
        "related": [853, 100],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/207",
    },
    {
        "broader": [1272],
        "id": 913,
        "labels": [
            {"label": "jeugdherbergen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'hotels' naar 'logeergelegenheden'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/913",
    },
    {
        "broader": [2009],
        "id": 2012,
        "labels": [
            {"label": "jonge duinen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "zeereepduinen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een jonge duin is een zeewerende kustduin onmiddellijk gelegen aan een actuele/huidige kustlijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2012",
    },
    {
        "broader": [160],
        "id": 718,
        "labels": [
            {"label": "justitiepaleizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/718",
    },
    {
        "broader": [20],
        "id": 209,
        "labels": [
            {"label": "jutefabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een jutefabriek is een industrieel of ambachtelijk bedrijf waar men jute produceert en verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/209",
    },
    {
        "broader": [383],
        "id": 960,
        "labels": [{"label": "juvenaten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/960",
    },
    {
        "broader": [923],
        "id": 1494,
        "labels": [
            {"label": "kaaimuren", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kademuren", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kaaimuur is een muur tot bekleding, bevestiging en bescherming van de walkanten van waterlopen, havens en sluiswerken.",
                "type": "scopeNote",
            }
        ],
        "related": [1493],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1494",
    },
    {
        "broader": [923],
        "id": 717,
        "labels": [{"label": "kaapstanders", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/717",
    },
    {
        "broader": [20],
        "id": 716,
        "labels": [{"label": "kaarderijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/716",
    },
    {
        "broader": [15],
        "id": 210,
        "labels": [
            {"label": "kaarsenfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kaarsenfabriek is een industrieel of ambachtelijk bedrijf waar men kaarsen produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/210",
    },
    {
        "broader": [212],
        "id": 1289,
        "labels": [
            {"label": "kalkbranderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kalkbranderij is een bewerkingsinstallatie voor het maken van kalk, die van oudsher kan bestaan uit rijen kalkovens en eventueel aanverwante mijnconstructies.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1296],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1289",
    },
    {
        "broader": [1910],
        "id": 2156,
        "labels": [
            {"label": "kalkgraslanden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2154],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kalkgraslanden zijn doorgaans droge graslanden met een specifieke soortensamenstelling van grassen en kruiden, be\xefnvloed door een kalk- of krijtsubstraat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/09/2015: toegevoegd bij revisie thesaurus landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2156",
    },
    {
        "broader": [1096],
        "id": 1098,
        "labels": [{"label": "kalkkuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kalkkuil is een uitgegraven kuip afgezet met dakpannen of planken, waarin ongebluste kalk werd bewaard tijdens bouwwerkzaamheden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1098",
    },
    {
        "broader": [212],
        "id": 700,
        "labels": [{"label": "kalkovens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kalkoven is een structuur om kalk uit kalksteen te branden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [1296],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/700",
    },
    {
        "broader": [1296],
        "id": 1298,
        "labels": [{"label": "kalkputten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kalkput is een put gevormd door het winnen van kalk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1298",
    },
    {
        "broader": [],
        "id": 2136,
        "labels": [
            {"label": "kalktufafzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2133],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kalktufafzetting is een afzetting in hellende gebieden, waarbij kalk langzaam neerslaat in koel, uitvloeiend of afstromend grondwater. De neerslag bestaat uit dunne korsten die zich soms kunnen ophopen of uit aanhechting van kalkomhullingen op wortel- of houtresten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2136",
    },
    {
        "broader": [1293],
        "id": 1296,
        "labels": [{"label": "kalkwinning", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1298],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar kalk gewonnen is. Kan voorkomen in samenhang met een kalkbranderij.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1289, 700],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1296",
    },
    {
        "broader": [174],
        "id": 1269,
        "labels": [{"label": "kamergraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kamergraf is een merovingisch graftype waarbij een brede grafkamer uit houten planken wordt gemaakt op een constructie van twee dwarsbalken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1269",
    },
    {
        "broader": [],
        "id": 2125,
        "labels": [{"label": "kamlijnen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kamlijn is een aaneenschakeling van hoogste punten van hogere reli\xebfeenheden die zich samen herkenbaar aftekenen en waarbij de niveauverschillen relatief klein zijn. Kamlijnen fungeren als waterscheiding tussen stroomgebieden van natuurlijke waterlopen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2125",
    },
    {
        "broader": [1033],
        "id": 1039,
        "labels": [{"label": "kampdorpen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1034],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kampdorp is een dorp dat zich gevormd heeft bij een kamp en waar de familieleden van de soldaten, handelaars, ambachtlui enz. verbleven.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1039",
    },
    {
        "broader": [1033],
        "id": 1040,
        "labels": [
            {"label": "kampplaatsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kampsites", "language": "nl-BE", "type": "altLabel"},
            {"label": "kampementen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1034],
        "narrower": [1041, 1050, 1049],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "De term kampplaats wordt voornamelijk gebruikt in een antropologische en archeologische context voor kleine, verspreid liggende, tijdelijke of seizoengebonden nederzettingen, meestal bedoeld als schuil- of slaapplaats, die vaak verband houden met specifieke bezigheden en over het algemeen geen permanente architectuur hebben.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1040",
    },
    {
        "broader": [1837],
        "id": 213,
        "labels": [
            {"label": "kanalen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vaarwegen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1946],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kanaal is een gegraven, bevaarbare waterweg.",
                "type": "scopeNote",
            }
        ],
        "related": [1525],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/213",
    },
    {
        "broader": [237],
        "id": 1525,
        "labels": [{"label": "kanalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kanaal in tuinen en parken is een lijnvormig gegraven waterpartij voor nut en sier.",
                "type": "scopeNote",
            }
        ],
        "related": [213],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1525",
    },
    {
        "broader": [881],
        "id": 214,
        "labels": [{"label": "kantines", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kantine is een gebouw waarin personeelsleden, clubleden, leerlingen of soldaten aan lage prijzen maaltijden of drank kunnen nuttigen.",
                "type": "scopeNote",
            }
        ],
        "related": [362, 294],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/214",
    },
    {
        "broader": [103],
        "id": 215,
        "labels": [
            {"label": "kantoorgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kantoorgebouw is een gebouw waarin de administraties of het bestuur van priv\xe9-bedrijven zetelen of waar vrije beroepen (zoals advocaten, architecten of ingenieurs) kantoor houden.",
                "type": "scopeNote",
            }
        ],
        "related": [8],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/215",
    },
    {
        "broader": [889],
        "id": 216,
        "labels": [
            {"label": "kanunnikenhuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kanunnikenhuis is het woonhuis van een seculiere kanunnik. Kanunniken zijn geestelijken die tot het kapittel van een kerk behoren.",
                "type": "scopeNote",
            }
        ],
        "related": [218, 359],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/216",
    },
    {
        "broader": [889],
        "id": 713,
        "labels": [
            {"label": "kapelanie\xebn", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/713",
    },
    {
        "broader": [1637],
        "id": 1639,
        "labels": [{"label": "kapelbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kapelboom is een boom aangeplant bij een kapel of een boom waartegen een boomkapel is bevestigd.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1639",
    },
    {
        "broader": [932],
        "id": 1643,
        "labels": [
            {"label": "kapelhofbeplantingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1756],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kapelhofbeplanting is beplanting die werd aangeplant in de hof aansluitend bij de kapel.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1643",
    },
    {
        "broader": [359],
        "id": 513,
        "labels": [{"label": "kapellen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [231, 46],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kapel is een vertrek in, of gebouw bij een aanzienlijk gebouw of gebouwencomplex zoals een kasteel, klooster, rusthuis, school, bedevaartsoord of kerkhof, ... , bestemd voor godsdienstbeoefening en met een beperkte liturgische functie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Op 3 maart 2010 is de scope-note gewijzigd. Tot dan werd een kapel omschreven als \"Toegankelijke kapellen in dorpen, stadswijken of langs de weg.\" (oude scope-note)\n20/01/2011: qualifier gewijzigd naar 'gebouwen en structuren'.",
                "type": "historyNote",
            },
        ],
        "related": [92, 507],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/513",
    },
    {
        "broader": [147],
        "id": 1776,
        "labels": [{"label": "kapellen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": ["http://vocab.getty.edu/aat/300004590"],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1767],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kapel (gebouwonderdeel) is een apart gedeelte van een kerk waarin het altaar van een heilige is geplaatst. Men onderscheidt transkapellen, straalkapellen, zijkapellen en torenkapellen. Vaak worden deze door fraaie afscheidingen van het kerkruim gescheiden.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1776",
    },
    {
        "broader": [237],
        "id": 507,
        "labels": [
            {"label": "kapellen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "muurkapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "gevelkapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "boskapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "veldkapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "wegkapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "beschermkapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "herinneringskapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "geloftekapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "dankkapellen", "language": "nl-BE", "type": "altLabel"},
            {"label": "devotiekapellen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [279, 318, 1018, 1019, 901],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Bescheiden gebouwtjes of constructies, opgericht door een geloofsgemeenschap of een priv\xe9-persoon uit devotie voor Christus, Maria of een heilige. Voornamelijk ter bescherming, om genezing af te smeken, of uit dank. Deze kapellen komen vaak voor langs de openbare weg, maar kunnen ook in een veld, bos, of op een priv\xe9domein of erf gelegen zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'De scope-note werd gewijzigd op 31 maart 2010. Tot dan luidde de definitie: "Bescheiden, niet-toegankelijke constructies langs de weg, als plaatsen van devotie en herdenking." (oude scope-note)\n31 maart 2010: Indexing note toegevoegd.',
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Kapellen kunnen worden benoemd op basis van hun locatie (boskapel, veldkapel, ...), op basis van de heilige waaraan ze zijn gewijd (Mariakapel), op basis van het motief van hun oprichting (beschermkapel, dankkapel, ...) of op basis van hun vormgeving. In deze thesaurus is gekozen voor een indeling op basis van vorm.\nAndere benamingen van kapellen zijn opgenomen als doorverwijsterm en zullen bij het zoeken doorverwijzen naar de algemene typologie "kapellen (klein erfgoed)".',
                "type": "note",
            },
        ],
        "related": [95, 184, 278, 513, 891, 921],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/507",
    },
    {
        "broader": [1608],
        "id": 1678,
        "labels": [{"label": "kaphagen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kaphaag is een haag van knotbomen, op zeer korte afstand van elkaar geplant die niet geschoren maar gekapt wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: BT aangepast van 'hagen naar beheersvorm'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1678",
    },
    {
        "broader": [230],
        "id": 218,
        "labels": [
            {"label": "kapittelkerken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "collegiale kerken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kapittelkerk is een kerk waaraan een kapittel van seculiere kanunniken verbonden was.",
                "type": "scopeNote",
            }
        ],
        "related": [216],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/218",
    },
    {
        "broader": [147],
        "id": 1790,
        "labels": [
            {"label": "kapittelzalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007418"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1785],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kapittelzaal is een lokaal in een klooster waar het kapittel (college van kanunniken) geregeld bijeenkomt. De zaal bevindt zich meestal aan de oostkant van de pandgang.",
                "type": "scopeNote",
            }
        ],
        "related": [4, 243],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1790",
    },
    {
        "broader": [894],
        "id": 219,
        "labels": [{"label": "kapsalons", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kapsalon is een zaak voor haarverzorging.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/219",
    },
    {
        "broader": [1212],
        "id": 1216,
        "labels": [{"label": "karrensporen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een karrenspoor is een weg (of een individueel spoor) die gevormd is door het veelvuldig berijden met karren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1216",
    },
    {
        "broader": [],
        "id": 2147,
        "labels": [
            {"label": "karstische processen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "oplossingsprocessen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een karstisch proces is het proces waarbij geomorfologische elementen gevormd worden onder invloed van  oplossing van kalksteen via grond- en/of neerslagwater in de ondergrond,  met de vorming van laagtes, spleten, holen en grotten tot gevolg.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "10/09/2015: toegevoegd bij aanvullen termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2147",
    },
    {
        "broader": [],
        "id": 2037,
        "labels": [
            {"label": "karstverschijnselen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een karstverschijnsel is een specifieke vorm van het aardoppervlak en de ondergrond in kalksteengebieden, bestaande uit laagtes, spleten, holen en grotten, die het gevolg zijn van het oplossen van de kalksteen door smelt-, rivier- en/of regenwater.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2037",
    },
    {
        "broader": [18],
        "id": 220,
        "labels": [
            {"label": "kartonfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kartonfabriek is een industrieel of ambachtelijk bedrijf dat karton produceert en verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [335],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/220",
    },
    {
        "broader": [1212],
        "id": 221,
        "labels": [{"label": "kasseiwegen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kasseiweg is een weg die is aangelegd met kasseistenen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'infrastructuur voor landverkeer' naar 'wegen'.",
                "type": "historyNote",
            },
        ],
        "related": [128],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/221",
    },
    {
        "broader": [323],
        "id": 222,
        "labels": [
            {"label": "kasselrijhuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kasselrijhuis is een gebouw waarin het bestuur van de kasselrij gevestigd is. Kasselrijen zijn districten van het graafschap Vlaanderen onder het gezag van een burggraaf.",
                "type": "scopeNote",
            }
        ],
        "related": [376, 41],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/222",
    },
    {
        "broader": [2113],
        "id": 2114,
        "labels": [
            {"label": "kasteeldomeinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kasteeldomein is een domein waarvan de eigendommen in bezit zijn van een kasteelheer. Dit bestaat (meestal) uit een kasteel, park, kapel, kasteelhoeve(s), omliggende landerijen, molen, ...",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2114",
    },
    {
        "broader": [190],
        "id": 223,
        "labels": [
            {"label": "kasteelhoeven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1419],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kasteelhoeve is een hoeve die bij een kasteel ligt en de bewoners van levensmiddelen voorziet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'gekoppeld aan gidsterm "hoeven naar functie" op 07/10/2011 (LM)',
                "type": "historyNote",
            },
        ],
        "related": [88, 262, 299, 734, 124],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/223",
    },
    {
        "broader": [1045],
        "id": 2108,
        "labels": [
            {
                "label": "kasteel-hof-kerknederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kasteel-hof-kerknederzetting is een kernnederzetting ontstaan bij een kasteel met hof en eigen (gestichte) kerk/kapel.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2108",
    },
    {
        "broader": [293],
        "id": 1371,
        "labels": [{"label": "kastelen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [88, 299, 1372],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kasteel is een gebouw of een groep van gebouwen die hoofdzakelijk is bedoeld als verblijfplaats voor een prins of edelman, al dan niet versterkt, die de status van de bewoner weerspiegelt. Het verdedigende element is nog duidelijk aanwezig. De verdediging kan bestaan uit grachten, wallen, torens, e.d.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'kastelen (woningen)' voor kastelen waar de verdedigende functie nog moeilijk te onderscheiden is. \nGebruik 'burchten' voor de versterkte woonplaats van een heer waar de nadruk eerder ligt op de militaire functie.",
                "type": "note",
            },
        ],
        "related": [225],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>\n2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1371",
    },
    {
        "broader": [520],
        "id": 225,
        "labels": [{"label": "kastelen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [262],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kasteel is een gebouw of een groep van gebouwen die hoofdzakelijk is bedoeld als verblijfplaats (woonfunctie) voor een prins of edelman, al dan niet versterkt, die de status van de bewoner weerspiegelt. De verdedigende functie is nog moeilijk te onderscheiden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN en IN toegevoegd.\n18/04/2011: Qualifier toegevoegd\n15/06/2011: Aangepast van PT naar gidsterm",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'kastelen (verdedigingswerken)' voor kastelen waar de verdedigende functie nog duidelijk aanwezig is. \nGebruik 'burchten' voor de versterkte woonplaats van een heer waar de nadruk eerder ligt op de militaire functie.",
                "type": "note",
            },
        ],
        "related": [1371],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>\n2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/225",
    },
    {
        "broader": [507],
        "id": 1019,
        "labels": [{"label": "kastkapellen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [763, 904],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kastjes met een heiligenbeeld in, afgesloten door glas of door doorzichtige kunststof. Deze kastjes zijn bevestigd tegen een gevel, op een staak (staakkapel) of aan een boom (boomkapel).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31 maart 2010: term + scope-note toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1019",
    },
    {
        "broader": [1660],
        "id": 1661,
        "labels": [
            {"label": "kathedraalbossen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kathedraalbos is een soortenarm hooghoutbos van schaduwboomsoorten (meestal hoogopgaande beuken), gekenmerkt door afwezigheid of gering voorkomen van een struik- en kruidlaag.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1661",
    },
    {
        "broader": [230],
        "id": 226,
        "labels": [{"label": "kathedralen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kathedraal is een hoofdkerk van een bisdom in de zetelplaats van de bisschop, waarin zich de bisschopszetel (cathedra) bevindt. Een kapittel van kanunniken is ook aan een kathedraal verbonden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/226",
    },
    {
        "broader": [1005],
        "id": 230,
        "labels": [
            {"label": "katholieke kerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [6, 52, 218, 226, 242, 308, 338, 772, 47],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/230",
    },
    {
        "broader": [20],
        "id": 227,
        "labels": [
            {"label": "katoenfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een katoenfabriek is een industrieel of ambachtelijk bedrijf waar men katoen produceert en verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/227",
    },
    {
        "broader": [1151],
        "id": 710,
        "labels": [{"label": "kazematten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kazemat is een vaak gewelfd vertrek in een borstwering, bastion of andere onderdelen van naar buiten liggende vestingwerken met openingen voor het afvuren van artillerie. Later wordt de term ook gebruikt om losstaande bomvrije stenen of betonnen bouwwerken aan te duiden die ook als schuilplaats werden gebruikt, hoewel men deze veelal bunkers noemt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Aangepast van NPT voor 'schuilplaatsen' naar PT onder 'verdedigingswerkonderdelen'. SN toegevoegd.\n06/05/2014: SN uitgebreid en indexing note toegevoegd om verwarring met bunkers te vermijden.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik voor vrijstaande bomvrije of betonnen bouwwerken eerder 'bunkers'.",
                "type": "note",
            },
        ],
        "related": [87],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/710",
    },
    {
        "broader": [1148],
        "id": 228,
        "labels": [{"label": "kazernes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [731],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kazerne is een gebouw voor de huisvesting van militairen en de opslag van hun uitrusting.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verblijfplaatsen voor militairen' naar 'militaire gebouwwen'. 'verblijfplaatsen voor militairen' niet meer nodig geacht.",
                "type": "historyNote",
            },
        ],
        "related": [392],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/228",
    },
    {
        "broader": [13],
        "id": 1493,
        "labels": [{"label": "keermuren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005073"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een keermuur is een muur die gebouwd is om zijdelingse belasting te weerstaan, zoals een muur die een aarden wal tegenhoudt.",
                "type": "scopeNote",
            }
        ],
        "related": [1494],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1493",
    },
    {
        "broader": [389],
        "id": 1935,
        "labels": [{"label": "keersluizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/900031582"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1862],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een keersluis is een sluis die moet voorkomen dat er achter de sluis een te hoge of juist een te lage waterstand komt (vooral in zeehavens).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Arends G.J. 1994: Sluizen en stuwen. De ontwikkeling van de sluis- en stuwbouw in Nederland tot 1940, Delft, 69.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1935",
    },
    {
        "broader": [479],
        "id": 709,
        "labels": [{"label": "kegelbanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/709",
    },
    {
        "broader": [147],
        "id": 1095,
        "labels": [{"label": "kelders", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004759"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1765],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kelder is een ruimte die geheel of voor het grootste deel ondergronds ligt en die wordt gebruikt voor opslag, vooral van voedsel. Bv. wijnkelders.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1095",
    },
    {
        "broader": [359],
        "id": 1005,
        "labels": [{"label": "kerken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007466"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [230, 330, 355],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kerk is een religieus gebouw waar christenen samenkomen om de liturgie/eucharistie te vieren. Een kerk onderscheidt zich soms enkel van een kapel door de grotere omvang.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN toegevoegd en aangepast van gidsterm naar voorkeursterm.",
                "type": "historyNote",
            },
        ],
        "related": [1768, 1769, 1770, 1771, 1772, 1773, 1776, 1777, 1778],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1005",
    },
    {
        "broader": [1762],
        "id": 1642,
        "labels": [
            {"label": "kerkhofbeplantingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kerkhofbeplanting is beplanting die werd aangeplant in de hof aansluitend bij de kerk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Daarom niet per se een boom die aangeplant is op de begraafplaats!",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1642",
    },
    {
        "broader": [513],
        "id": 231,
        "labels": [
            {"label": "kerkhofkapellen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kerkhofkapel is een kapel op een begraafplaats waarin de absoute gegeven wordt, d.w.z. de plechtigheid na een uitvaartmis waarin wordt gebeden om kwijtschelding van straf voor de overledene.",
                "type": "scopeNote",
            }
        ],
        "related": [54, 171, 232],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/231",
    },
    {
        "broader": [54],
        "id": 232,
        "labels": [{"label": "kerkhoven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kerkhof is een (meestal) omsloten terrein rondom de kerk, dat doorgaans wordt gebruikt als begraafplaats.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '24/01/2011: SN gewijzigd van "Begraafplaatsen rond kerken.".\n27/04/2011: SN gewijzigd van "Een kerkhof is een (meestal) omheind terrein dat aan de kerk toebehoort en dat wordt gebruikt als begraafplaats."',
                "type": "historyNote",
            },
        ],
        "related": [231],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/232",
    },
    {
        "broader": [78],
        "id": 1464,
        "labels": [{"label": "kerkschepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kerkschip is een door particulieren uitgerust schip met een predikant of priester aan bood, dat als kerk en geestelijk middelpunt dient voor vissers als zij op zee zijn en voor binnenschippers.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005\n2) Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1464",
    },
    {
        "broader": [147],
        "id": 1768,
        "labels": [{"label": "kerktorens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300003625"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1767],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kerktoren is een toren van een kerk, doorgaans verbonden met het kerkgebouw, maar soms ook los hiervan staand.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": "Art &amp; Architecture Thesaurus Nederlandstalig (concept ID 300003625)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1768",
    },
    {
        "broader": [1217],
        "id": 1498,
        "labels": [
            {"label": "kerkwegels", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kerkpaden", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kerkwegel is een smalle weg of veldweg waarlangs men naar de kerk gaat.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1498",
    },
    {
        "broader": [1033],
        "id": 1045,
        "labels": [
            {"label": "kernnederzettingen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "clusternederzettingen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1035],
        "narrower": [2108, 2110],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kernnederzetting is een weinig gestructureerde nederzetting waarbij de bebouwing in een kern gegroepeerd is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.\n23/06/2015: - voorkeursterm gewijzigd van clusternederzettingen naar kernnederzettingen en SN gewijzigd bij integratie termen landschappen; was: "Een clusternederzetting is een nederzetting waarvan het patroon onregelmatig oogt."',
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1045",
    },
    {
        "broader": [884],
        "id": 233,
        "labels": [{"label": "ketelhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ketelhuis is een gebouw waarin een of meerdere stoomketels opgesteld staan, meestal op industri\xeble sites. Doorgaans zijn de ketelhuizen gesitueerd naast de machinezaal waar de stoommachine is opgesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [275],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/233",
    },
    {
        "broader": [893],
        "id": 1516,
        "labels": [{"label": "kettingpalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kettingpaal is een lage en ronde, meestal conische hardstenen paal voor functionele en decoratieve doeleinden, met een paar zijdelings bevestigde ogen om zware metalen kettingen aan te bevestigen ter begrenzing.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1516",
    },
    {
        "broader": [290],
        "id": 705,
        "labels": [
            {"label": "kilometerpalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/705",
    },
    {
        "broader": [319],
        "id": 234,
        "labels": [
            {"label": "kinderdagverblijven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kindertuinen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kinderdagverblijf is een verblijf waar kinderen van 0 tot 2,5 \xe0\xa0 3 jaar, die nog niet naar school gaan, onder toezicht de dag doorbrengen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/234",
    },
    {
        "broader": [1252],
        "id": 1253,
        "labels": [{"label": "kindergraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kindergraf is een graf waarin gecremeerde of ge\xefnhumeerde resten van een kind zijn bijgezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1253",
    },
    {
        "broader": [885],
        "id": 235,
        "labels": [{"label": "kiosken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kiosk is een klein vrijstaand gebouw, gedeeltelijk of helemaal open, waar handelswaar, zoals kranten, bloemen en rookwaren, uitgestald en verkocht wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [303],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/235",
    },
    {
        "broader": [892],
        "id": 236,
        "labels": [{"label": "kippenhokken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1471],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kippenhok is een verblijf voor kippen, eventueel met bijhorende ren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/236",
    },
    {
        "broader": [892],
        "id": 1602,
        "labels": [{"label": "kippenrennen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1471],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kippenren is een afgesloten loopplaats voor de opkweek van fazanten, al dan niet met bijhorend hok.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Bij het toekennen van deze term ligt de nadruk op het belang van de ren en niet op het bijhorend hok. Als het hok van groter belang is dan de ren, ken dan de term 'kippenhokken' toe.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "OE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1602",
    },
    {
        "broader": [1245],
        "id": 1246,
        "labels": [{"label": "kistgraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kistgraf is een inhumatiebegraving in een houten kist.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1246",
    },
    {
        "broader": [1393],
        "id": 1400,
        "labels": [
            {
                "label": "kleding en -accessoires",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "kledij", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Objecten die door mensen worden gedragen ter verwarming, bescherming of verfraaiing. Hieronder vallen objecten als broeken, schoenen, hoeden/mutsen, maar ook onderdelen van kleding en accessoires, zoals riemen, gespen, fibulae, schoenzolen, \u2026",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1400",
    },
    {
        "broader": [],
        "id": 237,
        "labels": [
            {"label": "klein erfgoed", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            48,
            132,
            153,
            159,
            176,
            265,
            266,
            290,
            314,
            334,
            364,
            443,
            499,
            507,
            509,
            515,
            528,
            891,
            893,
            1016,
            1525,
            1531,
            1532,
            1533,
            1553,
            1554,
            2085,
            2087,
            140,
            2094,
            2116,
        ],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Klein erfgoed is alle erfgoed van beperkte afmetingen dat doorgaans op het publieke domein te vinden is, of voor het publiek bereikbaar, en dat weinig economische meerwaarde heeft.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/03/2015: SN toegevoegd o.b.v. voorstel Leen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/237",
    },
    {
        "broader": [1033],
        "id": 1064,
        "labels": [
            {"label": "kleine steden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1036],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Het onderscheid tussen dorp, gemeente en stad is betrekkelijk en varieert naar gelang de individuele, regionale context. Kleine steden zijn meestal compacte nederzettingen, die groter zijn dan een dorp, maar minder belangrijk en complex dan de grote steden in de regio.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Tys D., Buyle E., Verdurmen I. &amp; Canters F. 2010, Vectorisering en karakterisering van nederzettingskernen op basis van het zgn. 'gereduceerd kadaster', SKAR-rapport 5, VUB.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1064",
    },
    {
        "broader": [1645],
        "id": 1646,
        "labels": [{"label": "kleinfruit", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kleinfruit is een veredelde struik die eetbare vruchten voortbrengt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1646",
    },
    {
        "broader": [1393],
        "id": 1395,
        "labels": [
            {"label": "kleinsculptuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kleinsculptuur omvat kleinere objecten waarin beelden en vormen zijn uitgewerkt in reli\xebf, in intaglio of in rondsculptuur. De term is vooral van toepassing op objecten die worden gemaakt door in een hard materiaal te snijden of te graveren, door een pletbaar materiaal te vormgieten of te modelleren of door delen samen te voegen tot een driedimensionaal object.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'sculpturen' voor grotere en meer monumentale beeldhouwwerken.",
                "type": "note",
            },
        ],
        "related": [48],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>\n2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1395",
    },
    {
        "broader": [1299],
        "id": 938,
        "labels": [{"label": "kleiputten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kleiput is een plaats waar klei wordt ontgraven.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'groeven' naar 'kleiwinning'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/938",
    },
    {
        "broader": [1293],
        "id": 1299,
        "labels": [{"label": "kleiwinning", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [938],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar klei gewonnen is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1299",
    },
    {
        "broader": [319],
        "id": 238,
        "labels": [
            {"label": "kleuterscholen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kleuterschool is een gebouw waar voorbereidend onderwijs wordt verstrekt aan kinderen tot zes jaar.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/238",
    },
    {
        "broader": [932],
        "id": 1651,
        "labels": [{"label": "klimplanten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1604],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een klimplant is een plant met dunne buigzame houtige stengel, die niet rechtop op zichzelf kan staan, maar zich al dan niet met hechtorganen langs andere planten of langs voorwerpen omhoog werkt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: BT gewijzigd van 'houtige beplantingen'",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "1) Van Daele 2) Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1651",
    },
    {
        "broader": [1212],
        "id": 1500,
        "labels": [{"label": "klinkerwegen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een klinkerweg is een straat of rijweg met klinkerbestrating. Een klinker is een hard gebakken baksteen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1500",
    },
    {
        "broader": [18],
        "id": 239,
        "labels": [
            {"label": "klompenmakerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een klompenmakerij is een ambachtelijk bedrijf waar men klompen maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [378],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/239",
    },
    {
        "broader": [190],
        "id": 240,
        "labels": [
            {"label": "kloosterhoeven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1419],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kloosterhoeve is een hoeve die bij een klooster liggen en door dat klooster zelf wordt uitgebaat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'gekoppeld aan gidsterm "hoeven naar functie" op 07/10/2011 (LM)',
                "type": "historyNote",
            },
        ],
        "related": [243, 354],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/240",
    },
    {
        "broader": [230],
        "id": 242,
        "labels": [
            {"label": "kloosterkerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kerken van kloosters.",
                "type": "scopeNote",
            }
        ],
        "related": [6, 243, 354],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/242",
    },
    {
        "broader": [359],
        "id": 243,
        "labels": [{"label": "kloosters", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een klooster is een gebouwcomplex voor mensen die religieuze geloften hebben afgelegd en in gemeenschappen van een religieus instituut leven. Kloosters vallen onder het gezag van een lokale bisschop, terwijl een abt of abdis aan het hoofd staat van een abdij. In een klooster kan men enkele standaardruimten afbakenen waaronder de kapittelzaal, het calefactorium (warme ruimte), de kloosterkerk, de slaapzaal, de refter, het sciptorium (waar documenten werden gekopieerd) enz...",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '26/01/2011: SN aangepast. oorspronkelijk: "Gebouwcomplexen voor mensen die religieuze geloften hebben afgelegd en in gemeenschappen van een religieus instituut leven."',
                "type": "historyNote",
            },
        ],
        "related": [242, 4, 102, 240, 354, 1786, 1788, 1789, 1790],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/243",
    },
    {
        "broader": [1603],
        "id": 1904,
        "labels": [
            {"label": "kloostertuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300008124"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kloostertuin is een door muren of hagen van de buitenwereld afgesloten tuin van een klooster. Deze kunnen bestaan uit moestuinen en boomgaarden, een omsloten binnenhof en siertuinen vaak gestoffeerd met christelijke symbolen zoals kruiswegstaties, Lourdesgrotten, kapellen en calvariebergen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1904",
    },
    {
        "broader": [359],
        "id": 244,
        "labels": [
            {"label": "kluizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hermitages", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kluis is een bescheiden woonhuis in een kloostertuin of een eenzame streek, bewoond door een religieuze die individueel afzondering zoekt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/244",
    },
    {
        "broader": [1586],
        "id": 1592,
        "labels": [{"label": "knopentuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een knopentuin is een parterre bestaande uit laag geschoren haagplanten van eenzelfde of verschillende soort die ingeschreven, verstrengelde cirkels en vierkanten vormen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1592",
    },
    {
        "broader": [1608],
        "id": 1610,
        "labels": [{"label": "knotbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een knotboom is een boom waarvan de stam op een bepaalde hoogte wordt afgezet en die hierop opnieuw uitloopt. Door periodiek afzetten van de takken ontstaat een knot. Het knotten van de knotboom wordt uitgevoerd in kapcyclussen. De hoogte van de knot wordt bepaald tijdens de eerste knotbeurt. De minimale knothoogte van een knotboom wordt hier bepaald op 1 meter. Indien de knothoogte lager is dan spreken we van hakhout.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1610",
    },
    {
        "broader": [63],
        "id": 245,
        "labels": [
            {"label": "koetshuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "remises", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een koetshuis is een bijgebouw, in de eerste plaats van een kasteel en herenhuis, waarin men koetsen en andere voertuigen stalt.",
                "type": "scopeNote",
            }
        ],
        "related": [486],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/245",
    },
    {
        "broader": [343],
        "id": 702,
        "labels": [
            {"label": "koetsierswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/702",
    },
    {
        "broader": [21],
        "id": 246,
        "labels": [
            {"label": "koffiebranderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een koffiebranderij is een industrieel of ambachtelijk bedrijf waar men koffiebonen brandt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/246",
    },
    {
        "broader": [881],
        "id": 247,
        "labels": [{"label": "koffiehuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een koffiehuis is een openbare gelegenheid waar men vooral koffie serveert.",
                "type": "scopeNote",
            }
        ],
        "related": [91, 287, 423, 430],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/247",
    },
    {
        "broader": [522],
        "id": 248,
        "labels": [
            {"label": "koninklijke paleizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een koninklijk paleis is de riante verblijfplaats van leden van een koninklijk huis.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'paleizen' naar 'woonhuizen naar bewoners'. Overkoepelde term paleizen niet meer nodig.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/248",
    },
    {
        "broader": [147],
        "id": 1769,
        "labels": [{"label": "koren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004565"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1767],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een koor is een afzonderlijk deel van een kerk waar zich het (hoofd)altaar bevindt. Het koor is een meestal aan de oostzijde gelegen min of meer zelfstandige partij, veelal herkenbaar door zijn halfronde of veelhoekige koorsluiting.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1769",
    },
    {
        "broader": [522],
        "id": 249,
        "labels": [
            {"label": "kosterswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een kosterswoning is het woonhuis van een koster. Kosters zijn kerkelijke bedienden die belast zijn met de dagelijkse zorg voor het kerkgebouw en de kerkdienst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [340],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/249",
    },
    {
        "broader": [319],
        "id": 712,
        "labels": [
            {"label": "kostscholen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "pensionaten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kostschool is een priv\xe9-instelling voor lager en middelbaar onderwijs waar de leerlingen tevens kost en inwoning genieten.",
                "type": "scopeNote",
            }
        ],
        "related": [205],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/712",
    },
    {
        "broader": [384],
        "id": 1477,
        "labels": [
            {"label": "koude bakken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kweekbakken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een koude bak is een laag getimmerte, ook wel van steen, met glas gedekt, waarin gewassen koud worden gekweekt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1477",
    },
    {
        "broader": [466],
        "id": 283,
        "labels": [
            {"label": "kraamklinieken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "materniteiten", "language": "nl-BE", "type": "altLabel"},
            {"label": "moederhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kraamkliniek is een ziekenhuis waar vrouwen bevallen en daarna verzorgd worden.",
                "type": "scopeNote",
            }
        ],
        "related": [526],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/283",
    },
    {
        "broader": [2027],
        "id": 2029,
        "labels": [{"label": "kreekruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kreekrug is een rug, ontstaan bovenop een voormalige kreekbedding waarin grof bodemmateriaal (zand, silt) tijdens overstromingen langdurig is afgezet en die door reli\xebfinversie een beperkte hogere ligging kreeg dan zijn omgeving.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1979, 1978, 1976],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2029",
    },
    {
        "broader": [1962],
        "id": 1966,
        "labels": [{"label": "kreken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008706"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [2126, 2127],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kreek is een wigvormige natuurlijke waterloop gevormd onder getijdeninvloed, ofwel op een schor, ofwel ten gevolge van krachtige waterstroming door storm en/of een dijkdoorbraak in een polder.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1966",
    },
    {
        "broader": [1251],
        "id": 2166,
        "labels": [
            {"label": "krengbegravingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een krengbegraving is de begraving van de resten van \xe9\xe9n of meer dieren, of delen daarvan, waarbij de skeletonderdelen worden aangetroffen in dezelfde onderlinge positie als bij levende dieren het geval is (anatomisch verband).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/03/2016: toegevoegd bij afstemmen thesaurus met CGP.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Code Goede Praktijk", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2166",
    },
    {
        "broader": [1082],
        "id": 1085,
        "labels": [
            {"label": "kringgreppels", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kringgreppel is een randstructuur in de vorm van een ronde greppel rond een heuveltje met crematieresten uit de late bronstijd en vroege ijzertijd. De term wordt vrij `los` gehanteerd, d.w.z. ook wel gebruikt voor greppels met een andere dan ronde vorm.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1085",
    },
    {
        "broader": [1989],
        "id": 1990,
        "labels": [
            {"label": "kronkelwaardvlakten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een kronkelwaardvlakte is een (deel van een) alluviale vlakte met een door wisselende stromingen van een rivier gevormd patroon van ruggen en depressies. Door afzetting in de binnenbocht en erosie in de buitenbocht van de voormalige bedding van de natuurlijke waterloop hebben meanders zich zijdelings verplaatst en een microreli\xebfpatroon nagelaten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1990",
    },
    {
        "broader": [1565],
        "id": 752,
        "labels": [
            {"label": "kruidentuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1568],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kruidentuin, is een nutstuin voor het kweken van voornamelijk aromatische kruiden voor in de keuken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/752",
    },
    {
        "broader": [1637],
        "id": 1638,
        "labels": [{"label": "kruisbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kruisboom is een boom die bij een kruisbeeld is geplant of een boom waartegen een kruisbeeld of boomkruis is bevestigd.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1638",
    },
    {
        "broader": [237],
        "id": 891,
        "labels": [{"label": "kruisen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [92, 282, 508],
        "notes": [],
        "related": [507, 172],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/891",
    },
    {
        "broader": [1621],
        "id": 1622,
        "labels": [
            {"label": "kruispuntbomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kruispuntboom is een boom aangeplant bij een kruispunt van wegen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1622",
    },
    {
        "broader": [1045],
        "id": 2110,
        "labels": [
            {
                "label": "kruispuntnederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kruispuntnederzetting is een kernnederzetting gelegen aan een kruispunt van (spoor)wegen, kanalen of op een stopplaats zoals een station.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2110",
    },
    {
        "broader": [318],
        "id": 751,
        "labels": [{"label": "kruiswegen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kruisweg is een reeks van veertien afbeeldingen of staties waarop de route die Christus vlak voor zijn kruisiging aflegde is te zien. Kan aanwezig zijn in katholieke kerken, maar kan ook als een rondgang bij een kapel of Mariagrot of langs de openbare weg zijn gerealiseerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "11/04/2014: SN toegevoegd (definitie van Elise)",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/751",
    },
    {
        "broader": [],
        "id": 1096,
        "labels": [{"label": "kuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [1097, 1098, 1099],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kuil is een gat in de grond, een uitgegraven holte.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1096",
    },
    {
        "broader": [18],
        "id": 252,
        "labels": [{"label": "kuiperijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kuiperij is een ambachtelijk bedrijf waar men tonnen en vaten maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/252",
    },
    {
        "broader": [319],
        "id": 253,
        "labels": [
            {"label": "kunstacademies", "language": "nl-BE", "type": "prefLabel"},
            {"label": "academies", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kunstacademie is een gebouw voor onderwijs in de kunsten.",
                "type": "scopeNote",
            }
        ],
        "related": [304],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/253",
    },
    {
        "broader": [63],
        "id": 254,
        "labels": [
            {"label": "kunstenaarsateliers", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kunstenaarsatelier is een werkplaats voor een kunstenaar die losstaat van het woonhuis van de kunstenaar.",
                "type": "scopeNote",
            }
        ],
        "related": [255, 511, 32],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/254",
    },
    {
        "broader": [522],
        "id": 255,
        "labels": [
            {"label": "kunstenaarswoningen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "atelierwoningen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kunstenaarswoning is het woonhuis van een kunstenaar, meestal met (kunstenaars)atelier.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [254],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/255",
    },
    {
        "broader": [13],
        "id": 1837,
        "labels": [
            {
                "label": "kunstmatige waterlopen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [213, 1080, 1953],
        "notes": [],
        "related": [931, 1962],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1837",
    },
    {
        "broader": [],
        "id": 931,
        "labels": [
            {
                "label": "kunstmatige watervlakken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [467, 861, 920, 1110, 1597],
        "notes": [],
        "related": [1837, 1968],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/931",
    },
    {
        "broader": [932],
        "id": 1608,
        "labels": [
            {
                "label": "kunstmatig gevormde bomen en struiken",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "vormbomen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1604],
        "narrower": [
            1609,
            1610,
            1611,
            1706,
            1650,
            2197,
            1612,
            1671,
            1679,
            1678,
            1711,
            1709,
            2198,
        ],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kunstmatig gevormde boom of struik is een in een kunstmatige gedaante gesnoeide, periodiek onderhouden houtige plant.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: opnieuw aangepast van kunstmatig gevormde bomen naar kunstmatig gevormde bomen en struiken",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Van Daele", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1608",
    },
    {
        "broader": [1645],
        "id": 1649,
        "labels": [
            {
                "label": "kunstmatig gevormde struiken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1647],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kunstmatig gevormde struik is een in bepaalde kunstmatige gedaante gesnoeide struik.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1649",
    },
    {
        "broader": [2007],
        "id": 2009,
        "labels": [{"label": "kustduinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2008],
        "narrower": [2010, 2012],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kustduin is een duin(complex) ontstaan parallel aan een kustlijn en gevormd door het verstuiven van zand nabij de kust.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2009",
    },
    {
        "broader": [141],
        "id": 1178,
        "labels": [{"label": "kustforten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kustfort is een fort dat speciaal is ingericht voor, en deel uitmaakt van de kustverdediging.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1178",
    },
    {
        "broader": [78],
        "id": 1437,
        "labels": [
            {"label": "kustvaarders", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kustvaartuigen", "language": "nl-BE", "type": "altLabel"},
            {"label": "coasters", "language": "nl-BE", "type": "altLabel"},
            {"label": "kusters", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1428],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kustvaarder is een vaartuig dat in beginsel slechts van haven tot haven dicht onder de kust vaart.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1437",
    },
    {
        "broader": [1150],
        "id": 1181,
        "labels": [
            {"label": "kustversterkingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kustversterking is een versterking die is opgeworpen langs de zeekust, om de doorgang van schepen te verhinderen of om het land tegen aanvallen te beschermen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1181",
    },
    {
        "broader": [321],
        "id": 256,
        "labels": [{"label": "kuuroorden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kuuroord is een gebouw waar bezoekers heilzame behandelingen ondergaan, zoals geneeskrachtige baden en het drinken van bronwater.",
                "type": "scopeNote",
            }
        ],
        "related": [37],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/256",
    },
    {
        "broader": [2033],
        "id": 2034,
        "labels": [{"label": "kwelzones", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een kwelzone is een zone waar een diffuse, natuurlijke uitvloeiing van grondwater optreedt als gevolg van hydrostatische druk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2034",
    },
    {
        "broader": [73],
        "id": 1700,
        "labels": [
            {"label": "laagstamboomgaarden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een laagstamboomgaard is een boomgaard met fruitbomen op lage stam (ca. 30-60 cm)",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1700",
    },
    {
        "broader": [884],
        "id": 258,
        "labels": [{"label": "laboratoria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een laboratorium is een gebouw dat is uitgerust voor empirisch wetenschappelijk onderzoek en voor het bereiden van stoffen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/258",
    },
    {
        "broader": [440],
        "id": 1581,
        "labels": [{"label": "labyrinten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een labyrint is een ingewikkelde figuur, bestaande uit een concentrisch meanderende weg, die naar een centraal eindpunt leidt, van waaruit de weg recht naar de uitgang leidt. In een labyrint kan men niet verdwalen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'doolhoven' voor dergelijke constructies waarin men wel kan verdwalen",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1581",
    },
    {
        "broader": [319],
        "id": 259,
        "labels": [
            {"label": "lagere scholen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen waar onderwijs wordt verstrekt aan leerlingen tussen 6 en 12 jaar.",
                "type": "scopeNote",
            }
        ],
        "related": [320],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/259",
    },
    {
        "broader": [180],
        "id": 260,
        "labels": [{"label": "lakenhallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lakenhal is een markthal waar laken gekeurd, gemeten en verhandeld wordt. Ze komen vaak voor in samenhang met een belfort.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: Aanvullen SN met 'Ze komen vaak voor in samenhang met een belfort.'",
                "type": "historyNote",
            },
        ],
        "related": [281, 56],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/260",
    },
    {
        "broader": [924],
        "id": 1747,
        "labels": [
            {"label": "lampisterie\xebn", "language": "nl-BE", "type": "prefLabel"},
            {"label": "lampisterijen", "language": "nl-BE", "type": "altLabel"},
            {"label": "lampenhokken", "language": "nl-BE", "type": "altLabel"},
            {"label": "lampenwerkplaatsen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lampisterie is een werkplaats, meestal bij een trein- of tramstation, waar alle (olie- en petroleum)lampen werden onderhouden, schoongemaakt en gerepareerd.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1747",
    },
    {
        "broader": [1308],
        "id": 261,
        "labels": [
            {"label": "landbouwkolonies", "language": "nl-BE", "type": "prefLabel"},
            {
                "label": "rijksweldadigheidskolonies",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een landbouwkolonie is een nederzetting die op initiatief van een overheid op onvruchtbare grond gesticht is met de bedoeling deze om te zetten in landbouwgrond. Deze kolonies werden bewoond door armere families en/of bedelaars die werden aangemoedigd of verplicht hier te wonen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'huisvestingscomplexen' naar 'agrarische complexen'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/261",
    },
    {
        "broader": [2007],
        "id": 2015,
        "labels": [{"label": "landduinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2008],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een landduin is een duin(complex) ontstaan in het binnenland, buiten het kust- of riviergebied, gevormd onder droge omstandigheden en/of onder invloed van vegetatievernietiging door de mens.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2015",
    },
    {
        "broader": [1116],
        "id": 1117,
        "labels": [
            {
                "label": "landelijke heiligdommen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "openluchttempels", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een landelijk heilidom is een formele, ev. niet-overdekte locatie van niet-christelijke religieuze handelingen. Het waren min of meer vierkante terreinen die waren omgeven door een aarden wal en soms ook een greppel. Er was een toegang tot het binnenterrein waar vaak een klein gebouwtje in een hoek stond. Meestal hoorde een oude boom tot het religieuze complex. Dergelijke heiligdommen komen vooral voor tijdens de late bronstijd en de Vroeg-Romeinse Tijd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) De Wit G. &amp; Sloos A. 2008, De interpretatie van archeologische waarnemingen in Archis. Een concept voor een nieuwe set complextypen, in: Rapportage Archeologische Monumentenzorg 165, Amersfoort. 2) Hendriks J. 1994, Prisma Archeologie in de Lage Landen, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1117",
    },
    {
        "broader": [225],
        "id": 262,
        "labels": [
            {"label": "landhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hoven van plaisantie", "language": "nl-BE", "type": "altLabel"},
            {"label": "lusthoven", "language": "nl-BE", "type": "altLabel"},
            {"label": "buitenplaatsen", "language": "nl-BE", "type": "altLabel"},
            {"label": "speelhoven", "language": "nl-BE", "type": "altLabel"},
            {"label": "kasteeltjes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kastelen en 'kasteeltjes', gelegen buiten de stad, waarbij de nadruk ligt op de residenti\xeble functie en minder op de verdedigende functie. Doorgaans gesitueerd in een groot park of een ruime tuin.",
                "type": "scopeNote",
            }
        ],
        "related": [188, 206, 223, 468],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/262",
    },
    {
        "id": 1849,
        "labels": [
            {"label": "landinrichting", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [1847],
        "members": [1850, 2076, 2165],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1849",
    },
    {
        "id": 1850,
        "labels": [
            {
                "label": "landinrichting naar cultuurtechniek",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1849],
        "members": [2066, 2067, 2070, 2073, 2074, 2075],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1850",
    },
    {
        "id": 1847,
        "labels": [
            {
                "label": "landschappelijke gehelen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1848, 1849, 2103],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1847",
    },
    {
        "id": 1848,
        "labels": [
            {
                "label": "landschappen naar verschijningsvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1847],
        "members": [2059, 2060, 2064],
        "notes": [],
        "sources": [],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1848",
    },
    {
        "broader": [170],
        "id": 1266,
        "labels": [
            {"label": "langbedden", "language": "nl-BE", "type": "prefLabel"},
            {"label": "long barrows", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1265],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een langbed is een soort grafheuvel met een rechthoekige, ovale tot trapezo\xefdale vorm (mogelijk afgeleid van de gelijktijdige huisvorm) waaronder een stenen (cist) of houten grafkamer is aangelegd. Het aantal graven in een dergelijke heuvel is in de vroegste gebruiksperiode beperkt (nog geen collectieve bijzettingen) en het aantal grafgiften is gering. Langbedden kunnen omgeven worden door een houten pallissade en/of een greppel.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Roymans N. &amp; Kortlang F. 1999, Urnfield symbolism, ancestors and the land in the Lower Rhine Region, in: F. Theuws &amp; N. Roymans (eds.), Land and ancestors: cultural dynamics in the Urnfield Period and the Middle Ages in the Southern Netherlands, Amsterdam Archaeological Studies 4, pp. 33-63. 2) cursusmateriaal UGent (Prof. Ph. Cromb\xe9)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1266",
    },
    {
        "broader": [190],
        "id": 1422,
        "labels": [
            {"label": "langgestrekte hoeven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1418],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Toegevoegd op 07/10/2011 na overleg op inventariswerkgroep en met Sophie Mortier (LM)",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1422",
    },
    {
        "broader": [1948],
        "id": 1954,
        "labels": [
            {"label": "langsgrachten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "zijlingen", "language": "nl-BE", "type": "altLabel"},
            {"label": "meegangen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een langsgracht is een gracht aangelegd als tijdelijk in te schakelen omleiding rond een waterbouwkundige constructie (bijvoorbeeld watermolen, sluis,\u2026), vaak ook (als by-pass) in functie van vismigratie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1954",
    },
    {
        "broader": [237],
        "id": 265,
        "labels": [
            {"label": "lantaarns", "language": "nl-BE", "type": "prefLabel"},
            {"label": "lantarens", "language": "nl-BE", "type": "altLabel"},
            {"label": "lantarenpalen", "language": "nl-BE", "type": "altLabel"},
            {"label": "lantaarnpalen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kastjes met een of meer doorschijnende wanden, waarin een lichtbron geplaatst wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Enkel vrijstaande lantaarns, geplaatst op een paal, zijn opgenomen in de databank.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/265",
    },
    {
        "broader": [237],
        "id": 266,
        "labels": [{"label": "lapidaria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Stenen overblijfselen van gebouwen of grafmonumenten, doelbewust verzameld en uitgestald in openlucht.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/266",
    },
    {
        "broader": [1207],
        "id": 1208,
        "labels": [{"label": "latrines", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een latrine is oorspronkelijk een openbaar toilet waarin meerdere zitplaatsen voorzien zijn. Deze staan vaak in verbinding met een ander openbaar gebouw zoals een badhuis of ze komen voor in militaire context. Ze kunnen uitgevoerd zijn in hout of in steen. De lozing van een latrine gebeurde in een beerput, beerkuil of via een stortkoker naar buiten (eventueel naar een gracht).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Heirbaut E. 2008, Onderzoek naar de eerste eeuwse beerputten uit oppidum Batavorum (Nijmegen NL), in: Romeinendag. Jaarlijks Belgisch congres voor Romeinse archeologie 19/04/2008, pp. 55-59. 2) Lamarcq D. 1993, Het latrinair gebeuren. De geschiedenis van het W.C., Gent. 3) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1208",
    },
    {
        "broader": [466],
        "id": 267,
        "labels": [
            {"label": "lazaretten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "lazerijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [844, 750],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lazaret is een ziekenhuis waar besmettelijke ziekten worden behandeld, oorspronkelijk voornamelijk melaatsheid (lepra) of 'lazarusziekte'.",
                "type": "scopeNote",
            }
        ],
        "related": [526, 202, 369],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/267",
    },
    {
        "broader": [2027],
        "id": 2123,
        "labels": [
            {"label": "leemruggen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "l\xf6ssruggen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een leemrug is een rug, waarvan de bovenste laag overwegend is opgebouwd met door de wind afgezet leem of l\xf6ss.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1975],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2123",
    },
    {
        "broader": [1293],
        "id": 1300,
        "labels": [{"label": "leemwinning", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar leem gewonnen is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1300",
    },
    {
        "broader": [20],
        "id": 268,
        "labels": [
            {"label": "leerlooierijen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "huidevetterijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een leerlooierij is een ambachtelijk bedrijf waar men van huiden leer maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/268",
    },
    {
        "broader": [20],
        "id": 1290,
        "labels": [
            {"label": "leerlooierskuipen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1290",
    },
    {
        "broader": [1608],
        "id": 1706,
        "labels": [{"label": "leibomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1707],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een leiboom is een boom waarvan alle gesteltakken in \xe9\xe9n verticaal vlak worden geleid. Soms worden de geleide bomen tegen een muur geleid of wordt er in een leidconstructie voorzien.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1706",
    },
    {
        "broader": [1706],
        "id": 1707,
        "labels": [
            {"label": "leifruit", "language": "nl-BE", "type": "prefLabel"},
            {"label": "espalier", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Leifruit is een laagstammige leiboom van een specifiek fruitras die langs een muur, schutting, raamwerk e.d. geleid wordt. Er bestaan talrijke snoeivormen van leifruit (enkele en dubbele U-vorm, dubbele V-vorm, kandelaarvorm, waaiervorm, spilvorm,...).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/07/2016: SN aangepast.",
                "type": "historyNote",
            },
        ],
        "related": [73],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1707",
    },
    {
        "broader": [1948],
        "id": 1950,
        "labels": [{"label": "leigrachten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een leigracht is een perifere afvoergracht die lange tijd vrijwel parallel langs een rivier loopt. Soms is deze kunstmatige waterloop (gedeeltelijk) ontstaan door vergraving van natuurlijke waterlopen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1950",
    },
    {
        "broader": [267],
        "id": 750,
        "labels": [
            {"label": "leprozerie\xebn", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/750",
    },
    {
        "broader": [466],
        "id": 886,
        "labels": [
            {
                "label": "liefdadigheidsinstellingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300026005"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [506, 837, 1124],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/886",
    },
    {
        "broader": [2091],
        "id": 2093,
        "labels": [{"label": "liften", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": ["http://vocab.getty.edu/aat/300051186"],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lift is een hijstoestel met mechanismen voor het verticaal vervoer van mensen of goederen van en naar verdiepingen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd i.f.v. beschermingsdatabank",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>\n2) Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2093",
    },
    {
        "broader": [142],
        "id": 269,
        "labels": [
            {"label": "lijkenhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "dodenhuisjes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1226],
        "narrower": [736],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lijkenhuis is een gebouw op een begraafplaats, bij ziekenhuizen enz. waar lijken tijdelijk bewaard worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'funerair erfgoed' naar 'funerair gerelateerde constructies'.",
                "type": "historyNote",
            },
        ],
        "related": [331],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/269",
    },
    {
        "broader": [15],
        "id": 270,
        "labels": [
            {"label": "lijmfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lijmfabriek is een industrieel bedrijf waar men lijm produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/270",
    },
    {
        "broader": [1146],
        "id": 1160,
        "labels": [{"label": "limites", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "De limes vertegenwoordigt de Romeinse versterkte grenzen of verdedigingszones.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1160",
    },
    {
        "broader": [2078],
        "id": 2081,
        "labels": [
            {
                "label": "lineaire ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lineair ontginningspatroon bestaat uit evenwijdige stroken die (eventueel nadien) zijn opgedeeld in blokvormige percelen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2081",
    },
    {
        "broader": [293],
        "id": 1145,
        "labels": [
            {
                "label": "lineaire verdedigingswerken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [272, 1154, 1155, 1158, 1152],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1145",
    },
    {
        "broader": [293],
        "id": 1146,
        "labels": [{"label": "linies", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1160],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een linie is een samenhangende reeks van verdedigingswerken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1146",
    },
    {
        "broader": [],
        "id": 1978,
        "labels": [
            {"label": "litorale processen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een litoraal proces is het proces waarbij geomorfologische elementen gevormd worden onder invloed van getijden, gelegen in de kustvlakte.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1985, 2029],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1978",
    },
    {
        "broader": [103],
        "id": 1272,
        "labels": [
            {"label": "logeergelegenheden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [913, 193],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij opsplitsing van 'horecazaken' naar 'eet-en drinkgelegenheden' en 'logeergelegenheden'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1272",
    },
    {
        "broader": [27],
        "id": 2181,
        "labels": [
            {"label": "logementshuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vrijgezellentehuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een logementshuis is een appartementsgebouw voor alleenstaanden, met gedeelde essenti\xeble woningfuncties zoals badkamer en/of keuken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2181",
    },
    {
        "broader": [78],
        "id": 1445,
        "labels": [
            {"label": "loodsboten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "loodstenders", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een loodsboot is een vaartuig waarmee de loodsen aan boord van de in- en uitgaande schepen gebracht worden of van boord gehaald worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1445",
    },
    {
        "broader": [923],
        "id": 271,
        "labels": [
            {"label": "loodswezengebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een loodswezengebouw is een gebouw van de loodsdienst. De loodsdienst leidt schepen door een vaarwater en brengt bakens aan.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/271",
    },
    {
        "broader": [1841],
        "id": 1843,
        "labels": [{"label": "loofbossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1842],
        "narrower": [1921, 2140, 2141],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een loofbos is een bos geheel bestaand uit loofboomsoorten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1843",
    },
    {
        "broader": [1145],
        "id": 272,
        "labels": [{"label": "loopgraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Uitgegraven gangen als gevechtsopstellingen of waarin men zich kan verplaatsen terwijl men gedekt is tegen vijandelijk vuur",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'lineaire verdedigingswerken'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005; Begrippenlijst van de Stichting Menno van Coehoorn (<a href="http://www.coehoorn.nl/">http://www.coehoorn.nl/</a>)',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/272",
    },
    {
        "broader": [],
        "id": 1382,
        "labels": [
            {"label": "losse vondsten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1381],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Losse vondsten zijn vondsten die buiten hun oorspronkelijke context zijn geraakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1382",
    },
    {
        "broader": [925],
        "id": 273,
        "labels": [{"label": "luchthavens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een luchthaven is een vliegveld voor passagiers- en vrachtvliegtuigen, met gebouwen voor vertrek en aankomst.",
                "type": "scopeNote",
            }
        ],
        "related": [476],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/273",
    },
    {
        "broader": [1151],
        "id": 1190,
        "labels": [{"label": "lunetten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een lunet is een buitenwerk van een vesting dat het achterliggende verdedigingswerk dekt aan de hand van een sikkelvormige constructie met twee schuine muren (faces) die een punt vormen vooraan, maar achteraan open is gelaten door middel van twee muren die naar achter wijzen (flanken).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht. 2) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1190",
    },
    {
        "broader": [],
        "id": 2051,
        "labels": [{"label": "luvisols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1856],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een luvisol is een bodem met een aanrijkingshorizont van klei, gevormd in zandleem of leem, gekenmerkt door een basische samenstelling.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2051",
    },
    {
        "broader": [21],
        "id": 274,
        "labels": [
            {"label": "maalderijen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "bloemmolens", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [833],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een maalderij is een industrieel bedrijf waar men (in de eerste plaats graan) maalt met mechanische aandrijfkracht.",
                "type": "scopeNote",
            }
        ],
        "related": [297],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/274",
    },
    {
        "broader": [281],
        "id": 1273,
        "labels": [
            {"label": "macella", "language": "nl-BE", "type": "prefLabel"},
            {"label": "macellum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een macellum is een Romeinse vleesmarkt; kan ook meer algemeen worden gebruikt voor Romeinse voedselmarkten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1273",
    },
    {
        "broader": [884],
        "id": 275,
        "labels": [
            {"label": "machinezalen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "machinehuizen", "language": "nl-BE", "type": "altLabel"},
            {"label": "machinekamers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een machinezaal is een gebouw waar de motor (stoommotor, gasmotor, petroleummotor) van een bedrijf opgesteld staat.",
                "type": "scopeNote",
            }
        ],
        "related": [233],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/275",
    },
    {
        "broader": [18],
        "id": 276,
        "labels": [
            {"label": "mandenmakerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mandenmakerij is een ambachtelijk bedrijf waar men manden vlecht.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/276",
    },
    {
        "broader": [896],
        "id": 277,
        "labels": [{"label": "maneges", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een man\xe8ge is een gebouw voor paardrijles, met een piste en paardenstallen.",
                "type": "scopeNote",
            }
        ],
        "related": [365],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/277",
    },
    {
        "broader": [1131],
        "id": 1132,
        "labels": [{"label": "mansiones", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mansio is een rustplaats langs Romeinse of Byzantijnse wegen (gedurende de 7de eeuw), meestal een dagreis van elkaar verwijderd (ca. 32 tot 48 km) en bedoeld als plaats om te overnachten; aanvankelijk vooral bedoeld voor keizerlijke gezelschappen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'mutationes' voor tussenliggende rustplaatsen langs deze routes.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Adkins L. &amp; Adkins R. 1998, Handbook to life in ancient Rome, New York.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1132",
    },
    {
        "broader": [21],
        "id": 941,
        "labels": [
            {"label": "margarinefabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een margarinefabriek is een industrieel of ambachtelijk bedrijf waar men margarine maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/941",
    },
    {
        "broader": [1526],
        "id": 278,
        "labels": [{"label": "Mariabeelden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Driedimensionale beelden van Maria.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Enkel de Mariabeelden die voorkomen op plaatsen waar hun aanwezigheid niet logisch volgt uit de context, zijn opgenomen in de databank.",
                "type": "note",
            },
        ],
        "related": [279, 412, 507],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/278",
    },
    {
        "broader": [507],
        "id": 279,
        "labels": [
            {"label": "Mariagrotten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Lourdesgrotten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kunstmatige grotten waarin een Mariabeeld staat opgesteld. Deze grotten waren vooral populair in de eerste helft van de 20ste eeuw, en waren bedoeld om de verschijning van Maria in Lourdes (Frankrijk,1858) te herdenken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Op 3 maart 2010 werd de term verschoven van "kapellen (bouwkundig erfgoed)" naar "kapellen (klein erfgoed)" als broader term.\nOp 31 maart 2010 werden de scopenote en de indexing note aangepast.',
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Zowel grote, toegankelijke grotconstructies als zeer bescheiden kapellen in grotvorm vallen onder de term "mariagrotten".\n\nOpmerking: Na de verschijning van Maria te Banneux (Belgi\xeb, 1933) werden op diverse plaatsen Mariabeelden opgericht. Als het hierbij om vrijstaande, driedimensionale beelden gaat, zijn deze te vinden onder de term "Mariabeelden".',
                "type": "note",
            },
        ],
        "related": [278, 366, 441],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/279",
    },
    {
        "broader": [],
        "id": 1979,
        "labels": [
            {"label": "mariene processen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een marien proces is het proces waarbij geomorfologische elementen gevormd worden onder het zeeoppervlak waar geen getijdeninvloed heerst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [2004, 2029],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1979",
    },
    {
        "broader": [1147],
        "id": 280,
        "labels": [
            {"label": "marinebasissen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een marinebasis is een gebouw aan wal van waaruit de marine opereert en logistiek ondersteund wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'militaire gebouwen en constructies' naar 'militaire kampen en bases'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/280",
    },
    {
        "broader": [78],
        "id": 1443,
        "labels": [
            {"label": "marineschepen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een marineschip is een vaartuig gebouwd voor of gebruikt door de Marinecomponent van het leger.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1443",
    },
    {
        "broader": [932],
        "id": 1621,
        "labels": [
            {"label": "markeringsbomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1605],
        "narrower": [1622, 1623, 1624, 1625],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een markeringsboom is een boom waarmee een bepaalde plaats gemarkeerd wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1621",
    },
    {
        "broader": [891],
        "id": 282,
        "labels": [{"label": "marktkruisen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Stenen kruisen op marktpleinen, sinds de middeleeuwen opgericht als symbool van de marktvrede.",
                "type": "scopeNote",
            }
        ],
        "related": [406],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/282",
    },
    {
        "broader": [885],
        "id": 281,
        "labels": [
            {"label": "marktplaatsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "markten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1273],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een marktplaats is een plein of straat/straten waar vee, levensmiddelen en andere handelswaar uitgestald en verkocht worden, in kramen of in kleine permanente structuren. Men kan verschillende soorten markten onderscheiden, zoals kaasmarkten, veemarkten, vismarkten, groentenmarkten, enz\u2026",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '24/01/2011: SN uitgebreid. oorspronkelijke SN: "Pleinen of straten waar vee, levensmiddelen en andere handelswaar uitgestald en verkocht worden, in kramen of in een permanente structuur."',
                "type": "historyNote",
            },
        ],
        "related": [168, 469, 475, 260, 517, 347, 180],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/281",
    },
    {
        "broader": [1161],
        "id": 1165,
        "labels": [{"label": "marskampen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een marskamp is een kamp, opgericht voor een eenmalige overnachting, omgeven door een gracht en/of wal/palissade voor Romeinse troepen op campagne of doortocht.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'National Monuments Record thesaurus (English Heritage), <a href="http://thesaurus.english-heritage.org.uk/frequentuser.htm">http://thesaurus.english-heritage.org.uk/frequentuser.htm</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1165",
    },
    {
        "broader": [1227],
        "id": 1249,
        "labels": [{"label": "massagraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1230],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een massagraf is een graf waarin een groot aantal lijken/krengen tegelijk (ongekist) begraven worden. Vaak verbonden aan oorlogen en epidemie\xebn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1249",
    },
    {
        "broader": [],
        "id": 1967,
        "labels": [{"label": "meanders", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008727"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1859],
        "narrower": [2128, 2129, 2130],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een meander is een lusvormige bocht in een bestaande of vroegere natuurlijke waterloop, vaak in een aaneengeschakeld patroon, ontstaan door erosie van bodemmateriaal in de buitenbocht en afzetting in de binnenbocht. Meanders kunnen door natuurlijke processen of menselijk ingrijpen afgesneden worden van de actieve waterloop.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1967",
    },
    {
        "broader": [752],
        "id": 1568,
        "labels": [
            {"label": "medicinale tuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een medicinale tuin is een nutstuin waarin geneeskrachtige en/of aromatische kruiden worden gekweekt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1568",
    },
    {
        "broader": [520],
        "id": 284,
        "labels": [
            {"label": "meergezinswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005703"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [27, 417, 2182, 2183],
        "notes": [],
        "related": [196],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/284",
    },
    {
        "broader": [2],
        "id": 1931,
        "labels": [{"label": "meerpalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": ["http://vocab.getty.edu/aat/300007937"],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een meerpaal is een vast verankeringspunt aan een oever of kade waar vaartuigen zich aan kunnen vastleggen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1931",
    },
    {
        "broader": [1059],
        "id": 2105,
        "labels": [
            {
                "label": "meervoudige pleinnederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een meervoudige pleinnederzetting is een pleinnederzetting waar de bebouwing is geconcentreerd rond verschillende pleinen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2105",
    },
    {
        "broader": [343],
        "id": 285,
        "labels": [
            {"label": "meesterwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een meesterwoning is het woonhuis van een meester of voorman, die de leiding heeft over een ploeg collega's arbeiders.",
                "type": "scopeNote",
            }
        ],
        "related": [320, 29],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/285",
    },
    {
        "broader": [1319],
        "id": 1320,
        "labels": [{"label": "meilers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een meiler is een structuur bedoeld voor het vervaardigen van houtskool die wordt opgebouwd uit hakhout, gestapeld langs een centrale, met hout opgebouwde schoorsteen. Om het hout af te sluiten van de buitenlucht, werd het bedekt met aarde en zoden. In de schoorsteen werd reeds brandende houtskool gegoten om de oven te ontsteken. Men kan ook meilers onderscheiden waarvan de brandplaats als een grote kuil was ingegraven waarin het hout werd gedeponeerd om vervolgens te laten verkolen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "28/01/2011: Term toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Boeren I. e.a. 2009, Een archeologische evaluatie en waardering van houtskoolmeilers in het Zoerselbos (Zoersel, provincie Antwerpen), Instituut voor Natuur- en Bosonderzoek (INBO). <a href="http://www.onroerenderfgoed.be/nl/uploads/b1126.pdf">http://www.onroerenderfgoed.be/nl/uploads/b1126.pdf</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1320",
    },
    {
        "broader": [533],
        "id": 740,
        "labels": [{"label": "melkerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/740",
    },
    {
        "broader": [151],
        "id": 286,
        "labels": [
            {"label": "melkhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "melkkamers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een melkhuis (agrarisch gebouw) is een bijgebouw op een hoeve, gebruikt voor het koelen en verwerken van melk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Qualifier aangepast",
                "type": "historyNote",
            },
        ],
        "related": [287, 533],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/286",
    },
    {
        "broader": [881],
        "id": 287,
        "labels": [{"label": "melkhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een melkhuis (eet- en drinkgelegenheid) is een publieke gelegenheid waar men in de eerste plaats melk en andere zuiveldranken serveert, meestal in parken.",
                "type": "scopeNote",
            }
        ],
        "related": [286, 247, 533],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/287",
    },
    {
        "broader": [1227],
        "id": 1252,
        "labels": [{"label": "mensengraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1231],
        "narrower": [1253, 1254],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mensengraf is een graf waarin gecremeerde of ge\xefnhumeerde botresten van \xe9\xe9n of meer mensen werd geplaatst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1252",
    },
    {
        "broader": [1968],
        "id": 1969,
        "labels": [{"label": "meren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008680"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een meer is een uitgestrekt en meestal diep natuurlijk watervlak.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Objectencatalogus NGI: <a href="http://www.ngi.be/gdes/">http://www.ngi.be/gdes/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1969",
    },
    {
        "broader": [1293],
        "id": 1301,
        "labels": [
            {"label": "mergelwinning", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar mergel (kalkhoudende klei) gewonnen is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1301",
    },
    {
        "broader": [151],
        "id": 642,
        "labels": [{"label": "mestvaalten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mestvaalt is een constructie om vaste mest in te verzamelen en te bewaren.",
                "type": "scopeNote",
            }
        ],
        "related": [1],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/642",
    },
    {
        "broader": [22],
        "id": 288,
        "labels": [
            {"label": "metaalfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een metaalfabriek is een industrieel bedrijf waar men metaal(ertsen) verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/288",
    },
    {
        "broader": [18],
        "id": 289,
        "labels": [
            {"label": "meubelfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een meubelfabriek is een industrieel of ambachtelijk bedrijf waar men meubels produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [380],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/289",
    },
    {
        "broader": [],
        "id": 2035,
        "labels": [
            {"label": "microreli\xebfvormen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een microreli\xebfvorm is de natuurlijke interne variatie binnen een grotere geomorfologische reli\xebfvorm (heuvel, rug, vlakte, \u2026) bestaande uit kleine hoogteverschillen (zelden groter dan 0.5m) op korte afstand van elkaar.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2035",
    },
    {
        "broader": [1841],
        "id": 1666,
        "labels": [
            {"label": "middelhoutpercelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1659],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een middelhoutperceel is een bostype bestaande uit hakhout met periodiek beheer en overstaanders of opgaande bomen die selectief gekapt worden. De bomenetage verdwijnt zelden volledig.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1666",
    },
    {
        "broader": [1770],
        "id": 1771,
        "labels": [{"label": "middenbeuken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een middenbeuk is de middelste van drie, vijf of zeven beuken van een kerk.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1771",
    },
    {
        "broader": [152],
        "id": 738,
        "labels": [
            {"label": "middenscholen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/738",
    },
    {
        "broader": [290],
        "id": 962,
        "labels": [{"label": "mijlpalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/962",
    },
    {
        "broader": [28],
        "id": 2169,
        "labels": [{"label": "mijncit\xe9s", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mijncit\xe9 is een woonwijk voor arbeiders en personeel die in dienst zijn van de mijnindustrie, ontworpen als een geheel en meestal gefinancierd door de mijnindustrie. Vaak omvat dit ook collectieve voorzieningen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2169",
    },
    {
        "broader": [1008],
        "id": 291,
        "labels": [{"label": "mijngebouwen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300006423"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [915],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mijngebouw omvat gebouwen en constructies, zoals schachtbokken, om delfstoffen te ontginnen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Op 14/08/2009 onder de topterm steenkoolmijnen gebracht (i.p.v. rechtstreeks onder gebouwen voor delfstofwinning).",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/291",
    },
    {
        "broader": [2143],
        "id": 2144,
        "labels": [
            {"label": "mijnhoutbossen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "mastbossen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mijnhoutbos is een productiebos (meestal hoogopgaande dennen), oorspronkelijk uitsluitend ten behoeve van constructiehout voor het stutten van mijngangen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2144",
    },
    {
        "broader": [],
        "id": 1796,
        "labels": [{"label": "mijnkraters", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1373],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mijnkrater is een depressie in het landschap die is ontstaan als gevolg van de ontploffing van \xe9\xe9n of meerdere mijnen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1796",
    },
    {
        "broader": [54],
        "id": 292,
        "labels": [
            {
                "label": "militaire begraafplaatsen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {
                "label": "oorlogsbegraafplaatsen",
                "language": "nl-BE",
                "type": "altLabel",
            },
            {"label": "militaire kerkhoven", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een militaire begraafplaats is een begraafplaats voor uitsluitend militaire oorlogsslachtoffers.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Graven van militairen op een burgerlijke begraafplaats zijn niet opgenomen als militaire begraafplaatsen.",
                "type": "note",
            },
        ],
        "related": [1415, 1416, 293],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/292",
    },
    {
        "broader": [1147],
        "id": 1009,
        "labels": [
            {"label": "militaire domeinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Toegevoegd op 14/08/2009 in het kader van de revisie van de gehelen.\n21/01/2011: BT gewijzigd van 'militaire gebouwen en constructies' naar 'militaire kampen en bases' bij integratie.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1009",
    },
    {
        "broader": [54],
        "id": 1415,
        "labels": [
            {"label": "militaire ereperken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een militair ereperk is een verzameling van oorlogsgraven van tijdens de oorlog gesneuvelde militairen, gelegen op een burgerlijke begraafplaats.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Term toegevoegd op 07/07/2011 naar aanleiding van de synchronisatie met de databank Wereldoorlogerfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [292, 1416],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1415",
    },
    {
        "broader": [293],
        "id": 1148,
        "labels": [
            {"label": "militaire gebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [34, 228, 294, 392],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1148",
    },
    {
        "broader": [1147],
        "id": 1161,
        "labels": [
            {"label": "militaire kampen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1162, 1164, 1165, 1166],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een militair kamp is de verblijfplaats van een onderdeel van het leger. Het is in essentie een groep tenten of barakken in hout- en/of steenbouw, eventueel aangevuld met andere infrastructuur, die verdedigd worden met een wal en/of gracht(en); wordt in historische context gebruikt voor zowel zeer tijdelijke, semi-permanente als permanente kampplaatsen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1161",
    },
    {
        "broader": [293],
        "id": 1147,
        "labels": [
            {
                "label": "militaire kampen en bases",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1009, 1161, 280],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1147",
    },
    {
        "broader": [1148],
        "id": 294,
        "labels": [
            {"label": "militaire keukens", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een militaire keuken is een tijdelijk gebouw op het achterplan van een front waar voedsel voor de troepen bereid en verdeeld wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'militaire gebouwen en constructies' naar 'militaire gebouwen'.",
                "type": "historyNote",
            },
        ],
        "related": [214],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/294",
    },
    {
        "broader": [1116],
        "id": 1118,
        "labels": [{"label": "mithraea", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mithraeum is een heiligdom voor de volgelingen van de mysteriegodsdienst van het mithra\xefsme. Een mithraeum was vaak gelokaliseerd in een natuurlijke grot of in een ruimte die een grot imiteerde. Dergelijke heiligdommen zijn te herkennen aan de banken die langsheen de muren lopen en het kenmerkend symbolisme van Mithras die een stier doodt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1118",
    },
    {
        "broader": [],
        "id": 2135,
        "labels": [
            {
                "label": "moerasijzerertsafzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2133],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een moerasijzerertsafzetting is een afzetting in alluviale gebieden, die ontstaat doordat in water opgelost ijzer door kwel aan de oppervlakte komt en door contact met zuurstof neerslaat. De roestkleurige neerslag kan klein en korrelig, groot en vast zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2135",
    },
    {
        "broader": [],
        "id": 2137,
        "labels": [
            {"label": "moeraskalkafzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2133],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een moeraskalkafzetting is een afzetting in alluviale gebieden, die geleidelijk en onder invloed van grondwaterstroming ontstaat door neerslag van afgestorven kalkalgen en mollusken (slakken, tweekleppigen) in stilstaand water. De moeraskalk die door de kalkalgen en mollusken werd opgenomen is afkomstig van kalkrijke kwel. In verdroogde toestand bestaat de neerslag uit verkitte, soms verbrokkelde witgrijze tot leverkleurige banken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2137",
    },
    {
        "broader": [],
        "id": 1915,
        "labels": [{"label": "moerassen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300008903"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1840],
        "narrower": [1916],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een moeras is een weinig productief bodemgebruik op nat en drassig land, met een vegetatie die gedomineerd wordt door veenmos, zegge, riet en/of ijl bos (ook wel moer, goor).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1915",
    },
    {
        "broader": [1564],
        "id": 1567,
        "labels": [{"label": "moerastuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een moerastuin is een waterachtige, drassige tuin waarin moerasplanten aangeplant zijn.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1567",
    },
    {
        "broader": [1304],
        "id": 1305,
        "labels": [{"label": "moernering", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Moernering is de productie van en handel in veenproducten, waarbij met moer veen of veengebied wordt bedoeld. Hiermee kan men ook bedoelen: turf afgraven voor het winnen van zout.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1324],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1305",
    },
    {
        "broader": [1565],
        "id": 295,
        "labels": [{"label": "moestuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1569, 1570],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een moestuin is een tuin waarin men groenten, fruit en kruiden verbouwt voor eigen gebruik.",
                "type": "scopeNote",
            }
        ],
        "related": [792],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/295",
    },
    {
        "broader": [522],
        "id": 296,
        "labels": [
            {"label": "molenaarswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een molenaarswoning is het woonhuis van een molenaar, gelegen in de nabijheid van de molen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [297, 498, 514],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/296",
    },
    {
        "broader": [1837],
        "id": 1953,
        "labels": [{"label": "molenlopen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een molenloop is een kunstmatige waterloop bestemd voor de aanvoer van proceswater voor aandrijving van een watermolen. Soms is deze kunstmatige waterloop (gedeeltelijk) ontstaan door vergraving van natuurlijke waterlopen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1953",
    },
    {
        "broader": [307],
        "id": 297,
        "labels": [{"label": "molens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [929, 365, 498, 514],
        "notes": [],
        "related": [157, 274, 316, 296],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/297",
    },
    {
        "broader": [425],
        "id": 1542,
        "labels": [
            {"label": "monopteroi", "language": "nl-BE", "type": "prefLabel"},
            {"label": "zuilentempeltjes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1544],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een monopteros is een open, rond gebouw met een koepel als dak in tuinen en parken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale online 2) agentschap Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1542",
    },
    {
        "broader": [269],
        "id": 736,
        "labels": [{"label": "mortuaria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/736",
    },
    {
        "broader": [359],
        "id": 298,
        "labels": [{"label": "moskee\xebn", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een moskee is een gebedshuis voor moslims. Moslims zijn islamieten of aanhangers van de islam.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/298",
    },
    {
        "broader": [78],
        "id": 1430,
        "labels": [{"label": "motorschepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1427],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een motorschip is een vaartuig dat hoofdzakelijk wordt aangedreven door een machine die beweegkracht levert door elektriciteit of door verbranding van een gasmengsel (diesel of benzine).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005 (lemma motor)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1430",
    },
    {
        "broader": [78],
        "id": 1433,
        "labels": [{"label": "motorzeilers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1427],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een motorzeiler is een vaartuig waarvoor zeilen en motor gelijkwaardige voortstuwingsmiddelen zijn.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1433",
    },
    {
        "broader": [1151],
        "id": 1191,
        "labels": [{"label": "motteheuvels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een motteheuvel is een middeleeuwse kunstmatige, steile heuvel waarop een versterkte toren (donjon) staat of gestaan heeft. Versterkt door wallen, grachten, palissades en struikgewas. Om een mottekasteel te vormen, komt naast de motte een neerhof voor.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [299],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1191",
    },
    {
        "broader": [1371],
        "id": 299,
        "labels": [
            {"label": "mottekastelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mottekasteel is een kasteel of versterking op een aarden ophoging (motteheuvel) als residentie van een lokale heer en wordt gekenmerkt door een opperhof, met doorgaans circulair grondplan, met bijbehorend neerhof. Het opperhof, als militaire verdedigende component, bestaat meestal uit een versterkte toren (uit hout, steen of vakwerk) op een motteheuvel, terwijl op het neerhof gebouwen met een eerder agrarisch, religieus of residentieel karakter konden staan. Het geheel werd omgeven door een palissade om de verdediging te vervolledigen. Mottekastelen komen voornamelijk voor tijdens de volle middeleeuwen als een gevolg van het feodaliteitsprincipe. Ze kennen een enorme bloei tijdens de 12de eeuw. De 13de en 14de eeuw betekenen het einde van het mottekasteel. De oorlogstechnieken zijn veranderd en de mottekastelen blijken niet effici\xebnt genoeg meer. Tijdens de late middeleeuwen krijgen ze dus eerder een prestigefunctie.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "18/04/2011: SN aangepast; term aangepast van 'mottes' naar 'mottekastelen' om onderscheid te maken met 'motteheuvels'; BT gewijzigd van 'kastelen (woningen)' naar 'kastelen (verdedigingswerken)'.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'motteheuvels' wanneer men enkel het mottelichaam bedoeld zonder aanduiding voor een neerhof.",
                "type": "note",
            },
        ],
        "related": [1191, 223],
        "sources": [
            {
                "citation": "1) Claes B. &amp; Degryse H. 2006, Castrale mottes in het noordwesten van Vlaams-Brabant, in: Archeologie 2006: Recent archeologisch onderzoek in Vlaams-Brabant, pp. 27-32 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/299",
    },
    {
        "broader": [21],
        "id": 300,
        "labels": [{"label": "mouterijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mouterij is een industrieel bedrijf waar men van gerst mout maakt door het te laten weken en kiemen.",
                "type": "scopeNote",
            }
        ],
        "related": [84],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/300",
    },
    {
        "broader": [522],
        "id": 2176,
        "labels": [
            {"label": "Mulhousewoningen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kwadrantwoningen", "language": "nl-BE", "type": "altLabel"},
            {
                "label": "vier-onder-een-kapwoningen",
                "language": "nl-BE",
                "type": "altLabel",
            },
            {"label": "groupe \xe9conomique", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Mulhousewoning groepeert vier wooneenheden onder \xe9\xe9n dak in symmetrische vrijstaande panden, door middel van een eenvoudige kwartdeling (gekoppelde rug-aan rug-woningen), vaak in het midden van een groot rechthoekig perceel dat vervolgens in vieren gedeeld werd. Dit type werd voor het eerst gebruikt in de \u2018Cit\xe9 Ouvri\xe8re (1853)\u2019 van textielfabrikant Dolfuss te Mulhouse in Frankrijk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2176",
    },
    {
        "broader": [1393],
        "id": 1402,
        "labels": [{"label": "munten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Munten zijn stukjes metaal die met toestemming van de wettige macht worden geslagen om als betaalmiddel te dienen.",
                "type": "scopeNote",
            }
        ],
        "related": [1391],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1402",
    },
    {
        "broader": [1389],
        "id": 1391,
        "labels": [{"label": "muntschatten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een muntschat is een depositie van munten.",
                "type": "scopeNote",
            }
        ],
        "related": [1402],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1391",
    },
    {
        "broader": [1155],
        "id": 1156,
        "labels": [
            {"label": "muri gallici", "language": "nl-BE", "type": "prefLabel"},
            {"label": "murus gallicus", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een murus gallicus is een verdedigingsmuur uit de late ijzertijd, die over het algemeen is gemaakt van dikke lagen steen die bijeen worden gehouden en versterkt door een kern van houten geraamtes, aan elkaar gezet met ijzeren spijkers en voorzien van een aarden helling aan de binnenzijde. Aan de voorzijde werd een beschermlaag van stenen aangebracht.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1156",
    },
    {
        "broader": [321],
        "id": 301,
        "labels": [{"label": "musea", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een museum is een gebouw waar de materi\xeble getuigenissen van de mens en zijn omgeving tentoongesteld en bewaard worden.",
                "type": "scopeNote",
            }
        ],
        "related": [426],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/301",
    },
    {
        "broader": [1131],
        "id": 1133,
        "labels": [{"label": "mutationes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een mutatio is een aflossings- of rustplaats voor paarden en ezels langs Romeinse of vroeg-middeleeuwse wegen (gedurende de 7de eeuw) die voorzien in de minimale behoeften van reizigers. Gebruik 'mansiones' voor plaatsen langs deze oude routes om te overnachten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'mansiones' voor plaatsen langs deze oude routes om te overnachten.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Adkins L. &amp; Adkins R. 1998, Handbook to life in ancient Rome, New York.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1133",
    },
    {
        "broader": [2091],
        "id": 2150,
        "labels": [
            {"label": "muurschilderingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300033644"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Muurschilderingen zijn schilderingen op muren, gewelven en andere architecturale onderdelen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "22/09/2015: toegevoegd op vraag van Hilde voor invoer interieurs met muurschilderingen (Anna B.).",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'reclamemuurschilderingen' voor muurschilderingen aan buitenmuren met een advertentieboodschap.",
                "type": "note",
            },
        ],
        "related": [2116],
        "sources": [{"citation": "agentschap Onroerend Erfgoed.", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2150",
    },
    {
        "broader": [307],
        "id": 302,
        "labels": [
            {
                "label": "muziekinstrumentenfabrieken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een muziekinstrumentenfabriek is een fabriek of werkplaats waar men muziekinstrumenten maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/302",
    },
    {
        "broader": [321],
        "id": 303,
        "labels": [
            {"label": "muziekkiosken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een muziekkiosk is een vrijstaand, open gebouw op een plein of in een park, waar muziekuitvoeringen worden gegeven.",
                "type": "scopeNote",
            }
        ],
        "related": [235],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/303",
    },
    {
        "broader": [319],
        "id": 304,
        "labels": [
            {"label": "muziekscholen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [768],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een muziekschool is een gebouw voor muziekonderwijs.",
                "type": "scopeNote",
            }
        ],
        "related": [253],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/304",
    },
    {
        "broader": [1841],
        "id": 1844,
        "labels": [{"label": "naaldbossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1842],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een naaldbos is een bos geheel bestaand uit naaldboomsoorten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1844",
    },
    {
        "broader": [923],
        "id": 305,
        "labels": [
            {"label": "natiegebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een natiegebouw is een gebouw van naties of vemen. Naties zijn bedrijven die goederen wegen, sorteren, opslaan en veilen.",
                "type": "scopeNote",
            }
        ],
        "related": [306],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/305",
    },
    {
        "broader": [103],
        "id": 306,
        "labels": [{"label": "natiehuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een natiehuis is een bestuurlijke zetel en vergaderplaats van een natie of loge. Loges zijn verenigingen van kooplieden van dezelfde afkomst in een vreemde stad.",
                "type": "scopeNote",
            }
        ],
        "related": [305, 162],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005; WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/306",
    },
    {
        "broader": [1959],
        "id": 1961,
        "labels": [
            {"label": "natuurlijke taluds", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een natuurlijk talud is een steilrand met een meestal beperkt hoogteverschil (max. enkele meters), gevormd door bodemerosie of bodemverglijding al dan niet in combinatie met (vroegere) menselijke activiteit zoals het aanbrengen van houtige beplanting of langdurige betreding.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/09/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1961",
    },
    {
        "broader": [],
        "id": 1962,
        "labels": [
            {
                "label": "natuurlijke waterlopen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [1963, 1966, 1965],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een natuurlijke waterloop is een oorspronkelijk natuurlijk gevormde permanente of periodieke afstroming.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1837],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1962",
    },
    {
        "broader": [],
        "id": 1968,
        "labels": [
            {
                "label": "natuurlijke watervlakken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [1969, 1970, 1971],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een natuurlijk watervlak is een natuurlijke laagte die permanent of met tussenpozen met water is gevuld.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [931],
        "sources": [
            {
                "citation": 'Objectencatalogus NGI: <a href="http://www.ngi.be/gdes/">http://www.ngi.be/gdes/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1968",
    },
    {
        "broader": [932],
        "id": 1648,
        "labels": [
            {
                "label": "natuurlijk gevormde bomen en struiken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1604],
        "narrower": [1607],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een natuurlijk gevormde boom of struik is een op een stam of vanaf de grond vertakte houtige plant waarvan de vorm van de kruin overeenkomt met zijn natuurlijke, soortgebonden habitus.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: Term aangepast van natuurlijk gevormde struiken en BT aangepast naar houtige beplantingen naar beheersvorm ipv struiken naar beheersvorm.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1648",
    },
    {
        "broader": [1603],
        "id": 1564,
        "labels": [{"label": "natuurtuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [935, 1566, 1567],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een natuurtuin is een tuin die niet gecultiveerd is, met veel inheemse wilde planten en bloemen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1564",
    },
    {
        "broader": [],
        "id": 1033,
        "labels": [
            {"label": "nederzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1832],
        "narrower": [2111],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Term toegevoegd bij integratie met archeologisch erfgoed",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [1034, 1036, 1038, 1035],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1033",
    },
    {
        "id": 1034,
        "labels": [
            {
                "label": "nederzettingen naar functie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1039, 1040, 1051, 1053],
        "notes": [],
        "sources": [],
        "superordinates": [1033],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1034",
    },
    {
        "id": 1036,
        "labels": [
            {
                "label": "nederzettingen naar omvang",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1062, 1063, 1064, 1065],
        "notes": [],
        "sources": [],
        "superordinates": [1033],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1036",
    },
    {
        "id": 1038,
        "labels": [
            {
                "label": "nederzettingen naar uitzicht",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1068, 1069],
        "notes": [],
        "sources": [],
        "superordinates": [1033],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1038",
    },
    {
        "id": 1035,
        "labels": [
            {
                "label": "nederzettingen naar verschijningsvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1045, 1047, 1044, 1059, 1060],
        "notes": [],
        "sources": [],
        "superordinates": [1033],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1035",
    },
    {
        "broader": [1151],
        "id": 734,
        "labels": [{"label": "neerhoven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een neerhof is het lager gelegen gedeelte van een tweeledig mottekasteel, vaak ook lichtjes opgehoogd en omgeven door een gracht of greppel. Hier kunnen gebouwen teruggevonden worden die te maken hebben met de voedselvoorziening en het onderhoud van de kasteelbewoners. In sommige gevallen stond hier ook de kapel van die heer die later soms uitgroeide tot dorpskerk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: veranderd van NPT voor kasteelhoeven naar PT.",
                "type": "historyNote",
            },
        ],
        "related": [223],
        "sources": [
            {
                "citation": "Claes B. &amp; Degryse H. 2006, Castrale mottes in het noordwesten van Vlaams-Brabant, in: Archeologie 2006: Recent archeologisch onderzoek in Vlaams-Brabant, pp. 27-32.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/734",
    },
    {
        "broader": [1992],
        "id": 1994,
        "labels": [
            {
                "label": "niet-alluviale kommen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "gavers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een niet-alluviale kom is een schotelvormige depressie zonder hoofdwaterafvoer, vaak met resterend verlandingssubstraat (veen, moeraskalk).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1977],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1994",
    },
    {
        "broader": [1271],
        "id": 307,
        "labels": [
            {
                "label": "nijverheidsgebouwen en productieplaatsen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300121918"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [14, 15, 18, 20, 21, 24, 199, 297, 302, 884, 943, 1318, 1417, 22],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Nijverheidsgebouwen is een overkoepelende term voor zowel kleine, ambachtelijke gebouwen als uitgebreide gebouwcomplexen op industri\xeble sites.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'gebouwen en structuren' naar 'economische gebouwen en structuren'.\nTerm gewijzigd van 'nijverheidsgebouwen' naar 'nijverheidsgebouwen en productieplaatsen' bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/307",
    },
    {
        "broader": [507],
        "id": 901,
        "labels": [{"label": "niskapellen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1020, 1021],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Nissen waarin een heiligenbeeld staat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31 maart 2010: scope-note aangemaakt.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/901",
    },
    {
        "broader": [1072],
        "id": 1077,
        "labels": [
            {"label": "nivelleringslagen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een nivelleringslaag is een antropogene laag bedoeld om een onregelmatig oppervlak regelmatig te maken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1077",
    },
    {
        "broader": [230],
        "id": 308,
        "labels": [{"label": "noodkerken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een noodkerk is een tijdelijke parochiekerk die opgetrokken is in tijden van nood.",
                "type": "scopeNote",
            }
        ],
        "related": [338],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/308",
    },
    {
        "broader": [522],
        "id": 309,
        "labels": [{"label": "noodwoningen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een noodwoning is een woonhuis dat opgetrokken wordt in tijden van nood als tijdelijke huisvesting.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar vormelijk type\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/309",
    },
    {
        "broader": [152],
        "id": 733,
        "labels": [
            {"label": "normaalscholen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/733",
    },
    {
        "broader": [522],
        "id": 311,
        "labels": [
            {"label": "notariswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een notariswoning is het woonhuis van een notaris. Notarissen zijn ambtenaren die bevoegd zijn om akten te verlijden, die in bewaring te houden en er afschriften van uit te geven.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/311",
    },
    {
        "broader": [1603],
        "id": 1565,
        "labels": [{"label": "nutstuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [295, 752, 1571, 1572],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een nutstuin is de verzamelnaam voor tuinen waar men groenten, kruiden, fruit en bloemen voor eigen gebruik verbouwt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1565",
    },
    {
        "broader": [441],
        "id": 1536,
        "labels": [{"label": "nympaea", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een nymfeum is een gebouw met bassins waar een waterleiding in uitmondt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1536",
    },
    {
        "broader": [174],
        "id": 879,
        "labels": [{"label": "obelisken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een obelisk (funeraire constructie) is een grafmonument in de vorm van een naar boven toe versmallende, stenen schacht met vierkante basis en piramidevormige punt, naar het voorbeeld van de obelisken uit de Egyptische oudheid.",
                "type": "scopeNote",
            }
        ],
        "related": [312],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/879",
    },
    {
        "broader": [443],
        "id": 312,
        "labels": [{"label": "obelisken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Tuinornamentiek in de vorm van naar boven toe versmallende, stenen schachten met vierkantige basis en piramidevormige punt, naar het voorbeeld van de obelisken uit de Egyptische oudheid.",
                "type": "scopeNote",
            }
        ],
        "related": [879],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005; Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/312",
    },
    {
        "broader": [293],
        "id": 313,
        "labels": [
            {"label": "observatieposten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een observatiepost is een militair gebouw van waaruit men vijandelijke bewegingen kan waarnemen.",
                "type": "scopeNote",
            }
        ],
        "related": [314, 408, 58],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/313",
    },
    {
        "broader": [237],
        "id": 314,
        "labels": [
            {"label": "observatoria", "language": "nl-BE", "type": "prefLabel"},
            {"label": "sterrenwachten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen die zijn ingericht voor (telescopische) waarnemingen op astronomisch, meteorologisch en seismologisch gebied. Hoog gelegen en/of voorzien van een toren of een koepel.",
                "type": "scopeNote",
            }
        ],
        "related": [313, 58],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/314",
    },
    {
        "broader": [1161],
        "id": 1166,
        "labels": [{"label": "oefenkampen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1166",
    },
    {
        "broader": [2027],
        "id": 2028,
        "labels": [{"label": "oeverwallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oeverwal is een rug langs een natuurlijke waterloop, ontstaan doordat grof bodemmateriaal (zand, silt) tijdens overstromingen het dichtst bij de waterloop is afgezet als gevolg van de verminderde sleepkracht van het water wanneer de stroom buiten haar oevers treedt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1977],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2028",
    },
    {
        "broader": [228],
        "id": 731,
        "labels": [
            {"label": "officiersgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/731",
    },
    {
        "broader": [21],
        "id": 316,
        "labels": [
            {"label": "oliefabrieken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "olieslagerijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oliefabriek is een industrieel of ambachtelijk bedrijf waar men olie vervaardigt uit zaden.",
                "type": "scopeNote",
            }
        ],
        "related": [297],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/316",
    },
    {
        "broader": [295],
        "id": 1569,
        "labels": [
            {"label": "omhaagde moestuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een omhaagde moestuin is een moestuin met een doorgaans hoge geschoren, dichte haag die ter beschutting tegen gure winden en ongewenste dieren dient.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1569",
    },
    {
        "broader": [893],
        "id": 317,
        "labels": [
            {"label": "omheiningsmuren", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [792],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Muren die (een deel van) een domein afbakenen.",
                "type": "scopeNote",
            }
        ],
        "related": [404],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/317",
    },
    {
        "broader": [507],
        "id": 318,
        "labels": [{"label": "ommegangen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [751],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Reeks kapellen die gelovigen aandoen bij een processie.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/318",
    },
    {
        "broader": [295],
        "id": 1570,
        "labels": [
            {"label": "ommuurde moestuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ommuurde moestuin is een moestuin met hoge bakstenen leifruitmuren ter beschutting tegen gure winden en ongewenste dieren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1570",
    },
    {
        "id": 1765,
        "labels": [
            {
                "label": "onderdelen van gebouwen en structuren",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1095, 1151, 1766, 1791, 1792, 2089, 2090, 2091, 2096, 2097],
        "notes": [],
        "sources": [],
        "superordinates": [147],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1765",
    },
    {
        "id": 1767,
        "labels": [
            {
                "label": "onderdelen van kerken en kapellen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1766],
        "members": [1768, 1769, 1770, 1773, 1776, 1777, 1778, 2162, 1779],
        "notes": [],
        "sources": [],
        "superordinates": [147],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1767",
    },
    {
        "id": 1785,
        "labels": [
            {
                "label": "onderdelen van kloosters en abdijen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1766],
        "members": [1786, 1788, 1789, 1790, 1865],
        "notes": [],
        "sources": [],
        "superordinates": [147],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1785",
    },
    {
        "id": 1766,
        "labels": [
            {
                "label": "onderdelen van religieuze gebouwen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [1765],
        "members": [1767, 1785],
        "notes": [],
        "sources": [],
        "superordinates": [147],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1766",
    },
    {
        "broader": [13],
        "id": 1838,
        "labels": [
            {"label": "ondergrondse tunnels", "language": "nl-BE", "type": "prefLabel"},
            {"label": "mijnschachten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Ondergrondse tunnels zijn uitgegraven gangen die werden aangelegd voor het ondermijnen van een positie aan het front tijdens de Eerste Wereldoorlog.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {"citation": "Agentschap Onroerend Erfgoed (H. Verboven)", "markup": None}
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1838",
    },
    {
        "broader": [147],
        "id": 319,
        "labels": [
            {"label": "onderwijsgebouwen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "scholen", "language": "nl-BE", "type": "altLabel"},
            {"label": "schoolgebouwen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006495"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [
            259,
            152,
            191,
            204,
            325,
            383,
            205,
            234,
            238,
            253,
            304,
            643,
            712,
            853,
            883,
            1426,
        ],
        "notes": [],
        "related": [320],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/319",
    },
    {
        "broader": [522],
        "id": 320,
        "labels": [
            {"label": "onderwijzerswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een onderwijzerswoning is het woonhuis van een onderwijzer of hoofdonderwijzer/directeur, ontworpen in samenhang met de school.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "scopenote gewijzigd op 21/01/2010: 'leerkrachten' vervangen door 'onderwijzers' en 'gelegen in de nabijheid van' vervangen door 'ontworpen in samenhang met'.\n21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.\n01/10/2014: SN aangepast: 'hoofdonderwijzer/directeur' toegevoegd.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Woning en school hoeven niet noodzakelijk op \xe9\xe9n zelfde moment ontworpen te zijn.",
                "type": "note",
            },
        ],
        "related": [259, 285, 319],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/320",
    },
    {
        "broader": [78],
        "id": 1450,
        "labels": [
            {"label": "onderzoeksschepen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "onderzoeksvaartuigen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een onderzoeksschip is een vaartuig gebouwd en/of gebruikt voor onderzoeksdoeleinden, inclusief hydrografie en expedities.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1450",
    },
    {
        "broader": [],
        "id": 2077,
        "labels": [
            {
                "label": "onregelmatige ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2076],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een onregelmatig landontginningspatroon bestaat uit weinig rechte lijnen (wegen, waterlopen), de percelen zijn van onregelmatige vorm en grootte en zonder duidelijke structuur. Het ontginningspatroon wordt onder andere bepaald door het natuurlijke reli\xebf en daarin reeds aanwezige landschapselementen en zijn het resultaat van een geleidelijke en/of individuele ontginning.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2077",
    },
    {
        "id": 2076,
        "labels": [
            {"label": "ontginningspatronen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "member_of": [1849],
        "members": [2077, 2078],
        "notes": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "superordinates": [],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2076",
    },
    {
        "broader": [147],
        "id": 321,
        "labels": [
            {
                "label": "ontspannings- en verenigingsgebouwen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300122263"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [
            64,
            93,
            98,
            104,
            111,
            113,
            116,
            139,
            181,
            256,
            301,
            303,
            326,
            327,
            344,
            393,
            426,
            429,
            456,
            489,
            1126,
            1127,
            1504,
            463,
            896,
            2168,
        ],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/321",
    },
    {
        "broader": [],
        "id": 2070,
        "labels": [
            {"label": "ontwateringen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1850],
        "narrower": [2071],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ontwatering is een landinrichtingsvorm waarbij landbouwgronden door middel van natuurlijke of (meestal) kunstmatige waterlopen, gecontroleerd en permanent gedraineerd worden met als doel de opbrengst te verhogen. Initieel zijn ontwateringen vooral aangewend voor de ontginning van natuurlijk overstroombare gebieden. Het waterhuishoudingssysteem kan bestaan uit dijken, gemalen, hevelduikers, sluizen, stuwen, aan- en/of afvoergrachten,\u2026",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2070",
    },
    {
        "broader": [1080],
        "id": 1948,
        "labels": [
            {"label": "ontwateringsgrachten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "afvoergrachten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1950, 1951, 1954, 1957],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ontwateringsgrachten is een gracht aangelegd om gronden te ontwateren en overtollig (oppervlakte)water af te voeren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1948",
    },
    {
        "broader": [1843],
        "id": 2140,
        "labels": [{"label": "ooibossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ooibos is een bos gelegen op plaatsen die onregelmatig en in voorkomend geval langdurig overstromen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2140",
    },
    {
        "broader": [153],
        "id": 322,
        "labels": [
            {"label": "oorlogsmonumenten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oorlogsmonument is een vrijstaand gedenkteken of gedenkplaat om oorlogsslachtoffers of oorlogsfeiten te gedenken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: SN aangepast (monument aangepast naar gedenkteken of -plaat)",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/322",
    },
    {
        "broader": [284],
        "id": 2183,
        "labels": [
            {"label": "opbrengstwoningen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "maisons de rapport", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Woning, meestal burgerwoning of winkel-/caf\xe9pand, opgedeeld in verschillende wooneenheden voor verhuur of bewoning door verschillende gezinnen of alleenstaanden. Vaak in stedelijke context gebouwd als investering, soms later pas opgedeeld. Opbrengstwoningen werden voornamelijk gebouwd in de 19de eeuw en begin 20ste eeuw.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2183",
    },
    {
        "broader": [323],
        "id": 37,
        "labels": [
            {"label": "openbare badhuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openbaar badhuis is een openbare badinrichting met kuipbaden en/of douches.",
                "type": "scopeNote",
            }
        ],
        "related": [535, 492, 256],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/37",
    },
    {
        "broader": [147],
        "id": 323,
        "labels": [
            {"label": "openbare gebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008059"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [
            801,
            1122,
            56,
            158,
            160,
            376,
            402,
            8,
            11,
            31,
            45,
            60,
            62,
            80,
            109,
            127,
            161,
            222,
            37,
            348,
            353,
            356,
            363,
            646,
            940,
        ],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/323",
    },
    {
        "broader": [337],
        "id": 1558,
        "labels": [
            {"label": "openbare parken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1559],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openbaar park is een openbare groenzone met een permanente passieve recreatieve functie die meestal wordt gekenmerkt door zijn natuurlijke, historische of landschappelijke aspecten en vaak door een overheidsinstantie wordt beheerd.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT (lemma: parken)", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1558",
    },
    {
        "broader": [933],
        "id": 347,
        "labels": [
            {"label": "openbare pleinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openbaar plein is een onbebouwde, maar wel ombouwde ruimte van enige uitgestrektheid, gelegen in het stratennet van een stad of dorp. Bij een organisch gegroeide stad is de vorm onregelmatig.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN uitgebreid. 13/03/2014: 'pleinen' aangepast naar 'openbare pleinen'",
                "type": "historyNote",
            },
        ],
        "related": [129, 281],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/347",
    },
    {
        "broader": [1207],
        "id": 324,
        "labels": [
            {"label": "openbare toiletten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "urinoirs", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openbaar toilet is een sanitaire voorziening in de openbare ruimte.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Indexing note toegevoegd.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'toiletten' voor toiletten zonder openbaar karakter.",
                "type": "note",
            },
        ],
        "related": [156, 1207],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/324",
    },
    {
        "broader": [933],
        "id": 939,
        "labels": [
            {"label": "openbare trappen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openbare trap is een verbinding tussen twee op verschillende hoogte liggende vlakken of terreinen in openbare ruimte.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Term aangevuld met 'openbare'",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Enkel trappen die als zelfstandige elementen in de openbare ruimte voorkomen, zijn opgenomen in de databank.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/939",
    },
    {
        "broader": [1608],
        "id": 1650,
        "labels": [
            {
                "label": "op enen stam gezette struiken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een op enen (stam) gezette struik is een kunstmatig gevormde struik die door aangepaste snoei \xe9\xe9n stam en \xe9\xe9n kruin ontwikkelt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term aangepast van op enen gezette struiken naar op enen stam gezette struiken. BT aangepast naar kunstmatig gevormde bomen en struiken ipv kunstmatig gevormde struiken.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1650",
    },
    {
        "broader": [],
        "id": 2059,
        "labels": [
            {"label": "open landschappen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1848],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een open landschap is een landschap zonder perceelsrandbegroeiing of bossen (zoals kouterlandschappen, beemden, broeken, \u2026) waardoor in alle richtingen vergezichten zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2059",
    },
    {
        "broader": [319],
        "id": 325,
        "labels": [
            {"label": "openluchtscholen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openluchtschool is een onderwijsgebouw dat is ingericht om zoveel mogelijk buitenlucht en licht in de klaslokalen te brengen. Doorgaans kan \xe9\xe9n wand volledig geopend worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/325",
    },
    {
        "broader": [321],
        "id": 326,
        "labels": [
            {"label": "openluchttheaters", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openluchttheater is een plaats voor (toneel)voorstellingen in openlucht, naar het voorbeeld van het amfitheater uit de Grieks-Romeinse oudheid.",
                "type": "scopeNote",
            }
        ],
        "related": [429],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/326",
    },
    {
        "broader": [949],
        "id": 1513,
        "labels": [
            {"label": "openluchtzwembaden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een openluchtzwembad is een niet overdekt zwembad.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1513",
    },
    {
        "broader": [1542],
        "id": 1544,
        "labels": [
            {"label": "open monoptheroi", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een open monopteros is een monopteros zonder dak.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1544",
    },
    {
        "broader": [],
        "id": 933,
        "labels": [{"label": "open ruimte", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008072"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [129, 347, 939, 1114, 1115],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: BT gewijzigd van 'infrastructuur' naar 'onroerend erfgoed'. 'Open ruimte' ipv 'openbare ruimte'.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/933",
    },
    {
        "broader": [1545],
        "id": 1546,
        "labels": [{"label": "open tholoi", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een open tholos is een tholos zonder dak.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1546",
    },
    {
        "broader": [321],
        "id": 327,
        "labels": [
            {"label": "operagebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een operagebouw is een gebouw dat is ontworpen voor de opvoering van opera's.",
                "type": "scopeNote",
            }
        ],
        "related": [104],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/327",
    },
    {
        "broader": [1648],
        "id": 1607,
        "labels": [
            {"label": "opgaande bomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een opgaande boom is een boom waarvan de vorm van de kruin overeenkomt met zijn natuurlijke, soortgebonden habitus. Opgaande bomen kunnen een hoge, lage, brede, smalle of een afwijkende groeivorm hebben, zoals zuil- en treurvormen.\nDe boom kan zich op volstrekt natuurlijke wijze uitgezaaid hebben en zijn groeivorm kan bepaald zijn door de natuurlijke groeiomstandigheden (bv. natuurlijke snoei).\nOntstond de boom in kunstmatige omstandigheden, dan is de groeivorm bepaald door de jeugdsnoei in de kwekerij en is het eindbeeld van de boom bepaald door de begeleidingssnoei die wordt uitgevoerd vanaf het planten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1607",
    },
    {
        "broader": [1151],
        "id": 1192,
        "labels": [{"label": "opperhoven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Het opperhof is het hoger gelegen gedeelte van een tweeledig kasteel. Het had doorgaans een circulair grondplan en werd opgeworpen met aarde uit de omringende gracht, aangevuld met aarde van buitenaf.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Claes B. &amp; Degryse H. 2006, Castrale mottes in het noordwesten van Vlaams-Brabant, in: Archeologie 2006: Recent archeologisch onderzoek in Vlaams-Brabant, pp. 27-32.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1192",
    },
    {
        "broader": [1051],
        "id": 1052,
        "labels": [
            {"label": "oppida", "language": "nl-BE", "type": "prefLabel"},
            {"label": "oppidum", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Oppida worden gekenmerkd door hun zeer grote omvang (meerdere 10-tallen ha\xb2), hun strategische inplanting op hoogtes of aan verkeersassen, indrukwekkende versterkingen, verschillende wijken die verschillende functies vervullen, dense bewoning. De noordgrens van het voorkomen van oppida loopt van Normandi\xeb door Zuid-Limburg en zo verder tot in Bohemen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {"citation": "cursusmateriaal UGent (Prof. J. Bourgeois)", "markup": None}
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1052",
    },
    {
        "broader": [1212],
        "id": 1501,
        "labels": [{"label": "oprijlanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008280"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oprijlaan is een doorgaans particuliere rijweg die van de grote weg naar het woonhuis of een ander gebouw voert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1501",
    },
    {
        "broader": [1271],
        "id": 328,
        "labels": [
            {"label": "opslagplaatsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "magazijnen", "language": "nl-BE", "type": "altLabel"},
            {"label": "loodsen", "language": "nl-BE", "type": "altLabel"},
            {"label": "hangars", "language": "nl-BE", "type": "altLabel"},
            {"label": "stapelhuizen", "language": "nl-BE", "type": "altLabel"},
            {"label": "pakhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [3, 385, 821, 946, 1015, 1275, 1279, 1484, 381],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een opslagplaats is een gebouw of andere constructie voor opslag.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT aangepast van 'ambachtelijke en industri\xeble infrastructuur' naar 'economische gebouwen en structuren'.",
                "type": "historyNote",
            },
        ],
        "related": [34],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/328",
    },
    {
        "broader": [2082],
        "id": 2083,
        "labels": [
            {
                "label": "opstrekkende ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een opstrekkend landontginningspatroon bestaat uit een weg met daarlangs de bebouwing met daarachter de opstrekkende (langgerekte) percelen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2083",
    },
    {
        "broader": [1608],
        "id": 1612,
        "labels": [
            {
                "label": "op struiken gezette bomen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een op struiken gezette boom is een kunstmatig gevormde boom die in de jeugdfase, ten gevolge van een al dan niet op natuurlijke wijze ontstane snoei, meerstammig is uitgegroeid en hierdoor het voorkomen heeft van een struik.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: SN toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1612",
    },
    {
        "broader": [1586],
        "id": 1593,
        "labels": [
            {"label": "oranjerieparterres", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oranjerieparterre is een parterre waar gedurende de zomermaanden oranjerieplanten staan opgesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1593",
    },
    {
        "broader": [63],
        "id": 329,
        "labels": [{"label": "oranjeries", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oranjerie is een verwarmd gebouw met vensters op het zuiden, oorspronkelijk bedoeld voor het overwinteren van sinaasappelbomen. Bij uitbreiding ook voor andere vorstgevoelige exotische planten.",
                "type": "scopeNote",
            }
        ],
        "related": [518, 384, 461],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/329",
    },
    {
        "broader": [],
        "id": 2040,
        "labels": [
            {"label": "organische bodems", "language": "nl-BE", "type": "prefLabel"},
            {"label": "histosols", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2132],
        "narrower": [2041],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een organische bodem is een bodem gevormd in organisch materiaal en overwegend bestaande uit (gedeeltelijk afgebroken) organisch materiaal.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2040",
    },
    {
        "broader": [1779],
        "id": 1780,
        "labels": [{"label": "orgels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300041686"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een orgel is een blaasinstrument met \xe9\xe9n of meerdere rijen afzonderlijke pijpen waardoorheen, via een toetsenbord of hendels, lucht wordt geperst.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1780",
    },
    {
        "broader": [1005],
        "id": 330,
        "labels": [
            {"label": "orthodoxe kerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebedshuizen voor orthodoxe christenen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/330",
    },
    {
        "broader": [142],
        "id": 331,
        "labels": [
            {"label": "ossuaria", "language": "nl-BE", "type": "prefLabel"},
            {"label": "knekelhuizen", "language": "nl-BE", "type": "altLabel"},
            {"label": "beenderhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1226],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ossuarium is een bergplaats voor geruimde beenderen op begraafplaatsen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'funerair erfgoed' naar 'funerair gerelateerde constructies'.",
                "type": "historyNote",
            },
        ],
        "related": [269],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/331",
    },
    {
        "broader": [1841],
        "id": 2161,
        "labels": [{"label": "oude bossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Oud bos is een bos dat sinds het einde van de 18de eeuw (kabinetskaart van de Ferraris, 1771-1778) onafgebroken bebost is. Dit wil niet zeggen dat er geen bomen gekapt zijn, wel dat er geen ander landgebruik is geweest, bijvoorbeeld grasland of akker. Oud bos wordt verder gekenmerkt door het voorkomen van een specifieke vegetatie van oudbosplanten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "5/11/2015: toegevoegd op vraag van landschappers",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) DE KEERSMAEKER L., ROGIERS N., LAURIKS R. &amp; DE VOS B. 2001: Ecosysteemvisie Bos Vlaanderen: ruimtelijke uitwerking van de natuurlijke bostypes op basis van bodemgroeperingseenheden en historische boskaarten, Eindverslag van project VLINA C97/06b, IBW Geraardsbergen.\n2) Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2161",
    },
    {
        "broader": [2009],
        "id": 2010,
        "labels": [
            {"label": "oude duinen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "fossiele duinen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oude duin is een niet meer zeewerende kustduin, ontstaan toen de kustlijn meer landinwaarts gelegen was.  Ten gevolge van erosie zijn deze duinen deels genivelleerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2010",
    },
    {
        "broader": [],
        "id": 1100,
        "labels": [{"label": "ovens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een oven is een constructie waarmee voedsel of grondstoffen tot een hoge temperatuur kunnen worden verhit met als doel ze een fysische of chemische verandering te doen ondergaan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [1282, 1284, 1285, 1286, 1283],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1100",
    },
    {
        "broader": [923],
        "id": 1496,
        "labels": [{"label": "overstorten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een overstort is een inrichting in een leiding waardoor de overdruk van de wateraanvoer constant gehouden wordt op een matige waarde, onafhankelijk van de variabele druk van de waterleiding.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1496",
    },
    {
        "broader": [1096],
        "id": 1099,
        "labels": [{"label": "paalkuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paalkuil is een kuil bedoeld om een paal in de grond van de nodige steun te voorzien.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1099",
    },
    {
        "broader": [381],
        "id": 332,
        "labels": [{"label": "paalschuren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paalschuur is een schuur die bestaat uit rechtopstaande palen die een in de hoogte verstelbaar dak draagt.",
                "type": "scopeNote",
            }
        ],
        "related": [381],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/332",
    },
    {
        "broader": [],
        "id": 1101,
        "labels": [
            {"label": "paalsporen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "paalgaten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paalspoor is een verkleuring of holte (eventueel binnen een paalkuil) in de bodem die aangeeft waar de paal precies gestaan heeft.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1101",
    },
    {
        "broader": [411],
        "id": 333,
        "labels": [
            {"label": "paardenstallen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paardenstal is een bijgebouw waarin men paarden huisvest, voedert en verzorgt.",
                "type": "scopeNote",
            }
        ],
        "related": [411],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/333",
    },
    {
        "broader": [1212],
        "id": 1217,
        "labels": [{"label": "paden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1498],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pad is een smalle, niet verharde wandelweg.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1217",
    },
    {
        "broader": [425],
        "id": 1547,
        "labels": [{"label": "pagodes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pagode is een tuinpaviljoen met de kenmerken van een boeddhistische tempel bestaande uit drie tot dertien verdiepingen, ieder met een afdak.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1547",
    },
    {
        "broader": [237],
        "id": 334,
        "labels": [{"label": "palen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [372, 406],
        "notes": [],
        "related": [893],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/334",
    },
    {
        "broader": [174],
        "id": 1270,
        "labels": [{"label": "palenkransen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een palenkrans is een ring van houten palen als randbegrenzing van een grafheuvel.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1270",
    },
    {
        "broader": [],
        "id": 2057,
        "labels": [
            {"label": "paleobodems", "language": "nl-BE", "type": "prefLabel"},
            {"label": "fossiele bodems", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2132],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paleobodem is een bodem die na zijn vorming afgedekt werd. Eenmaal afgedekt hielden de bodemvormende processen op en het bodemprofiel is dus niet meer actief.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2057",
    },
    {
        "broader": [1967],
        "id": 2130,
        "labels": [
            {"label": "paleomeanders", "language": "nl-BE", "type": "prefLabel"},
            {"label": "fossiele meanders", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paleomeander is een voormalige, eventueel door bodemafzettingen afgedekte  meander. Een paleomeander werd gevormd in (pre)historische tijden door natuurlijke verlegging van een rivier of beek, onder andere landschappelijke en hydrologische omstandigheden dan de huidige.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2130",
    },
    {
        "broader": [2000],
        "id": 2001,
        "labels": [
            {"label": "paleovalleien", "language": "nl-BE", "type": "prefLabel"},
            {"label": "fossiele valleien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paleovallei is een door bodemafzettingen afgedekte of opgevulde vallei, al of niet met een bovenliggend watervoerend karakter.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2001",
    },
    {
        "broader": [1145],
        "id": 1154,
        "labels": [{"label": "palissaden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een palissade is een barri\xe8re die bestaat uit lange palen, meestal met puntige toppen, die vlak naast elkaar in de grond worden gedreven, en soms worden verbonden door middel van horizontale balken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1154",
    },
    {
        "broader": [384],
        "id": 1478,
        "labels": [
            {"label": "palmhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "palmenserres", "language": "nl-BE", "type": "altLabel"},
            {"label": "palmenkassen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006805"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een palmhuis is een grote serre waarin palmen worden gekweekt en/of tentoongesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1478",
    },
    {
        "broader": [147],
        "id": 1786,
        "labels": [
            {"label": "pandgangen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kloostergangen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007423"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1785],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pandgang is een galerij die doorgaans in drie of vier armen of panden rechthoekig rondom het kloosterhof lopen. Pandgangen zijn omgeven door de belangrijkste kloostergebouwen waardoor zij als verbindingsgangen dienst doen.",
                "type": "scopeNote",
            }
        ],
        "related": [4, 243],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1786",
    },
    {
        "broader": [18],
        "id": 335,
        "labels": [
            {"label": "papierfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006308"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een papierfabriek is een industrieel of ambachtelijk bedrijf waar men papier maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [220],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/335",
    },
    {
        "broader": [2007],
        "id": 2017,
        "labels": [
            {"label": "paraboolduinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2016],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een paraboolduin is een duin in hoefijzervorm waarvan de opening in de overheersende windrichting ligt. De randen worden gevormd door de aanwezige vegetatie die het zand beter vasthouden, in het midden ontbreekt vegetatie waardoor de zandverplaatsing onder invloed van de wind daar vlugger verloopt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2017",
    },
    {
        "broader": [1841],
        "id": 1663,
        "labels": [{"label": "parkbossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1846],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een parkbos is een bos dat de architectuur van een park bepaalt. De parkbossen zijn meestal voorzien van wandelpaden en van een (zicht-) begeleidende al dan niet wintergroene, decoratieve beplantingen bestaande uit een bomenetage, soms aangevuld met een struikenetage.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "30/07/2014: Verplaatst van 'hooghoutpercelen' naar 'bossen naar gebruik' bij integratie met landschapstermen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1663",
    },
    {
        "broader": [926],
        "id": 336,
        "labels": [
            {"label": "parkeergarages", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een parkeergarage is een gebouw voor het tijdelijk stallen van motorvoertuigen van verschillende eigenaars.",
                "type": "scopeNote",
            }
        ],
        "related": [145],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/336",
    },
    {
        "broader": [930],
        "id": 337,
        "labels": [{"label": "parken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1558, 1560],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een park is een uitgestrekt terrein, aangelegd met bomen, planten, wandelpaden en gras- en bloemperken. Vaak verfraaid met vijvers, tuinpaviljoenen en tuinornamentiek. Zowel openbaar (vb. stadsparken), als privaat (vb. parken bij landhuizen).",
                "type": "scopeNote",
            }
        ],
        "related": [30, 77, 195, 346, 443, 440],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/337",
    },
    {
        "broader": [196],
        "id": 2171,
        "labels": [{"label": "parkwijken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een parkwijk is een als geheel opgevatte woonwijk met appartementsgebouwen en/of woonhuizen, experimenteel ingeplant in doorlopend groen. Autoverkeer en voetgangers worden vaak strikt gescheiden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term toegevoegd bij integratie termen sociale huisvesting",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2171",
    },
    {
        "broader": [230],
        "id": 338,
        "labels": [
            {"label": "parochiekerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [720],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een parochiekerk is een kerk waar de openbare eredienst wordt gehouden voor de gelovigen van een parochie. Ook decanale kerken zijn hier opgenomen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Ook decanale kerken zijn hier opgenomen.",
                "type": "note",
            },
        ],
        "related": [308, 340],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/338",
    },
    {
        "broader": [463],
        "id": 339,
        "labels": [
            {"label": "parochiezalen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een parochiezaal is een zaal voor bijeenkomsten en activiteiten van leden van een parochie.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/339",
    },
    {
        "broader": [440],
        "id": 1586,
        "labels": [
            {"label": "parterretuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1587, 1588, 1590, 1592, 1593, 1594],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een parterretuin is een geometrische siertuin die uit parterres is samengesteld. Een parterre bestaat uit geometrisch aangelegde bloembedden, bloembakken of omheinde gedeelten van siertuinen, vaak gemaakt met verhoogde zijkanten en in verschillende vormen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {"citation": "1) agentschap Onroerend Erfgoed 2) AAT", "markup": None}
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1586",
    },
    {
        "broader": [78],
        "id": 1460,
        "labels": [
            {"label": "passagiersschepen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een passagiersschip is een vaartuig ingericht voor het vervoer van passagiers, inclusief toeristische rondvaarten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005\n2) Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1460",
    },
    {
        "broader": [1124],
        "id": 1125,
        "labels": [
            {"label": "passantenhuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een passantenhuis is een vorm van een gasthuis, specifiek bedoeld voor de opvang van reizigers. Vaak zijn deze passantenhuizen gelegen in de nabijheid van de stadspoorten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "27/04/2011: opmaak scope note door LM, naar aanleiding van korte studie over godshuizen, passantenhuizen en gasthuizen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": 'Opgelet: er bestaan ook "passantenhuizen" voor de overnachting van gevangenen op transport. Deze gebouwen moeten worden ondergebracht bij gevangenissen.',
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1125",
    },
    {
        "broader": [889],
        "id": 340,
        "labels": [
            {"label": "pastorie\xebn", "language": "nl-BE", "type": "prefLabel"},
            {"label": "pastorijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pastorie is de woning van een pastoor. Pastoors zijn priesters verantwoordelijk voor parochies.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Ook onderpastorie\xebn worden ingevoerd onder pastorie\xebn.",
                "type": "note",
            },
        ],
        "related": [338, 249, 359],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/340",
    },
    {
        "broader": [1603],
        "id": 1903,
        "labels": [
            {"label": "pastorietuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pastorietuin is een tuin bij een pastorie, vaak omgracht, ommuurd of omhaagd. In de 18de eeuw zijn deze tuinen volgens het \u201cvivre entre cour et jardin\u201d model ingericht met een bij het huis aansluitende strakke, vierkante tuin voor groenten, fruit en bloemen, meestal met een padenkruis en achteraan een zogenaamd \u201cpastoorsbosje\u201d met hakhout. In de 19de eeuw worden verschillende \u201cbosjes\u201d omgevormd tot miniatuurversies van de kasteelparken in landschappelijke stijl met een slingerpad, enkele bruine beuken,  een taxusbosje en eventueel een vijvertje met eilandje. Het hakhout wordt daarbij vervangen door typische parkheesters.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Toegevoegd op 1/10/2014",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1903",
    },
    {
        "broader": [522],
        "id": 2177,
        "labels": [
            {"label": "patiowoningen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "tuinkamerwoningen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een patiowoning is een (meestal) gelijkvloerse woning met inpandige binnentuin. Daarnaast wordt deze term gebruikt voor woningen met een kleine ommuurde tuin als verlengstuk van de binnenruimte (ook tuinkamerwoning).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2177",
    },
    {
        "broader": [319],
        "id": 853,
        "labels": [{"label": "patronaten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een patronaat is een gebouw gesticht op initiatief van een rooms-katholieke vereniging, waar kinderen uit lage inkomensgezinnen onderwijs genoten, voornamelijk op zondag. In de loop van de 19de eeuw primeerde de onderwijsfunctie. Later zouden de patronaten evolueren naar organisaties voor vrijetijdsbesteding.",
                "type": "scopeNote",
            }
        ],
        "related": [207],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/853",
    },
    {
        "broader": [892],
        "id": 1469,
        "labels": [{"label": "pauwenhokken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1471],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pauwenhok is een verblijf voor pauwen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1469",
    },
    {
        "broader": [931],
        "id": 1597,
        "labels": [
            {"label": "p\xe9diluves", "language": "nl-BE", "type": "prefLabel"},
            {"label": "paardenvoetbaden", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een p\xe9diluve is een kunstmatig aangelegde waterpartij waarin men paarden na een lange rit laat waden teneinde hun verhitte hoeven en benen af te koelen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1597",
    },
    {
        "broader": [21],
        "id": 341,
        "labels": [{"label": "pellerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pellerij is een industrieel of ambachtelijk bedrijf waar men rijst, gerst, haver e.d. pelt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/341",
    },
    {
        "broader": [],
        "id": 2165,
        "labels": [
            {"label": "perceelsgrenzen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1849],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een perceelsgrens is de zichtbare grens tussen twee kadastrale percelen of gebruikspercelen. Deze grens kan onder andere gevormd worden door beplantingen, grachten, hekken, of andere afsluitingen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "09/02/2016; toegevoegd op vraag van Aukje DH.",
                "type": "historyNote",
            },
        ],
        "related": [176],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2165",
    },
    {
        "broader": [1082],
        "id": 1086,
        "labels": [
            {"label": "perceelsgreppels", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een perceelsgreppel is een greppel bedoeld om een afbakening voor percelen te voorzien. Deze kunnen eventueel ook watervoerend zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1086",
    },
    {
        "broader": [932],
        "id": 1757,
        "labels": [
            {
                "label": "perceelsrandbeplantingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1756],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Perceelsrandbeplanting is beplanting die voorkomt op de perceelsrand.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1757",
    },
    {
        "broader": [443],
        "id": 342,
        "labels": [{"label": "pergola's", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Tuinconstructies bestaande uit twee aan twee geplaatste stenen, metalen of houten kolommen, bovenaan met elkaar verbonden door middel van een lattenwerk ter ondersteuning van bloeiende klimplanten.",
                "type": "scopeNote",
            }
        ],
        "related": [165, 746],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/342",
    },
    {
        "broader": [],
        "id": 1980,
        "labels": [
            {
                "label": "periglaciale processen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een periglaciaal proces is het proces waarbij geomorfologische elementen ontstaan zijn onder invloed van ijs of smeltwater tijdens de ijstijden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1991, 1998, 2000, 1999],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1980",
    },
    {
        "broader": [54],
        "id": 1416,
        "labels": [
            {
                "label": "perken voor oud-strijders",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een perk voor oud-strijders is een verzameling van graven voor oud-strijders, gelegen op een begraafplaats, vaak bestaande uit uniforme graven",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Term toegevoegd op 07/07/2011 naar aanleiding van de synchronisatie met de databank Wereldoorlogerfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [292, 1415],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1416",
    },
    {
        "broader": [923],
        "id": 645,
        "labels": [{"label": "pershuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een pershuis is een gebouw waarin hydraulische krachtcentrales zijn ondergebracht.",
                "type": "scopeNote",
            }
        ],
        "related": [349],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/645",
    },
    {
        "broader": [522],
        "id": 343,
        "labels": [
            {"label": "personeelswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [285, 702, 719, 77, 105, 195, 361],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een personeelswoning is een bescheiden woonhuis voor personeel, meestal gelegen in de nabijheid van de werkplek of de woning van de werkgever.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [29],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/343",
    },
    {
        "broader": [267],
        "id": 844,
        "labels": [{"label": "pesthuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/844",
    },
    {
        "broader": [901],
        "id": 1020,
        "labels": [
            {"label": "pijlerkapellen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Specifieke vormen van niskapellen, ingewerkt in een gemetste pijler die doorgaans wordt afgedekt door een zadeldakje. De nis wordt vaak afgeschermd door tralies, soms ook glas of doorzichtige kunststof.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31 maart 2010: term en scope-note toegevoegd.\n25/02/2016: SN aangevuld met afscherming",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1020",
    },
    {
        "broader": [346],
        "id": 1562,
        "labels": [{"label": "pineta", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pinetum is een aangeplante verzameling van naaldhoutgewassen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1562",
    },
    {
        "broader": [1541],
        "id": 345,
        "labels": [{"label": "piramides", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een piramide is een tuinelement in piramidevorm dat op de grafmonumenten van Egyptische koningen ge\xefnspireerd is.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/345",
    },
    {
        "broader": [2043],
        "id": 2044,
        "labels": [
            {"label": "plaggenbodems", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een plaggenbodem is een meestal zandige bodem met een dik humeus dek dat is ontstaan door eeuwenlange ophoging met plaggen vermengd met stalmest.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2044",
    },
    {
        "broader": [1142],
        "id": 1143,
        "labels": [
            {"label": "plaggenhutten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een plaggenhut is een eenvoudige, met heideplaggen bedekte, hut. Ze komen voor tijdens de Nieuwe Tijd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1143",
    },
    {
        "broader": [1959],
        "id": 2159,
        "labels": [
            {"label": "plateauranden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een plateaurand is een steilrand van een plateau.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/09/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [2002],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2159",
    },
    {
        "broader": [],
        "id": 2002,
        "labels": [{"label": "plateaus", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een plateau is een hoger gelegen, vlakke tot vrij vlakke markante reli\xebfvorm, nagenoeg volledig begrensd door steile plateauranden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [2159],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2002",
    },
    {
        "broader": [1033],
        "id": 1069,
        "labels": [
            {"label": "platformsites", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1038],
        "narrower": [1070],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een platformsite is een site die geheel of gedeeltelijk is aangelegd op een kunstmatige verhoging. Ze komen voor in de kuststreek.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '5.6.2.3.4.3. Landelijke bewoning uit de Romeinse tijd in Vlaanderen, in: Onderzoeksbalans Onroerend Erfgoed Vlaanderen, <a href="http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/civiele_nederzettingen/landelijk/vlaanderen">http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/civiele_nederzettingen/landelijk/vlaanderen</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1069",
    },
    {
        "broader": [1033],
        "id": 1059,
        "labels": [
            {"label": "pleinnederzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1035],
        "narrower": [2104, 2105],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pleinnederzetting is een min of meer geplande nederzetting rond een centrale open ruimte (meestal dries of bist/biest genoemd) die oorspronkelijk meestal gemeenschappelijk bezit was.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Antrop M. 2007: Perspectieven op het landschap, achtergronden om landschappen te lezen en begrijpen, Academia Press, Gent.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1059",
    },
    {
        "broader": [78],
        "id": 1458,
        "labels": [
            {"label": "pleziervaartuigen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pleziervaartuig is een vaartuig dat men voor zijn genoegen houdt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1458",
    },
    {
        "broader": [],
        "id": 1104,
        "labels": [
            {"label": "ploegsporen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "eergetouwkrassen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ploegspoor is een verkleuring in de bodem die aangeeft dat er ooit geploegd is geweest.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1104",
    },
    {
        "broader": [],
        "id": 2052,
        "labels": [{"label": "podzols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1854],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een podzol is een erg zandige en zure bodem met humusrijke bovenlaag en een sterke profielontwikkeling bestaande uit een bleke uitlogingshorizont met daaronder een typische zwarte aanrijkingshorizont van humus, boven een aanrijkingshorizont van ijzer, die uit de bovenlaag zijn opgelost.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2052",
    },
    {
        "broader": [931],
        "id": 861,
        "labels": [{"label": "poelen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een poel is een kleine, eerder ondiepe, stilstaande waterplas, doorgaans bij een hoeve.",
                "type": "scopeNote",
            }
        ],
        "related": [467],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/861",
    },
    {
        "broader": [157],
        "id": 956,
        "labels": [{"label": "poldermolens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/956",
    },
    {
        "broader": [2070],
        "id": 2071,
        "labels": [{"label": "polders", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2072],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een polder is een doorgaans grote, door dijken begrensde ontwatering, afgescheiden van de nabijgelegen zee of rivier, waarbinnen het waterpeil kunstmatig geregeld kan worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2071",
    },
    {
        "broader": [323],
        "id": 348,
        "labels": [
            {"label": "politiekantoren", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een politiekantoor is een kantoor van de politie, die toezicht houdt op de openbare orde en de veiligheid.",
                "type": "scopeNote",
            }
        ],
        "related": [363, 460],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/348",
    },
    {
        "broader": [78],
        "id": 1444,
        "labels": [
            {"label": "politieschepen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een politieschip is een vaartuig gebouwd voor of in gebruik bij politiediensten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1444",
    },
    {
        "broader": [157],
        "id": 1492,
        "labels": [{"label": "pompgemalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pompgemaal is een gemaal dat door zuigkracht werkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1492",
    },
    {
        "broader": [923],
        "id": 349,
        "labels": [{"label": "pomphuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pomphuis is een gebouw voor pompinstallaties voor het verplaatsen van water.",
                "type": "scopeNote",
            }
        ],
        "related": [499, 645],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/349",
    },
    {
        "broader": [2],
        "id": 1489,
        "labels": [{"label": "pontons", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ponton is een drijvende aanlegplaats in havens, rivieren enz., bestaande uit een of meer onderling gekoppelde, dichte bakken, waarover een (houten) dek is gelegd.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "1) Van Dale online 2) AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1489",
    },
    {
        "broader": [63],
        "id": 350,
        "labels": [
            {"label": "poorten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "poortgebouwen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een poort (bijgebouw) is een poortgebouw of grote, doorgaans houten (deur)vleugel tussen hekpijlers die tot afsluiting en bewaking dient aan de ingang van kastelen, kloosters, hoeven ed.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Poorten die deel uitmaken van een gevel, zoals koetspoorten, zijn in deze databank niet opgenomen.",
                "type": "note",
            },
        ],
        "related": [185, 407, 893, 1169, 1777],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/350",
    },
    {
        "broader": [147],
        "id": 2090,
        "labels": [{"label": "poorten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": ["http://vocab.getty.edu/aat/300069189"],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1765],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een poort (gebouwonderdeel) is een van de grond opgaande opening in een muur, boogvormig of horizontaal afgedekt, die toegang geeft tot een ruimte van een gebouw die achter de muur gelegen is, zoals een voorhuis of gang. Is deze afsluiting diep in een zware muur geplaatst zoals bv. bij kerkgevels dan spreekt men van een portaal.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: term toegevoegd i.f.v. beschermingsdatabank",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik portalen voor doorgangen in zware muren van kerkgevels.",
                "type": "note",
            },
        ],
        "related": [1777],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2090",
    },
    {
        "broader": [1149],
        "id": 1169,
        "labels": [{"label": "poorten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1170, 407],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een poort (verdedigingselement) is een doorgang door een hek of muur bedoeld als verdedigingselement van een bouwwerk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [350],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1169",
    },
    {
        "broader": [2149],
        "id": 2152,
        "labels": [
            {"label": "populierenaanplanten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een populierenaanplant is een doorgaans dichte aanplant van (vaak gekloonde) populierensoorten, meestal op natte gronden, waarbij een snelle productie van stamhout wordt beoogd .",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/09/2015: toegevoegd bij herziening thesaurus landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2152",
    },
    {
        "broader": [2149],
        "id": 2146,
        "labels": [
            {"label": "populierenplantages", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een populierenplantage is een plantage bestaande uit een dichte aanplant van (vaak gekloonde) populierensoorten, meestal op natte gronden, waarbij een snelle productie van stamhout wordt beoogd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/08/2015: term toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2146",
    },
    {
        "broader": [147],
        "id": 1777,
        "labels": [{"label": "portalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": [],
            "related": [
                "http://vocab.getty.edu/aat/300076641",
                "http://vocab.getty.edu/aat/300083076",
            ],
        },
        "member_of": [1767],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een portaal is een in de muur uitgespaarde ruimte voor en om de deuren van een kerk. Het kan door diep insnijdende dagkanten en archivolten omvat worden. Het kan ook een meer gesloten, onmiddellijk voor of achter de ingang van een gebouw geplaatste beschutting zijn, zoals een aangebouwd kerkportaal.",
                "type": "scopeNote",
            }
        ],
        "related": [350, 2090, 1005],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1777",
    },
    {
        "broader": [174],
        "id": 352,
        "labels": [
            {"label": "portieken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "aedicula", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een portiek is een grafmonument in de vorm van een portiek of aedicula, d.w.z. een samenstel van twee pilasters of zuilen met een hoofdgestel en fronton.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/352",
    },
    {
        "broader": [27],
        "id": 2180,
        "labels": [
            {"label": "portiekflatgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een portiekflatgebouw is een appartementsgebouw met ontsluiting en circulatie via een gemeenschappelijk trappenhuis aan de straatzijde, vaak met gespiegelde appartementen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [521],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2180",
    },
    {
        "broader": [1053],
        "id": 1054,
        "labels": [{"label": "portussteden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een portus(stad) is een handelsnederzetting. Deze ontwikkelde zich in bepaalde gevallen uit nederzettingen in de nabijheid van castra tijdens de Romeinse periode. Vanaf de 9de eeuw werd een dergelijke grote nederzetting een portus genoemd. Het waren plaatsen waar levensmiddelen en andere goederen werden aangevoerd, opgeslagen en verhandeld. Deze portussteden fungeerden eerst als transitcentrum, later kwam er ook een eigen nijverheid tot stand.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Heirman M. 2003, Vlaamse belforten. Werelderfgoed, Leuven.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1054",
    },
    {
        "broader": [323],
        "id": 353,
        "labels": [{"label": "postkantoren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een postkantoor is een kantoor van de post. In postkantoren wordt post ontvangen, gesorteerd en gedistribueerd en worden gerelateerde diensten verleend.",
                "type": "scopeNote",
            }
        ],
        "related": [646],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/353",
    },
    {
        "broader": [149],
        "id": 964,
        "labels": [
            {"label": "pottenbakkerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pottenbakkerij is een plaats waar aarden potten of vaten worden gemaakt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/964",
    },
    {
        "broader": [149],
        "id": 1285,
        "labels": [
            {"label": "pottenbakkersovens", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een pottenbakkersoven is een oven waarin aardewerken potten worden gebakken. Deze kunnen zeer primitief zijn (een kuil in de grond die afgedekt werd) of meer geavanceerd (constructie waarin meerdere potten tegelijk door middel van luchtcirculatie konden gebakken worden).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1100],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1285",
    },
    {
        "broader": [443],
        "id": 165,
        "labels": [
            {"label": "pri\xeblen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "glori\xebttes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006781"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Lichte, open bouwwerken, gevormd door bomen of klimplanten die zichzelf ondersteunen of een houten of metalen steunconstructie aan het zicht onttrekken.",
                "type": "scopeNote",
            }
        ],
        "related": [342, 746],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/165",
    },
    {
        "broader": [170],
        "id": 1264,
        "labels": [
            {"label": "prinsengraven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Furstengr\xe4ber", "language": "nl-BE", "type": "altLabel"},
            {"label": "vorstengraven", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1263],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een prinsengraf wordt gekenmerkt door de omvang van de grafheuvel (meerdere tientallen meters diameter), waaronder een houten grafkamer ligt met daarin de dode die meestal op of naast een vierwielige praalwagen ligt. In het graf worden vele bronzen containers gevonden die in verband kunnen gebracht worden met wijn. Ook goud en Grieks vaatwerk komen veelvuldig voor.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {"citation": "cursusmateriaal UGent (Prof. J. Bourgeois)", "markup": None}
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1264",
    },
    {
        "broader": [359],
        "id": 354,
        "labels": [{"label": "priorijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een priorij is een religieus huis dat qua rang net onder kloosters staat, maar afhankelijk is van een abdij als nieuwe nederzetting die vaak later abdij werd. De dagelijkse leiding is in handen van een prior of een priores.",
                "type": "scopeNote",
            }
        ],
        "related": [242, 243, 4, 240, 5],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/354",
    },
    {
        "broader": [337],
        "id": 1560,
        "labels": [
            {"label": "private parken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een privaat park is een park dat in particuliere handen is en niet voor het publiek is opengesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1560",
    },
    {
        "broader": [1841],
        "id": 2143,
        "labels": [
            {"label": "productiebossen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1846],
        "narrower": [2144],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een productiebos is een bos oorspronkelijk gebruikt voor grootschalige houtwinning.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2143",
    },
    {
        "broader": [889],
        "id": 845,
        "labels": [{"label": "proosdijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/845",
    },
    {
        "broader": [1005],
        "id": 355,
        "labels": [
            {"label": "protestantse kerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebedshuizen voor protestanten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/355",
    },
    {
        "broader": [323],
        "id": 356,
        "labels": [
            {"label": "provinciehuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "prefecturen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een provinciekantoor is een gebouw waarin het bestuur van een provincie is gevestigd. Ook gebouwen voor het bestuur van prefecturen worden opgenomen als provinciehuizen. De prefecturen of departementen uit de Franse periode komen in bestuursniveau immers grosso modo overeen met de huidige provincies.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/356",
    },
    {
        "broader": [466],
        "id": 357,
        "labels": [
            {
                "label": "psychiatrische instellingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een psychiatrische instelling is een gebouw voor de opvang, verzorging en behandeling van pati\xebnten met neurotische aandoeningen.",
                "type": "scopeNote",
            }
        ],
        "related": [154],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/357",
    },
    {
        "broader": [1072],
        "id": 1078,
        "labels": [{"label": "puinlagen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een puinlaag is een antropogene laag die ontstaan is door de depositie van bouwpuin.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1078",
    },
    {
        "broader": [411],
        "id": 2100,
        "labels": [
            {"label": "quarantainestallen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een quarantainestal is een in een grensgemeente opgericht gebouw waar ingevoerd vee gedurende enige  tijd in quarantaine wordt gehouden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2100",
    },
    {
        "broader": [1656],
        "id": 1664,
        "labels": [
            {"label": "quinconces", "language": "nl-BE", "type": "prefLabel"},
            {"label": "quincunx", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een quinconce is bos van opgaande bomen in een strak plantverband, gepositioneerd volgens de vijf van een teerling. In reeksen per groep van vijf, vier in elke hoek van een vierkant en de vijfde in het centrum.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term verplaatst van BT hooghoutpercelen naar bomengroepen (na eerdere verplaatsing van bomengroepen naar hooghoutpercelen).",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1664",
    },
    {
        "broader": [],
        "id": 2075,
        "labels": [{"label": "rabatten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1850],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rabat is een (vaak aaneengeschakelde) landinrichtingsvorm waarbij een deel van een bos of plantage als een verhoogd plantbed door parallelle grachten is afgescheiden. De grachten zelf staan in functie van een verbeterde ontwatering. Deze landinrichtingsvorm is voornamelijk toegepast op natte tot zeer natte bodems.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2075",
    },
    {
        "broader": [2007],
        "id": 2120,
        "labels": [
            {"label": "randwalduinen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "stuifwallen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2016],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een randwalduin is een duin ontstaan op de grens tussen oud akkerland en woeste gronden (meestal heide), meestal ontstaan doordat de mens een afscherming maakte rond de akkers, waarin zand vervolgens vastgehouden werd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2120",
    },
    {
        "broader": [1033],
        "id": 1047,
        "labels": [
            {"label": "rasternederzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1035],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rasternederzetting is een nederzetting aangelegd volgens een loodrecht wegenpatroon.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.\n23/06/2015: BT gewijzigd; SN gewijzigd, was: "Een rasternederzetting is een nederzetting die een loodrecht patroon kent."',
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1047",
    },
    {
        "broader": [237],
        "id": 2116,
        "labels": [
            {
                "label": "reclamemuurschilderingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een reclamemuurchildering is een geschilderde advertentie, over het algemeen op een (buiten)muur aangebracht.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "17/07/2015: term toegevoegd; nog niet op ideale plaats in boomstructuur.",
                "type": "historyNote",
            },
        ],
        "related": [2150],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2116",
    },
    {
        "broader": [1393],
        "id": 1403,
        "labels": [
            {"label": "recreatieve objecten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Objecten die gebruikt worden in de vrije tijd en ontspanning als doel hebben. Hieronder vallen objecten als speelgoed, dobbelstenen, muziekinstrumenten, ...",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1403",
    },
    {
        "broader": [78],
        "id": 1447,
        "labels": [
            {"label": "reddingsvaartuigen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "reddingsboten", "language": "nl-BE", "type": "altLabel"},
            {"label": "reddingssloepen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een reddingsvaartuig is een vaartuig bestemd en ingericht tot redding van schipbreukelingen of dienende om een verongelukt schip te verlaten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1447",
    },
    {
        "broader": [1150],
        "id": 1182,
        "labels": [{"label": "redoutes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een redoute is een kleine versterking van allerlei vormen, gewoonlijk vierkant of veelhoekig van opzet, soms gebruikt ter verdediging van een hooggelegen punt, soms afzonderlijk gelegen, soms ge\xefntegreerd in een linie. Onderscheidt zich van een fort door kleinere omvang, eenvoudiger verdedigingswerken en kleinere personeelsbezetting.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1182",
    },
    {
        "broader": [147],
        "id": 1865,
        "labels": [
            {"label": "refectoriums", "language": "nl-BE", "type": "prefLabel"},
            {"label": "refters", "language": "nl-BE", "type": "altLabel"},
            {"label": "eetzalen", "language": "nl-BE", "type": "altLabel"},
            {"label": "refectoria", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004347"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1785],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een refter is een eetzaal in een klooster, waar kloosterlingen gemeenschappelijk de maaltijd in gebruiken. Doorgaans zijn ze gelegen in de oost-westrichting aan de kloostergang, aan de arm die evenwijdig is aan de kerk en recht er tegenover ligt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1865",
    },
    {
        "broader": [889],
        "id": 358,
        "labels": [
            {"label": "refugiehuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een refugiehuis is een woonhuis in een stad, in bezit van een abdij, waar kloosterlingen op reis of op de vlucht tijdelijk onderdak vonden. Een inwonend beheerder stond in voor het onderhoud. Verder voerde hij enkele taken uit in opdracht van de abdij, zoals het innen van renten uit de omgeving.",
                "type": "scopeNote",
            }
        ],
        "related": [4, 359],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/358",
    },
    {
        "broader": [],
        "id": 2078,
        "labels": [
            {
                "label": "regelmatige ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2076],
        "narrower": [2079, 2081, 2082, 2084],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een regelmatig ontginningspatroon bestaat uit overwegend rechte lijnen (wegen en waterlopen), de percelen zijn van regelmatige vorm en grootte met duidelijke structuur en hebben veel rechte perceelsgrenzen. Het ontginningspatroon is ontstaan door planmatige ontginning van een (groter) gebied in \xe9\xe9n keer, meestal collectief en grootschalig.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2078",
    },
    {
        "broader": [],
        "id": 2056,
        "labels": [{"label": "regosols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1855],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een regosol is een bodem met beperkte profielontwikkeling waarvan de bodemvorming beperkt wordt en/of waarvan de oorspronkelijke bodem is verdwenen door erosieprocessen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2056",
    },
    {
        "broader": [147],
        "id": 359,
        "labels": [
            {
                "label": "religieuze gebouwen en complexen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007391"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [4, 53, 102, 243, 244, 298, 354, 420, 480, 513, 1116, 1005],
        "notes": [],
        "related": [50, 65, 216, 340, 358, 383, 889],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/359",
    },
    {
        "broader": [896],
        "id": 360,
        "labels": [{"label": "renbanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [724, 723, 826],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een renbaan is een terrein met banen voor wedrennen en bijhorende gebouwen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/360",
    },
    {
        "broader": [343],
        "id": 361,
        "labels": [
            {"label": "rentmeesterwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rentmeesterwoning is het woonhuis van een rentmeester. Rentmeesters voeren het financi\xeble beheer over een niet aan hen toebehorend vermogen (meeestal onroerende goederen), voornamelijk in opdracht van welstellende particulieren (kasteelheren) of kerkelijke instanties.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/361",
    },
    {
        "broader": [881],
        "id": 362,
        "labels": [
            {"label": "restaurants", "language": "nl-BE", "type": "prefLabel"},
            {"label": "brasserie\xebn", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een restaurant is een publieke gelegenheid waar men maaltijden serveert.",
                "type": "scopeNote",
            }
        ],
        "related": [214],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/362",
    },
    {
        "broader": [2003],
        "id": 2004,
        "labels": [
            {"label": "restheuvels", "language": "nl-BE", "type": "prefLabel"},
            {"label": "getuigenheuvels", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een restheuvel is een ge\xefsoleerde heuvel die mede door zijn erosiebestendigheid een overblijfsel is van oudere afzettingen die in de nabije omgeving grotendeels zijn wegge\xebrodeerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1979, 1974],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2004",
    },
    {
        "broader": [466],
        "id": 644,
        "labels": [
            {"label": "revalidatiecentra", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een revalidatiecentrum is een centrum waar personen met motorische, sensori\xeble en psychische beperkingen, eventueel na een intensieve medische behandeling, door therapeutische en andere maatregelen begeleid worden tot een voor hen optimaal lichamelijk en geestelijk herstel.",
                "type": "scopeNote",
            }
        ],
        "related": [526, 154],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/644",
    },
    {
        "broader": [1915],
        "id": 1916,
        "labels": [{"label": "rietlanden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rietland is een moeras waar de vegetatie hoofdzakelijk uit riet bestaat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1917],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1916",
    },
    {
        "broader": [],
        "id": 1917,
        "labels": [
            {"label": "rietsnijderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1840],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rietsnijderij is een productief bodemgebruik waarbij riet als bouwmateriaal (bvb. voor dakbedekking) wordt geoogst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/08/2015: verplaatst van BT rietlanden naar BT bodemgebruik bij revisie termen landschappen.",
                "type": "historyNote",
            },
        ],
        "related": [1916],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1917",
    },
    {
        "broader": [54],
        "id": 1258,
        "labels": [
            {"label": "rijengrafvelden", "language": "nl-BE", "type": "prefLabel"},
            {"label": "Reihengr\xe4berfelder", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rijengrafveld is een begraafplaats uit de vroege middeleeuwen, waarbij de begravingen in min of meer in keurig geordende rijen zijn gegroepeerd. Omstreeks 400 kwam, na een lange traditie van crematie, lijkbegraving opnieuw op. Deze graven werden niet als voorheen onder een grafheuvel geplaatst (met de uitzondering van enkele elitegraven), maar in individuele kuilen naast elkaar. Men kan een etnisch onderscheid maken in de ori\xebntatie van de graven (Germaans: noord-zuid; Merovingisch: oost-west) en een afname van de grafgiften. Met de verbreiding van het christendom en de eerste kerken werden de graven naar de kerk verplaatst. De meeste rijengrafvelden houden rond deze periode (ca. 900) dan ook op te functioneren. Ze komen vooral voor langs rivieren in Belgi\xeb, Nederland, Duitsland en Frankrijk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1258",
    },
    {
        "broader": [522],
        "id": 2173,
        "labels": [
            {"label": "rijkswachterswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rijkswachterswoning is een woning die gebouwd is voor rijkswachters. Vaak zijn meerdere woningen gegroepeerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term toegevoegd ikv integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2173",
    },
    {
        "broader": [323],
        "id": 363,
        "labels": [
            {"label": "rijkswachtkazernes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rijkswachtkazerne is de uitvalsbasis van de rijkswacht. In de rijkswachtkazernes worden de wagens gestald en worden de dienstdoende rijkswachters gehuisvest.",
                "type": "scopeNote",
            }
        ],
        "related": [348, 460],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/363",
    },
    {
        "broader": [1033],
        "id": 1060,
        "labels": [
            {"label": "rijnederzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1035],
        "narrower": [2106],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rijnederzetting is een nederzetting waarbij de bebouwing is gelegen langs een lineaire structuur zoals een weg, kanaal of een dijk, of langs de rand van bos of heide, vaak aangelegd in functie van een (systematische) ontginning.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Antrop M. 2007: Perspectieven op het landschap, achtergronden om landschappen te lezen en begrijpen, Academia Press, Gent.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1060",
    },
    {
        "broader": [2149],
        "id": 2151,
        "labels": [
            {"label": "rijshoutaanplanten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "grienden", "language": "nl-BE", "type": "altLabel"},
            {"label": "wijmeniers", "language": "nl-BE", "type": "altLabel"},
            {"label": "wiedauwen", "language": "nl-BE", "type": "altLabel"},
            {"label": "wijmiers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rijshoutaanplant is een dichte aanplant van wilgentenen, meestal op natte gronden, waarbij periodiek wissen voor vlechtwerkproductie worden geoogst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/09/2015: toegevoegd ter vervanging van rijshoutbossen bij herziening thesaurus landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2151",
    },
    {
        "broader": [1150],
        "id": 1183,
        "labels": [
            {"label": "ringwalburgen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vluchtburgen", "language": "nl-BE", "type": "altLabel"},
            {
                "label": "castellae recens factae",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ringwalburg is een grote collectieve versterking voorzien van stenen, houten of aarden omwallingen en met palissaden en struikgewas, die de bewoners van de omgeving bij gevaar als toevluchtsoord diende en waar ze zich konden verdedigen. Dergelijke structuren komen op vanaf de Karolingische periode en worden gelinkt aan de Noormanneninvallen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1183",
    },
    {
        "broader": [13],
        "id": 1196,
        "labels": [
            {"label": "riolen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "riolering", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een riool is een ondergrondse of (eventueel open) bovengrondse leiding voor het afvoeren van afval- of regenwater. Riolen in het antieke Rome worden cloaca's genoemd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1196",
    },
    {
        "broader": [1389],
        "id": 1392,
        "labels": [
            {"label": "rivierdeposities", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rivierdepositie is een intentionele depositie van offensieve en defensieve wapens, sieraden en gebruiksvoorwerpen (meestal in brons) en van (dierlijk of menselijk) skeletmateriaal in de rivier. De voorwerpen werden bewust in het water gegooid in het kader van religieus/culturele handelingen. Deze deposities beginnen vrij plots rond 1500 v.Chr.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) cursusmateriaal UGent (Prof. J. Bourgeois) 2) 4.7.3.1. Riviervondsten, in: Onderzoeksbalans Onroerend Erfgoed Vlaanderen <a href="http://www.onderzoeksbalans.be/.">http://www.onderzoeksbalans.be/.</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1392",
    },
    {
        "broader": [2007],
        "id": 2014,
        "labels": [{"label": "rivierduinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2008],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rivierduin is een duin(complex) ontstaan in of langs een (voormalige) riviervlakte, gevormd door het verstuiven van zand uit een droogliggende alluviale vlakte.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2014",
    },
    {
        "broader": [1962],
        "id": 1963,
        "labels": [{"label": "rivieren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008707"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1964],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rivier is een relatief brede natuurlijke waterloop die de afwatering van een stroomgebied verzorgt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Hydrologische woordenlijst, Nederlandse hydrologische vereniging, 2002",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1963",
    },
    {
        "broader": [1982],
        "id": 1991,
        "labels": [
            {"label": "rivierterrassen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rivierterras is een vlakte ontstaan als restant van een vroegere dalbodem waarin een oorspronkelijke natuurlijke waterloop zich heeft ingesneden. Het terras wordt doorgaans door een markante rand gescheiden van de huidige rivierbedding, waarbij het terras hoger ligt dan de huidige rivierbedding.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1977, 1980],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1991",
    },
    {
        "broader": [237],
        "id": 364,
        "labels": [
            {"label": "roepstenen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kerkstenen", "language": "nl-BE", "type": "altLabel"},
            {"label": "puien", "language": "nl-BE", "type": "altLabel"},
            {"label": "roephuisjes", "language": "nl-BE", "type": "altLabel"},
            {"label": "roepstoelen", "language": "nl-BE", "type": "altLabel"},
            {"label": "roeptribunes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Verhevenheden bij openbare gebouwen, zoals stadhuizen, gerechtsgebouwen en kerken, waar men afkondigingen deed of rechtshandelingen verrichtte.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/364",
    },
    {
        "broader": [871],
        "id": 1291,
        "labels": [{"label": "rootputten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rootput is een put die gebruikt werd voor het roten van vlas. Roten: door de inwerking van water en bacterie\xebn komen de vezels los van de vlasstengel.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1291",
    },
    {
        "broader": [297],
        "id": 365,
        "labels": [{"label": "rosmolens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rosmolen is een molen die door \xe9\xe9n of meerdere paarden wordt aangedreven.",
                "type": "scopeNote",
            }
        ],
        "related": [277],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/365",
    },
    {
        "broader": [472],
        "id": 871,
        "labels": [{"label": "roterijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1291],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/871",
    },
    {
        "broader": [439],
        "id": 1539,
        "labels": [{"label": "rotsbruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rotsbrug is een brug waarvan de gevelbekleding bestaat uit rotsen in natuursteen of kunstrotsen, ook wel grotwerk geheten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1539",
    },
    {
        "broader": [174],
        "id": 366,
        "labels": [
            {"label": "rotsformaties", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rotsformatie is een grafmonument in de vorm van een artifici\xeble rotspartij.",
                "type": "scopeNote",
            }
        ],
        "related": [92, 279],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/366",
    },
    {
        "broader": [440],
        "id": 1584,
        "labels": [{"label": "rotstuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1585],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rotstuin is een siertuin met natuurlijke of kunstmatige rotsen voor de teelt van rotsplanten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1584",
    },
    {
        "broader": [1574],
        "id": 1575,
        "labels": [{"label": "rozentuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300248615"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rozentuin is een siertuin waarin de meeste bloembedden voor het kweken van rozen worden gebruikt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1575",
    },
    {
        "broader": [],
        "id": 2027,
        "labels": [{"label": "ruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1859],
        "narrower": [2028, 2029, 2030, 2122, 2123],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rug is een hogergelegen reli\xebfvorm begrensd door flauwe, min of meer symmetrische flanken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2027",
    },
    {
        "broader": [],
        "id": 1918,
        "labels": [{"label": "ruigten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1840],
        "narrower": [1919, 1920],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ruigte is een niet productief en vaak tijdelijk bodemgebruik met spontane vegetatiegroei bestaande uit ruigtekruiden, struiken en/of jonge bomen, ontstaan na stopzetting van een ander bodemgebruik.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1918",
    },
    {
        "broader": [466],
        "id": 368,
        "labels": [
            {"label": "rusthuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "bejaardentehuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een rusthuis is een gebouw waar bejaarden verblijven en verzorgd worden.",
                "type": "scopeNote",
            }
        ],
        "related": [166, 55],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/368",
    },
    {
        "broader": [147],
        "id": 1778,
        "labels": [
            {"label": "sacristie\xebn", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004631"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1767],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sacristie is een ruimte aan of in kerken of kapellen waar de liturgische voorwerpen en misgewaden worden bewaard.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1778",
    },
    {
        "broader": [466],
        "id": 369,
        "labels": [
            {"label": "sanatoria", "language": "nl-BE", "type": "prefLabel"},
            {"label": "preventoria", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sanatorium is een gebouw waar chronisch zieken een langdurige behandeling ondergaan, vaak voor een longaandoening.",
                "type": "scopeNote",
            }
        ],
        "related": [267, 526, 202],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005; Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/369",
    },
    {
        "broader": [13],
        "id": 1200,
        "labels": [
            {
                "label": "sanitaire infrastructuur",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1201, 1203, 1206, 1207, 1337],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1200",
    },
    {
        "broader": [174],
        "id": 370,
        "labels": [{"label": "sarcofagen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sarcofaag is een grafmonument in de vorm van een stenen doodskist.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/370",
    },
    {
        "broader": [896],
        "id": 371,
        "labels": [{"label": "schaatsbanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schaatsbaan is een gebouw dat is ontworpen om er te (rol)schaatsen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/371",
    },
    {
        "broader": [291],
        "id": 915,
        "labels": [
            {"label": "schachtbokken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "schachttorens", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/915",
    },
    {
        "broader": [334],
        "id": 372,
        "labels": [
            {"label": "schandpalen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kaken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Palen waaraan veroordeelden tot hun schande vastgebonden en te kijk gezet werden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/372",
    },
    {
        "broader": [1150],
        "id": 868,
        "labels": [{"label": "schansen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schans is een doorgaans aarden verdedigingswerk, met wallen en grachten omheind dat door de mens is aangewend voor schuil- en verdedigingsdoeleinden. De term schans wordt vooral gebruikt voor kleinere verdedigingsstructuren die vanaf de Tachtigjarige Oorlog (1568-1648) voorkomen. Een schans is een versterking die vooral door de plattelandsbevolking op eigen initiatief werd opgetrokken om zich te beschermen tegen de vele bendes en legers die het land teisterden, maar men kan ook militaire schansen onderscheiden. De verdediging bestond vooral uit de ge\xefsoleerde en weinig toegankelijke ligging, grachten en een wal.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'versterkte sites'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Keijers D.M.G. 2009, Studieopdracht naar een archeologische evaluatie en waardering van 7 schansen, provincies Limburg en Vlaams-Brabant, RAAP-rapport 1977 in opdracht van Agentschap R-O Vlaanderen.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/868",
    },
    {
        "broader": [923],
        "id": 373,
        "labels": [
            {"label": "scheepshellingen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "slipways", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een scheepshelling is een helling, die afloopt naar het water, zodat vaartuigen op het droge getrokken kunnen worden of te water gelaten. Ze komen zowel voor op scheepswerven als alleen langs oevers.",
                "type": "scopeNote",
            }
        ],
        "related": [374],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/373",
    },
    {
        "broader": [923],
        "id": 374,
        "labels": [
            {"label": "scheepswerven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een scheepswerf is een plaats waar vaartuigen worden gebouwd of hersteld. Sommige scheepswerven beschikken over scheepshellingen.",
                "type": "scopeNote",
            }
        ],
        "related": [947, 373],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/374",
    },
    {
        "broader": [179],
        "id": 1686,
        "labels": [
            {"label": "scheidingshagen", "language": "nl-BE", "type": "prefLabel"},
            {
                "label": "gemeenschappelijke hagen",
                "language": "nl-BE",
                "type": "altLabel",
            },
            {"label": "gemene hagen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1681],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een scheidingshaag is een haag op de grens tussen kadastrale percelen. Indien eigenaars van belendende percelen overeenkomen dan wordt de haag gemeenschappelijk geplant op de grens. Meestal wordt volgens de lokale geplogenheden, voorzien in het Veldwetboek, de haag op een bepaalde afstand van de perceelgrens geplant.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1686",
    },
    {
        "broader": [441],
        "id": 1537,
        "labels": [
            {"label": "schelpengrotten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schelpengrot is een kunstmatige grot waarvan de binnen- en soms de buitenwanden gedecoreerd zijn met geometrische patronen van inheemse en exotische schelpen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1537",
    },
    {
        "broader": [147],
        "id": 1770,
        "labels": [{"label": "schepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004627"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1767],
        "narrower": [1771, 1772],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schip is de romp van een kerk, onderscheiden van het koor en voorbouwsels aan de tegenovergestelde zijde. Het schip is eenbeukig of onderverdeeld in middenbeuk en zijbeuken.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1770",
    },
    {
        "broader": [323],
        "id": 376,
        "labels": [
            {"label": "schepenhuizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schepenhuis is een locatie waar de schepenbank haar vergadering hield. In de middeleeuwen gebeurde dit voornamelijk in openlucht. Vanaf de 13de eeuw werden ook stenen gebouwen opgericht (vaak in samenhang met een belfort) waarin de schepenen konden samenkomen. Schepenhuizen zijn de voorlopers van de latere gemeente- en stadhuizen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '26/01/2011: SN aangepast. Oorspronkelijk: "Vergaderplaatsen van de schepenen van een stad. Voorlopers uit het ancien r\xe9gime van de latere gemeente- en stadhuizen."',
                "type": "historyNote",
            },
        ],
        "related": [158, 402, 222],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/376",
    },
    {
        "broader": [932],
        "id": 1640,
        "labels": [
            {"label": "schermbeplantingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Schermbeplanting is beplanting die aangeplant is om (meestal)een gebouw te beschermen tegen extreme weersomstandigheden. Ze werd geplant als regen-, wind- en zonnescherm.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1640",
    },
    {
        "broader": [479],
        "id": 377,
        "labels": [
            {"label": "schietstanden", "language": "nl-BE", "type": "prefLabel"},
            {"label": "wippen", "language": "nl-BE", "type": "altLabel"},
            {"label": "schutterstorens", "language": "nl-BE", "type": "altLabel"},
            {"label": "gaaipersen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Inrichtingen voor de schutterssport, vb. staande of liggende wippen, schutterstorens, schietbomen, schietbanen en gaaipersen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "scopenote aangepast op 21/01/2010. (die dienen als schuttersdoelen &gt; voor de schutterssport)",
                "type": "historyNote",
            },
        ],
        "related": [479],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/377",
    },
    {
        "broader": [237],
        "id": 2094,
        "labels": [
            {"label": "schildwachthuisjes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300048816"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Schildwachthuisjes zijn hokjes of huisjes die een schildwacht beschutting geven op zijn post.",
                "type": "scopeNote",
            }
        ],
        "related": [485, 1746],
        "sources": [
            {
                "citation": "Nederlandse Art &amp; Architecture Thesaurus (AAT-NL)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2094",
    },
    {
        "broader": [20],
        "id": 378,
        "labels": [
            {"label": "schoenfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schoenfabriek is een fabriek waar men schoenen produceert.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Ambachtelijke schoenmakerijen zijn niet opgenomen als schoenfabrieken, maar als werkplaats bij een winkel.",
                "type": "note",
            },
        ],
        "related": [239],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/378",
    },
    {
        "broader": [319],
        "id": 1426,
        "labels": [
            {"label": "schoolkolonies", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schoolkolonie is een onderwijsinstelling in een gezonde landstreek waarheen zwakke, behoeftige kinderen gezonden worden tot herstel of verbetering van hun gezondheid.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Toegevoegd na overleg op IW, zie #481.",
                "type": "historyNote",
            },
        ],
        "related": [456],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1426",
    },
    {
        "broader": [1565],
        "id": 1572,
        "labels": [{"label": "schooltuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schooltuin is een tuin voor nut en sier bij een school ten behoeve van het onderwijs in de plantkunde aangelegd, waarin scholieren ook zelf groenten of bloemen kweken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1572",
    },
    {
        "broader": [1985],
        "id": 1987,
        "labels": [{"label": "schorren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schor is een (deel van een) aangeslibde wadvlakte die enkel bij springtij overstroomt en doorgaans begroeid is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1987",
    },
    {
        "broader": [18],
        "id": 380,
        "labels": [
            {"label": "schrijnwerkerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schrijnwerkerij is een ambachtelijk bedrijf waar men fijn timmerwerk maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [194, 289],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/380",
    },
    {
        "broader": [945],
        "id": 1168,
        "labels": [
            {"label": "schuilkelders", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1168",
    },
    {
        "broader": [1149],
        "id": 945,
        "labels": [
            {"label": "schuilplaatsen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1168, 1467],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schuilplaats is een versterkte verdedigingsstelling, meestal in baksteen en gedeeltelijk in de grond ingegraven.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'versterkte gebouwen'.",
                "type": "historyNote",
            },
        ],
        "related": [87],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/945",
    },
    {
        "broader": [1941],
        "id": 1942,
        "labels": [{"label": "schuiven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1943],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schuif is een beweegbare stuw.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1942",
    },
    {
        "broader": [328],
        "id": 381,
        "labels": [
            {"label": "schuren", "language": "nl-BE", "type": "prefLabel"},
            {"label": "schobben", "language": "nl-BE", "type": "altLabel"},
            {"label": "vlasschuren", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [332],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schuur is een opslagplaats voor landbouwproducten en -gereedschap.",
                "type": "scopeNote",
            }
        ],
        "related": [332, 411],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/381",
    },
    {
        "broader": [389],
        "id": 1934,
        "labels": [
            {"label": "schutsluizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "sassen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300235059"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1862],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een schutsluis is een aan weerszijden met deuren afsluitbare sluis waarin, door aanpassing van het waterpeil, schepen van het ene op het andere niveau worden gebracht.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Hydrologische woordenlijst, Nederlandse hydrologische vereniging, 2002",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1934",
    },
    {
        "broader": [147],
        "id": 1789,
        "labels": [{"label": "scriptoria", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300132308"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1785],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een scriptorium is de schrijf- en verluchtkamer in een klooster, vaak verbonden met de librije (kloosterbibliotheek).",
                "type": "scopeNote",
            }
        ],
        "related": [4, 243],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1789",
    },
    {
        "broader": [237],
        "id": 48,
        "labels": [{"label": "sculpturen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [888],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Al dan niet vrijstaande, meestal driedimensionale kunstwerken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "19/04/2011: IN deel 2 toegevoegd.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Indien niet vrijstaand, zijn enkel de sculpturen die een relevante, onverwachte plaats innemen op een gevel, opgenomen in de databank.\nGebruik 'kleinsculptuur' voor archeologische objecten die als losse objecten voorkomen en van een kleinere schaal zijn.",
                "type": "note",
            },
        ],
        "related": [1395],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/48",
    },
    {
        "broader": [924],
        "id": 382,
        "labels": [{"label": "seinhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een seinhuis is een gebouw van waaruit seinen en wissels worden bediend, doorgaans van een spoorwegnet.",
                "type": "scopeNote",
            }
        ],
        "related": [485],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/382",
    },
    {
        "broader": [319],
        "id": 383,
        "labels": [{"label": "seminaries", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [960],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een seminarie is een gebouw voor de opleiding van rooms-katholieke geestelijken.",
                "type": "scopeNote",
            }
        ],
        "related": [359],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/383",
    },
    {
        "broader": [467],
        "id": 1599,
        "labels": [
            {"label": "serpentinevijvers", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een serpentinevijver is een vijver in landschappelijke stijl, waarvan de oevers in grote lijnen de curve van de 18de-eeuwse Britse schilder William Hogarth\u2019s line of beauty volgen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1599",
    },
    {
        "broader": [63],
        "id": 384,
        "labels": [{"label": "serres", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004938"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1475, 1477, 1478],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een serre is een al dan niet kunstmatig verwarmde glazen kas om gewassen te kweken waarvoor de gewone buitenlucht te koud is.",
                "type": "scopeNote",
            }
        ],
        "related": [329, 518],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/384",
    },
    {
        "broader": [522],
        "id": 1793,
        "labels": [
            {"label": "servitudewoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een servitudewoning is een houten huis in de buurt van een fort. Elk fort en elke schans of omwalling had een afgebakend schootsveld waarbinnen men geen stenen gebouwen mocht oprichten. In vredestijd mocht men er wel houten woningen bouwen. Bij oorlogsdreiging werden die snel afgebroken om het zicht vanuit het fort op het omliggende gebied te verbeteren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "14/03/2014: term toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [141],
        "sources": [
            {
                "citation": "GHEYLE W. &amp; BOURGEOIS I. (red.) 2013: Vergeten linies. Antwerpse bunkers en loopgraven door de lens van Leutnant Zimmermann (1918), Antwerpen, 245.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1793",
    },
    {
        "broader": [888],
        "id": 1530,
        "labels": [{"label": "sfinxen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sfinx is een stenen of gietijzeren beeld in leeuwengedaante met het hoofd van een mens.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "17/08/2015: BT gewijzigd bij verwijderen term 'tuinbeelden'.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1530",
    },
    {
        "broader": [],
        "id": 1092,
        "labels": [{"label": "shadow marks", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1090],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een 'shadow mark' of schaduwspoor is te wijten aan het feit dat lichte oneffenheden op naakte grond of in grasland en groeiverschillen in gewassen kunnen geobserveerd worden onder speciale omstandigheden, met name bij een zeer lage zon. Dit resulteert in slagschaduwen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Luchtfotografie boven Vlaanderen: Wat is luchtfotografie?, <a href="http://www.archaeology.ugent.be/luchtfotografie">http://www.archaeology.ugent.be/luchtfotografie</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1092",
    },
    {
        "broader": [1393],
        "id": 1404,
        "labels": [{"label": "sieraden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Sieraden zijn ornamenten zoals armbanden, halskettingen en ringen van edele of halfedele materialen die voor de sier op het lichaam worden gedragen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1404",
    },
    {
        "broader": [179],
        "id": 1685,
        "labels": [
            {"label": "sierhagen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "ornamentele hagen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1681],
        "narrower": [746],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sierhaag is een geschoren haag gebruikt als sierrelict: randpalm, loofgang, prieel.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1685",
    },
    {
        "broader": [1603],
        "id": 440,
        "labels": [{"label": "siertuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            1573,
            1574,
            1576,
            1577,
            1578,
            1579,
            1580,
            1581,
            1583,
            1584,
            1586,
            1595,
            1596,
        ],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een siertuin is een tuin, doorgaans bij een woning, waar bodembedekkers, eenjarige planten, bol- en knolgewassen, vaste planten, struiken en bomen als sierplanten combineert met gazon en/of verhardingen, tuinconstructies en tuinornamenten.",
                "type": "scopeNote",
            }
        ],
        "related": [443, 30, 337, 346, 439, 444],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/440",
    },
    {
        "broader": [21],
        "id": 1764,
        "labels": [
            {"label": "sigarenfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900026566"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sigarenfabriek is een industrieel of ambachtelijk bedrijf waar men sigaren maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [421],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1764",
    },
    {
        "broader": [328],
        "id": 385,
        "labels": [{"label": "silo's", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een silo is een bovengronds (hoog, meestal kokervormig) bouwwerk met onderaan een opening of een ondergrondse (meestal klokvormige) uitgraving waarin levensmiddelen zoals graan of voer voor dieren wordt opgeslagen, en die meestal is afgesloten om lucht buiten te houden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": '24/01/2011: SN gewijzigd bij integratie met archeologische termen. Oorspronkelijk: "Doorgaans kokervormige opslagplaatsen voor stortgoed, waarin via de bovenzijde goederen worden gestort, met onderaan een trechtervormige opening."',
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. \n2) VIOE\n3) HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005; Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/385",
    },
    {
        "broader": [1135],
        "id": 1137,
        "labels": [
            {"label": "sites met walgracht", "language": "nl-BE", "type": "prefLabel"},
            {"label": "walgrachtsites", "language": "nl-BE", "type": "altLabel"},
            {"label": "moated sites", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een site met walgracht  - moated site, omwalde of omgrachte hoeve - is een door een brede gracht omgeven wooncomplex, waarbij het voornaamste gebouw opgetrokken is uit (bak)steen. De rest bestaat uit steen- of meestal houtbouw. De gebouwen kunnen defensieve elementen, zoals torens en een poortgebouw, bezitten, maar zijn niet re\xebel verdedigbaar. Deze elementen vervullen voornamelijk een statusfunctie. De vorm van de woonzone kan vierkant, rechthoekig, cirkelvormig of onregelmatig zijn. In enkele gevallen werd de woonzone opgehoogd. Ze kunnen gedateerd worden tussen de late middeleeuwen en de nieuwe tijd. De sites zijn vaak nog te herkennen in het landschap door de aanwezigheid van een gracht rondom een hoevecomplex. Vaak is ook het wooneiland nog als ophoging herkenbaar. In de 18de eeuw werden ook pastorie\xebn in landelijk gebied vaak als site met walgracht geconcipieerd.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.\n13/08/2014: SN aangepast: verduidelijking hoeven en pastorie\xebn",
                "type": "historyNote",
            },
        ],
        "related": [1109, 1080],
        "sources": [
            {
                "citation": '1) Vangheluwe H. 1997-1998, Geografische aspecten van sites met walgracht in de omgeving van Ieper, scriptie voorgelegd tot het behalen van de graad van Licentiaat in de geografie, Universiteit Gent. 2) De Wit G. &amp; Sloos A. 2008, De interpretatie van archeologische waarnemingen in Archis. Een concept voor een nieuwe set complextypen, in: Rapportage Archeologische Monumentenzorg 165, Amersfoort. 3) <a href="https://onderzoeksbalans.onroerenderfgoed.be/onderzoeksbalans/archeologie/late_middeleeuwen_en_moderne_tijden/landelijke_archeologie/sites_met_walgracht">https://onderzoeksbalans.onroerenderfgoed.be/onderzoeksbalans/archeologie/late_middeleeuwen_en_moderne_tijden/landelijke_archeologie/sites_met_walgracht</a> (geraadpleegd op 13/08/2014) 4) Verhaeghe F. 1977: De middeleeuwse landelijke bewoningssites in een deel van Veurne-Ambacht. Een bijdrage tot de middeleeuwse archeologie, onuitgegeven doctoraatproefschrift.',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1137",
    },
    {
        "broader": [21],
        "id": 386,
        "labels": [
            {"label": "slachthuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "abattoirs", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een slachthuis is een gebouw waarin men vee slacht.",
                "type": "scopeNote",
            }
        ],
        "related": [388, 474],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/386",
    },
    {
        "broader": [885],
        "id": 388,
        "labels": [{"label": "slagerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een slagerij is een winkel waar men vlees verwerkt en verkoopt.",
                "type": "scopeNote",
            }
        ],
        "related": [386, 474],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/388",
    },
    {
        "broader": [933],
        "id": 1114,
        "labels": [{"label": "slagvelden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een slagveld is de plaats waar twee of meer legers of groepen strijders hun geschil uitvechten (slag leveren).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1114",
    },
    {
        "broader": [792],
        "id": 1517,
        "labels": [{"label": "slangenmuren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een slangenmuur is een fruitmuur op doorgaande golvende of slingerende plattegrond, bestaande uit regelmatig elkaar afwisselende cirkelsegmenten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1517",
    },
    {
        "broader": [78],
        "id": 1459,
        "labels": [
            {"label": "sleep- en duwboten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sleep- of duwboot is een zeer sterke stoom- of motorboot die andere vaartuigen op sleeptouw neemt of ingericht is om andere vaartuigen te duwen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1459",
    },
    {
        "broader": [1985],
        "id": 1986,
        "labels": [{"label": "slikken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een slik is een (deel van een) buitendijkse aangeslibde wadvlakte die dagelijks bij vloed overstroomt en bij eb droogvalt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1986",
    },
    {
        "broader": [484],
        "id": 959,
        "labels": [
            {
                "label": "sluis- en brugwachterswoningen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {"label": "brugwachterswoningen", "language": "nl-BE", "type": "altLabel"},
            {"label": "sluiswachterswoningen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sluis- en brugwachterswoning is het woonhuis voor een sluis- of brugwachter. Een sluiswachter is belast met het toezicht op en de bediening van een sluis. Een brugwachter bedient een draai- of wipbrug.",
                "type": "scopeNote",
            }
        ],
        "related": [86, 389],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/959",
    },
    {
        "broader": [923],
        "id": 389,
        "labels": [{"label": "sluizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sluis is een waterbouwkundige constructie die wordt gekenmerkt door een beweegbare waterkering en tevens door de mogelijkheid om waterwegen/kunstmatige waterlopen aan beide zijden van de sluis met elkaar te verbinden, ook als de waterstand niet gelijk is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: SN aangepast; oude SN: Een sluis is een kunstmatige waterkering op plaatsen met ongelijk waterpeil, uitgerust met een afsluitklep of deur die het water (en in het geval van een schutssluis of sas ook het vaartuig) ophouden, terwijl het peil ervan geregeld wordt.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "De lokalen waar de sluiswachter toezicht houdt op de sluis, maken deel uit van de sluisinfrastructuur en worden opgenomen bij sluizen.",
                "type": "note",
            },
        ],
        "related": [959],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [1861, 1862, 1863],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/389",
    },
    {
        "id": 1863,
        "labels": [
            {
                "label": "sluizen met militaire functie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1933],
        "notes": [],
        "sources": [],
        "superordinates": [389],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1863",
    },
    {
        "id": 1862,
        "labels": [
            {
                "label": "sluizen voor scheepvaart",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1934, 1935, 1936],
        "notes": [],
        "sources": [],
        "superordinates": [389],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1862",
    },
    {
        "id": 1861,
        "labels": [
            {
                "label": "sluizen voor waterhuishouding",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1937, 1938, 1939],
        "notes": [],
        "sources": [],
        "superordinates": [389],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1861",
    },
    {
        "broader": [22],
        "id": 1281,
        "labels": [{"label": "smelterijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een smelterij is een werkplaats waar grondstoffen/metalen gesmolten worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1281",
    },
    {
        "broader": [22],
        "id": 1282,
        "labels": [{"label": "smeltovens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een smeltoven is een oven waarin metalen gesmolten worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1100],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1282",
    },
    {
        "broader": [22],
        "id": 390,
        "labels": [
            {"label": "smidsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "smederijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een smidse is een ambachtelijk bedrijf waar smeden metaal bewerken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/390",
    },
    {
        "broader": [],
        "id": 1093,
        "labels": [{"label": "snow marks", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1090],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een snow mark is een spoor in de sneeuw veroorzaakt door verschillen in smeltstadia die onderliggende structuren aangeven. Snow marks worden gebruikt om op luchtfoto's archeologische sites op te sporen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1093",
    },
    {
        "broader": [522],
        "id": 391,
        "labels": [
            {"label": "sociale woningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300101336"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Sociale woningen omvatten woningen voor minderbedeelden, vooral gebouwd door overheden of huisvestingsmaatschappijen, waarvan de huizen aan een sociale prijs verhuurd of verkocht worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: verplaatst van huisvestingscomplexen naar hier + aangepast van sociale huisvesting naar sociale woningen.",
                "type": "historyNote",
            },
        ],
        "related": [28],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/391",
    },
    {
        "broader": [],
        "id": 1094,
        "labels": [{"label": "soil marks", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1090],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een soil mark is een spoor aan niet-begroeide oppervlakte waar, door verschillen in wateropname, een patroon in te zien is dat een onderliggende structuur aangeeft. Soil marks worden gebruikt om op luchtfoto's archeologische sites op te sporen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1094",
    },
    {
        "broader": [1148],
        "id": 392,
        "labels": [
            {"label": "soldatenbarakken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een soldatenbarak is een tijdelijk gebouw als huisvesting voor soldaten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verblijfplaatsen voor militairen' naar 'militaire gebouwen'. 'verblijfplaatsen voor militairen' niet meer nodig geacht.",
                "type": "historyNote",
            },
        ],
        "related": [228],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/392",
    },
    {
        "broader": [1653],
        "id": 1654,
        "labels": [
            {"label": "solitaire bomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een solitaire boom is een alleenstaande boom die als eenling en blikvanger geplant is.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "1) Van Daele 2) Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1654",
    },
    {
        "broader": [1040],
        "id": 1050,
        "labels": [
            {
                "label": "special activity sites",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1050",
    },
    {
        "broader": [321],
        "id": 393,
        "labels": [{"label": "speeltuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een speeltuin is een al dan niet omheind terrein met speeltuigen voor kinderen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/393",
    },
    {
        "broader": [467],
        "id": 1600,
        "labels": [
            {"label": "spiegelvijvers", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spiegelvijver is een kunstmatige, al dan niet geometrische waterpartij die aangelegd is met de bedoeling om een object in het water te laten weerspiegelen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1600",
    },
    {
        "broader": [328],
        "id": 821,
        "labels": [
            {"label": "spijkers", "language": "nl-BE", "type": "prefLabel"},
            {"label": "spiekers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1277, 1278],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spijker is een (bij)gebouw(tje) dat dient als opslagplaats voor voedingsmiddelen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: SN toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/821",
    },
    {
        "broader": [1942],
        "id": 1943,
        "labels": [
            {"label": "spindelschuiven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spindelschuif is een verticaal beweegbare stuw bediend door met een tand- en heugelsysteem.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1943",
    },
    {
        "broader": [20],
        "id": 394,
        "labels": [{"label": "spinnerijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spinnerij is een industrieel of ambachtelijk bedrijf waar men draden spint.",
                "type": "scopeNote",
            }
        ],
        "related": [448, 472],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/394",
    },
    {
        "broader": [],
        "id": 1105,
        "labels": [
            {"label": "spitsporen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "schopsteken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spitspoor is een verkleuring in de bodem die aangeeft dat er ooit gespit is geweest.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1105",
    },
    {
        "broader": [2067],
        "id": 2069,
        "labels": [{"label": "spoelpolders", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spoelpolder is een watering initieel aangelegd met als doel zeewater op te sparen om een havengeul periodiek te spuien en zo aanslibbing of verzanding tegen te gaan. Na verhoogde aanslibbing in de watering zelf evolueerden deze wateringen tot polders.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2069",
    },
    {
        "broader": [1751],
        "id": 1752,
        "labels": [
            {"label": "spoorrijtuigen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spoorrijtuig is een rijtuig van een spoortrein of -tram.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale Groot Woordenboek der Nederlandse Taal, 12de editie",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1752",
    },
    {
        "broader": [924],
        "id": 396,
        "labels": [
            {"label": "spoorwegbeddingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spoorwegbedding is een strook opgeworpen aarde waarop de rails van een spoorweg lopen.",
                "type": "scopeNote",
            }
        ],
        "related": [398],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/396",
    },
    {
        "broader": [924],
        "id": 398,
        "labels": [{"label": "sporen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1224, 1225],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Rails waarover voertuigen op wielen geleid worden.",
                "type": "scopeNote",
            }
        ],
        "related": [396],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/398",
    },
    {
        "broader": [321],
        "id": 896,
        "labels": [
            {
                "label": "sportgebouwen en -infrastructuur",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007250"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [277, 360, 371, 399, 400, 403, 435, 479, 535, 1511, 1512],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/896",
    },
    {
        "broader": [896],
        "id": 400,
        "labels": [
            {"label": "sportterreinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sportterrein is een terrein waar men buitensporten beoefent.",
                "type": "scopeNote",
            }
        ],
        "related": [399, 403],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/400",
    },
    {
        "broader": [896],
        "id": 399,
        "labels": [
            {"label": "sportzalen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "sporthallen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [447],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sportzaal is een gebouw ontworpen en uitgerust voor zaalsporten, lichaamsoefeningen of gymnastiek en training.",
                "type": "scopeNote",
            }
        ],
        "related": [447, 400],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/399",
    },
    {
        "broader": [923],
        "id": 401,
        "labels": [{"label": "spuikommen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spuikom is een kom van een spuisluis, waarin het binnenwater opgestuwd wordt om met meer kracht te kunnen spuien.  Spuien is met kracht water lozen om aanslibbing van vaarwater tegen te gaan.",
                "type": "scopeNote",
            }
        ],
        "related": [122, 534],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/401",
    },
    {
        "broader": [389],
        "id": 1936,
        "labels": [{"label": "spuisluizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900032084"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1862],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een spuisluis is een sluis die tot doel heeft een aansluitende vaarweg of haven op diepte te houden door het opwekken van een plotselinge krachtige waterstroming (zie spuikom en spoelpolder).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Hydrologische woordenlijst, Nederlandse hydrologische vereniging, 2002",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1936",
    },
    {
        "broader": [1019],
        "id": 904,
        "labels": [
            {"label": "staakkapellen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Specifieke vormen van kastkapellen, bevestigd op een staak. Soms als \xe9\xe9n geheel in beton gegoten, zoals de kapelletjes van de Boerenjeugdbond (BJB) tijdens en kort na Wereldoorlog II.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "31 maart 2010: BT gewijzigd van kapellen (klein erfgoed) naar kastkapellen.Scope-note toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/904",
    },
    {
        "broader": [1072],
        "id": 1079,
        "labels": [
            {"label": "stabiliseringslagen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stabiliseringslaag is een laag bedoeld om de ondergrond te stabiliseren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1079",
    },
    {
        "broader": [323],
        "id": 402,
        "labels": [{"label": "stadhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadhuis is een gebouw waarin het bestuur en doorgaans de administratie van een stad is ondergebracht en waar zich de raadszalen en het kantoor van de burgemeester bevinden.",
                "type": "scopeNote",
            }
        ],
        "related": [158, 376],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/402",
    },
    {
        "broader": [896],
        "id": 403,
        "labels": [{"label": "stadions", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadion is een groot terrein voor sportwedstrijden, met rondom gelegen tribunes en bijgebouwen.",
                "type": "scopeNote",
            }
        ],
        "related": [400, 435],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/403",
    },
    {
        "broader": [1155],
        "id": 404,
        "labels": [{"label": "stadsmuren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadsmuur is een stenen verdedigingsmuur rondom een stad.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'verdedigingsmuren'.",
                "type": "historyNote",
            },
        ],
        "related": [317, 408, 407],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/404",
    },
    {
        "broader": [1158],
        "id": 1159,
        "labels": [
            {"label": "stadsomwallingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadsomwalling is het geheel van verdedigingswerken rondom een stad, nl. grachten, wallen, muren, torens, enz..., bedoeld om de stad te beschermen tegen invallen van buitenaf. Tijdens de eerste stadsontwikkelingen bestonden deze stadsomwallingen uit aarden wallen, later werden deze wallen vervangen door stenen muren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1159",
    },
    {
        "broader": [522],
        "id": 405,
        "labels": [
            {"label": "stadspaleizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadspaleis is de imposante residentie van een gezagsdrager in een stad.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'paleizen' naar 'woonhuizen naar vormelijk type'. Overkoepelde term 'paleizen' niet meer nodig geacht.",
                "type": "historyNote",
            },
        ],
        "related": [65, 188],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/405",
    },
    {
        "broader": [334],
        "id": 406,
        "labels": [
            {"label": "stadspalen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "perroens", "language": "nl-BE", "type": "altLabel"},
            {"label": "perrons", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Palen op marktpleinen als symbool van de stedelijke vrijheid.",
                "type": "scopeNote",
            }
        ],
        "related": [282],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/406",
    },
    {
        "broader": [1558],
        "id": 1559,
        "labels": [{"label": "stadsparken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadspark is een door een stedelijke overheid onderhouden openbaar park.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1559",
    },
    {
        "broader": [1169],
        "id": 407,
        "labels": [{"label": "stadspoorten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadspoort is een versterkte bouwconstructie in een stadsmuur die toegang geeft tot de stad.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'poorten'.\n26/01/2011: SN aangepast. Oorspronkelijk: \"Versterkte doorgangen in een stadsmuur\"",
                "type": "historyNote",
            },
        ],
        "related": [404, 350],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/407",
    },
    {
        "broader": [1171],
        "id": 408,
        "labels": [{"label": "stadstorens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Torens met een defensief karakter op strategische plaatsen in stadsmuren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'verdedigingswerken' naar 'torens'.",
                "type": "historyNote",
            },
        ],
        "related": [404, 313],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/408",
    },
    {
        "broader": [522],
        "id": 409,
        "labels": [
            {"label": "stadswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stadswoning is een bescheiden woonhuis in de stad of in verstedelijkt gebied.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar vormelijk type\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [89, 126],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/409",
    },
    {
        "broader": [],
        "id": 2048,
        "labels": [{"label": "stagnosols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1853],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stagnosol is een bodem waar de infiltratie van het (regen)water verhinderd wordt door een ondiepe, slecht doorlatende laag en hierop (tijdelijk) stagneert. Deze bodem is overheersend grijs ten gevolge van een anaeroob milieu maar vertoont rood/bruin/gele \u2018spikkels\u2019 in het profiel ten gevolg van oxidatieverschijnselen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2048",
    },
    {
        "broader": [892],
        "id": 411,
        "labels": [{"label": "stallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [333, 2100],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stal is een gebouw waarin vee gehuisvest en gevoederd wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [333, 381, 892],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/411",
    },
    {
        "broader": [888],
        "id": 412,
        "labels": [{"label": "standbeelden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Vrijstaande, driedimensionale voorstellingen van personen, meestal van kop tot teen afgebeeld en op een sokkel in de openbare ruimte opgesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [95, 278, 184],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/412",
    },
    {
        "broader": [1082],
        "id": 1087,
        "labels": [
            {"label": "standgreppels", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een standgreppel is een greppel bedoeld om steun te geven aan gebouwconstructies die hierin geplaatst worden (bv. palissades, wanden van gebouwen e.d.).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1087",
    },
    {
        "broader": [1131],
        "id": 1134,
        "labels": [{"label": "stationes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een statio was oorspronkelijk een door wachters of militairen bewaakte rustplaats voor reizigers. Later kreeg het de betekenis van aflossingspost voor paarden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Adkins L. &amp; Adkins R. 1998, Handbook to life in ancient Rome, New York.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1134",
    },
    {
        "broader": [522],
        "id": 944,
        "labels": [
            {"label": "stationschefwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stationschefwoning is het woonhuis van een stationschef. Een stationschef is het hoofd van een spoorwegstation of tramstelplaats.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.\n05/03/2015: 'of tramstelplaats' toegevoegd aan SN.",
                "type": "historyNote",
            },
        ],
        "related": [958],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/944",
    },
    {
        "broader": [924],
        "id": 397,
        "labels": [
            {"label": "stationsgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stationsgebouw is een gebouw op de plaats waar treinen halt houden met onder meer wachtruimtes en lokettenzalen.",
                "type": "scopeNote",
            }
        ],
        "related": [434, 415, 485],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/397",
    },
    {
        "broader": [1033],
        "id": 1065,
        "labels": [{"label": "steden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1036],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Het onderscheid tussen dorp, gemeente en stad is betrekkelijk en varieert naar gelang de individuele, regionale context. Over het algemeen is een stad een grote, belangrijke gemeenschap met meer bewoners, status en interne complexiteit dan de meeste gemeenten in de regio.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Tys D., Buyle E., Verdurmen I. &amp; Canters F. 2010, Vectorisering en karakterisering van nederzettingskernen op basis van het zgn. 'gereduceerd kadaster', SKAR-rapport 5, VUB.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1065",
    },
    {
        "broader": [150],
        "id": 817,
        "labels": [
            {"label": "steenbakkerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een steenbakkerij is een fabriek/werkplaats waar bakstenen worden gemaakt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/817",
    },
    {
        "broader": [1302],
        "id": 177,
        "labels": [{"label": "steengroeven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een steengroeve is een open, uitgegraven plaats waar men steen wint.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: term gewijzigd van 'groeven' naar 'steengroeven'. BT gewijzigd van 'gebouwen, structuren en indicaties voor delfstofwinning' naar 'steenwinning'",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/177",
    },
    {
        "broader": [24],
        "id": 413,
        "labels": [
            {"label": "steenhouwerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een steenhouwerij is een ambachtelijk bedrijf waar steenhouwers natuursteen bewerken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/413",
    },
    {
        "broader": [14],
        "id": 1008,
        "labels": [
            {"label": "steenkoolmijnen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [291],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Term toegevoegd op 14/08/2009 als topterm van reeds bestaande term mijngebouwen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1008",
    },
    {
        "broader": [150],
        "id": 1286,
        "labels": [{"label": "steenovens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een steenoven is een oven voor het bakken van baksteen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1100],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1286",
    },
    {
        "broader": [1293],
        "id": 1302,
        "labels": [{"label": "steenwinning", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [177, 1303],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar steen gewonnen is. Steensoorten die in onze streken voorkomen zijn Wommersomkwartsiet, Doornikse kalksteen, Gobertangesteen, Balegemse kalkzandsteen, blauwe hardsteen, veldsteen, Avendersteen, schiefer, silex, kwartsiet van Tienen (glimmerzandsteen), enz...",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1302",
    },
    {
        "broader": [],
        "id": 1959,
        "labels": [{"label": "steilranden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300132356"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1859],
        "narrower": [1960, 2024, 2159, 1961],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een steilrand is een duidelijk geknikte reli\xebfvorm die zich uit als een doorgaans langgerekte (zeer) steile helling tussen twee eerder vlakke reli\xebfvormen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/09/2015: term hellingen vervangen door steilranden bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1959",
    },
    {
        "broader": [174],
        "id": 414,
        "labels": [{"label": "st\xe8les", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een st\xe8le is een grafmonument in de vorm van vrijstaande stenen platen.",
                "type": "scopeNote",
            }
        ],
        "related": [173],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/414",
    },
    {
        "broader": [13],
        "id": 415,
        "labels": [{"label": "stelplaatsen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stelplaats is een gebouw waar men bussen, trams en treinen stalt.",
                "type": "scopeNote",
            }
        ],
        "related": [397, 434],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/415",
    },
    {
        "broader": [89],
        "id": 825,
        "labels": [{"label": "stenen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een steen is een middeleeuws natuurstenen burgerhuis. Stenen waren vaak gebouwen van enig aanzien en sterkte. Ze vervulden vaak een prominente functie, zoals bijvoorbeeld de functie van gevangenis (Het Steen te Mechelen) of verblijfplaats van heren (Gravensteen te Gent).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "27/01/2011: SN toegevoegd. 03/10/2014: SN verduidelijkt o.b.v. beschermingsdossier.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden. 2) Troubleyn L. e.a. 2009, Consumption patterns and living conditions inside Het Steen, the late medieval prison of Malines (Mechelen, Belgium), in: Journal of archaeology in the Low Countries Vol. 1, nr. 2, pp. 5-47.3) Beschermingsdossier DO002325 Gent: middeleeuwse stenen",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/825",
    },
    {
        "broader": [1927],
        "id": 2142,
        "labels": [{"label": "sterrebossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een sterrebos is een jachtbos met een stervormig knooppunt van dreven van waaruit het opgedreven wild gemakkelijk gevangen of geschoten kon worden. Een sterrebos kan ook deel uitmaken van een tuin- of parkarchitecturaal concept. In voorkomend geval zijn de dreven vaak als zichtas uitgewerkt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2142",
    },
    {
        "broader": [2078],
        "id": 2084,
        "labels": [
            {
                "label": "stervormige ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stervormig ontginningspatroon bestaat uit wegen die radiaal vertrekken uit \xe9\xe9n punt, waartussen de percelen geschikt zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2084",
    },
    {
        "broader": [15],
        "id": 907,
        "labels": [
            {"label": "stijfselfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stijfselfabriek is een industrieel of ambachtelijk bedrijf waar men stijfsel produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/907",
    },
    {
        "broader": [641],
        "id": 814,
        "labels": [
            {"label": "stoeterijen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "haras", "language": "nl-BE", "type": "altLabel"},
            {"label": "paardenfokkerijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stoeterij is een plaats waar men paarden fokt. Ze worden archeologisch gekenmerkt door open weides afgebakend door een omwalling voorafgegaan door een gracht.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: SN toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/814",
    },
    {
        "broader": [78],
        "id": 1431,
        "labels": [{"label": "stoomschepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1427],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stoomschip is een vaartuig dat hoofdzakelijk wordt aangedreven door stoom (een stoommachine of stoomturbine).",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1431",
    },
    {
        "broader": [321],
        "id": 1127,
        "labels": [
            {"label": "stoven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "stoof", "language": "nl-BE", "type": "altLabel"},
            {"label": "badhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een middeleeuws badhuis of stoof is een gebouw met sauna's verwarmd door kachels en badmogelijkheden. Hier werd echter ook eten en drinken geserveerd en het had vaak een bordeelfunctie. Dergelijke stoven groeiden dan ook snel uit tot ontmoetingsplaatsen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1202, 1201],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1127",
    },
    {
        "broader": [237],
        "id": 2085,
        "labels": [
            {"label": "straatnaambordjes", "language": "nl-BE", "type": "prefLabel"},
            {"label": "straatnaamborden", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900027035"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een straatnaambordje is een bordje waarop de naam van een straat is aangebracht.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: term toegevoegd n.a.v. verwijderen term straatmeubilair.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal, 1994, Van Dale Lexicografie, Utrecht, Antwerpen.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2085",
    },
    {
        "broader": [1060],
        "id": 2106,
        "labels": [
            {"label": "straatnederzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een straatnederzetting is een rijnederzetting waarbij de bebouwing aaneengesloten (zonder tussenruimte) langs een weg ligt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Antrop M. 2007: Perspectieven op het landschap, achtergronden om landschappen te lezen en begrijpen, Academia Press, Gent.\n2) Agentschap Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2106",
    },
    {
        "broader": [1982],
        "id": 1983,
        "labels": [
            {"label": "strandvlakten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een strandvlakte is een deels onder getijdeninvloed staande zandige vlakte gelegen tussen de zee en de (vroegere) duinen (i.e. litorale reli\xebfvorm).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1983",
    },
    {
        "broader": [1212],
        "id": 1218,
        "labels": [{"label": "straten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een straat is een weg in een stads- of dorpsbebouwing die met stenen, kiezels of asfalt verhard is. Buiten de bebouwde kom spreekt men van een straatweg. De Romeinen kenden reeds bestrating, maar het werd pas vanaf het einde van de 12de eeuw een onderdeel van stadsaanleg.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1218",
    },
    {
        "broader": [2078],
        "id": 2082,
        "labels": [
            {
                "label": "strookvormige ontginningspatronen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2083],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een strookvormig ontginningspatroon bestaat uit vierhoekige percelen die duidelijk langer zijn dan breed.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2082",
    },
    {
        "broader": [21],
        "id": 416,
        "labels": [
            {"label": "stroopfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stroopfabriek is een industrieel bedrijf waar men fruit verwerkt tot stroop.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/416",
    },
    {
        "broader": [307],
        "id": 1318,
        "labels": [
            {
                "label": "structuren voor houtskoolproductie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1319],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1318",
    },
    {
        "broader": [24],
        "id": 1324,
        "labels": [
            {
                "label": "structuren voor zoutproductie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1325],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar zout gewonnen is door het uitvoeren van bepaalde processen.",
                "type": "scopeNote",
            }
        ],
        "related": [1305],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1324",
    },
    {
        "broader": [932],
        "id": 1645,
        "labels": [
            {"label": "struiken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "heesters", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1646, 1668],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een struik is een houtachtige plant die van nature geen stam vormt en doorgaans dicht bij de grond vertakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [1647],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1645",
    },
    {
        "id": 1647,
        "labels": [
            {
                "label": "struiken naar beheersvorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1649],
        "notes": [],
        "sources": [],
        "superordinates": [1645],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1647",
    },
    {
        "broader": [1645],
        "id": 1668,
        "labels": [
            {"label": "struikenrijen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "heesterrijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een struikenrij omvat al dan niet kunstmatig gevormde struiken die met het oog op het bekomen van een architecturaal of esthetisch doel op rij(en) zijn gezet.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1668",
    },
    {
        "broader": [1918],
        "id": 1920,
        "labels": [
            {"label": "struwelige ruigten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een struwelige ruigte is een ruigte waarvan de spontane vegetatiegroei gedomineerd wordt door vaak doornige struiken en/of jonge bomen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1920",
    },
    {
        "broader": [284],
        "id": 417,
        "labels": [
            {"label": "studentenhuisvesting", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006640"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Studentenhuisvesting omvat huisvesting voor studenten, meestal in opdracht van en beheerd door instellingen van het hoger onderwijs.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term verplaatst van huisvestingscomplexen naar hier.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "De doorsnee 'studentenkoten' worden hieronder niet opgenomen.",
                "type": "note",
            },
        ],
        "related": [643, 455, 191],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/417",
    },
    {
        "broader": [2007],
        "id": 2019,
        "labels": [
            {"label": "stuifduinen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "actieve duinen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stuifduin is een duin(complex) met een ontbrekende begroeiing (veelal onder invloed van de mens) waardoor het zand momenteel herverstuift. Daar de duinvormende processen nog plaatsvinden worden deze duinen gekenmerkt door een onregelmatig en veranderlijk reli\xebf.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2019",
    },
    {
        "broader": [923],
        "id": 1941,
        "labels": [{"label": "stuwen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900019825"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1942],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een stuw is een waterbouwkundige constructie om de waterstand of het verval van kunstmatige waterlopen/waterwegen te reguleren of te controleren, zowel ter voorkoming of beperking van wateroverlast elders als bij watersnood. Stuwen komen vooral voor op niet-bevaarbare waterlopen en kunnen ervoor zorgen dat de waterstand voor of achter de stuw zoveel als mogelijk op een gewenst peil wordt gebracht. Bij een overschot aan water kan het afsluitsysteem/mechanisme geheel of gedeeltelijk worden afgesteld.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1941",
    },
    {
        "broader": [21],
        "id": 419,
        "labels": [
            {"label": "suikerraffinaderijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een suikerraffinaderij is een industrieel bedrijf waar men suiker zuivert en bewerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [35],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/419",
    },
    {
        "broader": [359],
        "id": 420,
        "labels": [{"label": "synagogen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een synagoge is een gebedshuis voor joden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/420",
    },
    {
        "broader": [1905],
        "id": 1908,
        "labels": [{"label": "tabaksakkers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tabaksakker is een akkerland beplant met tabak.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1908",
    },
    {
        "broader": [21],
        "id": 421,
        "labels": [
            {"label": "tabaksfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tabaksfabriek is een industrieel of ambachtelijk bedrijf waar men tabak bereidt voor gebruik.",
                "type": "scopeNote",
            }
        ],
        "related": [422, 1764],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/421",
    },
    {
        "broader": [151],
        "id": 422,
        "labels": [
            {"label": "tabaksstellingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tabaksstelling is een houten stelling waaraan tabaksranken worden opgehangen om te drogen.",
                "type": "scopeNote",
            }
        ],
        "related": [35, 421],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/422",
    },
    {
        "broader": [881],
        "id": 423,
        "labels": [{"label": "tearooms", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tearoom is een publieke gelegenheid waar men in de eerste plaats warme dranken en gebak serveert.",
                "type": "scopeNote",
            }
        ],
        "related": [247, 91, 430],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/423",
    },
    {
        "broader": [],
        "id": 2045,
        "labels": [{"label": "technosols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1852],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een technosol is een bodem die gevormd werd door zware technische ingrepen (bebouwde gebieden, vergraven en industri\xeble terreinen, vervuilde gronden, storten, mijnterrils).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2045",
    },
    {
        "broader": [149],
        "id": 812,
        "labels": [
            {"label": "tegelbakkerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tegelbakkerij is een complex/werkplaats waar tegels worden gemaakt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Term aangepast van 'tegelfabrieken' naar 'tegelbakkerijen'.\n26/01/2011: SN toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/812",
    },
    {
        "broader": [],
        "id": 1981,
        "labels": [
            {"label": "tektonische processen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1858],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tektonisch proces is het proces waarbij geomorfologische elementen gevormd worden door horizontale en verticale verschuivingen in de aardkorst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1981",
    },
    {
        "broader": [13],
        "id": 424,
        "labels": [
            {"label": "telefooncentrales", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een telefooncentrale is een gebouw waar de draden van een telefoonnet samenkomen en de gewenste verbindingen tot stand worden gebracht.",
                "type": "scopeNote",
            }
        ],
        "related": [646],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/424",
    },
    {
        "broader": [323],
        "id": 646,
        "labels": [
            {"label": "telegraafkantoren", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een telegraafkantoor is een gebouw waar men telegrafische berichten verzendt en ontvangt.",
                "type": "scopeNote",
            }
        ],
        "related": [424, 353],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/646",
    },
    {
        "broader": [1116],
        "id": 1119,
        "labels": [{"label": "tempels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1120],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tempel is een religieus gebouw dat is gewijd aan het dienen van een godheid of godheden, vaak met een cultusafbeelding; wordt niet gebruikt voor christelijke en islamitische religieuze gebouwen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1119",
    },
    {
        "broader": [1541],
        "id": 425,
        "labels": [{"label": "tempels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1542, 1545, 1547],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Tuinpaviljoenen in de vorm van tempels.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/425",
    },
    {
        "broader": [321],
        "id": 426,
        "labels": [
            {
                "label": "tentoonstellingspaviljoenen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tentoonstellingspaviljoen is een gebouw dat onderdeel en onderwerp uitmaakt van een grote tentoonstelling, zoals een wereldtentoonstelling.",
                "type": "scopeNote",
            }
        ],
        "related": [301],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/426",
    },
    {
        "broader": [1069],
        "id": 1070,
        "labels": [
            {"label": "terpen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "wierde", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een terp is een verzameling gelijktijdige huisplaatsen of erven (&gt;1) op een kunstmatige ophoging (om te beschermen tegen wateroverlast), die samen omgeven kunnen zijn door een greppel(systeem), palissade etc. Het verspreidingsgebied beslaat het westelijk en noordelijk kustgebied. Wanneer we te maken hebben met een individuele huisplaats, dan spreekt men van een huisterp.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "De Wit G. &amp; Sloos A. 2008, De interpretatie van archeologische waarnemingen in Archis. Een concept voor een nieuwe set complextypen, in: Rapportage Archeologische Monumentenzorg 165, Amersfoort.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1070",
    },
    {
        "broader": [],
        "id": 2074,
        "labels": [{"label": "terrassen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1850],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een terras is een (vaak aaneengeschakelde) landinrichtingsvorm waarbij een deel van een heuvel is afgevlakt, zodat de cultuurgronden in min of meer vlakke treden wordt aangelegd om de bewerking te vereenvoudigen en erosie tegen te gaan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2074",
    },
    {
        "broader": [440],
        "id": 1595,
        "labels": [{"label": "terrastuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een terrastuin is een siertuin die in terrassen van verschillende niveaus is aangelegd, meestal in de periode van het modernisme.",
                "type": "scopeNote",
            }
        ],
        "related": [1596, 1549],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1595",
    },
    {
        "broader": [522],
        "id": 427,
        "labels": [
            {"label": "teutenwoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een teutenwoning is het woonhuis van een teut. Teuten zijn rondreizende handelaars en ambachtslieden uit de Limburgse Kempen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/427",
    },
    {
        "broader": [20],
        "id": 428,
        "labels": [
            {"label": "textieldrukkerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een textieldrukkerij is een industrieel of ambachtelijk bedrijf waar men weefsels met gekleurde patronen bedrukt.",
                "type": "scopeNote",
            }
        ],
        "related": [465],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/428",
    },
    {
        "broader": [20],
        "id": 465,
        "labels": [
            {"label": "textielververijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een textielververij is een industrieel of ambachtelijk bedrijf waar men vezels, garen en weefsels verft.",
                "type": "scopeNote",
            }
        ],
        "related": [464, 428],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/465",
    },
    {
        "broader": [321],
        "id": 429,
        "labels": [
            {"label": "theaters", "language": "nl-BE", "type": "prefLabel"},
            {"label": "schouwburgen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een theater is een gebouw dat is ontworpen voor toneelvoorstellingen.",
                "type": "scopeNote",
            }
        ],
        "related": [104, 326],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/429",
    },
    {
        "broader": [444],
        "id": 430,
        "labels": [{"label": "theekoepels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1540],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een theekoepel is een element in tuinen en parken waar men thee of andere warme dranken nuttigt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "16/10/2012: met de uitbreiding van de thesaurus met de termen voor Tuinen en Parken werd deze term aangepast van 'theehuizen' naar 'theekoepels'.",
                "type": "historyNote",
            },
        ],
        "related": [247, 423],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/430",
    },
    {
        "broader": [1201],
        "id": 1202,
        "labels": [{"label": "thermen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Thermen zijn monumentale Romeinse badhuizen. De ruimtes die in een thermencomplex kunnen voorkomen zijn apoditerium (kleedkamer), frigidarium (koud bad), tepidarium (lauw bad), caldarium (warm bad), sudarium (zweetruimte).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'badhuizen' voor Romeinse badhuizen van normale grootte.\nGebruik 'stoven' voor middeleeuwse badhuizen met ruimere functie van ontmoetingsplaats.",
                "type": "note",
            },
        ],
        "related": [1127],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1202",
    },
    {
        "broader": [425],
        "id": 1545,
        "labels": [{"label": "tholoi", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1546],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tholos is een gesloten, rond gebouw met een koepel als dak, met of zonder zuilengalerij in tuinen en parken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1545",
    },
    {
        "broader": [237],
        "id": 1016,
        "labels": [
            {"label": "toegangsbruggen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Bruggen die toegang verlenen tot een gebouw of een domein, voornamelijk bedoeld voor priv\xe9-gebruik.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "term toegevoegd 21/01/2010.",
                "type": "historyNote",
            },
        ],
        "related": [86, 439],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1016",
    },
    {
        "broader": [1200],
        "id": 1207,
        "labels": [
            {"label": "toiletten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "wc's", "language": "nl-BE", "type": "altLabel"},
            {"label": "privaten", "language": "nl-BE", "type": "altLabel"},
            {"label": "secreten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [156, 324, 1208],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een toilet of wc (watercloset) is een onderdeel van het sanitair bedoeld voor de opvang (en eventueel het wegspoelen) van urine en ontlasting.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'openbare toiletten' voor sanitaire voorzieningen in openbare ruimte.",
                "type": "note",
            },
        ],
        "related": [156, 324],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) Lamarcq D. 1993, Het latrinair gebeuren. De geschiedenis van het W.C., Gent.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1207",
    },
    {
        "broader": [323],
        "id": 940,
        "labels": [
            {"label": "tolkantoren", "language": "nl-BE", "type": "prefLabel"},
            {"label": "octrooibureaus", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tolkantoor is een kantoor, waar tol moet worden betaald. Tol is de heffing voor het gebruik van een weg of brug, of voor het (mogen) passeren van een tol.",
                "type": "scopeNote",
            }
        ],
        "related": [127],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/940",
    },
    {
        "broader": [1608],
        "id": 1709,
        "labels": [
            {"label": "topiary", "language": "nl-BE", "type": "prefLabel"},
            {"label": "figuursnoeiwerk", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300061887"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een topiary is een kunstmatig gevormde boom of struik  die geleid en gesnoeid is in diverse geometrische, fantasie- of diervormen. De vorm wordt bepaald bij het jonge plantgoed en tijdens de eerste vormsnoei van de gesteltakken. Het beheer wordt uitgevoerd in periodieke scheerbeurten, \xe9\xe9n of meerdere keren per jaar.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: BT aangepast van 'houtige beplantingen' + SN aangepast.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1709",
    },
    {
        "broader": [27],
        "id": 2178,
        "labels": [
            {"label": "torenflatgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300164243"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een torenflatgebouw is een hoogbouw (minimum vijf bouwlagen) met appartementen rond een centrale kern, in tegenstelling tot flatgebouwen die eerder horizontaal zijn (\u2018slab blocks').",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [521],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2178",
    },
    {
        "broader": [1149],
        "id": 1171,
        "labels": [{"label": "torens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [408, 1172, 1173, 1174, 1745, 124],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een toren is een losstaand/afzonderlijk gebouw of een deel van een gebouw of andere structuur dat hoog is in verhouding tot zijn breedte. Ze worden voornamelijk teruggevonden in de context van verdedigingswerken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1171",
    },
    {
        "broader": [893],
        "id": 1519,
        "labels": [
            {"label": "tourniquets", "language": "nl-BE", "type": "prefLabel"},
            {"label": "draaikruisen", "language": "nl-BE", "type": "altLabel"},
            {"label": "stichels", "language": "nl-BE", "type": "altLabel"},
            {"label": "draaikhekken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tourniquet is een draaihek aan de ingang van een gebouw of afgesloten terrein, ter controle op wie binnentreedt of een draaihek om personen ongehinderd toegang te verschaffen tot een weiland zonder dat het vee via die weg kan ontsnappen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "1) Van Dale online 2) AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1519",
    },
    {
        "broader": [20],
        "id": 432,
        "labels": [
            {"label": "touwslagerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een touwslagerij is een industrieel of ambachtelijk bedrijf waar men touw maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [448],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/432",
    },
    {
        "broader": [924],
        "id": 433,
        "labels": [
            {"label": "tractiestations", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tractiestation is een gebouw waar de elektriciteit voor de aandrijving van het spoorweg- of tramverkeer wordt opgewekt.",
                "type": "scopeNote",
            }
        ],
        "related": [16],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/433",
    },
    {
        "broader": [485],
        "id": 842,
        "labels": [{"label": "tramhokjes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/842",
    },
    {
        "broader": [398],
        "id": 1224,
        "labels": [{"label": "tramsporen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Tramsporen zijn rails waarover trams geleid worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1224",
    },
    {
        "broader": [924],
        "id": 434,
        "labels": [{"label": "tramstations", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tramstation is een gebouw op de plaats waar trams halt houden met onder meer wachtruimtes en lokettenzalen.",
                "type": "scopeNote",
            }
        ],
        "related": [397, 415, 485],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/434",
    },
    {
        "broader": [147],
        "id": 1773,
        "labels": [
            {"label": "transepten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "dwarsbeuken", "language": "nl-BE", "type": "altLabel"},
            {"label": "dwarsschepen", "language": "nl-BE", "type": "altLabel"},
            {"label": "kruisbeuken", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004645"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1767],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een transept is een dwarsbeuk van een kerk, tot dezelfde hoogte opgetrokken als het schip, gewoonlijk in open verbinding ermee. Het bestaat uit drie delen, nl. de kruising of viering (het gedeelte dat het met het schip gemeen heeft) en de kruisarmen aan weerszijden.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1773",
    },
    {
        "broader": [398],
        "id": 1225,
        "labels": [{"label": "treinsporen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Treinsporen zijn rails waarover treinen geleid worden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1225",
    },
    {
        "broader": [1948],
        "id": 1951,
        "labels": [
            {"label": "trekgrachten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "treksloten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een trekgracht is een ontwateringsgracht leidend naar een poldermolen of pompgemaal.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1951",
    },
    {
        "broader": [896],
        "id": 435,
        "labels": [{"label": "tribunes", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tribune wordt gevormd door oplopende rijen (zit)plaatsen voor toeschouwers, al dan niet overdekt.",
                "type": "scopeNote",
            }
        ],
        "related": [403],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/435",
    },
    {
        "broader": [443],
        "id": 1538,
        "labels": [{"label": "triomfbogen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een triomfboog is een van oorsprong Romeinse, vrijstaande stenen poort of boog, opgericht ter ere van een overwinnaar of ter herinnering aan een overwinning, soms met een beeldengroep. Thans gebruikt als tuinelement.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.\n2) agentschap Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1538",
    },
    {
        "broader": [1308],
        "id": 438,
        "labels": [
            {"label": "tuinbouwbedrijven", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kwekerijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [767],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tuinbouwbedrijf is een bedrijf dat aan groenten-, fruit- of sierteelt doet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: BT gewijzigd van 'gebouwen voor land- en tuinbouw' naar 'agrarische complexen'.",
                "type": "historyNote",
            },
        ],
        "related": [641],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/438",
    },
    {
        "broader": [443],
        "id": 439,
        "labels": [{"label": "tuinbruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1539],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Sierbruggen in tuinen en parken.",
                "type": "scopeNote",
            }
        ],
        "related": [440, 86, 1016, 930],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/439",
    },
    {
        "broader": [930],
        "id": 1603,
        "labels": [{"label": "tuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [440, 1561, 1564, 1565, 1903, 1904, 1973],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1603",
    },
    {
        "broader": [],
        "id": 930,
        "labels": [
            {"label": "tuinen en parken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [337, 1603],
        "notes": [],
        "related": [443, 77, 195, 439, 444],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/930",
    },
    {
        "broader": [932],
        "id": 1641,
        "labels": [
            {
                "label": "tuin- en parkbeplantingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1756],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Tuin- en parkbeplanting is beplanting die omwille van zijn sierwaarde aangewend wordt voor de aanleg van tuinen en parken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1641",
    },
    {
        "broader": [237],
        "id": 443,
        "labels": [
            {
                "label": "tuin- en parkelementen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [
            165,
            312,
            342,
            439,
            441,
            444,
            1535,
            1538,
            1549,
            1550,
            1551,
            1552,
            1555,
            1557,
        ],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "16/10/2012: tuinornamentiek aangepast naar tuin- en parkelementen in kader van uitbreiding thesaurus met termen voor Tuinen en Parken. SN verwijderd (wordt uitgebreid); zou nog gidsterm moeten worden, als koppelingen verwijderd zijn.",
                "type": "historyNote",
            }
        ],
        "related": [888, 440, 337, 930],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/443",
    },
    {
        "broader": [443],
        "id": 444,
        "labels": [
            {"label": "tuinpaviljoenen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1541],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kleine bouwwerken in tuinen of parken met een sterk decoratieve functie.",
                "type": "scopeNote",
            }
        ],
        "related": [440, 206, 930],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [1540],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/444",
    },
    {
        "id": 1540,
        "labels": [
            {
                "label": "tuinpaviljoenen naar gebruik",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [58, 430],
        "notes": [],
        "sources": [],
        "superordinates": [444],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1540",
    },
    {
        "broader": [444],
        "id": 1541,
        "labels": [
            {
                "label": "tuinpaviljoenen naar vorm",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [345, 367, 425, 1548],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1541",
    },
    {
        "broader": [443],
        "id": 1549,
        "labels": [
            {"label": "tuinterrassen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tuinterras is een terras dat bij of in een tuin is aangelegd.",
                "type": "scopeNote",
            }
        ],
        "related": [1595],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1549",
    },
    {
        "broader": [443],
        "id": 1550,
        "labels": [{"label": "tuintrappen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tuintrap is een trap die naar (een deel van) de tuin leidt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1550",
    },
    {
        "broader": [443],
        "id": 1551,
        "labels": [{"label": "tuinvazen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tuinvaas is een vaas, meestal hoger dan breed en met een vernauwde hals, zonder oren, tot versiering van tuinen dienend.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1551",
    },
    {
        "broader": [196],
        "id": 445,
        "labels": [{"label": "tuinwijken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tuinwijk is een woonwijk die als een geheel opgevat werd, met veel aandacht voor openbare ruimtes en groenaanleg, veelal met vrijstaande of gekoppelde eengezinswoningen (cit\xe9 pavillionaire) en/of aaneengesloten bebouwing rond een gemeenschappelijk plein (close).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/07/2016: SN aangepast bij integratie termen sociale huisvesting",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "De term 'tuinwijk' wordt ook toegekend aan naoorlogse volkswijken met groenaanleg.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/445",
    },
    {
        "broader": [170],
        "id": 858,
        "labels": [{"label": "tumuli", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1262],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "De term tumulus wordt specifiek gebruikt voor grafheuvels uit de Romeinse periode.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Was aangegeven als NPT van grafheuvels. Aangepast bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/858",
    },
    {
        "broader": [13],
        "id": 446,
        "labels": [{"label": "tunnels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een tunnel is een kunstmatige onderaardse doorgang in de vorm van een koker.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/446",
    },
    {
        "broader": [213],
        "id": 1946,
        "labels": [{"label": "turfvaarten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een turfvaart is een kanaal in een turfwinningsgebied, dienstig als transportweg voor de afvoer van turf en ter ontwatering van het veen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Baas H., Mobach B. &amp; Renes H., 2005: Leestekens van het landschap, 188 landschapselementen in kort bestek. Landschapsbeheer Nederland, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1946",
    },
    {
        "broader": [399],
        "id": 447,
        "labels": [{"label": "turnzalen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen ontworpen om in te turnen.",
                "type": "scopeNote",
            }
        ],
        "related": [399],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/447",
    },
    {
        "broader": [20],
        "id": 448,
        "labels": [{"label": "twijnderijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een twijnderij is een industrieel of ambachtelijk bedrijf waar men twijnt. Twijnen is twee of meer gesponnen draden ineendraaien voor verdere verwerking tot textiel of touw.",
                "type": "scopeNote",
            }
        ],
        "related": [394, 432],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/448",
    },
    {
        "broader": [],
        "id": 2066,
        "labels": [{"label": "uiterwaarden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1850],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een uiterwaard is een landinrichtingsvorm tussen het zomerbed van een rivier en de winterdijk gelegen gebied, overstroombaar bij (extreem) hoog water.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2066",
    },
    {
        "broader": [943],
        "id": 449,
        "labels": [{"label": "uitgeverijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een uitgeverij is een bedrijf dat boeken, kranten, tijdschriften en andere grafische producten (laat) drukt(/drukken) en in de handel brengt.",
                "type": "scopeNote",
            }
        ],
        "related": [130],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/449",
    },
    {
        "broader": [1393],
        "id": 1405,
        "labels": [
            {
                "label": "uitrusting voor dieren",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Uitrusting voor dieren omvat objecten waaronder paardenuitrusting voor dagelijks gebruik, maar ook voor militaire doeleinden (zoals hoefijzers, teugels, zadels, stijgbeugels, bepantsering, hoofdstel), uitrusting voor jachtdieren (zoals kapjes voor jachtvalken), enz...",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) VIOE 2) National Monuments Record thesaurus (English Heritage), <a href="http://thesaurus.english-heritage.org.uk/frequentuser.htm">http://thesaurus.english-heritage.org.uk/frequentuser.htm</a> (MDA archaeological objects thesaurus)',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1405",
    },
    {
        "broader": [389],
        "id": 1937,
        "labels": [
            {"label": "uitwateringssluizen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/900031054"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1861],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een uitwateringssluis is een sluis die gebruik maakt van verschillen in de waterstand tussen waterlopen om overtollig water uit een gebied af te voeren (drainage).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1937",
    },
    {
        "broader": [],
        "id": 2055,
        "labels": [{"label": "umbrisols", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1855],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een umbrisol is een bodem met een beginnende profielontwikkeling, wat zich uit in het ontwikkelen van bodemstructuur en/of duidelijke verkleuring en die gekenmerkt is door een zure organisch rijke toplaag.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2055",
    },
    {
        "broader": [643],
        "id": 453,
        "labels": [
            {"label": "universiteitsaula's", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Universiteitsgebouwen voornamelijk bestaande uit een grote gehoorzaal.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/453",
    },
    {
        "broader": [643],
        "id": 455,
        "labels": [
            {"label": "universiteitscolleges", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Verblijven bij universiteiten waar studenten samenwonen onder toezicht van professoren.",
                "type": "scopeNote",
            }
        ],
        "related": [417],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/455",
    },
    {
        "broader": [319],
        "id": 643,
        "labels": [
            {"label": "universiteitsgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [455, 453],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen die tot een universiteit behoren.",
                "type": "scopeNote",
            }
        ],
        "related": [191, 417],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/643",
    },
    {
        "broader": [1233],
        "id": 1243,
        "labels": [{"label": "urnengraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een urnengraf is een graf waarvan de geselecteerde crematieresten (al dan niet met houtskool) van de overledene in een recipi\xebnt in aardewerk, glas of metaal zijn gedeponeerd en in een grafkuil geplaatst, eventueel met enkele bijgiften.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1243",
    },
    {
        "broader": [54],
        "id": 1260,
        "labels": [{"label": "urnenvelden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een urnenveld is een begraafplaats die kan toegewezen worden aan de urnenveldencultuur (late bronstijd) en die gekenmerkt wordt door de begraving van crematieresten in urnen, hetzij onder een grafheuveltje, hetzij in een eenvoudige kuil, met eventuele grafgiften.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1260",
    },
    {
        "broader": [1228],
        "id": 1229,
        "labels": [{"label": "ustrinae", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ustrina is een - meestal herbruikbare - centrale brandstapel waarop de verbranding van doden plaatsvond. De meeste doden werden op gemeenschappelijke brandstapels gecremeerd. Ze onderscheiden zich van de busta door hun afmetingen. In onze streken had het ustrina veeleer een tijdelijk karakter; na verscheidene keren gebruikt te zijn geweest, werd de plek verlaten ten voordele van een nieuwe locatie. Sporen van ustrinae komen niet vaak voor in Vlaanderen omdat deze constructies zich doorgaans aan het oppervlak bevonden en hun restanten door de latere landbewerking meestal helemaal verdwenen zijn. Enkel wanneer eerst een ondiepe kuil werd gegraven treft men er sporen van aan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1235],
        "sources": [
            {
                "citation": 'Onderzoeksbalans <a href="http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving">http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/romeinse_tijd/bronnen/archeologisch/begraving</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1229",
    },
    {
        "broader": [237],
        "id": 1531,
        "labels": [{"label": "uurwerken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [67, 481, 531],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een uurwerk is een instrument voor het meten en vastleggen van het verstrijken van de tijd.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1531",
    },
    {
        "broader": [],
        "id": 78,
        "labels": [
            {"label": "vaartuigen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "boten", "language": "nl-BE", "type": "altLabel"},
            {"label": "schepen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Schepen en boten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "19/04/2011: BT gewijzigd van 'varend erfgoed' naar 'onroerend erfgoed'",
                "type": "historyNote",
            },
        ],
        "related": [74],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [1427, 1428, 1429],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/78",
    },
    {
        "id": 1429,
        "labels": [
            {
                "label": "vaartuigen naar functie",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [
            1442,
            1443,
            1444,
            1445,
            1447,
            1450,
            1452,
            1456,
            1459,
            1460,
            1461,
            1462,
            1463,
            1464,
            1458,
        ],
        "notes": [],
        "sources": [],
        "superordinates": [78],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1429",
    },
    {
        "id": 1428,
        "labels": [
            {
                "label": "vaartuigen naar vaargebied",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1435, 1436, 1437, 1441],
        "notes": [],
        "sources": [],
        "superordinates": [78],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1428",
    },
    {
        "id": 1427,
        "labels": [
            {
                "label": "vaartuigen naar voortstuwing",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [1430, 1431, 1432, 1433, 1434],
        "notes": [],
        "sources": [],
        "superordinates": [78],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1427",
    },
    {
        "broader": [78],
        "id": 1434,
        "labels": [
            {
                "label": "vaartuigen zonder eigen aandrijving",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1427],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vaartuig zonder eigen aandrijving is een vaartuig zonder eigen voortstuwingsmiddelen dat wordt voortbewogen met roeiriemen of peddels, door te bomen, jagen, slepen of duwen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1434",
    },
    {
        "broader": [1408],
        "id": 1409,
        "labels": [
            {"label": "vaartuigonderdelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1409",
    },
    {
        "broader": [1393],
        "id": 1406,
        "labels": [{"label": "vaatwerk", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Vaatwerk omvat houders voor het bevatten van een vloeistof of een andere substantie, meestal rond van doorsnede en gemaakt van duurzaam materiaal; met name houders van dit type voor huishoudelijk gebruik, worden gebruikt voor het opslaan, bereiden of opdienen van voedsel of drank, en zijn meestal van draagbaar formaat.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1406",
    },
    {
        "broader": [321],
        "id": 456,
        "labels": [
            {"label": "vakantietehuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "kindertehuizen", "language": "nl-BE", "type": "altLabel"},
            {"label": "vakantiekolonies", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vakantietehuis is een gebouw op een plaats met een gezonde buitenlucht, waar voornamelijk kinderen met een zwakke gezondheid hun vakantie doorbrengen.",
                "type": "scopeNote",
            }
        ],
        "related": [457, 1426],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/456",
    },
    {
        "broader": [522],
        "id": 457,
        "labels": [
            {"label": "vakantiewoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vakantiewoning is een woonhuis ontworpen om er de vakantie door te brengen, vaak in de natuur gelegen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar vormelijk type\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [456],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/457",
    },
    {
        "broader": [1997],
        "id": 2000,
        "labels": [{"label": "valleien", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2001],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vallei is een dal dat afhelt in \xe9\xe9n richting en vrijwel altijd watervoerend is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1977, 1980],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2000",
    },
    {
        "broader": [1959],
        "id": 1960,
        "labels": [{"label": "valleiranden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een valleirand is een steilrand langs een dal of een vlakte, gevormd door een vroegere insnijding van een natuurlijke waterloop.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen\n29/09/2015: steilrand vervangen door valleirand bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1960",
    },
    {
        "broader": [1561],
        "id": 1563,
        "labels": [{"label": "varentuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een varentuin is een collectie- en siertuin waarvan de kruidlaag hoofdzakelijk uit varens is samengesteld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1563",
    },
    {
        "broader": [1185],
        "id": 1186,
        "labels": [
            {"label": "Vaubanvestingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "De Vaubanvesting is een type versterking opgericht in de periode tussen 1667 en 1707 en werd genoemd naar S\xe9bastien Le Prestre de Vauban, een maarschalk onder Lodewijk XIV. Ze werden opgericht langsheen de westelijke, noordelijke en oostelijke Franse grens als verdedigingslinie. Deze vestingsteden worden gekenmerkt door uitgebreide verdedigingswerken met het gebruik van bastions, lunetten, gracht -en walsystemen en vertonen een stervorm. Vauban introduceerde het principe om de verdediging van een regio in verschillende linies uit te bouwen om zo de aanvaller tot een verspreide slagorde te dwingen. Hij werkte in totaal aan de bouw van 160 vestingen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) De Roux A. 1997, Villes Neuves. Urbanisme classique, Paris. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1186",
    },
    {
        "broader": [179],
        "id": 1683,
        "labels": [
            {"label": "veekeringshagen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "weerhagen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1681],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veekeringshaag is een geschoren haag om vee tegen te houden, als heining van een weide, huisweide, weideboomgaard, met al dan niet gelegd vlechtwerk.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1683",
    },
    {
        "broader": [151],
        "id": 1314,
        "labels": [
            {"label": "veekralen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "schaapskooien", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veekraal is een gebouw of omheining, al dan niet overdekt, in de vorm van bijvoorbeeld een palenrij met vlechtwerk of greppel, waarbinnen vee gehouden wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "De Wit G. &amp; Sloos A. 2008, De interpretatie van archeologische waarnemingen in Archis. Een concept voor een nieuwe set complextypen, in: Rapportage Archeologische Monumentenzorg 165, Amersfoort.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1314",
    },
    {
        "broader": [],
        "id": 2134,
        "labels": [
            {"label": "veenafzettingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2133],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veenafzetting is een afzetting in natte gebieden die ontstaat door ophoping van onvolledig afgebroken plantenresten (met of zonder bijmenging van zand, silt of klei) gevormd onder permanent natte en zuurstofarme omstandigheden. Afhankelijk van de samenstelling wordt onder meer bosveen, mosveen, rietveen, wollegrasveen en zeggeveen onderscheiden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2134",
    },
    {
        "broader": [2040],
        "id": 2041,
        "labels": [{"label": "veenbodems", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veenbodem is een organische bodem waarbij het organisch materiaal bestaat uit veen. Veen bestaat uit onvolledig afgebroken plantenresten (met of zonder bijmenging van zand, silt of klei), gevormd onder permanent natte omstandigheden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Dondeyne, Deckers &amp; Van Ranst, Bodemkaart van Belgi\xeb volgens World Reference Base for Soil resources. In opmaak.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2041",
    },
    {
        "broader": [1212],
        "id": 1219,
        "labels": [
            {"label": "veenwegen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "veenbruggen", "language": "nl-BE", "type": "altLabel"},
            {"label": "knuppelwegen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veenweg is een (vaak prehistorische) weg door een veenmoeras dat bestaat uit dwars geplaatste boomstammetjes, planken, vlechtwerk of een combinatie van deze elementen. De functie van deze wegen was waarschijnlijk om hoger gelegen, droge plaatsen in het veen(moeras) met elkaar te verbinden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Louwe Kooijmans L., van den Broecke P.W., Fokkens H. en van Gijn A. (eds.), 2005, Nederland in de prehistorie, Amsterdam. 2) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1219",
    },
    {
        "broader": [1293],
        "id": 1304,
        "labels": [{"label": "veenwinning", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1305],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar veen gewonnen is (bv. om als brandstof te gebruiken: turf).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1304",
    },
    {
        "broader": [522],
        "id": 458,
        "labels": [{"label": "veerhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veerhuis is het woonhuis van een veerman, in de nabijheid van een overzetveer. Vaak is er een herberg aan verbonden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/458",
    },
    {
        "broader": [78],
        "id": 1452,
        "labels": [
            {"label": "veerponten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "ponten", "language": "nl-BE", "type": "altLabel"},
            {"label": "overzetboten", "language": "nl-BE", "type": "altLabel"},
            {"label": "overzetschuiten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veerpont is een platte vierkante schuit of een groter vaartuig om personen en voertuigen mee over te zetten.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1452",
    },
    {
        "broader": [274],
        "id": 833,
        "labels": [
            {"label": "veevoederfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/833",
    },
    {
        "broader": [885],
        "id": 459,
        "labels": [
            {"label": "veilinggebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veilinggebouw is een gebouw waar goederen bij opbod (en afslag) openbaar verkocht worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/459",
    },
    {
        "broader": [1245],
        "id": 1247,
        "labels": [{"label": "veldgraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veldgraf is een ge\xefsoleerd graf, vaak voor een ter plaatse gesneuvelde soldaat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1247",
    },
    {
        "broader": [150],
        "id": 1283,
        "labels": [{"label": "veldovens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veldoven is een open oven, bedoeld voor het maken van bakstenen, alleen gevormd door zijmuren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [1100],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1283",
    },
    {
        "broader": [522],
        "id": 460,
        "labels": [
            {"label": "veldwachterswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veldwachterswoningis het woonhuis van een veldwachter. Veldwachters zijn politieagenten op het platteland.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [348, 363, 484],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/460",
    },
    {
        "broader": [1910],
        "id": 2158,
        "labels": [
            {"label": "venige graslanden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2154],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Venige graslanden zijn doorgaans natte graslanden met een specifieke soortensamenstelling be\xefnvloed door een venig substraat. Er komen zowel voedselarme als voedselrijke varianten voor.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/09/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2158",
    },
    {
        "broader": [1968],
        "id": 1970,
        "labels": [{"label": "vennen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ven is een van oorsprong voedselarm en meestal zuur, ondiep natuurlijk watervlak van beperkte omvang.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1970",
    },
    {
        "broader": [63],
        "id": 461,
        "labels": [{"label": "veranda's", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veranda is een beglaasde aanbouw tegen een woonhuis, om in te verpozen. Meestal  gaat het om een afdak op palen, soms geheel of gedeeltelijk met glas  gesloten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/03/2015: SN aangevuld o.b.v. voorstel Hilde K.",
                "type": "historyNote",
            },
        ],
        "related": [329, 518],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/461",
    },
    {
        "broader": [520],
        "id": 1131,
        "labels": [
            {"label": "verblijfplaatsen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1132, 1133, 1134],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1131",
    },
    {
        "id": 1471,
        "labels": [
            {
                "label": "verblijven voor hoenderachtigen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [138, 236, 1469, 1470, 1601, 1602],
        "notes": [],
        "sources": [],
        "superordinates": [892],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1471",
    },
    {
        "broader": [1145],
        "id": 1155,
        "labels": [
            {"label": "verdedigingsmuren", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1156, 404],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een verdedigingsmuur omvat alle soorten muren die gebouwd zijn om een aanval te weerstaan.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1155",
    },
    {
        "broader": [147],
        "id": 293,
        "labels": [
            {"label": "verdedigingswerken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "versterkingen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": [],
            "narrow": ["http://vocab.getty.edu/aat/300006888"],
            "related": [],
        },
        "member_of": [],
        "narrower": [313, 1145, 1146, 1147, 1148, 1149, 1150, 1371],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: term 'militaire gebouwen en constructies' gewijzigd naar 'verdedigingswerken'.",
                "type": "historyNote",
            }
        ],
        "related": [88, 292, 1151, 124],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/293",
    },
    {
        "broader": [147],
        "id": 1151,
        "labels": [
            {
                "label": "verdedigingswerkonderdelen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1765],
        "narrower": [734, 771, 1187, 1188, 1189, 1190, 1191, 1192, 1193, 1746, 710],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [293],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1151",
    },
    {
        "broader": [440],
        "id": 1596,
        "labels": [
            {"label": "verdiepte tuinen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een verdiepte tuin is een siertuin die verdiept is aangelegd. Verdiepte tuinen komen veel voor in het Interbellum waarbij ook stapelmuren met muurplanten worden gebruikt.",
                "type": "scopeNote",
            }
        ],
        "related": [1591, 1595],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1596",
    },
    {
        "broader": [321],
        "id": 463,
        "labels": [
            {"label": "verenigingsgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007063"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [100, 207, 339, 478],
        "notes": [],
        "related": [162],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/463",
    },
    {
        "broader": [15],
        "id": 464,
        "labels": [
            {"label": "verffabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een verffabriek is een industrieel of ambachtelijk bedrijf waar men verf of kleurstoffen produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [465],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/464",
    },
    {
        "broader": [1393],
        "id": 1407,
        "labels": [
            {
                "label": "versieringsonderdelen van voorwerpen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Objecten die werden gebruikt voor het versieren van allerhande voorwerpen, en los van het oorspronkelijk object werden teruggevonden. Het gaat hier bijvoorbeeld om beslagplaatjes, ringetjes (geen sieraden!) gebruikt ter versiering, enz...",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1407",
    },
    {
        "broader": [1033],
        "id": 2111,
        "labels": [
            {"label": "verspreide bebouwing", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Verspreide bebouwing is een losse groepering van verspreide, individuele bebouwing zonder een duidelijk herkenbare of afgebakende kern.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/06/2015: toegevoegd bij integratie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2111",
    },
    {
        "broader": [],
        "id": 1383,
        "labels": [
            {"label": "verspreide vondsten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1381],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Verspreide vondsten zijn vondsten die zich niet voordoen op \xe9\xe9n bepaalde locatie met een duidelijke concentratie, maar eerder over een groter oppervlak en waar men te veel objecten heeft om nog van een losse vondst te kunnen spreken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1383",
    },
    {
        "broader": [293],
        "id": 1149,
        "labels": [
            {"label": "versterkte gebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [87, 945, 1169, 1171, 1797],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1149",
    },
    {
        "broader": [1033],
        "id": 1051,
        "labels": [
            {
                "label": "versterkte nederzettingen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1034],
        "narrower": [1052],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een versterkte nederzetting is een nederzetting die versterkt is, maar die geen militaire functie heeft.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1051",
    },
    {
        "broader": [293],
        "id": 1150,
        "labels": [
            {"label": "versterkte sites", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [141, 967, 1176, 1181, 1182, 1183, 1184, 868],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1150",
    },
    {
        "broader": [1393],
        "id": 1408,
        "labels": [
            {
                "label": "vervoermiddelonderdelen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1409, 1410, 1411],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1408",
    },
    {
        "broader": [792],
        "id": 1518,
        "labels": [
            {"label": "verwarmde fruitmuren", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300179263"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een verwarmde fruitmuur of hot wall is een tuinmuur voorzien van verwarmingsbuizen of rookkanalen, die een kunstmatig microklimaat cre\xebren ter bevordering van het groeien of rijpen van vruchtbomen of struiken die tegen de muren zijn geleid. Populair in de 18de en 19de eeuw.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1518",
    },
    {
        "broader": [147],
        "id": 466,
        "labels": [
            {"label": "verzorgingsgebouwen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006707"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [267, 526, 115, 154, 202, 283, 357, 644, 368, 369, 2101, 886],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/466",
    },
    {
        "broader": [1150],
        "id": 1184,
        "labels": [{"label": "vestingen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [99, 1185],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vesting is een grote, permanente, zwaarversterkte militaire verdedigingspositie, soms met een stad erbij.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'forten' voor militaire constructies die kleiner en minder zwaar versterkt zijn dan vestingen.",
                "type": "note",
            },
        ],
        "related": [141],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1184",
    },
    {
        "broader": [1184],
        "id": 1185,
        "labels": [
            {
                "label": "vestingen van het gebastioneerd stelsel",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1186],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een een vesting van het gebastioneerd stelsel is een vesting gekenmerkt door de toepassing van bastions. Er bestaan verschillende types: Oud-Italiaans stelsel, Oud- en Nieuw-Nederlands stelsel, Frans stelsel (Vauban), polygonaal stelsel en getenailleerd stelsel.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [771],
        "sources": [
            {
                "citation": 'Begrippenlijst van de Stichting Menno van Coehoorn (<a href="http://www.coehoorn.nl/">http://www.coehoorn.nl/)</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1185",
    },
    {
        "broader": [1171],
        "id": 1173,
        "labels": [
            {"label": "vestingtorens", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vestingtoren is een buitenwerk van een middeleeuws vestingwerk; een vooruitgeschoven post die wordt gebruikt om de toegang tot een poort te versterken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Kamps P.J.M. (red.) 1999, Terminologie verdedigingswerken. Inrichting, aanval en verdediging, Utrecht.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1173",
    },
    {
        "broader": [1608],
        "id": 2198,
        "labels": [
            {"label": "veteraanbomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een veteraanboom is een natuurlijk of kunstmatige gevormde boom of uitzonderlijk een struik die zich omwille van de individuele ouderdom in een langzame aftakelingsfase bevindt. Veteraanbomen worden vaak gekenmerkt door een opvallende groei, of door een voor de betreffende soort grote stamomtrek, of door de aanwezigheid van holtes in de stam of in de takken, of door dood hout in de kruin, of door een epifytenbegroeiing op de stam, of door spleten of loslatende delen in de schors, of door sapuitvloei, slijmvloed, luchtwortel- of schimmelgroei ter hoogte van beschadigingen. (Onroerend Erfgoed en Inverde)",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/07/2016: term toegevoegd",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2198",
    },
    {
        "broader": [86],
        "id": 841,
        "labels": [{"label": "viaducten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007890"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1485],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een viaduct is een brug, meestal bestaande uit meerdere min of meer gelijke boogvormige overspanningen, bedoeld om verkeer over een lagergelegen gebied te leiden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "26/01/2011: SN toegevoegd.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "1) AAT \n2)VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/841",
    },
    {
        "broader": [1053],
        "id": 1055,
        "labels": [
            {"label": "vici", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vicus", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vicus is zowel een Romeinse landelijke nederzetting als een Romeinse en middeleeuwse handelswijk of dorp, dat meestal buiten de muren van een nabijgelegen militaire nederzetting (militaire vicus) lag of op de kruising van belangrijke handelswegen (civiele vicus).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1055",
    },
    {
        "broader": [1116],
        "id": 1121,
        "labels": [
            {"label": "viereckschanzen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Viereckschanze is een rechthoekige wal- en grachtenclosure die dateert uit de ijzertijd. Ze komen voor in Frankrijk, zuid-Duitsland, Belgi\xeb en Bohemi\xeb. Ze werden vroeger ge\xefnterpreteerd als cultusplaatsen, maar recent wordt een seculiere functie niet uitgesloten. Kenmerkend zijn (rituele?) schachten/kuilen die voorkomen in de hoeken van structuren en vierkante paalconstructies die kunnen ge\xefnterpreteerd worden als kleine tempeltjes of opslagplaatsen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1121",
    },
    {
        "broader": [1420],
        "id": 1425,
        "labels": [
            {"label": "vierkantshoeven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1425",
    },
    {
        "broader": [821],
        "id": 1277,
        "labels": [
            {"label": "vierpostenspijkers", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vierpostenspijker is een spijker (bijgebouwtje) opgetrokken op vier palen of posten, zodat de bodem niet op de grond rust.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1277",
    },
    {
        "broader": [160],
        "id": 1123,
        "labels": [{"label": "vierscharen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vierschaar is een plaatselijk gerechtsorgaan in handen van een lokale ambachtsheer (heer met bevoegdheid voor rechtspraak). Een vierschaar was oorspronkelijk een met 4 gespannen touwen of banken afgebakende zone in openlucht (vaak onder een linde) waar recht werd gesproken. Later werd de vierschaar ondergebracht in een gebouw. De functie van de vierscharen verviel met de Franse Revolutie toen de rechtspraak volledig in handen van de staat kwam.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": ") Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1123",
    },
    {
        "broader": [931],
        "id": 467,
        "labels": [{"label": "vijvers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1599, 1600],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vijver is een gegraven waterbekken, vaak als onderdeel van een tuin- of parkaanleg.",
                "type": "scopeNote",
            }
        ],
        "related": [861],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/467",
    },
    {
        "broader": [1308],
        "id": 1311,
        "labels": [
            {"label": "villa's", "language": "nl-BE", "type": "prefLabel"},
            {"label": "villae rusticae", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Romeinse villa is een van stedelijk comfort voorziene woning op het platteland. Het is een landbouwbedrijf dat ge\xefntegreerd is in de sociale en economische organisatie van de Romeinse wereld en waarvan het hoofdgebouw in Romeinse stijl is gebouwd. Dergelijke villa's bestaan uit een woongedeelte (pars urbana) en een bedrijfsgedeelte (pars rustica). De grootste villae rusticae hebben een hoofdgebouw (pars urbana) met links en rechts daarvan twee vleugels met de bedrijfsgebouwen (pars rustica).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) De Wit G. &amp; Sloos A. 2008, De interpretatie van archeologische waarnemingen in Archis. Een concept voor een nieuwe set complextypen, in: Rapportage Archeologische Monumentenzorg 165, Amersfoort. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1311",
    },
    {
        "broader": [522],
        "id": 468,
        "labels": [{"label": "villa's", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een villa is een aanzienlijk, vrijstaand woonhuis uit de 19de en 20ste eeuw, omgeven door een tuin. Voornamelijk gelegen in residenti\xeble wijken, op het platteland of in groene stadsgedeelten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar vormelijk type\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [188, 262],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl); WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/468",
    },
    {
        "broader": [440],
        "id": 1579,
        "labels": [{"label": "villatuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een villatuin is een siertuin bij een vrijstaand aanzienlijk huis dat vooral landelijk gelegen is of in een parkachtige stadswijk. In grote villatuinen treft men ook vaak openluchtzwembaden, tennisbanen en moestuinen aan.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1579",
    },
    {
        "broader": [180],
        "id": 469,
        "labels": [
            {"label": "vishallen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vismijnen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vishal is een markthal waar vis verhandeld wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [281],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/469",
    },
    {
        "broader": [21],
        "id": 1292,
        "labels": [
            {"label": "viskweekvijvers", "language": "nl-BE", "type": "prefLabel"},
            {"label": "viskwekerijen", "language": "nl-BE", "type": "altLabel"},
            {"label": "weiers", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een viskweekvijver is een inrichting waar viseitjes worden uitgebroed en de jonge vissen, die eventueel later in meren, stromen en vijvers worden uitgezet, worden grootgebracht. Vaak is het mogelijk de vijver gedeeltelijk te laten leeglopen voor vereenvoudigde visvangst. Visvijvers rond kloosters kunnen hiervoor gebruikt worden. Viskwekerijen komen echter ook voor verspreid in het landschap als speciaal daarvoor uitgegraven structuren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.\n30/07/2014: SN aangepast bij integratie met landschappelijke termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) agentschap Onroerend Erfgoed",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1292",
    },
    {
        "broader": [1053],
        "id": 1058,
        "labels": [
            {"label": "vissersdorpen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            }
        ],
        "related": [470],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1058",
    },
    {
        "broader": [78],
        "id": 1461,
        "labels": [
            {"label": "vissersschepen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vissersschip is een vaartuig van vissers dat voor de visvangst is bestemd en ingericht.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1461",
    },
    {
        "broader": [522],
        "id": 470,
        "labels": [
            {"label": "visserswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een visserswoning is het bescheiden woonhuis van een visser. Meestal gelegen in vissersdorpen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [1058],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/470",
    },
    {
        "broader": [21],
        "id": 471,
        "labels": [
            {
                "label": "visverwerkingsbedrijven",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een visverwerkingsbedrijf is een industrieel bedrijf waar men vis verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/471",
    },
    {
        "broader": [237],
        "id": 1553,
        "labels": [
            {"label": "vlaggenmasten", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300082991"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vlaggenmast is een paal waaraan een of meer vlaggen gehesen kunnen worden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1553",
    },
    {
        "broader": [1227],
        "id": 1257,
        "labels": [{"label": "vlakgraven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1248],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vlakgraf is een eenvoudig graf zonder monumenten/aanduiding aan de oppervlakte. Deze kan zowel inhumatie als crematie bevatten.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1257",
    },
    {
        "broader": [],
        "id": 1982,
        "labels": [
            {"label": "vlakten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vlaktes", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300008805"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1859],
        "narrower": [1983, 1985, 1989, 1991],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vlakte is een (vrijwel) horizontaal gelegen reli\xebfvorm zonder grote niveauverschillen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1982",
    },
    {
        "broader": [1905],
        "id": 1907,
        "labels": [{"label": "vlasakkers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vlasakker is een akkerland bezaaid met vlas.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1907",
    },
    {
        "broader": [20],
        "id": 472,
        "labels": [
            {"label": "vlasfabrieken", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vlasspinnerijen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [830, 871],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vlasfabriek is een industrieel of ambachtelijk bedrijf waar men vlas verwerkt. Deze verwerking bestond uit het roten, brakelen, zwingelen en hekelen.",
                "type": "scopeNote",
            }
        ],
        "related": [394],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/472",
    },
    {
        "broader": [522],
        "id": 936,
        "labels": [
            {
                "label": "vlashandelaarswoningen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vlashandelaarswoning is het woonhuis van een vlashandelaar, met bijhorende opslagruimte. Deze huizen waren doorgaans voorzien van een aparte toegangsdeur tot deze opslagruimtes.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/936",
    },
    {
        "broader": [180],
        "id": 475,
        "labels": [{"label": "vleeshallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vleeshal is een markthal waar vlees verhandeld wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [281],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/475",
    },
    {
        "broader": [21],
        "id": 474,
        "labels": [
            {
                "label": "vleesverwerkingsbedrijven",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vleesverwerkingsbedrijf is een industrieel bedrijf waar men vlees verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [388, 386],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/474",
    },
    {
        "broader": [925],
        "id": 2098,
        "labels": [
            {"label": "vliegtuigloodsen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "vliegtuighangars", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300007768"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vliegtuigloods is een gebouw voor de opslag van en herstellingen aan vliegtuigen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2098",
    },
    {
        "broader": [1408],
        "id": 1410,
        "labels": [
            {"label": "vliegtuigonderdelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1410",
    },
    {
        "broader": [925],
        "id": 476,
        "labels": [{"label": "vliegvelden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vliegveld is een terrein waar vliegtuigen kunnen opstijgen en landen, al dan niet met bijhorende gebouwen.",
                "type": "scopeNote",
            }
        ],
        "related": [273],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/476",
    },
    {
        "broader": [1843],
        "id": 2141,
        "labels": [{"label": "vloedbossen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vloedbos is een bos gelegen op plaatsen die periodiek, op basis van getijdenwerking, overstromen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "06/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2141",
    },
    {
        "broader": [2067],
        "id": 2068,
        "labels": [{"label": "vloeiweiden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vloeiweide is een watering gericht op het bevloeien van hooilanden of \u2013weiden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2068",
    },
    {
        "broader": [],
        "id": 1108,
        "labels": [{"label": "vloeren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vloer is het oppervlak van een kamer of ruimte waar men op loopt. Hier kan men verschillende soorten onderscheiden, zoals lemen vloeren, tegelvloeren, baksteenvloeren enz\u2026",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1108",
    },
    {
        "broader": [],
        "id": 1751,
        "labels": [{"label": "voertuigen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300219258"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [1752],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Voertuigen zijn toestellen of apparaten waarmee mensen of voorwerpen worden vervoerd of gedragen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Art &amp; Architecture Thesaurus", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1751",
    },
    {
        "broader": [1408],
        "id": 1411,
        "labels": [
            {"label": "voertuigonderdelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1411",
    },
    {
        "broader": [237],
        "id": 1554,
        "labels": [{"label": "voetstukken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300001656"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een voetstuk is een relatief massief element dat het onderste gedeelte van structuren of objecten vormt en waarop de overige delen rusten of waardoor die worden ondersteund.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1554",
    },
    {
        "broader": [443],
        "id": 1552,
        "labels": [
            {"label": "vogeldrinkbakjes", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vogeldrinkbakje is een rechthoekig natuurstenen, bewerkt voorwerp bestaande uit een ondiep gedeelte waarin vogels kunnen drinken en een dieper gedeelte waarin zij kunnen baden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1552",
    },
    {
        "broader": [892],
        "id": 477,
        "labels": [{"label": "voli\xe8res", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een voli\xe8re is een grote kooi in openlucht om siervogels te houden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/477",
    },
    {
        "broader": [463],
        "id": 478,
        "labels": [{"label": "volkshuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een volkshuis is een gebouw voor ontspanning en ontwikkeling van het volk, opgericht door ideologische organisaties zowel uit socialistische, liberale als katholieke hoek.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/478",
    },
    {
        "broader": [896],
        "id": 479,
        "labels": [
            {
                "label": "volkssportvoorzieningen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [377, 709, 966, 764],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebouwen of constructies voor de beoefening van volkssporten.",
                "type": "scopeNote",
            }
        ],
        "related": [377],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/479",
    },
    {
        "broader": [1565],
        "id": 1571,
        "labels": [{"label": "volkstuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een volkstuin is een klein lapje grond, buiten of aan de rand van de stad, van overheidswege beschikbaar gesteld waarop door stadsbewoners voeding- en siergewassen worden geteeld.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1571",
    },
    {
        "broader": [1252],
        "id": 1254,
        "labels": [
            {"label": "volwassenengraven", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een volwassenengraf is een graf waarin ge\xefnhumeerde of gecremeerde resten van een volwassene zijn bijgezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1254",
    },
    {
        "broader": [],
        "id": 1384,
        "labels": [
            {"label": "vondstenconcentraties", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1381],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1384",
    },
    {
        "broader": [2089],
        "id": 2088,
        "labels": [
            {"label": "voorpleinen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "erepleinen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300004104"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een voorplein is een open ruimte voor de hoofdingang van een gebouw en aan twee of drie zijden door vleugels of armen omvat.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: term toegevoegd i.f.v. beschermingsdatabank",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandstalige Art &amp; Architecture Thesaurus",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2088",
    },
    {
        "broader": [328],
        "id": 1279,
        "labels": [
            {"label": "voorraadkuilen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "opslagkuilen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een voorraadkuil is een kuil in de grond bedoeld voor de opslag van allerhande objecten en goederen, niet alleen levensmiddelen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'silo's' voor bovengrondse en ondergrondse opslagplaatsen voor levensmiddelen.",
                "type": "note",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1279",
    },
    {
        "broader": [78],
        "id": 1462,
        "labels": [
            {"label": "vrachtschepen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vrachtschip is een vaartuig uitsluitend bestemd voor goederenvervoer.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1462",
    },
    {
        "broader": [1618],
        "id": 1619,
        "labels": [{"label": "vredesbomen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vredesboom is een vrijheidsboom die na de bevrijding in 1918 en 1945 werd geplant.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1619",
    },
    {
        "broader": [1617],
        "id": 1618,
        "labels": [
            {"label": "vrijheidsbomen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1619],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vrijheidsboom is een boom die staat voor vrijheid en democratie. De vrijheidsboom was een veelgebruikt symbool van de vernieuwde maatschappij die bewerkstelligd werd na het einde van het Ancien R\xe9gime aansluitend op de Franse Revolutie. De aanhangers van de Franse Revolutie inspireerden zich op een gelijkaardig gebruik gedurende de aanloop naar de Amerikaanse Revolutie (Boston Liberty Tree). Er werden ook vrijheidsbomen geplant na de Belgische Revolutie in 1830 om de onafhankelijkheid van Belgi\xeb te vieren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1618",
    },
    {
        "broader": [359],
        "id": 480,
        "labels": [
            {"label": "vrijmetselaarstempels", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een vrijmetselaarstempel is een gebouw waar vrijmetselaars samenkomen. Vrijmetselaars vormen een besloten humanistische vereniging met een sociaal en professioneel doel, de zgn. loges.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/480",
    },
    {
        "broader": [1531],
        "id": 481,
        "labels": [
            {"label": "vrijstaande uurwerken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Uurwerken die opgesteld zijn in de openbare ruimte.",
                "type": "scopeNote",
            }
        ],
        "related": [67, 531],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/481",
    },
    {
        "broader": [1302],
        "id": 1303,
        "labels": [
            {"label": "vuursteenwinning", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar vuursteen is gewonnen door middel van dag- of mijnbouw. De diepte van individuele extractieputten kan vari\xebren van enkele decimeters tot meer dan 10 m. Oppervlaktewinning (simpelweg het verzamelen van dagzomend of ondiep in bodem aanwezig materiaal) laat zich moeilijk en hoogstens indirect, aan de hand van het debitagemateriaal, herkennen. Afhankelijk van de regio en het matrixsediment kan vuursteen gewonnen worden uit een primaire (kalksteen), secundaire (eluvium) of een tertiaire (grind, keileem) geologische context.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1303",
    },
    {
        "broader": [923],
        "id": 482,
        "labels": [{"label": "vuurtorens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een vuurtoren is een toren, meestal langs de kust, met een sterke lichtbron bovenin, waarop schepen en vliegtuigen zich kunnen ori\xebnteren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/482",
    },
    {
        "broader": [885],
        "id": 483,
        "labels": [{"label": "waaggebouwen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waaggebouw is een gebouw waar goederen door de overheid gewogen worden ten behoeve van de handel.",
                "type": "scopeNote",
            }
        ],
        "related": [505],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/483",
    },
    {
        "broader": [522],
        "id": 484,
        "labels": [
            {"label": "wachterswoningen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1139],
        "narrower": [958, 959],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wachterswoning is het woonhuis van toezichters en bewakers.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van \u2018woonhuizen\u2019 naar \u2018woonhuizen naar bewoners\u2019.",
                "type": "historyNote",
            },
        ],
        "related": [485, 77, 460],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/484",
    },
    {
        "broader": [13],
        "id": 485,
        "labels": [{"label": "wachthuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [755, 842],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wachthuis is een gebouw waarin men tijdens het wachten op trein, bus of tram kan schuilen.",
                "type": "scopeNote",
            }
        ],
        "related": [382, 397, 434, 484, 2094],
        "sources": [
            {
                "citation": "WNT Woordenboek der Nederlandsche Taal via de Ge\xefntegreerde Taalbank",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/485",
    },
    {
        "broader": [1151],
        "id": 1746,
        "labels": [{"label": "wachtposten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wachtpost is een onderdeel van een verdedigingswerk en werd gebruikt om onderdak te bieden aan officieren en soldaten van wacht, die elk over een eigen lokaal beschikten, en aan een portier. Deze wachtposten bevinden zich meestal nabij de poort doorheen het verdedigingswerk.",
                "type": "scopeNote",
            }
        ],
        "related": [2094],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1746",
    },
    {
        "broader": [1171],
        "id": 1174,
        "labels": [
            {"label": "wachttorens", "language": "nl-BE", "type": "prefLabel"},
            {"label": "uitkijktorens", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wachttoren of uitkijktoren is een toren op de wal of boven een poort van een stadsmuur, vesting of burcht bedoeld om de vijand snel te kunnen zien naderen; kan ook meer binnenwaarts gelegen zijn.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1174",
    },
    {
        "broader": [923],
        "id": 1944,
        "labels": [
            {"label": "wadden", "language": "nl-BE", "type": "prefLabel"},
            {"label": "voorden", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wad is een doorwaadbare plaats in een natuurlijke waterloop die dient om deze waterloop over te steken.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1944",
    },
    {
        "broader": [1982],
        "id": 1985,
        "labels": [
            {"label": "wadvlakten", "language": "nl-BE", "type": "prefLabel"},
            {"label": "estuariumvlakten", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1986, 1987],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wadvlakte is een buitendijkse onder getijdeninvloed staande vlakte (zoals langs kusten en mondingsgebieden van rivieren) bestaande uit lager gelegen, grotendeels onbegroeide delen die dagelijks overstromen (slikken) en hoger gelegen, begroeide delen die enkel bij springtij overstromen (schorren).",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1976, 1978],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1985",
    },
    {
        "broader": [63],
        "id": 486,
        "labels": [
            {"label": "wagenhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "karrenhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wagenhuis is een bijgebouw, in de eerste plaats op een hoeve, waarin de wagens en karren worden gestald.",
                "type": "scopeNote",
            }
        ],
        "related": [245],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/486",
    },
    {
        "broader": [18],
        "id": 487,
        "labels": [
            {"label": "wagenmakerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wagenmakerij is een ambachtelijk bedrijf waar men rijtuigen maakt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/487",
    },
    {
        "broader": [1152],
        "id": 1153,
        "labels": [{"label": "walgrachten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een walgracht (verdedigingselement) is een brede gracht die de vorm en omvang van de binnengelegen zone bepaalt en bedoeld is als (onderdeel van) de verdediging. Walgrachten vormen het geheel van wal en gracht, zijn breder dan gewone grachten en zijn steeds gevuld met water.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1153",
    },
    {
        "broader": [],
        "id": 1109,
        "labels": [{"label": "wallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1071],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wal (morfologisch element) is een aarden ophoging die (eventueel met begeleidende gracht) de omsluiting vormt van een structuur en verder niet functioneel te duiden is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "20/01/2011: Toegevoegd bij integratie met archeologisch erfgoed.",
                "type": "historyNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'wallen (verdedigingselementen)' voor wallen specifiek bedoeld voor verdediging.",
                "type": "note",
            },
        ],
        "related": [1137, 1158, 1080],
        "sources": [
            {
                "citation": "1) Collis J. 2001, Digging up the past. An introduction to archaeological excavation, Sparkford. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1109",
    },
    {
        "broader": [1145],
        "id": 1158,
        "labels": [{"label": "wallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1159],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wal (verdedigingselement) is een aarden dam die (eventueel met begeleidende gracht) de omsluiting en verdediging vormt van een vesting, burcht, kamp of andere versterking. Eventuele houten palissades maken de afweer volledig. De term 'wal' kan vanaf de 12de eeuw ook gebruikt worden om een stenen muur aan te duiden.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Gebruik 'wallen (morfologische elementen)' voor wallen die niet functioneel te duiden zijn.",
                "type": "historyNote",
            },
        ],
        "related": [1109],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1158",
    },
    {
        "broader": [321],
        "id": 489,
        "labels": [
            {"label": "wandelgalerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wandelgalerij is een overdekte gang, aan \xe9\xe9n of beide kanten open, om in te kuieren.",
                "type": "scopeNote",
            }
        ],
        "related": [516, 344],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/489",
    },
    {
        "broader": [321],
        "id": 344,
        "labels": [{"label": "wandelpieren", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wandelpier is een vaste dijk of houten palenconstructie (staketsel) die vanaf het strand een eind in zee loopt en die gebruikt wordt om op te wandelen. Op het uiteinde van de pieren staat soms een bouwwerk, bijvoorbeeld een restaurant,  caf\xe9 of een observatieruimte.",
                "type": "scopeNote",
            }
        ],
        "related": [489],
        "sources": [{"citation": "WIKI", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/344",
    },
    {
        "broader": [1393],
        "id": 1412,
        "labels": [
            {"label": "wapens en munitie", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1413],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Objecten die zijn bedoeld als fysiek aanvals- of verdedigingsmiddel of als jachtwapens. Hieronder vallen handwapens zoals 'zwaarden', grondwapens of op rijdend materieel vervoerde wapens zoals 'artillerie', componenten van wapens en projectielen die met vuurwapens worden afgevuurd (bijvoorbeeld 'patronen'), maar ook verdedigingsmiddelen zoals schilden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1412",
    },
    {
        "broader": [885],
        "id": 491,
        "labels": [
            {"label": "warenhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "grootwarenhuizen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een warenhuis is een aanzienlijke winkel waar levensmiddelen of andere handelswaar in het klein verkocht worden.",
                "type": "scopeNote",
            }
        ],
        "related": [178, 517],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/491",
    },
    {
        "broader": [63],
        "id": 492,
        "labels": [{"label": "washuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een washuis is een bijgebouw waarin men de was doet.",
                "type": "scopeNote",
            }
        ],
        "related": [493, 37],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/492",
    },
    {
        "broader": [894],
        "id": 493,
        "labels": [{"label": "wasserijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wasserij is een bedrijf waar men wast en strijkt.",
                "type": "scopeNote",
            }
        ],
        "related": [492],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/493",
    },
    {
        "broader": [931],
        "id": 920,
        "labels": [{"label": "waterbekkens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterbekken is een kunstmatige, ondiepe waterpartij met een geometrisch grondplan en met een zichtbare opstaande boord van natuur- of baksteen voor passieve reflectie van de omgeving of met een fontein in het midden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/920",
    },
    {
        "broader": [21],
        "id": 494,
        "labels": [
            {
                "label": "water- en frisdrankenfabrieken",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een water- en frisdrankenfabriek is een industrieel bedrijf waar men bronwater bottelt en/of frisdrank produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [79],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/494",
    },
    {
        "broader": [],
        "id": 2067,
        "labels": [{"label": "wateringen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1850],
        "narrower": [2068, 2069],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een watering is een landinrichtingsvorm waarbij landbouwgronden door middel van natuurlijke of (meestal) kunstmatige waterlopen gecontroleerd en periodiek bevloeid worden met (nutri\xebntenrijk) water met als doel de opbrengst te verhogen. Het waterhuishoudingssysteem kan bestaan uit dijken, sluizen, stuwen, aan- en/of afvoergrachten,\u2026",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "03/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2067",
    },
    {
        "broader": [1371],
        "id": 1372,
        "labels": [
            {"label": "waterkastelen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterkasteel is een kasteel dat letterlijk 'met de voeten in het water staat'. Het is dus direct omgeven door een brede gracht of is gebouwd in een meer of rivier. De configuratie van opperhof en neerhof, zoals bij de mottekastelen, blijft hier echter ook behouden.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1372",
    },
    {
        "broader": [13],
        "id": 1195,
        "labels": [{"label": "waterkuilen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterkuil is een kuil die tot onder het grondwaterniveau is uitgegraven. Ze waren niet beschoeid. Mogelijk werden deze kuilen gebruikt als drenkplaatsen voor vee of voor een tijdelijke watervoorziening.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Jansen R. &amp; Fokkens H. 1998, Archeologisch onderzoek in de gemeente Oss in 1997, Leiden. (opgravingsverslag Universiteit Leiden)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1195",
    },
    {
        "broader": [13],
        "id": 1197,
        "labels": [
            {"label": "waterleidingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [1198],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterleiding is een leiding(netwerk) om drinkwater vanuit een waterreservoir naar de verbruiker te vervoeren.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1197",
    },
    {
        "broader": [297],
        "id": 498,
        "labels": [{"label": "watermolens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een watermolen is een molen die door water wordt aangedreven.",
                "type": "scopeNote",
            }
        ],
        "related": [296],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/498",
    },
    {
        "broader": [1586],
        "id": 1594,
        "labels": [
            {"label": "waterparterres", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterparterre is een parterre waarvan water het belangrijkste bestanddeel is.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1594",
    },
    {
        "broader": [237],
        "id": 499,
        "labels": [{"label": "waterpompen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Verankerde werktuigen om water op te pompen uit de grond.",
                "type": "scopeNote",
            }
        ],
        "related": [500, 1, 349],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/499",
    },
    {
        "broader": [1169],
        "id": 1170,
        "labels": [{"label": "waterpoorten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterpoort is een poort in een vestingmuur die een rivier of gegraven water toegang biedt tot de stad, of in het geval van een havenstad een toegangspoort tot de haven.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1170",
    },
    {
        "broader": [13],
        "id": 500,
        "labels": [{"label": "waterputten", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterput is een put om water te onttrekken aan met water verzadigde lagen. Deze kunnen opgebouwd zijn uit steen, hout of vlechtwerk. Houten waterputten kunnen op hun beurt opgebouwd zijn uit tonnen of een vierkante doorsnede (in planken) hebben. In de vroege en volle middeleeuwen komen ook waterputten voor die een beschoeiing hebben bestaande uit een uitgeholde boomstam.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'klein erfgoed' naar 'infrastructuur voor waterbevoorrading en -afvoer'.",
                "type": "historyNote",
            },
        ],
        "related": [499, 83, 140],
        "sources": [
            {
                "citation": "1) Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005. 2) VIOE",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/500",
    },
    {
        "broader": [13],
        "id": 501,
        "labels": [
            {"label": "waterreservoirs", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [1199],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterreservoir is een vergaarbak voor (regen)water.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'gebouwen voor de productie en distributie van elektriciteit, gas en water' naar 'infrastructuur voor waterbevoorrading en -afvoer'.",
                "type": "historyNote",
            },
        ],
        "related": [502],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/501",
    },
    {
        "broader": [13],
        "id": 502,
        "labels": [{"label": "watertorens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een watertoren is een toren waarin men gezuiverd water oppompt zodat er voldoende druk wordt gecre\xeberd op het waterleidingnet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'gebouwen voor de productie en distributie van elektriciteit, gas en water' naar 'infrastructuur voor waterbevoorrading en -afvoer'.",
                "type": "historyNote",
            },
        ],
        "related": [501],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/502",
    },
    {
        "broader": [443],
        "id": 1555,
        "labels": [{"label": "watervallen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1556],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterval als tuinelement is een plaats waar stromend water op natuurlijke of kunstmatige wijze van een hoogte of helling naar beneden valt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "1) agentschap Onroerend Erfgoed 2) Van Dale online",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1555",
    },
    {
        "broader": [13],
        "id": 503,
        "labels": [
            {
                "label": "waterwinningsgebouwen",
                "language": "nl-BE",
                "type": "prefLabel",
            },
            {
                "label": "waterbedelingsgebouwen",
                "language": "nl-BE",
                "type": "altLabel",
            },
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterwinningsgebouw is een gebouw en infrastructuur voor het winnen van drinkwater uit grond- of oppervlaktewater.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'gebouwen voor de productie en distributie van elektriciteit, gas en water' naar 'infrastructuur voor waterbevoorrading en -afvoer'.",
                "type": "historyNote",
            },
        ],
        "related": [504],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/503",
    },
    {
        "broader": [13],
        "id": 504,
        "labels": [
            {
                "label": "waterzuiveringsstations",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1194],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een waterzuiveringsstation is een gebouw en infrastructuur waar afvalwater gezuiverd en terug geloosd wordt.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: BT gewijzigd van 'gebouwen voor de productie en distributie van elektriciteit, gas en water' naar 'infrastructuur voor waterbevoorrading en -afvoer'.",
                "type": "historyNote",
            },
        ],
        "related": [503],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/504",
    },
    {
        "broader": [886],
        "id": 837,
        "labels": [{"label": "weduwhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [166],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/837",
    },
    {
        "broader": [926],
        "id": 505,
        "labels": [{"label": "weegbruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een weegbrug is een weegtoestel om voertuigen met hun lading te wegen.",
                "type": "scopeNote",
            }
        ],
        "related": [483],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/505",
    },
    {
        "broader": [1151],
        "id": 1193,
        "labels": [{"label": "weergangen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een weergang is een doorloop over de ringmuur van een burcht of vesting, aan de buiten- of veldzijde verdedigd door een gekanteelde borstwering. Oorspronkelijk in hout, later in steen.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997, Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1193",
    },
    {
        "broader": [886],
        "id": 506,
        "labels": [{"label": "weeshuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Liefdadigheidsinstellingen voor de opvang van wezen.",
                "type": "scopeNote",
            }
        ],
        "related": [166],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/506",
    },
    {
        "broader": [932],
        "id": 1761,
        "labels": [
            {"label": "wegbeplantingen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1756],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1761",
    },
    {
        "broader": [926],
        "id": 1212,
        "labels": [{"label": "wegen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [128, 221, 1214, 1216, 1217, 1218, 1219, 1500, 1501],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een weg is een strook grond geschikt gemaakt voor en gebruikt door het verkeer.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek der Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1212",
    },
    {
        "broader": [891],
        "id": 508,
        "labels": [
            {"label": "wegkruisen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "doodskruisen", "language": "nl-BE", "type": "altLabel"},
            {"label": "grenskruisen", "language": "nl-BE", "type": "altLabel"},
            {"label": "hagelkruisen", "language": "nl-BE", "type": "altLabel"},
            {"label": "moordkruisen", "language": "nl-BE", "type": "altLabel"},
            {"label": "ongelukskruisen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Kruisen opgesteld langs de weg, uit devotie of om iets te herdenken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/508",
    },
    {
        "broader": [237],
        "id": 509,
        "labels": [{"label": "wegwijzers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Borden langs de weg, die plaatsnamen, richtingen en eventueel afstanden aangeven",
                "type": "scopeNote",
            }
        ],
        "related": [290],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/509",
    },
    {
        "broader": [1910],
        "id": 1911,
        "labels": [{"label": "weilanden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300008876"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [2153],
        "narrower": [1912],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een weiland is een grasland waarbij vee voor begrazing wordt ingezet.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1911",
    },
    {
        "broader": [1626],
        "id": 1629,
        "labels": [
            {"label": "welkomstbomen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "wachterbomen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een welkomstboom is een afweerboom (meestal een linde) aangeplant bij de inkom van een erf.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1629",
    },
    {
        "broader": [884],
        "id": 511,
        "labels": [{"label": "werkplaatsen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een werkplaats is een gebouw waar voornamelijk ambachtelijk werk of werk met lichte machines verricht wordt.",
                "type": "scopeNote",
            }
        ],
        "related": [254, 108],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/511",
    },
    {
        "broader": [1393],
        "id": 1414,
        "labels": [{"label": "werktuigen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Uitrusting die wordt gebruikt bij de verwerking van materialen en de vervaardiging van objecten. Hieronder vallen bijlen, graafgereedschap (schop, spade), maalstenen, bepaalde lithische artefacten (vuistbijlen, schrabbers, boren), maar ook messen, vorken, lepels, naalden, sleutels (sloten vallen onder bevestigingselementen), ...",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": '1) Nederlandse Art &amp; Architecture Thesaurus, <a href="http://browser.aat-ned.nl/">http://browser.aat-ned.nl/</a> 2) VIOE',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1414",
    },
    {
        "broader": [20],
        "id": 512,
        "labels": [{"label": "weverijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een weverij is een industrieel of ambachtelijk bedrijf waar men weeft.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/512",
    },
    {
        "broader": [1968],
        "id": 1971,
        "labels": [
            {"label": "wielen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "welen", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wiel is een kolkgat langs de rivier, ontstaan na een dijkdoorbraak door de kracht van het instromende water. Indien de dijk hersteld werd/wordt, blijft het wiel zichtbaar onder de vorm van een diepe plas achter de dijk.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1971",
    },
    {
        "broader": [360],
        "id": 826,
        "labels": [{"label": "wielerbanen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/826",
    },
    {
        "broader": [],
        "id": 1930,
        "labels": [{"label": "wijngaarden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300000248"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [1840],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wijngaard is een productief bodemgebruik waarbij wijnstokken zijn aangeplant waarbij druiven voor wijnproductie worden geoogst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "01/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1930",
    },
    {
        "broader": [1504],
        "id": 1507,
        "labels": [{"label": "wildparken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wildpark is een dierenpark waarin traditionele wildsoorten worden gehouden om desgevallend te bejagen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1507",
    },
    {
        "broader": [297],
        "id": 514,
        "labels": [{"label": "windmolens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een windmolen is een molen die door de wind wordt aangedreven.",
                "type": "scopeNote",
            }
        ],
        "related": [296],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/514",
    },
    {
        "broader": [237],
        "id": 515,
        "labels": [{"label": "windschermen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Schermen die op open plaatsen mensen beschutting bieden tegen de wind.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/515",
    },
    {
        "broader": [885],
        "id": 2167,
        "labels": [{"label": "winkelcentra", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een winkelcentrum is een geheel, voornamelijk bestaande uit winkels en andere (commerci\xeble) voorzieningen, die gezamenlijk een dienstverlenende functie hebben in een stadsdeel of wijk.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2167",
    },
    {
        "broader": [885],
        "id": 516,
        "labels": [
            {"label": "winkelgalerijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een winkelgalerij is een galerij met aan weerszijden winkels. Vaak vormen deze galerijen een doorsteek tussen twee (winkel)straten in een stad.",
                "type": "scopeNote",
            }
        ],
        "related": [489],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/516",
    },
    {
        "broader": [885],
        "id": 517,
        "labels": [{"label": "winkels", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een winkel is een gebouw voor detailhandel, doorgaans met bovengelegen woonfunctie.",
                "type": "scopeNote",
            }
        ],
        "related": [281, 178, 491],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/517",
    },
    {
        "broader": [1223],
        "id": 1490,
        "labels": [{"label": "winterdijken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een winterdijk is een dijk die het winterbed van een waterloop indijkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1490",
    },
    {
        "broader": [63],
        "id": 518,
        "labels": [{"label": "wintertuinen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wintertuin is een beglaasde aanbouw of vertrek met bovenlicht, waar men in volle grond of in pochetten in de muur vorstgevoelige planten houdt en waar men kan verpozen.",
                "type": "scopeNote",
            }
        ],
        "related": [329, 384, 461],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/518",
    },
    {
        "broader": [20],
        "id": 519,
        "labels": [{"label": "wolfabrieken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een wolfabriek is een industrieel bedrijf waar men wol verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/519",
    },
    {
        "broader": [147],
        "id": 520,
        "labels": [{"label": "woningen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [225, 284, 1131, 522, 1135, 196],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT toegevoegd 'woon- en verblijfplaatsen' bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/520",
    },
    {
        "broader": [522],
        "id": 889,
        "labels": [
            {
                "label": "woningen van religieuzen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005639"],
            "narrow": [],
            "related": [],
        },
        "member_of": [1139],
        "narrower": [50, 65, 216, 340, 358, 713, 803, 845, 934],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: BT gewijzigd van 'woningen' naar 'woonhuizen naar bewoners'.",
                "type": "historyNote",
            }
        ],
        "related": [359],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/889",
    },
    {
        "broader": [27],
        "id": 521,
        "labels": [{"label": "woonblokken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een woonblok is een vrijstaand appartementsgebouw, meestal grootschalig en in het kader van sociale huisvesting. Vaak omvat het een volledig bouwblok en vormt het een op zichzelf staand geheel in het stedelijk weefsel.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: BT aangepast van meergezinswoningen naar hier + SN uitgebreid.",
                "type": "historyNote",
            },
        ],
        "related": [2178, 2179, 2180],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/521",
    },
    {
        "broader": [196],
        "id": 2172,
        "labels": [{"label": "woonerven", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een woonerf is een woonbuurt waarvan de stratenaanleg door verkeersdrempels, plantenbakken, niveauverschillen, bochten of versmallingen gericht is op het veilig samengaan van autoverkeer en voetgangers.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term toegevoegd bij integratie termen sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2172",
    },
    {
        "broader": [520],
        "id": 522,
        "labels": [{"label": "woonhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300005433"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [1139, 1140],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/522",
    },
    {
        "id": 1139,
        "labels": [
            {
                "label": "woonhuizen naar bewoners",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [
            32,
            41,
            69,
            71,
            85,
            119,
            167,
            248,
            249,
            255,
            296,
            311,
            343,
            427,
            458,
            460,
            470,
            484,
            936,
            1754,
            320,
            944,
            123,
            889,
            2173,
            55,
            391,
            2174,
        ],
        "notes": [],
        "sources": [],
        "superordinates": [522],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1139",
    },
    {
        "id": 1140,
        "labels": [
            {
                "label": "woonhuizen naar vormelijk type",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "member_of": [],
        "members": [
            89,
            126,
            188,
            309,
            405,
            409,
            457,
            468,
            1141,
            1142,
            1144,
            1793,
            2175,
            2176,
            2177,
            29,
        ],
        "notes": [],
        "sources": [],
        "superordinates": [522],
        "type": "collection",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1140",
    },
    {
        "broader": [520],
        "id": 1135,
        "labels": [{"label": "woonplaatsen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1136, 1137],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            }
        ],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1135",
    },
    {
        "broader": [78],
        "id": 1463,
        "labels": [{"label": "woonschepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1429],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een woonschip is een geheel of gedeeltelijk tot woning ingericht schip.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1463",
    },
    {
        "broader": [522],
        "id": 1144,
        "labels": [
            {"label": "woonstalhuizen", "language": "nl-BE", "type": "prefLabel"},
            {"label": "hallenhuizen", "language": "nl-BE", "type": "altLabel"},
            {"label": "longhouses", "language": "nl-BE", "type": "altLabel"},
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1140],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een woonstalhuis bestaat uit een houten geraamte dat in de bodem gefundeerd was en waarvan de zware middenpalen het dakgebinte droegen en de minder zware wandpalen deel uitmaakten van een wandstructuur uit vlechtwerk en leem. Het dak was bedekt met stro of riet. In een woonstalhuis vonden zowel dieren als mensen gezamenlijk onderdak, de dieren in een stalgedeelte - al dan niet onderverdeeld met tussenschotten/boxen - de mensen in een woongedeelte waarin zich ook een haard bevond. Stal- en woongedeelte waren duidelijk van elkaar gescheiden. Vaak vormden de ingangspartijen in de lange zijden van het gebouw de scheiding tussen beide delen. Ze komen voor vanaf het laatneolithicum.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "21/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [
            {
                "citation": 'R. Annaert, J. Bourgeois &amp; G. Creemers, Onderzoeksbalans Archeologie. Bronstijd/ijzertijd: Nederzettingen. <a href="http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/metaaltijden/bronnen/archeologisch/nederzettingen">http://www.onderzoeksbalans.be/onderzoeksbalans/archeologie/metaaltijden/bronnen/archeologisch/nederzettingen</a>',
                "markup": "HTML",
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1144",
    },
    {
        "broader": [1171],
        "id": 1745,
        "labels": [{"label": "woontorens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": ["http://vocab.getty.edu/aat/300182716"],
            "exact": [],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een woontoren is een toren als centrale verdedigbare woning van de heer binnen een kasteel. Gaat in ontwerp en oorsprong terug op de donjon, maar is eerder van latere datum.",
                "type": "scopeNote",
            }
        ],
        "related": [124],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1745",
    },
    {
        "broader": [520],
        "id": 196,
        "labels": [{"label": "woonwijken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300000762"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [2170, 2171, 2172, 28, 445],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een woonwijk is een deel van een stad of gemeente met een dominante woonfunctie, waar een bepaalde aanleg en bebouwingsvorm overheerst.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "29/06/2016: term aangepast van huisvestingscomplexen naar woonwijken ikv intergratie thesaurus sociale huisvesting.",
                "type": "historyNote",
            },
        ],
        "related": [284],
        "sources": [{"citation": "Agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/196",
    },
    {
        "broader": [2027],
        "id": 2122,
        "labels": [
            {"label": "zandleemruggen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zandleemrug is een rug, waarvan de bovenste laag overwegend is opgebouwd met door de wind afgezet zandleem.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "05/08/2015: toegevoegd bij revisie termen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1975],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2122",
    },
    {
        "broader": [2027],
        "id": 2030,
        "labels": [{"label": "zandruggen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [2032, 2031],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zandrug is een rug met flauwe hellingen, overwegend opgebouwd met door de wind afgezet zand.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "02/10/2014: toegevoegd bij integratie thesaurustermen landschappen",
                "type": "historyNote",
            },
        ],
        "related": [1975],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2030",
    },
    {
        "broader": [1293],
        "id": 1306,
        "labels": [{"label": "zandwinning", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Locatie waar zand gewonnen is.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "25/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1306",
    },
    {
        "broader": [524],
        "id": 832,
        "labels": [
            {"label": "zeepziederijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/832",
    },
    {
        "broader": [78],
        "id": 1436,
        "labels": [{"label": "zeeschepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1428],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zeeschip is een vaartuig dat gebouwd is om de zee te bevaren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1436",
    },
    {
        "broader": [78],
        "id": 1441,
        "labels": [
            {
                "label": "zeewaardige binnenschepen",
                "language": "nl-BE",
                "type": "prefLabel",
            }
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1428],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zeewaardige binnenschip is een binnenschip dat gebouwd is om ook de zee te kunnen bevaren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1441",
    },
    {
        "broader": [78],
        "id": 1432,
        "labels": [{"label": "zeilschepen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [1427],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zeilschip is een vaartuig dat hoofdzakelijk wordt voortbewogen door middel van zeilen.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1432",
    },
    {
        "broader": [13],
        "id": 523,
        "labels": [{"label": "zendstations", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zendstation is een gebouw waar men radio- en televisiesignalen uitzendt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/523",
    },
    {
        "broader": [821],
        "id": 1278,
        "labels": [
            {"label": "zespostenspijkers", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zespostenspijker is een spijker (bijgebouwtje) opgetrokken op zes palen of posten, zodat de bodem niet op de grond rust.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "24/01/2011: Toegevoegd bij integratie met archeologische termen.",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1278",
    },
    {
        "broader": [15],
        "id": 524,
        "labels": [{"label": "ziederijen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [831, 832],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ziederij is een industrieel of ambachtelijk bedrijf waar men iets bereidt door stoffen aan de kook te brengen, bijvoorbeeld om zeep en zout te maken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/524",
    },
    {
        "broader": [466],
        "id": 526,
        "labels": [{"label": "ziekenhuizen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [899],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een ziekenhuis is een gebouw voor onderzoek, behandeling en verpleging van zieken en gewonden.",
                "type": "scopeNote",
            }
        ],
        "related": [267, 202, 283, 644, 369],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/526",
    },
    {
        "broader": [1770],
        "id": 1772,
        "labels": [{"label": "zijbeuken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zijbeuk is een deel van een basilicale of pseudobasilicale kerk, evenwijdig met de hoofdkerk.",
                "type": "scopeNote",
            }
        ],
        "related": [1005],
        "sources": [
            {
                "citation": "Haslinghuis E.J. &amp; Janse H. 1997: Bouwkundige termen. Verklarend woordenboek van de westerse architectuur- en bouwhistorie, Leiden.",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1772",
    },
    {
        "broader": [20],
        "id": 527,
        "labels": [
            {"label": "zijdefabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "een zijdefabriek is een industrieel of ambachtelijk bedrijf waar men zijde produceert en verwerkt.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/527",
    },
    {
        "broader": [1910],
        "id": 2155,
        "labels": [
            {"label": "zilte graslanden", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [2154],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Zilte graslanden zijn doorgaans natte graslanden met een specifieke soortensamenstelling van grassen, be\xefnvloed door een zoute of brakke grondwaterstand.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "23/09/2015: toegevoegd bij revisie thesaurus landschappen",
                "type": "historyNote",
            },
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/2155",
    },
    {
        "broader": [237],
        "id": 528,
        "labels": [{"label": "zitbanken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Zitmeubels in de openbare ruimte.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/528",
    },
    {
        "broader": [443],
        "id": 1557,
        "labels": [{"label": "zodenbanken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {
            "broad": [],
            "close": [],
            "exact": ["http://vocab.getty.edu/aat/300006820"],
            "narrow": [],
            "related": [],
        },
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zodenbank is een verhoogde zitgelegenheid die met graszoden of geurige kruiden zijn bedekt, in middeleeuwse tuinen veel voorkomend.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "AAT", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1557",
    },
    {
        "broader": [1223],
        "id": 1491,
        "labels": [{"label": "zomerdijken", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zomerdijk is een dijk die alleen de zomerstanden van een waterloop kan keren.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "Van Dale online", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1491",
    },
    {
        "broader": [151],
        "id": 529,
        "labels": [{"label": "zomerkeukens", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zomerkeuken is een keuken waar men in de zomer kookt en vaak ook woont, met name op een hoeve.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [
            {
                "citation": "HASLINGHUIS, E.J. en JANSE, H., Verklarend woordenboek van de westerse architectuur- en bouwhistorie: bouwkundige termen, Leiden, 2005; Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/529",
    },
    {
        "broader": [319],
        "id": 883,
        "labels": [
            {"label": "zondagsscholen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/883",
    },
    {
        "broader": [1531],
        "id": 531,
        "labels": [{"label": "zonnewijzers", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Meetinstrumenten die bij zonlicht de tijd aangeven door middel van een staaf die een schaduw werpt op een oppervlak met een schaalverdeling.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "scopenote aangepast op 21/01/2010 ('bij benadering' verwijderd).",
                "type": "historyNote",
            },
        ],
        "related": [67, 481],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/531",
    },
    {
        "broader": [524],
        "id": 831,
        "labels": [
            {"label": "zoutziederijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/831",
    },
    {
        "broader": [21],
        "id": 533,
        "labels": [
            {"label": "zuivelfabrieken", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [740],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zuivelfabriek is een industrieel bedrijf waar men melk verwerkt en melkproducten produceert.",
                "type": "scopeNote",
            }
        ],
        "related": [286, 287],
        "sources": [
            {
                "citation": "Nederlandse Art and Architecture Thesaurus (www.aat-ned.nl)",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/533",
    },
    {
        "broader": [923],
        "id": 534,
        "labels": [{"label": "zwaaikommen", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een zwaaikom is een verbrede plaats in een waterweg waar vaartuigen kunnen keren.",
                "type": "scopeNote",
            }
        ],
        "related": [122, 401],
        "sources": [
            {
                "citation": "Van Dale groot woordenboek van de Nederlandse taal. 14de editie, Utrecht/Antwerpen, 2005",
                "markup": None,
            }
        ],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/534",
    },
    {
        "broader": [535],
        "id": 949,
        "labels": [{"label": "zwembaden", "language": "nl-BE", "type": "prefLabel"}],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [1513],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/949",
    },
    {
        "broader": [896],
        "id": 535,
        "labels": [
            {"label": "zweminfrastructuur", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [949],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Al dan niet overdekte inrichtingen om te zwemmen en hun ondersteunende infrastructuur, zoals de badhokjes of gebouwen met kleedkamers.",
                "type": "scopeNote",
            },
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Badhokjes of gebouwen met kleedkamers aan de zee of een meer worden ingevoerd als zweminfrastructuur.",
                "type": "note",
            },
        ],
        "related": [37],
        "sources": [{"citation": "VIOE", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/535",
    },
    {
        "broader": [472],
        "id": 830,
        "labels": [
            {"label": "zwingelarijen", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [],
        "related": [],
        "sources": [],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/830",
    },
    {
        "broader": [1541],
        "id": 1548,
        "labels": [
            {"label": "Zwitserse chalets", "language": "nl-BE", "type": "prefLabel"}
        ],
        "matches": {"broad": [], "close": [], "exact": [], "narrow": [], "related": []},
        "member_of": [],
        "narrower": [],
        "notes": [
            {
                "language": "nl-BE",
                "markup": None,
                "note": "Een Zwitserse chalet is een pittoresk gebouw naar Zwitsers model in tuinen en parken.",
                "type": "scopeNote",
            }
        ],
        "related": [],
        "sources": [{"citation": "agentschap Onroerend Erfgoed", "markup": None}],
        "subordinate_arrays": [],
        "type": "concept",
        "uri": "https://id.erfgoed.net/thesauri/erfgoedtypes/1548",
    },
]
